unit gossdat;
//## ==========================================================================================================================================================================================================================
//##
//## MIT License
//##
//## Copyright 2025 Blaiz Enterprises ( http://www.blaizenterprises.com )
//##
//## Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
//## files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
//## modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
//## is furnished to do so, subject to the following conditions:
//##
//## The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//##
//## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//## OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
//## LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
//## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//##
//## ==========================================================================================================================================================================================================================
//## Library.................. static data (gossdat.pas)
//## Version.................. -
//## Items.................... -
//## Last Updated ............ 17mar2025
//## Lines of Code............ -
//##
//## main.pas ................ app code
//## gossroot.pas ............ console/gui app startup and control
//## gossio.pas .............. file io
//## gossimg.pas ............. image/graphics
//## gossnet.pas ............. network
//## gosswin.pas ............. 32bit windows api's
//## gosssnd.pas ............. sound/audio/midi/chimes
//## gossgui.pas ............. gui management/controls
//## gossdat.pas ............. static data/icons/splash/help documents
//##
//## ==========================================================================================================================================================================================================================
//## Important Format(s) Note:
//##
//## Many of the images and documents used below require a specific file format and storage in a binary pascal array in order to work.  A free gui tool
//## is available at http://www.blaizenterprises.com/blaiztools.html  The tool provides one button actions for pasting and converting images into
//## TEA/JPEG/PNG image formats, and packing them into a pascal array, as well as support for loading, compressing and packing text documents into
//## pascal arrays.
//## ==========================================================================================================================================================================================================================
//## Performance Note:
//##
//## The runtime compiler options "Range Checking" and "Overflow Checking", when enabled under Delphi 3
//## (Project > Options > Complier > Runtime Errors) slow down graphics calculations by about 50%,
//## causing ~2x more CPU to be consumed.  For optimal performance, these options should be disabled
//## when compiling.
//## ==========================================================================================================================================================================================================================

interface

uses
   gossroot;

const
//program icons ----------------------------------------------------------------
//app icon (required) - 32w x 32h size in TEA format only, accessed via tepIcon32
//Note: This icon is used by Gossamer internally for display on the app's Window Header (Title bar) and must be in the TEA (text picture) format.
//      A separate MS icon (.ico) is required for display on Windows Desktop/Explorer/Taskbar etc, currently stored within the resource file
//      "app-icon-16-256px.res".

program_icon32h
:array[0..2521] of byte=(
84,69,65,51,35,1,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,32,0,0,0,0,0,0,3,0,60,118,235,1,66,60,119,236,1,179,60,119,236,1,237,60,119,236,20,255,60,119,236,1,237,60,119,236,1,179,60,118,235,1,66,0,0,0,4,0,60,116,230,1,10,60,116,231,1,169,60,117,232,26,255,60,116,231,1,169,60,116,230,1,10,0,0,0,2,0,59,114,227,1,169,60,114,227,28,255,59,114,227,1,169,0,0,0,1,0,59,111,222,1,66,59,112,223,30,255,59,111,222,1,66,59,109,218,1,179,59,109,218,13,255,64,111,213,1,255,86,120,199,1,255,119,142,192,1,255,133,149,180,1,255,121,138,168,1,255,119,135,163,1,255,118,136,170,1,255,119,140,188,1,255,80,117,204,1,255,59,109,218,8,255,59,109,218,1,179,58,107,214,1,237,58,107,214,9,255,71,113,210,1,255,121,141,187,1,255,150,161,161,1,255,165,169,129,1,255,169,169,97,1,255,169,169,95,1,255,168,168,94,1,255,165,165,90,1,255,171,171,97,1,255,178,178,103,1,255,182,182,107,1,255,180,180,105,1,255,185,185,111,1,255,160,168,151,1,255,76,115,208,1,255,58,107,214,6,255,58,107,214,1,237,58,104,209,8,255,80,115,200,
1,255,152,162,161,1,255,192,193,125,1,255,204,204,129,1,255,207,207,132,1,255,212,212,137,1,255,206,206,131,1,255,210,210,135,1,255,210,212,140,1,255,205,209,141,1,255,204,210,145,1,255,203,211,149,1,255,201,209,149,1,255,202,210,148,1,255,194,199,132,1,255,193,193,118,1,255,172,176,140,1,255,72,112,208,1,255,58,104,209,6,255,58,102,205,6,255,59,102,204,1,255,134,148,172,1,255,189,190,123,1,255,189,189,114,1,255,195,195,120,1,255,197,197,122,1,255,204,208,138,1,255,208,215,152,1,255,208,219,162,1,255,210,217,154,1,255,207,217,157,1,255,185,209,173,1,255,169,201,179,1,255,163,198,181,1,255,158,195,182,1,255,157,194,182,1,255,160,196,182,1,255,183,199,154,1,255,196,196,121,1,255,175,193,175,1,255,64,107,204,1,255,58,102,205,5,255,57,99,200,5,255,74,109,198,1,255,173,179,155,1,255,201,201,126,1,255,195,195,120,1,255,198,199,127,1,255,205,213,151,1,255,204,220,170,1,255,188,211,175,1,255,178,202,168,1,255,176,179,111,1,255,188,188,113,1,255,199,199,124,1,255,191,194,126,1,255,127,
175,187,1,255,102,164,195,1,255,95,160,196,1,255,91,158,197,1,255,89,157,198,1,255,174,190,156,1,255,209,209,133,1,255,205,219,167,1,255,124,168,191,1,255,58,102,200,1,255,57,99,200,4,255,57,97,196,4,255,61,99,194,1,255,186,191,154,1,255,223,223,147,1,255,218,219,144,1,255,215,222,157,1,255,200,218,172,1,255,178,206,177,1,255,156,194,182,1,255,144,185,178,1,255,189,193,126,1,255,199,199,124,1,255,190,190,115,1,255,197,200,129,1,255,206,214,152,1,255,188,209,175,1,255,76,133,198,1,255,55,113,199,1,255,62,109,197,1,255,152,167,167,1,255,207,207,132,1,255,206,207,134,1,255,199,217,172,1,255,141,186,186,1,255,71,132,198,1,255,57,97,196,4,255,57,94,191,4,255,140,152,171,1,255,209,209,134,1,255,211,212,138,1,255,213,224,167,1,255,185,210,176,1,255,157,195,182,1,255,133,181,188,1,255,110,169,193,1,255,172,188,150,1,255,196,196,121,1,255,194,194,118,1,255,206,210,141,1,255,201,219,172,1,255,173,203,179,1,255,156,194,182,1,255,131,175,185,1,255,133,147,168,1,255,200,202,149,1,255,209,
209,134,1,255,214,214,140,1,255,212,223,166,1,255,177,206,177,1,255,131,181,188,1,255,74,147,200,1,255,57,94,191,4,255,56,92,187,4,255,170,176,154,1,255,206,206,130,1,255,212,221,160,1,255,180,207,177,1,255,146,189,184,1,255,117,173,191,1,255,90,158,197,1,255,66,142,201,1,255,185,189,129,1,255,191,191,116,1,255,203,206,135,1,255,202,218,169,1,255,182,204,167,1,255,167,192,164,1,255,195,209,163,1,255,193,195,124,1,255,204,204,128,1,255,211,211,135,1,255,216,220,151,1,255,207,221,168,1,255,180,207,177,1,255,147,189,184,1,255,109,168,193,1,255,65,140,201,1,255,56,92,187,4,255,56,89,182,4,255,157,163,149,1,255,203,203,127,1,255,200,218,171,1,255,152,192,183,1,255,112,170,192,1,255,79,152,200,1,255,56,125,197,1,255,110,129,173,1,255,211,211,135,1,255,199,200,125,1,255,207,220,165,1,255,205,209,139,1,255,211,211,136,1,255,223,224,148,1,255,235,237,163,1,255,214,218,150,1,255,209,218,156,1,255,205,221,171,1,255,187,211,175,1,255,166,200,180,1,255,141,186,186,1,255,112,170,192,1,255,
79,152,200,1,255,54,115,193,1,255,56,89,182,4,255,55,87,178,4,255,112,127,169,1,255,226,227,154,1,255,214,221,157,1,255,153,188,178,1,255,84,155,199,1,255,54,120,195,1,255,56,87,178,1,255,181,184,143,1,255,209,209,133,1,255,212,219,156,1,255,184,209,175,1,255,204,208,141,1,255,193,193,116,1,255,195,195,120,1,255,200,208,146,1,255,180,207,175,1,255,167,200,180,1,255,153,193,183,1,255,137,184,187,1,255,119,174,191,1,255,98,163,195,1,255,73,149,201,1,255,54,118,193,1,255,55,87,178,5,255,55,84,173,5,255,117,129,162,1,255,204,206,141,1,255,207,207,130,1,255,156,181,181,1,255,55,85,174,1,255,115,127,159,1,255,197,197,120,1,255,216,218,146,1,255,197,217,173,1,255,155,194,182,1,255,128,174,182,1,255,179,187,136,1,255,212,212,136,1,255,221,221,145,1,255,200,208,149,1,255,126,176,189,1,255,100,163,195,1,255,85,155,198,1,255,70,145,201,1,255,58,126,194,1,255,54,99,181,1,255,55,84,173,6,255,55,82,169,6,255,99,122,170,1,255,183,205,174,1,255,191,213,174,1,255,113,143,174,1,255,190,192,139,
1,255,212,212,136,1,255,212,223,165,1,255,172,203,179,1,255,129,180,188,1,255,87,157,198,1,255,70,126,189,1,255,191,193,143,1,255,213,213,137,1,255,215,215,138,1,255,198,206,154,1,255,76,125,186,1,255,53,101,180,1,255,55,85,171,1,255,55,82,169,8,255,54,79,164,7,255,71,106,170,1,255,119,170,188,1,255,169,195,172,1,255,210,210,134,1,255,214,218,148,1,255,191,213,174,1,255,148,190,184,1,255,104,166,194,1,255,63,139,199,1,255,54,82,166,1,255,85,102,163,1,255,223,224,163,1,255,231,231,154,1,255,222,222,146,1,255,191,196,155,1,255,60,85,165,1,255,54,79,164,9,255,54,77,160,8,255,58,88,164,1,255,200,205,147,1,255,215,215,139,1,255,208,222,167,1,255,167,200,180,1,255,123,176,190,1,255,80,152,199,1,255,53,103,178,1,255,54,77,160,2,255,117,127,161,1,255,232,232,158,1,255,228,228,152,1,255,227,228,153,1,255,157,182,174,1,255,56,82,162,1,255,54,77,160,8,255,54,74,155,8,255,120,127,145,1,255,212,212,136,1,255,212,216,148,1,255,188,212,175,1,255,143,187,185,1,255,99,163,195,1,255,59,130,194,
1,255,54,74,155,4,255,159,162,129,1,255,226,226,150,1,255,236,236,160,1,255,193,214,174,1,255,101,148,181,1,255,54,74,155,8,255,53,72,151,8,255,179,181,136,1,255,205,205,129,1,255,208,218,158,1,255,184,199,150,1,255,126,175,185,1,255,76,150,200,1,255,52,92,166,1,255,53,72,151,4,255,139,144,137,1,255,194,194,118,1,255,213,215,142,1,255,190,213,175,1,255,126,177,190,1,255,58,106,173,1,255,53,72,151,7,255,53,69,146,7,255,79,90,142,1,255,192,193,119,1,255,197,199,127,2,255,200,200,125,1,255,181,196,156,1,255,68,129,188,1,255,53,69,146,5,255,167,169,134,1,255,211,211,135,1,255,212,220,158,1,255,176,205,178,1,255,122,176,190,1,255,64,128,187,1,255,53,69,146,7,255,52,67,142,7,255,127,131,132,1,255,188,188,112,1,255,186,186,111,1,255,195,197,123,1,255,179,179,104,1,255,185,189,121,1,255,146,176,171,1,255,55,72,144,1,255,52,67,142,3,255,128,133,135,1,255,197,197,124,1,255,218,221,151,1,255,197,217,173,1,255,155,194,183,1,255,108,168,193,1,255,60,125,187,1,255,52,67,142,7,255,52,64,137,
7,255,102,107,129,1,255,185,187,118,1,255,200,202,131,1,255,204,218,165,1,255,189,193,125,1,255,193,193,118,1,255,182,192,138,1,255,143,163,155,1,255,123,127,132,1,255,136,139,128,1,255,168,169,122,1,255,197,197,122,1,255,202,208,141,1,255,200,218,171,1,255,167,200,180,1,255,129,179,188,1,255,87,156,198,1,255,53,104,170,1,255,52,64,137,7,255,52,62,133,8,255,111,124,144,1,255,183,207,174,1,255,173,204,178,1,255,142,183,179,1,255,172,186,146,1,255,200,202,131,1,255,206,207,133,1,255,211,212,138,1,255,209,211,140,1,255,212,218,153,1,255,207,220,166,1,255,189,212,175,1,255,163,198,181,1,255,133,182,187,1,255,99,163,195,1,255,63,137,196,1,255,52,67,137,1,255,52,62,133,7,255,51,59,128,9,255,79,105,145,1,255,117,171,189,1,255,106,167,194,1,255,80,151,200,1,255,154,183,172,1,255,183,209,176,1,255,187,211,175,1,255,184,209,176,1,255,175,204,178,1,255,161,197,181,1,255,143,187,185,1,255,121,175,190,1,255,96,161,196,1,255,66,143,200,1,255,50,85,151,1,255,51,59,128,8,255,51,57,124,10,255,
54,84,144,1,255,59,117,175,1,255,51,96,159,1,255,55,66,127,1,255,96,148,180,1,255,116,172,192,1,255,119,174,191,1,255,116,172,191,1,255,107,167,193,1,255,93,160,197,1,255,75,150,201,1,255,57,125,186,1,255,51,74,139,1,255,51,57,124,9,255,51,54,119,1,237,51,54,119,14,255,53,93,152,1,255,58,115,173,1,255,59,118,175,1,255,56,116,176,1,255,52,100,161,1,255,50,71,134,1,255,51,54,119,10,255,51,54,119,1,237,50,52,115,1,178,50,52,115,30,255,50,52,115,1,178,50,50,111,1,66,50,49,110,30,255,50,50,111,1,66,0,0,0,1,0,49,47,106,1,169,49,47,106,28,255,49,47,106,1,169,0,0,0,2,0,49,45,103,1,10,49,45,102,1,169,49,44,101,26,255,49,45,102,1,169,49,45,103,1,10,0,0,0,4,0,49,43,98,1,66,49,42,97,1,178,49,42,97,1,237,49,42,97,20,255,49,42,97,1,237,49,42,97,1,178,49,43,98,1,66,0,0,0,3,0);


//app small icon (optional) - 20w x 20h size in TEA format only, accessed via tepIcon20
program_icon20h
:array[0..1216] of byte=(
84,69,65,51,35,1,0,0,0,0,0,0,0,0,0,0,0,0,0,20,0,0,0,20,0,0,0,0,0,0,1,0,60,117,232,1,40,60,118,234,1,177,60,119,235,1,246,60,119,235,12,255,60,119,235,1,246,60,118,234,1,177,60,117,232,1,40,0,0,0,1,0,59,114,226,1,40,60,115,228,1,245,60,115,228,16,255,60,115,228,1,245,59,114,226,1,40,59,110,220,1,177,59,110,220,9,255,78,119,211,1,255,97,127,204,1,255,88,120,202,1,255,76,118,213,1,255,59,110,220,5,255,59,110,220,1,177,58,106,213,1,246,58,106,213,5,255,108,133,196,1,255,151,162,171,1,255,166,171,140,1,255,175,176,108,1,255,179,180,105,1,255,175,175,100,1,255,178,178,103,1,255,183,183,108,1,255,167,173,142,1,255,90,122,205,1,255,58,106,213,3,255,58,106,213,1,246,58,103,206,4,255,96,123,195,1,255,168,172,140,1,255,194,194,119,1,255,202,203,130,1,255,210,215,148,1,255,209,215,150,1,255,208,217,158,1,255,188,210,173,1,255,182,208,177,1,255,178,204,175,1,255,183,198,152,1,255,184,190,148,1,255,73,114,204,1,255,58,103,206,3,255,57,99,199,3,255,136,151,184,1,255,209,209,139,1,255,206,209,
138,1,255,201,214,160,1,255,183,208,177,1,255,183,199,154,1,255,189,189,115,1,255,203,203,129,1,255,151,182,173,1,255,85,150,198,1,255,79,144,199,1,255,161,182,163,1,255,209,213,144,1,255,142,179,187,1,255,57,101,199,1,255,57,99,199,2,255,57,94,192,2,255,93,116,188,1,255,201,202,131,1,255,212,219,155,1,255,182,208,177,1,255,141,186,186,1,255,144,181,180,1,255,193,193,117,1,255,202,204,134,1,255,194,214,170,1,255,163,198,181,1,255,127,152,177,1,255,181,186,154,1,255,207,208,134,1,255,201,216,166,1,255,138,184,187,1,255,62,119,196,1,255,57,94,192,2,255,56,90,184,2,255,111,127,171,1,255,201,203,131,1,255,180,207,177,1,255,121,175,191,1,255,76,145,198,1,255,154,170,165,1,255,205,206,132,1,255,206,217,158,1,255,199,208,152,1,255,221,224,157,1,255,209,211,139,1,255,210,217,155,1,255,194,214,172,1,255,153,192,183,1,255,100,163,195,1,255,56,109,191,1,255,56,90,184,2,255,55,87,177,2,255,73,97,174,1,255,209,211,153,1,255,180,199,162,1,255,82,145,195,1,255,79,106,178,1,255,205,206,138,1,
255,205,216,160,1,255,187,204,160,1,255,197,198,121,1,255,205,211,144,1,255,174,203,177,1,255,148,189,185,1,255,121,175,191,1,255,89,156,198,1,255,58,119,191,1,255,55,87,177,3,255,55,83,170,3,255,72,94,167,1,255,178,190,158,1,255,156,178,175,1,255,157,163,150,1,255,215,218,147,1,255,177,205,178,1,255,110,168,193,1,255,146,164,163,1,255,220,220,144,1,255,195,204,149,1,255,87,141,190,1,255,58,114,185,1,255,54,89,173,1,255,55,83,170,4,255,54,78,163,4,255,59,86,164,1,255,124,162,178,1,255,208,209,136,1,255,200,215,166,1,255,137,184,187,1,255,72,141,195,1,255,54,79,164,1,255,186,190,162,1,255,230,230,154,1,255,192,197,155,1,255,61,86,164,1,255,54,78,163,5,255,54,74,155,5,255,159,163,142,1,255,214,218,149,1,255,169,201,180,1,255,99,162,196,1,255,54,96,170,1,255,54,74,155,1,255,64,82,155,1,255,205,206,139,1,255,229,232,161,1,255,132,169,180,1,255,54,74,155,5,255,53,71,149,4,255,57,74,147,1,255,194,194,127,1,255,205,210,143,1,255,176,192,152,1,255,66,133,191,1,255,53,71,149,3,255,182,
183,127,1,255,207,215,152,1,255,145,187,185,1,255,59,104,169,1,255,53,71,149,4,255,52,67,141,4,255,104,110,136,1,255,190,190,115,1,255,196,198,126,1,255,186,186,112,1,255,142,165,164,1,255,52,67,141,1,255,55,69,141,1,255,142,145,133,1,255,206,209,138,1,255,190,212,174,1,255,122,175,190,1,255,56,106,170,1,255,52,67,141,4,255,52,62,134,4,255,62,71,134,1,255,154,164,140,1,255,186,209,174,1,255,167,184,147,1,255,193,196,126,1,255,188,191,134,1,255,200,203,137,1,255,200,209,148,1,255,188,211,174,1,255,142,186,186,1,255,84,152,197,1,255,52,72,142,1,255,52,62,134,4,255,51,58,127,6,255,94,139,170,1,255,79,149,197,1,255,133,163,168,1,255,167,199,181,1,255,164,198,181,1,255,147,189,185,1,255,119,173,191,1,255,82,151,197,1,255,53,90,152,1,255,51,58,127,5,255,51,55,120,1,246,51,55,120,8,255,61,102,155,1,255,69,124,173,1,255,66,122,174,1,255,55,105,164,1,255,50,66,129,1,255,51,55,120,5,255,51,55,120,1,246,50,51,113,1,177,50,51,113,18,255,50,51,113,1,177,50,47,107,1,40,49,46,105,1,245,49,46,
105,16,255,49,46,105,1,245,50,47,107,1,40,0,0,0,1,0,49,44,101,1,40,49,43,99,1,177,49,42,98,1,246,49,42,98,12,255,49,42,98,1,246,49,43,99,1,177,49,44,101,1,40,0,0,0,1,0);
//:array[0..0] of byte=(0);


//app splash/about screen image (optional) - recommended dimensions of 208w x 208h for best scaling, supports image formats of TEA and PNG
program_splash_logo_208px
:array[0..27788] of byte=(
137,80,78,71,13,10,26,10,0,0,0,13,73,72,68,82,0,0,0,208,0,0,0,208,8,6,0,0,0,118,164,239,116,0,0,32,0,73,68,65,84,120,218,236,189,105,140,100,89,118,223,247,187,247,237,239,197,150,91,85,214,222,107,117,247,76,55,135,156,33,103,72,78,207,144,212,208,3,203,90,40,192,182,8,24,22,12,24,208,7,127,144,108,45,148,101,24,50,12,11,130,101,81,178,12,249,131,33,24,144,13,203,160,204,15,166,97,202,50,160,145,9,74,156,30,146,166,40,105,100,210,228,44,189,119,117,85,101,101,101,102,100,172,111,187,247,250,195,125,239,230,139,200,204,238,38,61,170,174,238,206,11,36,34,50,35,50,51,34,222,253,223,115,206,255,156,243,63,130,15,121,125,233,63,57,148,198,240,4,240,169,230,235,41,224,26,112,153,139,117,177,78,214,30,240,46,240,58,240,59,192,239,8,193,155,95,255,47,55,245,135,249,162,196,135,241,79,95,254,139,7,79,1,95,5,254,0,240,69,96,23,144,23,123,228,98,253,30,150,6,238,3,223,0,126,9,248,71,175,252,213,173,215,63,182,0,122,249,63,126,120,29,33,126,26,248,105,224,179,128,119,177,7,46,214,247,112,
41,224,159,3,63,143,49,63,255,202,127,181,125,231,35,15,160,47,255,197,135,66,27,126,12,248,83,192,31,2,162,139,235,124,177,30,193,42,128,127,0,252,45,41,248,149,95,249,171,219,230,35,5,160,47,255,197,125,161,13,95,5,254,51,224,71,62,44,87,241,98,125,226,151,1,126,13,248,47,164,224,107,191,242,87,119,204,99,15,160,151,255,194,254,247,3,63,11,124,229,2,56,23,235,49,2,210,47,1,63,243,202,95,219,249,230,99,9,160,151,255,194,131,1,240,151,129,255,0,8,46,174,217,197,122,12,87,5,252,119,192,95,122,229,175,93,154,60,54,0,122,249,103,246,126,2,193,127,15,60,125,113,141,46,214,71,96,189,134,225,79,190,242,179,151,127,249,67,5,208,151,126,230,190,103,224,47,129,248,79,1,255,226,186,92,172,143,208,170,193,252,21,1,127,249,235,63,187,171,30,57,128,94,254,153,251,155,192,255,132,101,215,46,214,197,250,168,174,127,0,252,137,87,126,118,247,232,145,1,232,229,63,127,239,9,224,239,3,47,94,124,254,23,235,99,176,126,11,248,163,175,252,245,43,111,254,43,7,208,203,127,254,238,115,32,254,17,112,227,
226,115,191,88,31,163,245,54,152,175,190,242,215,175,126,251,95,25,128,94,254,115,239,62,135,16,95,7,118,46,62,239,139,245,49,92,251,24,243,165,87,254,198,181,111,127,207,1,244,242,159,123,247,9,224,87,46,44,207,197,250,152,175,119,128,47,191,242,55,174,189,249,61,3,208,203,127,238,206,70,3,158,139,152,231,98,125,18,214,111,91,16,93,127,95,98,225,125,43,160,191,244,103,223,241,128,191,123,1,158,139,245,9,90,47,2,127,183,217,251,239,185,222,55,119,99,224,47,97,204,5,85,125,177,62,105,235,15,217,28,39,255,249,239,219,133,251,226,159,125,251,39,128,175,113,145,36,189,88,159,204,85,3,95,253,198,127,125,243,151,127,207,0,250,226,159,121,123,128,237,175,184,40,207,185,88,159,228,245,26,240,217,111,252,205,155,147,223,163,11,103,254,242,5,120,46,214,197,226,105,108,145,244,127,248,129,45,208,23,255,204,155,223,15,252,6,23,85,213,23,235,98,129,173,226,254,252,55,254,230,19,223,124,95,0,125,233,207,188,33,180,17,95,3,126,242,226,115,187,88,23,203,173,255,75,10,243,213,175,255,205,39,205,
123,186,112,182,147,212,124,229,226,243,186,88,23,107,101,125,165,233,178,254,135,231,90,160,47,253,71,175,11,109,120,5,248,209,139,207,235,98,93,172,83,235,87,165,224,229,175,255,55,79,57,43,36,215,172,207,151,177,26,6,23,235,98,93,172,211,235,71,26,140,156,231,194,153,63,205,133,142,193,197,186,88,231,45,1,252,105,224,159,156,114,225,190,248,167,95,189,14,188,202,133,244,212,197,186,88,239,181,10,224,153,111,252,173,103,238,172,89,32,243,211,23,224,185,88,23,235,125,87,132,21,7,253,27,235,46,220,79,95,124,54,31,97,223,66,104,4,32,132,65,96,8,164,2,1,190,172,241,165,198,24,141,49,0,6,33,4,218,24,140,54,24,64,27,65,173,35,132,128,90,251,24,36,32,48,8,140,185,240,232,207,88,14,64,2,224,139,127,234,59,79,2,223,229,66,110,247,177,92,82,104,164,48,248,82,17,7,53,129,44,73,130,130,40,208,196,97,69,228,23,244,226,28,85,205,9,188,18,223,247,8,196,4,85,21,4,190,102,144,86,32,32,207,75,170,170,166,44,10,234,90,161,141,5,157,50,33,70,246,208,198,99,94,246,144,158,143,50,9,181,137,144,193,
54,165,238,147,87,146,89,30,50,47,2,10,21,161,181,196,124,114,195,101,5,60,251,141,255,246,246,27,173,5,250,234,5,120,62,108,144,40,4,154,208,171,44,56,188,57,190,40,217,28,148,108,246,107,134,89,77,28,20,36,254,148,44,206,9,196,130,229,226,136,94,22,48,236,7,72,105,48,170,66,107,69,81,228,44,151,75,22,139,57,179,217,12,179,48,24,99,240,149,34,148,146,94,44,8,130,16,99,52,190,239,163,148,194,24,168,235,10,165,52,74,105,118,46,93,38,73,250,32,83,144,41,113,50,100,178,8,184,187,111,56,156,247,153,230,3,30,78,83,230,213,128,105,49,160,212,33,198,124,98,230,3,120,13,102,254,182,5,144,209,23,137,211,71,230,106,25,60,169,9,100,77,40,103,68,242,152,52,152,147,122,251,140,122,21,189,164,36,48,15,241,204,1,105,12,55,174,109,209,203,36,105,236,97,140,166,44,75,180,214,4,65,128,220,12,81,74,225,251,53,8,193,193,120,204,124,62,103,177,88,82,20,57,158,231,17,69,17,210,243,16,128,49,39,73,116,173,53,121,94,81,215,53,66,8,251,247,164,68,8,129,148,2,79,26,164,40,145,162,166,174,14,9,226,9,55,
182,18,174,109,104,14,143,142,153,206,53,203,194,227,112,154,178,55,189,204,184,184,194,188,190,194,209,114,147,101,157,98,204,199,254,82,126,5,248,219,226,229,63,245,45,105,12,239,0,87,47,182,247,247,122,25,124,89,19,122,37,89,48,35,246,142,233,133,199,12,226,99,122,73,73,104,238,17,138,67,122,105,141,100,78,224,25,234,186,194,24,131,148,146,52,77,185,122,245,42,89,150,113,124,60,33,203,82,170,170,194,243,60,138,162,100,62,159,147,231,75,106,165,200,151,57,203,229,2,33,4,97,20,146,38,41,6,131,86,218,1,71,107,141,214,26,165,106,164,148,132,97,68,154,166,248,190,143,214,26,41,37,101,85,17,248,1,74,213,14,168,27,27,27,148,101,73,89,150,28,29,29,81,85,21,189,94,175,177,92,6,223,15,152,45,37,211,101,159,163,242,105,222,216,191,202,222,252,58,243,106,128,254,248,90,165,187,66,112,195,55,198,220,194,206,231,185,88,223,3,55,44,144,37,177,55,163,23,140,73,131,99,178,96,159,94,56,165,31,238,211,79,166,120,34,199,212,83,162,200,214,233,42,165,232,37,61,60,207,18,160,82,166,4,65,136,239,
123,120,158,135,82,138,197,98,65,81,228,44,22,115,242,188,96,62,159,161,181,66,107,227,192,225,121,246,249,97,24,226,251,190,251,185,49,6,173,45,136,130,32,104,172,96,136,239,7,196,73,140,20,18,99,12,97,20,130,193,90,44,41,41,203,178,3,214,130,241,120,140,231,73,124,223,199,243,60,170,170,66,41,133,16,54,14,138,3,200,226,154,109,245,79,185,54,232,113,239,248,58,119,198,55,185,51,121,138,73,177,241,113,140,151,118,141,225,150,143,225,211,92,12,183,250,125,89,23,79,42,2,89,208,15,103,244,163,35,82,127,159,141,228,144,141,244,136,141,222,20,201,28,105,150,128,194,243,36,203,101,14,128,159,68,196,113,76,150,101,248,190,207,81,227,122,109,110,110,18,199,49,66,72,180,86,206,106,140,199,99,246,247,247,221,230,149,210,110,100,223,247,0,65,93,215,238,103,0,117,93,55,192,177,32,243,125,159,40,10,65,8,60,207,195,247,124,7,206,46,216,106,85,55,247,13,158,231,187,248,168,40,138,198,125,84,14,80,66,128,16,130,225,112,136,239,251,238,126,158,231,8,33,120,86,140,57,154,28,243,221,123,7,124,107,
239,54,111,29,94,35,175,194,143,213,121,9,124,218,55,152,23,46,192,240,65,45,140,33,242,75,250,209,156,81,252,144,136,119,217,202,14,217,204,142,73,131,35,146,176,100,115,35,97,54,155,161,181,110,172,65,143,162,40,8,130,128,225,112,212,4,247,11,60,207,163,44,11,102,179,25,170,174,81,74,113,247,238,93,146,36,33,77,83,180,54,40,85,227,121,62,69,145,19,4,1,97,24,34,26,16,8,33,48,198,96,48,14,12,22,116,54,134,41,203,10,99,52,82,122,4,65,128,16,146,126,191,143,231,73,170,170,110,64,97,26,16,5,192,137,133,234,245,122,76,167,83,180,182,36,131,125,174,253,12,6,131,1,198,24,162,40,198,24,237,172,84,28,199,132,97,136,49,134,229,114,73,146,36,92,219,13,184,117,99,201,75,227,215,249,230,27,5,191,249,234,85,238,29,247,63,78,91,226,5,31,99,46,154,230,222,99,249,158,34,11,11,182,179,67,54,146,3,134,241,3,134,209,30,33,247,240,24,19,133,130,126,191,79,20,69,248,126,207,5,227,173,235,228,251,62,65,16,82,85,37,74,41,130,32,96,107,107,203,185,92,85,85,89,166,172,137,37,180,182,46,27,64,85,149,248,
126,224,78,248,214,194,72,41,157,117,145,82,226,249,214,42,5,65,192,124,62,167,170,170,230,249,33,65,16,144,166,41,97,24,34,165,160,40,74,231,234,5,65,224,172,149,245,237,192,147,30,69,145,35,165,68,74,73,85,85,72,41,137,227,152,170,170,156,139,24,69,214,138,150,101,201,98,177,112,207,111,65,238,251,62,82,74,84,93,112,105,80,241,242,243,19,34,177,199,175,127,247,57,222,61,190,244,113,33,25,158,246,177,3,125,47,86,103,69,190,98,51,203,185,178,49,97,171,119,192,181,205,67,46,15,143,8,196,17,158,40,145,82,32,196,6,82,110,97,140,33,203,82,119,242,27,99,168,107,229,226,155,162,40,137,162,144,186,174,40,203,138,178,44,1,200,178,140,36,77,144,66,58,38,108,58,157,82,215,214,58,116,99,12,173,149,219,144,54,117,103,86,54,191,125,61,30,243,249,28,223,247,72,146,132,193,160,79,16,132,205,239,24,22,139,37,74,41,23,248,7,65,224,92,184,22,124,173,203,216,186,132,45,32,202,178,68,74,251,58,239,220,121,151,91,79,220,66,107,141,231,123,248,218,119,135,133,214,138,48,12,201,243,156,162,40,154,195,
35,176,207,165,224,135,158,205,233,37,154,95,251,142,226,187,123,151,63,14,4,195,53,31,204,197,52,108,192,19,138,97,146,115,99,235,152,107,91,99,110,95,155,176,51,156,208,139,11,162,144,102,3,141,168,170,146,162,44,9,131,208,109,184,36,73,145,210,30,225,214,202,104,150,203,37,66,8,210,52,161,44,75,234,218,110,94,41,37,158,39,41,138,194,110,172,198,253,18,66,208,239,247,40,203,202,109,222,60,207,49,24,164,180,177,78,107,1,140,161,249,63,161,179,74,66,8,103,85,164,148,68,81,204,124,62,199,24,227,8,129,32,8,28,80,90,230,205,24,195,116,58,197,247,125,122,189,158,163,180,181,214,20,69,225,8,138,40,138,216,218,218,178,32,109,44,231,209,225,145,3,188,214,154,201,100,226,0,88,148,5,24,92,5,132,231,121,4,65,200,149,222,17,63,254,169,2,79,40,190,117,255,202,71,29,68,151,253,79,2,97,255,94,43,13,75,118,135,99,118,251,239,114,169,127,159,39,118,231,236,110,25,226,72,184,128,221,243,108,210,209,110,2,203,146,229,121,238,78,91,165,106,130,32,70,107,237,220,151,225,112,232,54,97,24,134,120,
158,68,41,205,98,177,96,185,92,54,116,178,5,78,93,215,43,76,89,154,102,140,70,35,234,186,102,62,159,53,155,221,56,26,186,125,94,107,69,90,0,181,22,166,40,10,231,22,26,99,8,195,144,209,104,228,98,148,186,174,1,72,146,4,173,53,81,20,81,215,181,251,121,203,172,5,65,128,231,249,24,99,147,171,85,85,17,69,17,139,197,2,165,148,179,166,173,139,105,63,31,27,171,181,175,69,41,229,44,101,85,85,132,129,224,201,225,62,158,247,45,132,16,252,238,221,143,182,37,242,237,244,187,79,214,18,24,178,112,198,213,225,3,158,186,244,128,103,175,29,115,235,74,77,93,77,152,28,31,115,116,168,72,211,148,75,151,46,81,213,21,199,199,199,36,73,210,196,30,116,24,50,235,2,217,141,62,103,62,159,19,69,81,3,24,143,60,207,29,203,229,121,62,74,149,12,135,67,70,163,81,3,164,28,99,236,6,46,203,146,60,207,137,162,136,193,96,208,108,72,217,108,216,37,105,154,32,132,64,8,208,218,56,23,175,101,4,141,129,56,142,221,255,85,202,190,135,32,240,1,225,128,183,92,46,153,205,102,110,163,231,121,78,89,150,238,251,22,116,158,231,57,
247,174,141,233,140,49,54,238,169,42,150,139,5,113,28,59,55,176,5,99,235,142,182,191,215,222,239,18,12,71,135,15,185,54,170,249,137,151,36,66,120,252,206,187,219,232,143,104,205,221,39,74,239,77,10,205,48,89,112,125,116,135,203,233,119,120,246,218,49,151,183,52,27,163,190,173,31,235,109,16,248,62,147,201,132,162,40,248,246,183,191,77,146,164,108,109,109,54,212,173,32,142,99,226,56,33,12,35,71,18,184,191,223,108,52,123,34,219,77,211,205,209,120,158,221,204,109,96,223,198,8,74,41,170,170,68,74,207,81,213,45,203,150,36,9,89,150,185,68,103,235,54,182,20,115,187,97,91,235,81,85,21,89,150,33,4,44,151,57,158,239,99,180,38,142,99,130,48,68,122,62,113,146,161,180,198,147,146,193,40,113,214,205,254,111,137,16,18,33,176,197,166,141,229,45,139,130,36,137,168,170,10,140,181,82,173,69,146,82,50,155,205,58,135,133,215,177,102,146,36,137,40,203,138,170,42,157,139,8,154,167,119,15,200,203,239,176,63,9,216,155,140,62,162,0,250,4,184,112,66,24,182,122,11,110,239,222,227,169,203,119,185,58,218,199,
51,15,73,211,8,223,183,193,184,244,164,59,65,61,207,150,5,246,251,125,199,42,77,167,83,22,139,5,190,239,187,147,61,203,122,13,69,124,18,216,87,85,69,81,20,77,142,39,106,200,5,217,80,191,194,89,145,40,10,137,227,168,217,188,170,137,93,4,66,200,198,210,233,230,117,24,192,254,142,105,54,174,148,162,201,1,129,215,0,56,73,51,164,231,33,165,5,170,210,134,108,8,82,250,4,97,132,244,236,243,226,62,52,73,28,247,247,172,77,102,197,125,131,166,244,199,24,140,86,24,12,194,104,180,170,1,141,174,43,22,243,41,203,229,156,34,95,54,135,64,229,92,191,150,88,144,82,82,20,22,156,97,152,33,132,112,46,236,116,122,204,141,205,37,63,252,236,128,127,248,47,51,242,202,191,176,64,143,215,50,244,163,130,221,254,91,220,28,125,139,31,255,65,159,65,90,81,20,37,147,137,112,76,146,49,6,209,108,210,150,178,245,60,175,137,31,130,198,114,224,152,175,52,77,73,211,212,253,143,182,47,177,141,75,218,77,110,140,181,22,54,49,41,87,44,136,16,178,177,90,162,249,50,206,234,8,129,123,190,104,54,186,148,1,66,122,24,3,70,8,
148,50,196,158,143,144,30,66,122,72,233,163,17,32,44,83,103,171,223,154,215,0,40,99,65,98,68,227,180,27,48,70,156,156,159,230,189,157,121,129,253,211,66,26,16,32,67,67,26,111,146,168,146,42,159,81,44,166,228,139,41,70,43,231,218,182,32,183,175,195,176,92,182,249,175,210,29,18,190,175,249,161,103,191,195,254,241,54,191,250,221,221,143,162,5,210,31,75,232,4,94,205,238,224,1,79,110,125,151,79,223,188,135,84,239,114,180,31,144,94,187,70,24,134,12,135,195,21,247,170,170,42,234,186,114,1,111,107,29,236,230,21,164,105,74,20,69,24,99,89,183,54,33,169,181,1,148,139,77,90,107,3,39,133,153,237,70,62,1,79,123,218,219,223,233,126,239,121,214,253,179,180,158,196,243,3,12,210,130,7,235,94,25,36,162,233,215,209,205,198,55,166,185,111,104,250,120,218,251,39,64,177,247,155,91,44,154,186,160,49,239,7,34,209,0,169,65,148,196,67,202,8,153,246,72,146,109,226,97,78,185,56,162,92,140,41,243,5,101,217,214,221,217,188,83,146,164,148,101,185,18,99,89,43,187,224,143,125,249,187,140,23,67,126,231,78,116,
97,129,62,236,56,103,51,57,228,201,237,215,120,114,251,117,118,55,14,145,148,108,236,108,179,88,204,57,60,60,116,110,138,239,251,100,89,134,148,130,170,42,93,165,115,91,142,18,199,113,115,114,230,44,22,11,151,48,181,140,82,141,82,150,194,13,163,200,197,5,243,249,156,186,174,109,98,53,240,17,77,204,99,193,162,241,155,66,77,33,193,151,62,66,24,52,224,5,62,66,218,47,217,128,198,224,161,132,60,1,138,17,104,77,99,85,58,128,49,93,32,217,6,185,21,176,116,1,212,124,223,2,6,78,126,207,222,23,239,75,192,116,193,36,133,117,145,165,240,240,100,136,151,101,68,225,16,127,121,136,42,142,169,171,202,21,166,166,105,210,84,104,4,20,69,129,231,73,130,32,101,185,204,17,242,30,127,226,143,188,198,255,240,139,207,242,157,119,131,143,18,128,62,62,49,80,22,206,121,102,231,77,110,239,190,193,238,240,46,113,88,53,101,42,62,203,229,18,41,61,164,20,46,193,88,20,182,48,51,8,66,194,48,36,142,147,166,236,38,100,50,57,38,207,151,120,158,239,114,50,45,171,102,243,44,145,203,212,151,85,133,223,156,168,54,184,
175,41,203,194,209,212,109,5,66,16,4,54,78,241,2,132,231,35,189,0,137,7,210,135,198,178,24,4,85,3,2,221,1,135,110,129,209,220,55,70,160,187,128,233,130,5,78,89,35,206,249,89,23,56,103,1,234,189,44,145,20,141,59,215,90,79,105,144,66,226,203,13,188,36,5,124,164,126,232,136,14,33,132,203,137,197,177,165,206,243,220,146,51,170,46,24,120,71,252,187,63,117,151,255,241,127,187,194,235,247,130,143,8,128,62,6,248,241,164,98,183,191,207,115,187,223,230,246,149,55,233,39,243,38,216,31,54,76,152,113,27,34,12,3,130,48,164,174,235,166,112,19,234,90,57,11,145,36,137,203,103,212,117,237,232,215,150,97,146,82,52,229,54,115,138,166,179,211,6,255,194,213,156,165,105,74,191,223,183,44,91,24,217,24,197,11,240,252,16,225,5,22,44,194,67,25,105,147,162,206,178,172,129,69,27,107,105,180,181,56,238,241,115,92,54,109,86,173,77,23,128,39,46,218,234,227,45,96,232,88,166,223,171,59,39,132,117,67,37,32,165,193,19,216,3,197,219,69,122,21,66,216,152,231,248,120,66,146,36,77,94,75,173,144,22,249,114,65,86,206,
217,220,40,249,227,127,120,143,159,251,223,47,243,246,94,112,97,129,254,85,175,97,50,231,233,157,183,120,254,202,171,220,186,60,38,77,60,96,64,24,134,20,69,193,114,185,36,142,109,83,153,86,154,162,40,89,44,150,12,135,3,60,233,33,4,36,137,215,196,46,118,59,217,114,254,130,178,44,89,46,151,174,154,185,165,172,91,230,174,77,150,218,10,3,15,3,40,165,137,147,148,48,238,17,198,9,126,152,34,164,135,70,58,171,162,181,112,32,209,186,107,109,12,152,26,129,70,24,5,170,66,87,37,6,65,169,36,90,132,224,37,40,2,11,58,103,145,206,139,133,86,45,149,89,119,237,58,160,89,1,211,7,116,231,90,151,238,180,59,7,190,52,120,178,71,63,186,206,86,22,178,156,60,104,92,223,166,173,188,44,26,134,83,18,134,1,105,154,224,123,134,80,212,108,245,43,254,216,31,220,231,127,253,63,119,120,247,129,255,184,91,160,143,38,128,124,79,113,107,251,128,23,111,188,206,11,55,246,200,162,57,74,225,152,171,110,61,151,45,106,180,53,96,121,158,59,6,45,138,78,50,243,45,40,218,173,19,4,1,163,209,168,41,166,20,77,189,88,184,210,189,
105,51,237,26,132,196,11,66,60,63,66,250,33,126,24,35,61,27,199,84,6,148,90,5,202,202,173,54,24,93,83,229,51,164,94,82,231,19,34,95,179,49,28,160,76,197,162,152,19,197,49,177,4,35,124,132,159,49,175,2,150,58,161,212,49,165,10,236,223,57,195,157,59,239,254,202,109,135,72,56,113,245,58,150,168,107,162,206,161,231,78,196,76,90,16,129,39,12,158,132,210,203,144,165,32,109,26,4,237,178,137,94,91,224,234,57,75,228,123,210,130,200,211,108,246,43,254,224,79,30,240,247,191,182,197,222,190,119,97,129,190,151,171,23,229,188,120,227,14,159,125,250,109,110,236,28,35,68,141,214,30,105,154,186,236,124,154,166,8,97,45,66,89,150,46,191,210,50,97,179,217,156,48,178,221,159,170,174,89,44,150,77,118,191,38,73,18,87,75,214,5,78,155,44,69,72,130,48,38,141,18,12,30,90,120,72,47,108,172,140,117,201,42,101,45,141,234,88,26,181,6,32,85,151,136,122,134,94,30,242,224,238,235,12,123,17,117,85,49,3,250,105,132,239,251,196,113,212,148,212,180,21,1,37,169,95,162,168,152,150,75,198,101,198,81,145,178,84,254,90,
140,68,135,124,88,179,68,29,6,174,107,169,86,221,185,223,63,59,39,176,86,72,10,200,189,144,237,193,6,27,169,114,127,189,174,51,215,78,113,194,122,198,24,221,138,167,24,34,223,176,217,175,249,202,79,140,249,218,47,13,121,120,224,61,174,0,250,8,37,68,49,92,221,152,242,3,79,190,193,247,61,117,151,237,97,9,120,104,13,109,53,116,16,196,32,192,96,136,194,168,73,44,218,242,150,227,227,227,134,170,86,46,209,215,54,134,217,242,152,146,40,138,154,76,188,196,247,61,132,144,13,211,22,51,26,109,16,198,41,26,15,225,5,22,60,198,130,164,82,2,101,4,170,107,105,26,87,109,29,56,90,27,170,252,152,160,58,130,242,144,56,128,64,212,68,97,159,91,55,111,82,215,85,211,145,42,9,195,172,73,120,158,108,86,137,32,16,53,177,95,147,249,5,153,159,115,103,58,224,160,76,92,92,117,174,235,182,22,7,173,147,15,172,89,40,58,241,145,121,159,100,181,232,130,73,52,253,83,158,141,227,130,48,64,96,203,159,108,181,131,77,6,159,208,254,16,68,9,70,130,39,105,64,164,217,232,85,188,252,165,41,255,228,87,250,28,29,62,126,32,
242,205,71,196,133,11,125,197,237,171,7,124,230,214,107,188,112,243,33,189,84,16,4,81,19,220,107,215,41,217,102,254,165,108,59,64,109,130,114,177,152,187,250,177,186,174,208,218,184,138,3,16,120,158,192,247,19,130,32,116,197,157,105,214,35,73,82,252,40,193,11,98,144,1,26,105,1,161,26,235,210,88,25,213,5,75,215,242,152,85,64,213,85,201,252,240,29,196,242,30,187,155,33,27,91,67,215,225,185,183,183,71,154,38,24,3,211,233,148,56,142,93,130,54,142,99,6,131,254,74,75,131,214,154,36,208,196,193,28,84,193,178,24,241,176,218,88,33,28,76,135,116,88,191,191,10,162,147,159,117,45,145,254,253,16,11,226,36,54,242,66,69,22,40,188,38,113,106,255,190,112,4,142,16,18,99,180,171,153,51,66,52,214,203,224,53,150,104,212,171,249,161,31,153,243,235,223,200,56,62,146,143,155,5,122,252,1,148,69,57,223,119,235,46,159,191,253,54,55,118,166,228,249,130,131,131,130,56,142,217,216,24,145,231,5,69,81,48,26,13,73,211,172,1,136,38,8,146,6,52,154,164,233,242,4,211,72,55,213,20,69,137,16,184,147,208,247,109,141,
90,154,245,8,227,148,52,27,32,253,24,45,60,106,35,80,234,196,194,156,0,166,5,209,42,128,90,54,205,62,207,186,112,117,181,164,56,124,157,114,252,26,82,45,96,227,38,71,71,71,228,249,146,205,205,45,210,52,97,52,26,33,132,224,210,165,157,134,240,88,160,148,166,215,235,81,215,53,227,241,49,155,155,27,174,244,167,45,20,77,204,67,134,234,144,163,250,41,230,102,251,148,59,183,146,27,90,113,231,214,104,238,243,242,68,43,174,157,120,239,60,81,7,72,87,210,138,65,84,55,13,128,154,178,44,154,42,15,175,177,68,198,253,93,41,4,181,203,231,173,90,162,81,175,230,51,159,95,242,207,255,239,132,217,88,60,70,0,122,204,241,179,221,159,243,217,167,94,227,179,207,188,195,214,160,116,148,243,230,230,38,85,85,177,183,247,192,145,1,182,33,205,6,167,247,238,221,67,107,205,104,52,180,110,88,158,19,4,126,83,150,99,92,131,88,91,15,230,7,33,97,20,147,164,125,162,180,143,23,68,104,227,81,54,36,128,210,130,250,20,120,78,172,144,94,185,111,129,211,90,33,165,65,151,83,228,252,45,82,189,71,146,74,60,111,200,193,193,
33,155,155,155,108,108,108,184,202,230,178,180,29,170,7,7,7,12,134,3,182,183,182,40,10,219,207,227,251,30,89,150,81,215,246,121,227,241,24,223,247,217,220,220,96,56,232,99,222,252,109,122,8,14,77,143,130,236,204,156,209,234,253,147,56,9,206,175,92,88,103,228,204,7,41,251,17,144,249,21,187,217,140,216,203,157,37,237,106,48,180,228,129,109,45,175,209,165,192,139,87,193,216,198,68,161,167,25,102,53,207,127,182,224,255,253,167,17,203,137,184,176,64,188,207,69,184,177,61,229,71,63,117,135,23,111,222,37,137,106,192,50,95,214,181,49,164,89,74,191,223,115,29,156,182,84,127,206,131,7,15,24,12,6,108,110,110,112,112,112,224,170,159,45,177,96,251,117,202,210,230,39,194,48,34,233,245,137,211,1,194,11,65,248,212,70,80,52,214,70,233,147,216,70,53,224,89,117,215,214,111,91,224,156,252,188,94,30,194,241,119,96,254,54,179,42,119,185,167,170,42,185,127,255,190,219,88,182,164,168,38,138,66,146,52,101,62,155,51,159,205,89,46,151,148,101,229,52,15,122,189,140,163,163,35,148,170,137,227,132,217,236,
18,131,193,128,178,88,114,101,248,128,73,53,231,205,101,239,220,100,171,238,184,112,93,203,212,141,117,78,200,134,118,135,156,0,237,131,36,91,165,48,220,76,143,217,9,246,168,138,2,154,66,219,182,130,195,243,60,170,186,70,55,125,69,66,8,54,182,46,173,168,219,8,209,90,162,6,68,190,97,144,213,60,249,25,201,171,255,34,160,156,93,144,8,231,36,70,13,183,175,142,249,210,139,119,120,238,250,61,4,21,74,153,166,38,45,115,22,164,42,43,180,39,93,47,77,89,90,189,178,235,215,175,163,148,98,50,153,184,248,161,205,215,216,242,28,8,194,144,172,63,34,136,51,100,144,160,145,212,186,113,211,140,64,41,11,128,122,37,198,17,206,178,40,221,128,102,197,125,91,115,231,180,192,215,83,194,229,27,80,222,5,95,48,47,116,67,133,135,174,104,245,232,232,16,223,247,27,173,4,159,217,108,202,241,120,140,0,134,195,97,163,11,119,220,36,110,107,242,124,233,40,225,186,174,120,248,240,161,45,15,18,146,229,236,136,151,46,125,151,135,229,54,123,203,240,76,66,65,159,65,99,235,53,0,233,53,74,187,11,166,245,56,233,172,181,
25,76,184,44,94,39,63,124,147,119,143,69,147,144,214,13,109,109,40,203,138,126,191,71,20,197,248,190,109,20,12,194,168,41,134,61,29,91,57,119,206,51,12,50,197,213,79,75,222,249,109,15,53,255,208,93,184,199,171,152,212,243,224,179,207,28,243,213,31,218,227,133,39,74,164,216,4,44,221,89,213,53,97,16,160,148,198,243,100,211,14,173,153,205,166,120,158,207,96,32,93,147,216,100,50,69,74,91,249,171,148,34,138,98,6,131,16,207,11,72,122,125,164,31,99,68,128,66,82,233,6,40,238,118,213,218,172,144,4,250,228,231,117,151,68,48,226,196,93,107,54,105,234,229,92,203,142,233,247,66,138,252,42,85,85,115,120,120,72,154,38,108,111,111,179,92,230,20,69,206,245,235,215,221,251,95,46,151,4,65,192,181,107,215,136,227,136,56,78,136,227,152,173,173,45,170,170,228,232,104,76,81,228,157,164,174,79,20,197,212,117,205,193,193,1,69,81,33,245,148,159,122,241,128,255,229,155,187,236,205,61,103,101,244,57,236,220,9,213,125,6,67,215,90,164,117,119,174,5,216,25,72,234,7,57,159,26,188,205,173,222,125,252,166,49,
176,21,105,140,227,152,186,182,45,31,139,133,77,82,231,121,78,146,102,22,172,221,10,241,53,151,80,10,67,224,25,34,79,211,207,20,91,207,73,246,127,23,204,194,92,88,160,214,242,252,192,211,199,252,161,31,121,192,11,79,230,72,225,185,54,233,32,8,8,58,189,58,173,239,236,121,134,225,112,196,96,48,108,116,161,139,230,36,53,141,66,141,173,112,30,142,70,248,81,74,148,13,17,65,76,141,116,128,105,45,79,221,0,164,110,173,200,41,48,177,2,40,181,102,145,186,49,208,32,44,121,114,52,103,55,213,188,245,230,152,135,15,247,25,141,134,196,113,212,196,111,53,71,71,135,100,89,198,124,49,39,137,19,134,195,33,199,199,199,86,11,193,216,22,136,201,196,178,113,126,224,51,159,217,188,212,214,214,150,11,202,211,52,35,73,98,238,222,189,235,26,217,4,134,81,90,241,199,94,58,224,239,253,179,29,238,45,188,85,50,225,12,54,78,115,86,213,246,89,85,220,226,84,235,67,55,38,234,7,21,63,120,233,30,159,187,252,128,65,24,82,215,214,130,37,73,66,24,134,86,212,190,209,145,104,155,9,149,214,182,42,93,6,142,124,233,50,130,
45,136,90,118,206,247,44,59,215,79,53,139,167,125,166,223,209,136,194,124,88,0,122,60,98,32,41,52,47,221,58,228,143,190,60,230,246,141,69,211,159,115,146,252,108,99,151,110,0,218,230,16,90,48,129,21,191,0,154,66,209,57,211,233,140,36,235,211,31,109,227,71,25,218,120,20,186,3,148,117,224,232,19,194,96,197,10,117,191,55,107,177,81,199,82,105,35,200,130,138,43,201,49,98,250,38,199,165,199,230,230,136,52,77,168,170,210,85,100,79,167,71,141,128,162,33,77,108,210,55,8,252,21,16,89,233,222,156,32,12,232,247,250,196,113,196,214,214,54,195,225,128,217,108,70,81,148,13,171,168,24,143,199,212,181,34,138,34,178,222,0,79,10,70,105,197,79,189,116,200,223,251,103,59,220,157,123,107,53,116,171,214,231,52,128,206,72,180,182,223,40,16,218,156,220,98,111,35,161,121,254,202,61,126,96,227,85,118,250,53,74,89,15,192,243,60,242,162,64,55,125,87,90,43,171,41,87,219,238,214,48,8,72,178,30,210,143,168,90,214,178,105,215,56,189,79,176,181,118,210,16,250,154,94,170,89,222,242,168,95,173,221,107,249,196,
177,112,66,24,62,117,253,128,127,253,11,247,120,238,166,88,233,138,116,2,130,77,226,179,109,116,107,159,179,126,219,246,232,199,73,130,23,68,100,195,109,164,159,96,100,224,92,181,90,117,192,98,56,237,190,117,93,186,243,172,205,10,112,78,220,55,223,228,92,238,29,145,214,239,240,206,219,175,145,36,9,79,63,253,116,83,250,19,113,116,116,68,93,87,36,73,204,108,54,227,157,119,222,38,73,82,110,222,188,193,225,225,33,119,238,188,139,49,218,53,226,181,122,216,118,35,202,134,10,46,209,218,16,39,9,81,19,223,165,105,102,59,100,195,136,225,198,22,52,109,217,195,180,226,167,94,58,224,231,254,217,14,119,23,222,169,130,212,46,120,80,6,89,106,100,101,16,202,184,91,81,55,95,202,32,206,241,248,123,113,205,231,158,125,192,151,63,181,199,102,47,39,207,107,23,191,216,6,187,128,60,207,161,185,118,173,134,130,109,11,143,73,210,1,90,72,71,192,180,109,27,103,49,126,66,24,60,87,177,160,73,123,146,241,174,143,247,110,245,201,180,64,79,236,28,241,7,62,183,199,167,158,170,200,115,91,242,209,54,186,185,242,
153,142,197,49,198,176,183,183,71,85,213,140,70,163,38,249,104,92,146,81,27,1,194,71,134,1,198,88,86,173,86,39,192,169,53,212,90,162,52,29,171,179,14,156,198,10,117,64,82,235,38,25,170,215,232,235,198,58,161,43,54,120,27,113,244,6,121,44,184,116,233,114,3,146,59,12,135,67,182,119,182,93,97,170,231,89,165,157,52,77,121,240,224,1,175,191,254,6,190,239,53,186,110,113,67,16,212,142,182,14,195,144,249,220,42,237,68,113,74,24,247,193,11,144,94,136,1,174,220,74,17,198,6,226,97,156,81,234,54,183,98,44,136,190,239,128,191,247,155,151,184,59,151,136,74,35,11,141,172,13,94,161,145,165,118,0,249,253,172,157,65,206,143,124,250,33,159,127,254,46,195,116,218,180,178,135,128,112,61,86,0,177,111,147,167,237,129,96,165,184,34,178,254,16,47,76,173,245,113,44,103,23,232,103,129,168,101,231,32,242,12,225,134,71,57,150,120,115,245,168,45,208,135,11,160,75,163,130,31,124,246,93,54,162,239,80,22,151,81,74,187,4,33,24,167,57,214,150,214,216,170,1,217,52,166,89,221,232,195,195,131,166,41,75,50,28,109,
210,31,110,227,199,17,90,123,46,198,169,26,90,186,214,130,106,197,226,172,2,165,11,156,179,30,239,90,155,46,189,109,180,102,195,220,101,59,184,67,40,75,146,100,228,78,218,150,37,20,8,242,188,32,8,124,170,106,201,165,75,59,28,28,28,186,18,35,223,247,25,12,134,14,60,82,150,78,204,36,207,151,108,108,108,145,244,70,136,192,186,59,202,72,103,33,101,108,75,152,180,128,66,225,220,73,99,108,171,250,48,169,249,195,47,60,228,23,126,49,99,249,61,98,174,194,64,243,220,245,5,159,127,97,143,91,219,111,66,53,97,58,149,12,6,125,134,195,97,163,69,231,83,150,37,69,81,186,54,134,147,10,16,240,131,128,48,238,217,246,14,213,177,242,174,130,67,56,18,228,76,98,65,218,152,40,244,53,249,165,0,239,13,197,163,220,211,31,170,5,74,195,154,47,60,191,199,15,189,112,68,18,13,92,43,181,141,99,68,227,234,36,46,56,62,25,211,97,92,124,208,230,66,182,182,119,232,13,54,240,162,30,26,239,148,187,182,254,165,52,43,143,117,221,181,117,224,212,157,83,241,204,88,72,195,78,56,225,102,184,71,92,219,161,86,179,217,204,185,
155,198,24,70,163,17,81,20,54,42,165,53,189,94,143,217,108,206,116,58,37,73,18,130,96,64,28,199,140,70,35,226,56,66,169,19,25,170,201,100,66,111,48,90,137,227,42,181,14,236,198,13,19,182,31,7,78,136,141,54,47,179,49,172,249,234,79,46,249,218,215,98,150,203,255,63,46,55,108,15,10,126,240,185,35,190,240,233,99,158,190,86,178,204,99,14,30,206,209,218,166,15,162,40,38,73,98,39,167,101,45,145,37,121,90,213,210,48,140,72,123,35,100,144,82,234,19,239,160,251,89,59,87,78,115,54,59,135,173,252,246,61,131,159,10,234,158,196,159,214,31,127,22,78,96,120,242,210,30,79,95,158,186,192,100,0,0,32,0,73,68,65,84,250,14,194,20,204,102,53,179,217,140,205,205,77,167,132,99,235,165,196,74,67,91,203,202,133,97,64,175,103,85,94,130,40,65,248,9,90,4,212,90,58,139,211,117,215,234,6,48,202,172,129,170,217,136,181,89,35,16,186,164,130,57,177,94,167,24,57,45,136,152,50,82,175,227,23,119,41,85,229,148,123,236,198,169,16,2,250,253,1,69,81,48,157,78,26,235,105,55,90,127,208,119,221,172,105,106,229,178,78,154,
247,236,196,133,32,74,201,134,219,24,17,156,121,48,168,181,218,187,150,177,66,24,247,90,141,1,137,97,107,171,230,203,127,160,224,31,255,82,72,145,255,222,179,249,253,164,226,211,79,44,248,129,219,135,188,244,244,140,94,82,50,155,45,152,78,39,141,103,96,137,131,131,131,3,174,95,191,230,164,132,157,27,151,36,174,59,55,235,143,8,211,33,181,145,107,239,101,45,137,237,220,185,51,40,238,38,217,234,55,49,81,53,242,225,145,2,232,67,114,225,182,7,115,190,239,169,187,140,122,199,204,102,53,203,101,78,175,151,113,255,254,125,198,227,49,131,193,192,9,14,182,74,57,246,100,86,174,69,58,140,34,60,63,70,203,8,229,78,229,14,120,212,170,187,182,186,241,56,195,42,157,118,215,84,231,121,43,143,55,64,242,132,230,133,221,130,219,61,65,185,24,34,132,112,226,138,109,247,101,203,10,30,29,29,225,251,62,27,27,86,37,116,99,99,131,163,163,35,180,214,141,54,131,231,18,190,182,26,219,39,233,141,8,104,128,163,108,206,170,82,130,90,225,54,222,9,152,79,104,106,27,51,158,88,34,235,6,89,119,110,99,67,243,133,31,
171,249,245,95,246,41,139,15,118,189,226,80,241,244,213,5,159,121,102,204,231,158,95,50,72,199,100,105,204,241,241,194,13,220,18,82,162,213,73,97,239,193,193,1,66,72,162,56,114,2,148,24,67,175,215,35,74,50,252,168,71,141,223,188,183,213,107,114,2,30,78,21,230,26,196,217,49,145,48,152,204,199,72,126,223,241,220,71,194,133,147,194,112,115,103,143,43,163,119,209,170,213,18,243,81,74,83,215,21,121,110,69,60,218,141,216,10,247,181,173,214,131,65,31,131,192,243,98,180,140,169,140,164,82,242,76,240,56,176,172,187,107,186,243,184,90,189,112,186,195,206,157,231,206,213,77,153,206,173,193,130,171,241,3,134,89,192,156,12,99,172,182,156,245,251,11,170,202,158,134,195,225,128,36,73,152,207,231,236,237,61,32,207,151,132,97,216,156,204,130,227,227,99,178,44,179,238,170,82,100,105,70,210,27,129,31,81,233,46,112,132,219,112,43,177,92,135,142,111,55,90,155,124,20,216,247,210,82,214,66,24,70,35,205,103,94,214,124,243,21,65,245,30,32,138,2,205,181,173,57,207,223,60,226,179,207,79,185,178,57,35,10,
237,8,148,178,172,154,228,104,180,34,48,169,117,230,106,251,218,100,111,203,156,182,218,117,138,128,202,4,142,220,105,15,8,231,94,119,14,134,150,88,112,12,162,62,59,204,105,99,34,149,122,248,211,234,81,89,160,15,193,250,12,151,60,127,99,159,56,88,176,88,20,78,143,173,61,189,91,45,130,32,8,152,76,172,203,147,101,41,190,111,5,251,148,6,47,138,209,94,66,213,113,217,170,206,230,234,146,7,231,197,65,103,2,107,141,125,235,2,103,61,86,74,124,205,237,173,57,207,92,9,121,247,206,125,14,14,14,232,245,122,78,4,222,110,38,43,42,120,239,222,125,151,178,63,201,91,89,57,222,197,98,129,214,154,131,131,3,198,227,49,91,91,59,164,253,45,140,151,82,107,73,165,4,101,103,163,85,90,186,19,219,30,28,171,84,188,171,2,239,36,32,5,216,202,9,211,178,115,48,24,106,110,127,193,231,91,191,102,80,229,234,53,74,162,154,155,151,114,94,124,122,206,103,159,91,48,76,31,178,189,153,225,251,163,166,127,74,35,165,213,149,104,167,233,105,173,153,207,231,43,186,122,109,12,212,182,43,128,64,17,82,25,191,185,102,242,244,
53,82,103,120,5,134,213,94,171,78,185,209,122,178,85,197,18,38,31,83,18,65,8,120,241,169,37,255,218,151,118,64,181,85,5,146,32,240,155,102,54,225,244,154,165,148,108,110,110,54,229,43,246,152,28,12,71,4,81,15,26,240,56,224,180,155,171,179,161,236,133,145,84,103,184,107,103,93,164,250,84,101,130,88,161,186,91,250,186,110,216,162,39,7,115,110,12,102,212,85,65,20,197,244,251,125,242,60,111,196,3,45,3,213,198,49,173,62,118,93,87,110,147,41,165,56,58,26,55,65,183,37,23,210,172,207,238,181,91,36,189,205,198,178,118,222,95,227,194,57,32,169,117,75,123,242,122,187,101,69,98,141,88,104,221,60,41,160,63,48,220,250,156,228,205,223,212,152,218,48,76,75,110,236,204,248,212,147,51,94,120,98,206,238,118,193,160,231,163,117,232,90,219,219,195,46,203,108,93,162,105,244,28,166,211,25,135,135,135,4,65,208,28,132,138,40,10,233,245,122,248,190,79,85,107,100,24,163,26,240,148,221,235,214,121,15,213,89,49,94,183,226,189,195,206,157,149,59,53,129,228,81,237,235,71,78,34,244,226,146,103,174,207,24,246,
52,198,12,220,9,221,230,120,218,169,2,0,121,81,80,149,37,97,104,47,8,66,16,167,67,68,144,82,105,121,114,1,206,216,92,235,183,167,253,108,233,92,132,106,141,80,80,103,48,118,93,242,65,105,129,47,106,54,189,61,138,227,183,120,184,16,68,81,76,20,197,77,141,151,213,144,107,173,75,27,72,27,163,8,35,235,238,76,38,19,14,15,15,221,216,145,195,195,25,27,155,91,220,124,242,25,210,193,22,117,11,158,90,80,234,181,247,183,114,96,156,127,40,168,78,233,142,107,116,107,137,5,115,146,39,218,26,21,108,255,232,156,240,112,202,213,141,49,79,95,155,114,235,154,79,190,156,82,230,146,99,21,52,146,94,30,151,46,93,118,213,30,139,197,194,201,125,181,213,240,173,94,247,124,62,119,37,60,198,24,194,56,37,74,134,214,250,56,240,156,92,67,11,28,86,223,79,231,96,83,93,207,160,113,227,78,202,147,214,0,36,31,93,171,131,111,30,177,5,218,221,172,120,230,134,162,44,139,166,252,164,230,218,181,107,142,165,209,141,16,122,59,191,38,204,50,91,206,18,132,132,73,31,47,238,175,128,167,236,186,1,29,87,206,221,95,115,229,
170,149,114,157,53,66,225,61,40,239,174,5,82,90,208,11,10,50,125,159,135,15,238,53,53,94,181,155,122,0,112,124,124,236,98,156,214,101,179,109,11,118,10,93,146,216,230,185,60,207,25,141,70,36,73,202,96,99,155,164,191,69,109,188,147,247,167,79,222,95,11,160,114,197,93,109,227,35,108,12,113,70,121,145,234,18,11,141,232,7,70,211,243,115,182,131,41,125,30,50,220,60,164,119,107,142,52,118,30,234,195,125,143,56,137,233,197,189,21,22,244,254,253,251,110,124,101,221,140,166,172,170,234,212,184,150,54,94,245,60,31,63,136,9,147,33,218,139,86,15,188,206,225,102,15,11,185,26,19,173,88,32,78,177,115,46,71,212,41,65,114,32,122,100,22,232,17,179,112,151,70,75,6,217,146,56,78,216,217,217,113,115,58,219,185,161,109,163,219,222,222,158,125,254,165,75,132,81,100,123,117,252,204,197,4,103,94,8,213,57,161,87,78,109,86,130,212,21,119,77,157,19,27,117,30,87,103,148,253,140,250,57,55,182,37,155,233,147,220,189,123,207,89,206,170,170,154,81,40,30,90,171,149,249,61,139,197,194,141,72,156,76,38,100,153,
45,191,41,202,146,193,104,155,184,183,137,106,115,88,103,189,191,186,125,79,184,247,182,30,251,173,31,12,221,254,37,128,196,43,232,251,51,250,114,204,118,52,97,51,206,9,68,142,170,75,164,231,81,228,86,82,88,8,65,145,219,33,89,22,8,158,19,187,159,207,237,140,163,86,92,178,27,239,180,223,91,65,148,132,222,112,147,40,29,162,240,155,247,116,114,253,74,189,122,29,91,247,109,213,35,144,43,68,73,183,125,164,181,66,167,41,110,243,200,146,169,143,52,6,10,60,195,206,104,193,98,246,128,123,42,36,207,11,162,40,36,77,83,166,179,25,253,158,29,130,155,231,5,151,47,95,198,24,67,81,148,4,97,132,23,196,40,179,186,105,202,115,55,151,88,141,143,186,113,141,238,186,118,171,46,156,90,169,90,88,115,33,214,78,195,205,20,110,236,142,48,245,130,172,151,113,124,60,118,115,68,243,60,39,73,18,87,182,210,110,176,214,58,157,104,115,91,97,13,225,133,12,183,118,209,194,119,27,172,60,7,60,229,89,224,89,115,227,186,27,80,27,8,165,98,43,169,73,56,164,111,30,112,115,83,147,5,5,85,49,111,170,169,173,149,76,147,4,
140,225,248,248,216,205,81,109,193,16,4,129,171,168,222,218,178,180,124,235,154,182,21,34,221,250,69,109,4,194,143,45,85,109,188,21,79,96,221,5,93,121,207,206,34,209,120,11,156,118,231,214,24,83,167,175,183,66,44,60,50,11,244,232,172,79,20,104,174,236,24,146,56,104,26,200,50,183,193,236,96,171,35,110,221,186,137,239,123,44,22,75,55,25,45,74,135,104,17,172,156,94,142,218,61,107,115,173,92,156,51,54,215,25,108,221,42,193,112,58,14,90,63,209,15,142,115,254,159,223,250,109,132,178,86,101,119,119,215,190,143,201,196,13,177,106,71,191,111,109,109,57,0,217,2,74,235,226,204,231,11,118,46,239,50,216,220,197,200,232,228,64,80,171,52,123,85,55,135,69,231,253,149,157,207,161,203,200,85,218,102,237,99,175,38,13,43,46,13,20,87,251,37,151,122,21,197,244,62,15,238,190,201,173,203,207,97,76,72,93,39,148,101,229,146,159,227,241,152,197,98,65,150,245,216,218,218,36,73,18,0,39,134,216,178,108,198,192,114,105,227,188,118,202,66,81,228,118,84,139,49,164,217,128,32,233,131,12,169,140,116,214,116,245,
240,58,7,60,93,139,212,101,231,218,91,179,150,139,51,171,101,75,198,8,68,169,31,153,93,120,164,22,200,147,154,36,180,5,146,211,233,140,170,170,155,193,181,119,220,212,231,150,210,109,105,209,40,233,97,188,168,249,224,196,217,238,154,146,206,29,88,33,22,78,109,174,85,119,174,58,195,149,83,239,67,117,183,207,153,46,129,145,112,238,141,165,164,19,162,40,194,243,60,30,62,60,160,174,237,180,236,217,108,214,78,249,113,177,221,114,185,32,235,13,72,122,27,32,163,83,140,98,169,86,45,104,11,158,117,226,196,110,38,131,47,52,189,184,166,23,86,12,163,138,141,104,65,63,200,217,25,133,164,145,157,234,253,27,191,243,26,189,94,198,59,239,188,195,112,56,114,45,238,175,190,250,90,163,3,238,185,206,209,118,66,158,148,158,115,215,218,102,69,43,183,21,130,56,121,63,66,88,181,162,40,29,128,12,81,72,91,1,226,192,115,218,141,46,235,181,195,78,55,215,175,94,101,228,170,51,216,185,211,21,241,184,74,110,89,212,143,210,2,61,58,0,105,5,139,220,86,82,31,29,29,18,4,161,235,129,105,233,209,182,187,84,54,74,150,
113,218,67,11,159,186,110,2,101,189,154,227,177,190,52,167,192,83,42,235,59,175,91,163,234,28,107,164,212,249,49,208,41,75,100,192,247,34,110,61,241,52,1,115,148,82,244,251,125,123,72,52,238,90,123,58,183,227,13,219,128,91,107,227,134,9,107,17,162,189,100,13,20,98,37,41,92,41,59,11,200,216,217,146,8,13,190,81,72,12,137,172,24,246,36,203,249,24,89,30,210,23,134,76,212,4,117,197,40,205,208,181,102,57,139,209,85,232,42,35,218,33,88,251,251,15,200,243,220,129,99,52,26,57,54,212,30,0,251,228,121,159,225,112,128,49,154,227,227,99,87,171,104,135,27,123,84,77,91,69,146,246,240,227,16,35,195,115,83,5,231,229,231,202,238,53,170,197,170,123,234,62,3,86,127,191,123,77,204,106,194,85,27,65,48,43,63,158,49,80,89,195,225,177,224,246,53,159,173,173,109,226,216,142,254,59,58,58,194,152,150,206,246,144,178,178,250,108,202,96,68,120,182,59,181,110,129,214,192,115,202,223,94,163,179,215,193,83,189,71,158,168,11,40,93,25,194,253,57,161,153,114,184,127,192,176,111,171,40,14,14,30,54,115,80,79,148,
126,210,52,181,147,221,230,194,141,146,143,162,144,249,98,65,16,101,24,25,159,249,250,42,221,84,99,215,5,137,94,90,102,76,151,248,190,160,22,154,56,16,248,18,140,174,168,138,57,201,208,167,200,23,182,27,85,89,189,60,207,243,232,245,122,205,52,59,155,173,120,241,197,79,115,116,116,68,81,20,188,246,218,107,110,142,170,19,120,111,198,186,244,251,125,46,93,218,37,73,98,167,26,106,31,47,236,123,107,102,23,197,73,66,148,244,172,165,49,2,85,175,125,126,235,213,28,107,174,220,9,91,42,41,21,171,7,135,22,231,50,118,171,238,116,135,230,54,96,74,133,44,63,166,197,164,181,130,227,105,201,98,89,160,85,225,250,91,90,166,202,138,29,10,164,180,157,165,73,218,3,233,159,193,46,157,166,58,235,115,192,83,158,98,229,44,221,123,86,201,79,107,225,148,62,13,40,165,4,222,209,146,100,111,70,230,149,92,122,238,33,152,41,117,157,56,65,143,86,150,202,110,60,155,39,57,81,72,181,157,152,121,158,147,100,125,20,161,117,103,214,179,241,202,160,150,99,252,122,66,44,115,116,57,99,115,99,224,218,58,162,196,214,3,
30,28,28,80,215,53,65,224,51,175,36,158,231,187,185,171,45,69,222,146,22,173,101,4,216,222,217,230,205,55,223,114,3,195,108,187,65,69,191,223,231,242,229,203,72,41,184,119,239,62,81,20,162,84,221,232,79,88,237,9,165,141,165,196,69,68,152,100,8,47,34,175,229,10,59,185,158,148,94,111,155,119,7,68,235,98,183,132,65,55,21,209,186,227,93,139,116,234,96,147,43,204,99,107,133,252,241,242,145,214,6,60,82,23,78,96,144,40,48,10,99,88,81,106,137,227,216,245,200,183,237,219,81,146,81,27,185,146,7,56,181,233,245,42,177,112,22,120,202,110,17,166,62,241,177,171,15,72,44,176,168,136,238,79,241,230,214,253,185,178,51,229,198,165,35,194,166,210,192,198,108,210,141,82,169,107,75,95,47,151,11,43,90,95,217,210,164,170,170,136,147,140,212,79,29,93,93,117,146,187,160,73,197,148,90,239,17,250,21,101,145,147,47,23,20,105,212,204,103,245,92,161,230,96,48,104,92,66,141,239,123,140,70,27,100,153,85,234,9,194,144,192,15,86,186,117,219,228,180,68,176,123,249,50,71,135,135,164,105,234,90,11,164,20,238,127,
24,163,217,219,219,179,82,83,155,155,248,65,196,112,51,165,143,68,120,33,70,88,29,110,117,70,75,133,114,110,213,217,109,35,239,247,185,151,237,109,189,26,219,214,29,215,246,60,215,90,43,136,14,151,31,223,126,32,41,12,253,94,196,104,52,100,58,157,184,192,219,15,124,234,170,110,212,115,66,210,52,67,41,237,166,14,232,78,15,142,118,167,27,142,49,91,169,129,91,183,60,231,80,190,221,223,57,139,33,114,238,218,253,9,254,56,119,23,37,9,21,183,111,30,179,187,85,186,126,29,91,73,45,93,213,193,98,185,196,104,205,96,48,32,78,82,6,253,30,119,239,222,37,8,35,122,195,45,68,144,156,114,219,164,208,244,131,37,178,60,166,138,52,189,222,136,233,116,74,81,228,236,237,237,209,239,247,93,204,216,150,253,180,213,219,113,28,179,181,189,229,198,181,156,86,14,237,206,95,181,149,237,59,59,59,60,120,240,128,32,176,109,33,90,107,14,15,15,73,146,132,225,104,131,170,210,68,73,138,31,38,24,225,59,29,112,221,17,154,84,134,83,57,50,221,28,114,122,61,57,109,78,199,150,85,183,32,246,44,183,109,237,48,116,215,74,
157,88,177,46,128,188,241,18,81,213,143,210,169,122,180,52,182,106,217,175,170,118,73,71,99,12,122,161,173,200,68,85,59,234,52,235,245,161,97,118,218,26,168,213,22,236,179,105,230,149,204,246,58,59,87,175,91,45,86,18,120,93,240,120,135,11,146,123,51,132,210,43,213,138,55,119,38,188,248,212,33,253,94,64,175,55,162,213,121,46,203,146,170,42,45,89,80,87,46,166,240,125,159,249,124,198,214,246,54,126,144,16,196,253,147,154,189,102,51,168,90,145,152,49,82,205,208,170,106,218,212,109,69,115,175,215,167,174,43,38,147,9,158,239,53,241,140,96,177,152,98,140,97,119,119,151,254,160,143,39,173,128,126,219,75,101,235,213,232,76,226,182,111,96,62,159,115,112,112,64,94,20,108,108,108,88,11,106,12,158,103,59,67,189,32,66,134,25,73,106,69,38,43,179,170,127,167,244,170,148,215,170,78,158,120,79,119,110,61,215,118,166,75,174,88,241,24,78,192,115,18,7,149,29,96,118,15,187,100,111,246,200,155,11,30,169,5,50,218,48,158,40,170,218,150,181,83,213,84,85,233,6,91,181,217,238,162,40,17,114,137,159,26,87,
235,164,187,194,134,77,3,220,58,253,188,206,182,85,103,128,103,197,157,91,79,232,181,86,231,221,49,254,113,126,70,29,95,205,15,126,122,193,115,79,69,196,81,234,232,246,246,32,72,211,140,32,8,155,94,28,233,70,64,6,97,72,173,32,234,245,108,27,182,58,161,211,43,5,197,108,31,93,222,167,16,202,21,106,6,129,45,194,236,247,251,24,99,184,124,249,178,27,208,107,133,56,194,70,148,208,103,49,95,144,101,217,138,116,174,253,58,209,147,176,163,68,236,235,68,8,164,244,241,130,16,63,8,137,226,12,233,71,8,207,7,225,185,128,92,169,110,103,104,87,170,184,163,133,119,174,208,10,107,21,238,167,243,107,234,61,220,57,71,105,119,192,179,238,206,117,203,179,194,251,19,68,245,104,245,16,30,57,128,180,129,163,105,196,34,135,56,192,149,252,219,156,131,215,204,41,141,137,162,8,109,12,70,41,140,100,109,40,213,201,201,183,158,153,174,215,205,124,251,85,119,72,132,245,214,128,14,193,32,166,5,201,59,71,136,90,159,89,69,254,236,245,25,207,63,49,33,240,173,74,106,158,151,77,105,142,135,231,217,60,201,241,241,184,
81,213,49,174,137,204,243,2,250,163,109,116,55,89,218,190,230,186,66,214,83,170,124,70,152,101,40,101,93,144,118,216,215,98,177,104,38,75,212,46,55,182,177,177,65,16,244,93,121,144,141,29,107,38,147,169,149,181,202,50,238,220,121,151,203,151,47,53,83,189,155,57,73,149,66,25,65,156,109,146,12,2,59,110,18,15,205,170,218,234,186,64,164,234,232,129,119,31,59,215,250,152,85,141,9,165,214,43,218,215,114,108,234,116,174,167,123,189,214,89,185,178,67,44,84,90,32,143,115,252,195,15,71,162,244,145,87,99,31,207,51,42,189,193,245,237,204,5,182,97,24,58,245,22,99,154,47,109,48,186,2,97,92,7,162,94,105,169,94,85,203,169,214,154,228,170,51,168,210,211,177,209,73,130,213,223,159,17,222,59,191,137,100,152,150,188,244,204,49,151,55,75,102,51,59,97,32,203,82,164,108,85,116,68,83,125,32,233,245,250,204,102,83,22,139,133,45,233,241,66,180,140,86,130,229,246,245,129,33,244,12,181,111,197,55,130,192,214,201,141,199,99,94,127,253,117,55,18,190,174,107,39,48,98,7,128,69,120,190,239,10,111,151,203,28,
99,96,56,242,209,243,156,36,27,178,40,65,72,1,194,130,68,123,2,154,65,198,78,85,104,125,114,222,218,32,176,247,20,207,239,38,48,215,164,191,78,37,59,205,217,46,221,89,185,162,149,207,73,117,136,5,117,250,58,154,165,34,190,115,196,135,181,30,121,49,233,254,145,207,221,253,136,103,111,25,23,12,91,217,87,159,162,40,233,245,250,40,85,179,88,204,137,144,152,40,2,211,91,25,140,219,234,80,175,180,94,171,245,68,157,180,110,155,58,27,60,174,236,167,134,232,221,35,252,195,197,123,244,48,25,158,185,118,196,149,141,119,121,240,96,230,106,196,234,186,114,26,215,105,154,16,39,113,83,97,189,116,137,213,48,74,17,81,223,181,95,159,228,162,172,43,39,145,92,191,126,149,196,191,236,198,73,182,151,36,207,115,14,15,15,89,46,151,174,207,40,8,2,151,0,181,73,218,136,48,74,72,123,3,130,40,65,201,4,100,132,136,37,117,59,161,174,105,174,51,205,176,98,221,105,253,62,115,142,209,89,128,58,71,60,95,157,210,14,231,12,233,227,78,69,187,57,191,109,164,90,111,128,60,135,88,104,175,163,42,52,241,155,7,103,122,12,
31,75,23,14,96,186,244,249,23,191,43,121,226,242,132,79,61,127,133,52,77,153,76,38,128,164,215,179,181,98,90,27,178,44,67,72,129,144,5,149,137,0,111,101,162,64,183,18,87,157,163,113,176,98,137,244,105,240,212,21,196,111,62,196,155,189,183,48,192,206,176,224,165,167,199,92,223,245,241,188,77,55,186,190,45,180,180,50,194,51,167,12,106,199,145,148,40,13,65,186,129,193,239,100,223,87,217,35,169,173,212,21,158,45,251,89,46,75,230,243,121,195,236,9,46,93,186,196,254,254,126,147,7,178,195,193,108,178,214,160,20,77,31,206,156,195,131,7,72,63,36,27,108,17,101,27,68,233,200,234,127,115,122,26,67,119,98,195,58,96,204,218,92,163,117,87,174,107,161,86,136,133,83,173,6,167,213,91,215,91,67,234,243,18,228,122,181,220,234,172,100,170,42,52,241,235,251,77,217,14,31,166,5,122,180,255,208,24,120,227,238,38,223,252,246,17,70,253,14,66,88,85,77,223,183,201,211,43,87,174,82,85,173,37,178,121,142,76,192,98,111,2,58,195,152,168,169,186,109,221,138,213,11,87,183,77,89,157,178,159,170,67,117,119,193,19,
189,241,254,224,145,210,240,236,245,67,158,189,57,195,24,69,28,167,141,42,80,232,18,149,85,85,186,68,231,116,58,229,225,195,125,180,129,221,171,55,145,126,178,18,252,182,170,65,173,255,111,148,32,175,32,241,237,208,227,170,42,59,185,37,171,163,182,181,181,217,128,167,110,166,51,20,77,98,214,184,10,14,154,56,39,159,61,164,202,103,76,198,135,132,189,29,194,116,19,35,195,70,129,116,13,72,173,85,63,107,106,56,156,6,207,26,88,186,50,95,186,35,173,117,150,244,215,105,145,202,213,62,172,179,172,81,189,214,170,209,90,31,157,43,226,215,31,126,232,224,249,80,26,234,0,198,139,152,215,238,94,227,133,167,125,110,93,177,178,79,97,24,177,189,189,229,74,252,219,73,216,179,217,148,183,222,122,141,163,227,57,195,203,207,224,7,155,20,85,140,49,177,235,9,105,165,143,234,181,24,169,94,115,151,234,134,209,169,107,8,223,216,71,206,138,247,125,247,87,182,42,190,255,249,146,65,79,83,215,134,195,195,67,27,248,55,57,151,32,8,200,50,91,50,99,169,236,154,40,138,217,218,190,76,212,180,101,159,218,24,43,238,
73,192,107,247,10,162,229,171,12,122,150,64,233,247,237,225,241,240,225,126,83,70,211,206,52,178,181,103,86,104,69,52,228,139,239,14,26,168,155,214,2,80,106,66,61,201,81,85,14,241,14,198,235,157,30,253,120,202,2,157,109,149,186,253,55,235,163,44,187,177,210,202,224,49,125,198,124,165,181,206,210,243,68,91,222,43,63,167,23,53,241,107,251,136,90,61,22,170,238,31,138,172,149,49,240,237,183,7,220,124,205,231,169,39,114,174,92,242,9,2,223,37,251,38,147,41,251,251,15,217,220,220,164,223,239,243,212,83,79,178,187,88,144,101,41,179,124,193,70,92,114,119,60,227,176,26,177,175,98,231,206,41,151,228,59,93,12,218,117,229,130,59,7,120,211,252,253,251,151,2,248,220,167,11,94,124,86,225,75,91,13,80,85,101,67,183,75,226,56,33,140,66,84,93,51,155,45,157,101,16,210,71,203,0,189,226,186,173,170,232,184,238,82,237,35,195,171,132,162,192,243,199,76,167,19,138,162,32,77,211,102,168,150,173,140,110,219,62,90,224,180,4,140,141,155,90,145,125,28,165,14,2,99,230,36,129,160,156,45,209,209,46,185,220,68,
179,58,169,65,195,154,251,182,30,255,180,247,207,30,152,124,106,216,216,218,64,178,243,216,185,245,60,209,169,14,225,182,122,190,227,206,137,241,146,248,206,225,135,66,87,63,54,49,80,187,150,5,188,242,47,18,54,55,66,254,141,47,87,108,111,88,165,151,163,163,49,101,89,177,187,123,185,233,159,49,205,41,111,103,159,6,162,230,114,86,176,149,250,236,79,22,188,141,207,3,177,193,221,69,159,69,21,57,107,212,158,116,235,101,63,222,131,9,254,193,7,27,109,246,196,174,226,251,111,231,236,108,69,132,97,159,44,203,86,26,228,236,156,27,59,199,212,13,201,53,134,193,112,131,40,25,156,46,80,213,93,23,243,228,117,149,117,202,162,186,130,209,37,125,191,164,44,45,219,102,219,163,85,67,105,155,134,249,203,168,149,66,54,186,210,109,142,116,185,204,81,74,33,61,137,20,86,84,67,105,109,149,106,244,156,229,226,77,132,92,80,250,87,168,72,86,38,53,116,99,159,245,9,227,231,89,169,149,97,98,250,12,235,179,22,51,157,103,145,234,46,59,167,206,142,97,85,5,254,253,67,130,7,51,30,183,137,138,31,234,124,160,195,137,
224,239,255,178,71,89,20,124,229,11,51,158,184,57,96,107,107,243,36,111,164,173,78,220,114,185,100,185,92,96,12,77,97,163,162,40,38,4,85,201,101,177,100,24,167,140,196,6,247,252,29,222,156,108,179,40,211,83,50,85,149,22,152,69,69,120,119,252,129,94,91,20,24,62,251,194,146,155,87,230,236,239,143,201,178,140,201,100,130,82,53,131,193,144,225,104,72,93,213,192,12,99,116,35,150,14,189,254,136,193,198,165,115,173,207,122,6,222,49,76,108,83,215,146,27,241,93,18,239,126,35,89,28,55,18,191,214,10,21,69,225,20,112,90,137,168,94,191,71,18,219,233,226,90,43,231,90,218,28,84,75,58,40,6,82,162,76,206,131,197,125,14,234,75,204,85,127,101,240,86,215,2,153,247,112,235,214,169,236,179,38,147,119,231,37,157,232,186,173,230,142,234,117,197,215,181,22,133,214,50,153,101,77,244,214,67,228,162,228,113,92,31,186,184,252,193,24,254,143,127,28,48,62,170,249,241,207,191,77,22,47,25,141,134,77,163,150,113,185,17,235,182,104,242,124,217,81,222,148,100,105,66,79,24,182,250,71,60,169,115,174,100,11,254,233,
253,235,188,122,60,88,77,222,41,65,244,246,67,235,200,127,128,117,121,52,101,171,247,54,7,251,199,205,255,205,27,234,218,86,66,167,105,218,176,112,1,80,52,196,66,76,146,13,16,141,120,70,87,5,72,233,211,244,236,9,144,172,187,178,80,219,228,19,193,147,169,102,40,31,54,195,168,148,117,21,195,128,163,163,177,85,184,9,67,6,131,126,51,177,97,78,93,217,216,199,30,56,170,41,14,213,132,97,128,231,217,190,170,186,182,237,215,81,88,18,47,14,120,119,41,216,207,237,103,180,18,23,113,58,70,178,162,134,156,206,9,173,3,202,156,49,197,92,175,49,114,230,180,230,94,55,54,234,182,141,248,15,198,4,15,38,160,31,223,73,216,143,197,132,186,201,34,224,235,255,242,18,101,237,243,197,207,212,8,49,65,107,69,175,223,39,12,194,198,165,145,20,101,65,221,248,248,66,216,198,175,86,75,14,64,20,75,158,202,222,38,223,212,220,159,223,102,86,36,110,80,150,60,154,35,231,31,76,199,54,9,21,159,251,212,130,23,111,251,4,254,6,85,85,89,119,173,180,34,27,74,213,220,187,119,151,157,157,75,100,89,74,146,196,228,121,78,173,
5,97,54,178,229,58,167,104,117,78,213,219,85,107,148,118,165,5,15,235,29,150,199,146,155,145,225,214,104,138,196,52,90,107,126,19,151,165,12,6,125,242,188,112,51,83,151,203,101,243,89,196,205,103,97,220,224,229,54,230,108,75,132,4,154,75,233,130,80,62,160,174,42,238,85,91,148,218,59,229,194,153,247,112,227,212,90,85,136,214,93,151,110,29,80,171,83,203,213,25,250,215,117,247,231,10,188,131,41,241,189,241,135,154,223,249,200,88,32,151,31,154,123,188,242,205,77,14,199,154,31,126,233,62,151,55,143,184,127,255,62,253,254,128,157,157,29,130,64,16,71,17,126,150,185,185,160,101,89,82,148,5,199,227,177,147,153,237,103,49,95,216,80,252,198,158,225,238,236,228,52,140,30,28,127,176,50,119,1,87,183,39,92,30,189,195,209,161,157,2,215,230,93,108,109,155,109,77,88,46,151,204,231,115,182,182,182,109,53,179,129,40,29,88,129,123,37,222,83,200,241,92,21,160,166,222,107,174,46,145,147,193,226,14,183,55,15,121,98,52,226,232,104,204,98,49,119,140,101,146,36,29,89,169,186,161,179,173,184,71,59,10,166,
205,85,89,241,15,221,84,122,64,89,150,132,122,193,173,212,150,254,191,57,223,97,81,5,171,115,84,223,143,165,91,81,199,57,93,102,245,129,137,133,246,103,181,193,27,207,137,238,143,145,121,197,71,101,61,86,99,238,243,82,242,205,87,119,184,127,152,241,71,126,108,196,179,55,15,40,150,51,142,142,14,25,141,54,26,185,40,171,59,54,30,239,57,9,224,48,140,136,162,216,213,209,33,12,255,222,231,30,242,87,126,249,6,243,18,196,44,71,206,243,15,244,26,178,168,230,165,167,199,220,186,90,33,240,216,216,216,96,48,24,52,205,107,1,253,126,223,85,93,123,222,201,236,155,32,206,64,70,171,174,218,25,236,210,74,99,152,146,43,117,124,46,121,168,4,247,202,1,7,243,91,220,31,195,115,189,87,201,34,195,214,214,22,117,173,120,248,240,161,27,145,178,187,187,235,38,119,139,102,42,93,89,150,205,248,144,16,207,147,77,127,82,13,136,166,67,213,35,12,19,194,178,194,19,119,17,104,190,117,124,133,105,25,172,18,10,116,128,163,197,105,112,157,83,246,115,250,182,43,244,184,90,218,99,138,10,255,96,74,248,96,178,90,249,254,
17,89,222,245,79,253,241,63,9,92,123,92,94,144,49,48,93,4,252,238,235,125,54,55,82,158,123,174,71,26,135,244,178,212,117,79,182,21,198,121,190,108,168,229,138,178,44,168,42,27,104,10,207,103,208,247,121,110,187,230,55,222,234,83,222,159,224,205,62,24,128,110,223,152,241,229,31,60,166,151,20,204,231,11,138,162,112,237,216,109,59,180,148,146,249,124,206,241,241,177,109,66,11,34,210,254,22,202,41,7,201,85,93,186,186,219,231,223,86,22,203,19,141,187,182,60,165,243,88,165,4,243,58,102,175,216,36,87,25,87,123,51,202,229,184,33,9,90,16,68,204,231,115,150,203,133,43,200,77,146,152,170,170,157,118,193,98,177,116,67,154,219,166,62,160,17,113,137,172,194,106,82,81,213,154,135,203,148,89,233,119,218,61,58,162,32,107,221,179,39,157,162,157,194,78,37,79,126,87,183,101,55,235,143,11,59,120,248,104,78,240,238,1,225,157,3,188,233,18,97,12,31,193,117,215,187,254,194,227,5,160,118,85,181,224,183,190,19,51,220,232,113,243,201,20,41,160,44,10,170,210,74,231,142,199,71,141,66,102,68,24,218,105,117,
203,101,78,173,52,81,58,64,6,9,113,84,115,123,179,226,215,95,201,49,229,251,159,110,131,172,230,135,95,58,228,169,107,15,49,166,205,53,88,34,99,177,176,154,3,139,197,130,249,124,198,124,110,197,68,226,56,97,231,242,85,240,211,213,10,98,45,79,122,88,214,0,181,218,61,43,87,42,194,203,110,191,146,22,44,235,128,187,203,13,166,213,22,183,47,107,66,153,35,5,174,153,175,40,114,132,176,7,74,146,196,132,97,228,196,41,237,12,165,190,171,55,84,205,9,175,148,141,155,90,169,42,73,201,229,190,34,244,224,225,34,97,156,7,157,220,153,60,233,161,90,7,140,19,190,239,188,79,181,254,248,9,104,204,52,199,191,115,64,248,214,62,254,193,204,186,106,31,73,220,156,0,200,127,156,223,129,49,240,115,191,0,203,58,225,139,159,143,73,188,152,32,44,240,188,37,131,48,107,166,14,216,4,98,214,15,26,5,211,8,35,173,254,178,214,130,43,155,11,254,253,127,83,240,119,254,103,243,190,4,220,19,187,199,220,190,121,72,18,251,72,25,18,134,181,83,219,236,110,64,207,147,78,57,104,56,218,68,248,201,74,71,236,122,108,227,228,179,
12,171,242,89,43,42,65,103,180,43,183,197,147,181,224,55,30,236,176,63,79,248,227,159,250,54,155,225,3,84,185,32,142,147,134,88,240,27,86,208,119,22,185,215,179,179,85,61,79,179,181,181,233,196,249,149,178,84,247,124,62,183,207,173,43,162,48,34,148,21,79,165,111,193,85,201,215,223,185,204,221,105,180,18,251,152,115,226,32,87,86,117,134,59,103,42,131,156,45,240,15,167,200,241,2,161,53,31,183,229,63,238,71,128,1,126,225,23,21,69,229,243,195,159,239,211,139,82,226,104,72,232,105,60,161,145,194,56,189,103,213,140,70,215,157,58,56,109,224,153,103,5,255,206,79,123,252,220,207,215,231,130,104,212,171,121,241,246,146,39,111,38,248,190,116,57,40,192,181,11,216,106,232,147,89,55,66,122,248,81,138,50,222,57,195,186,62,0,145,208,74,54,233,211,210,77,235,226,248,191,125,52,224,224,55,191,159,63,241,233,223,98,59,124,3,83,228,248,126,224,164,132,251,253,158,19,124,63,60,60,68,8,73,158,231,244,122,189,198,146,86,14,68,190,239,59,101,209,241,120,220,28,12,30,151,244,111,241,233,254,140,233,242,
105,238,207,211,247,40,60,61,227,103,26,196,178,68,206,151,4,227,57,222,228,209,234,19,124,56,49,208,11,255,246,99,233,194,173,175,239,126,87,35,67,201,96,219,239,244,150,52,226,125,70,54,174,70,119,200,86,227,179,27,123,191,63,146,108,237,72,190,253,187,250,140,49,129,134,31,120,110,206,143,126,230,144,56,170,27,151,199,50,88,66,8,202,178,34,77,83,134,195,33,131,193,144,36,73,9,163,144,56,233,217,25,62,198,59,29,27,156,114,221,100,211,216,119,210,214,208,117,125,202,51,4,82,78,158,35,157,114,231,248,160,228,59,191,186,228,201,39,61,210,112,70,224,219,138,133,170,233,54,109,105,237,60,47,154,74,137,220,234,75,104,205,241,241,24,173,85,243,30,98,146,36,33,73,108,178,182,21,19,145,212,108,37,75,138,210,240,238,124,192,180,10,87,101,134,187,238,103,45,208,203,26,49,158,227,237,141,9,223,218,39,184,63,198,27,47,62,14,238,217,7,141,129,254,173,143,4,128,0,222,120,77,129,239,209,223,10,154,113,243,86,143,236,212,248,195,206,247,221,100,101,127,232,177,185,227,241,234,183,235,21,16,
109,14,42,190,244,217,49,55,119,109,254,41,12,131,70,30,42,109,20,57,3,146,36,102,177,88,186,14,80,233,249,120,65,74,165,189,83,196,193,89,177,205,137,96,226,121,0,91,189,45,215,72,135,74,75,84,161,136,191,123,231,255,107,239,76,99,36,187,174,251,254,187,247,237,245,170,170,247,238,217,135,67,138,155,36,138,28,146,146,108,89,178,13,111,89,236,36,150,5,219,65,236,0,222,146,231,251,51,219,0,0,32,0,73,68,65,84,40,9,28,3,73,62,38,249,96,56,95,12,35,78,236,216,177,99,203,145,13,7,145,141,32,136,13,7,136,100,43,81,180,139,18,87,113,145,184,136,179,112,102,122,150,222,170,107,125,239,221,123,243,225,190,247,234,213,210,195,161,68,113,102,186,235,0,141,225,244,52,187,166,239,188,83,231,220,255,249,159,255,159,65,23,206,156,243,121,219,221,62,75,77,107,155,40,133,204,217,218,170,76,244,32,240,173,176,73,24,209,233,180,89,94,94,206,7,191,86,154,215,194,226,146,213,213,85,226,184,14,8,106,181,136,165,249,58,167,86,12,158,235,113,102,171,198,246,192,35,85,160,250,10,90,61,228,181,22,206,
250,22,254,217,43,184,151,183,113,182,59,200,238,96,95,182,104,175,159,64,247,221,62,9,4,112,254,76,134,114,28,226,69,191,148,86,82,186,234,13,52,148,148,173,42,252,23,109,80,109,206,97,126,217,225,213,23,237,59,164,148,134,7,239,105,241,232,59,54,136,2,157,51,28,68,41,185,101,117,159,19,58,21,180,79,41,133,144,197,150,169,83,209,52,147,99,194,246,114,4,154,46,164,134,139,63,207,202,68,25,69,174,70,23,199,134,213,201,63,179,142,204,73,176,157,158,228,252,107,30,119,222,229,178,186,0,97,96,21,123,236,192,213,154,148,109,231,243,49,187,18,177,132,16,214,42,179,223,239,131,16,168,44,43,237,51,179,204,106,100,23,109,95,210,219,97,217,223,69,109,166,92,124,106,23,241,141,107,120,235,91,184,155,187,56,187,189,188,194,24,14,120,92,116,142,221,255,161,219,42,129,0,46,157,77,81,142,67,109,209,175,236,150,12,55,81,179,17,9,43,57,70,157,145,132,13,135,230,146,203,249,151,83,86,23,18,222,127,122,131,147,71,250,248,190,71,24,134,68,81,173,20,130,47,188,112,146,65,66,175,215,69,107,67,24,213,
240,107,77,180,244,203,234,147,85,19,100,90,101,153,146,96,137,186,14,18,55,246,61,196,198,46,222,133,107,163,12,142,142,100,107,75,114,236,24,44,52,20,65,174,49,145,101,89,185,246,13,134,110,183,135,231,185,165,64,73,225,42,103,193,17,147,11,222,39,249,142,147,155,179,191,51,66,95,115,114,69,210,222,214,92,184,236,112,240,10,204,62,107,225,170,113,229,124,74,34,29,162,133,160,212,34,75,205,48,73,70,245,17,228,152,38,179,36,106,122,52,150,36,71,162,109,222,255,72,159,90,36,241,60,171,198,217,239,247,81,42,35,8,130,28,60,144,248,190,87,106,170,69,245,57,164,87,159,128,170,179,61,42,79,82,105,39,71,170,77,181,237,27,111,247,42,119,32,53,80,4,47,189,134,152,194,9,187,182,237,208,233,184,156,60,33,153,175,27,6,57,197,39,138,106,86,183,58,138,8,195,176,244,37,42,146,166,16,243,47,76,191,236,144,213,41,239,126,198,24,130,32,36,142,52,203,139,138,141,45,143,245,107,114,150,50,227,9,116,244,190,15,221,150,9,4,176,241,90,66,34,93,130,185,0,141,44,129,133,180,2,36,84,213,44,83,53,154,96,
39,86,19,222,247,246,30,115,81,167,108,221,138,21,0,99,236,252,39,73,18,192,148,27,162,181,184,142,27,54,173,207,167,182,174,106,123,87,27,57,105,30,53,173,26,101,99,237,91,101,152,154,106,137,119,102,29,217,238,237,9,245,95,190,38,80,169,224,232,17,205,124,93,176,184,184,148,207,135,68,110,116,21,32,165,83,110,205,218,213,11,43,157,21,4,126,233,71,91,16,85,11,89,173,194,113,124,174,174,88,90,16,188,124,198,165,213,17,179,180,217,47,9,4,176,125,113,192,64,184,120,115,97,201,123,171,110,162,142,250,4,201,114,125,216,17,134,123,150,219,44,251,235,100,57,131,33,8,2,150,22,151,114,253,53,107,126,156,166,86,212,176,221,110,147,36,41,126,212,192,13,26,55,124,207,41,42,83,86,117,32,208,114,152,32,149,246,111,36,33,243,100,98,187,131,119,254,202,117,207,64,27,193,229,107,18,157,101,220,119,79,141,249,166,71,24,70,196,113,76,24,70,156,59,119,158,102,211,42,155,74,233,32,29,137,64,144,36,131,124,9,80,150,137,85,184,106,23,243,47,41,37,97,24,112,228,144,203,194,188,195,147,207,217,159,97,
22,69,2,221,251,99,183,117,2,1,236,174,247,233,225,34,155,81,190,160,37,43,123,37,114,248,251,74,133,90,169,245,184,179,185,201,161,37,11,79,123,158,75,179,217,164,215,235,145,36,150,229,172,180,34,138,194,146,229,60,191,176,68,220,92,65,225,78,129,173,199,80,183,177,202,146,76,80,96,42,147,251,41,192,67,170,5,217,192,16,188,120,30,145,189,254,6,102,154,194,181,45,143,90,232,114,215,73,135,40,148,57,229,201,48,55,215,44,165,195,162,40,36,200,237,86,236,61,41,44,215,192,93,215,43,221,28,138,150,181,223,239,231,43,236,130,227,71,28,130,208,225,201,231,56,8,16,245,141,86,160,219,63,129,0,186,151,123,116,140,11,245,218,112,78,52,34,98,56,188,115,72,147,113,188,118,133,35,113,139,65,191,203,206,142,93,148,219,221,221,37,73,210,124,85,66,226,230,2,237,75,75,75,68,181,26,126,212,4,39,220,163,250,188,30,108,61,37,129,178,10,136,160,199,169,48,18,247,181,43,56,219,237,27,62,131,222,0,174,92,51,4,1,156,56,42,241,92,11,40,216,196,144,229,214,172,227,88,7,135,98,69,220,15,44,187,187,144,
204,42,140,193,172,14,157,204,205,146,13,70,103,156,56,238,128,27,240,181,23,103,136,66,158,64,31,220,23,9,4,144,92,237,210,49,14,58,142,115,121,218,49,116,46,135,181,215,194,109,238,93,220,36,114,211,178,85,177,171,218,178,116,155,246,60,143,48,12,24,12,6,86,102,170,222,68,120,113,94,81,198,238,54,123,86,35,153,175,40,72,107,16,182,7,204,61,81,133,180,68,119,6,248,175,92,120,195,111,245,173,14,92,189,6,113,36,56,118,200,16,248,133,127,169,41,23,2,179,44,37,203,178,252,103,30,174,132,105,109,24,12,172,64,163,82,89,46,83,108,74,221,62,41,37,174,99,56,114,204,69,73,159,151,95,201,102,9,180,31,90,184,106,168,141,46,157,84,144,198,86,135,90,233,209,233,191,47,51,238,95,216,224,228,124,167,148,132,42,246,102,138,54,167,48,154,42,118,105,130,32,68,184,53,140,147,91,49,230,149,163,100,26,103,211,135,168,35,168,220,216,156,167,88,103,152,158,64,2,239,229,11,200,222,55,183,198,188,213,130,107,27,154,184,6,199,15,75,100,5,60,43,156,208,109,194,168,210,170,209,174,66,136,114,57,209,18,116,
237,27,73,171,181,91,158,71,224,123,120,174,100,249,72,72,98,28,206,124,35,59,232,9,244,193,125,149,64,0,102,187,75,127,103,192,160,222,64,9,103,184,66,172,4,167,154,45,30,88,185,76,232,36,185,60,148,204,237,231,61,124,223,203,231,62,182,149,105,183,219,86,107,186,222,68,6,117,82,237,140,128,5,67,225,243,73,182,117,54,181,58,13,215,27,50,189,55,237,71,108,182,240,46,92,253,150,206,96,115,27,182,91,176,182,34,88,91,46,102,63,26,109,12,201,32,201,7,167,94,14,24,20,178,88,148,10,64,253,126,159,36,177,162,41,205,102,51,119,178,3,199,117,17,70,99,132,203,210,225,128,190,113,120,237,76,122,144,19,232,71,247,93,2,129,37,53,102,87,90,244,189,144,212,15,81,70,80,247,50,222,123,116,147,123,86,123,200,92,2,170,219,237,82,175,215,113,93,171,63,221,233,118,74,47,83,55,223,63,10,106,115,185,167,143,156,104,207,38,230,58,35,72,156,152,14,18,140,207,129,42,200,91,150,130,255,226,217,27,2,14,94,23,230,223,178,234,165,167,78,72,230,26,195,234,226,186,110,238,138,161,243,55,17,91,149,12,6,41,236,
66,157,85,90,205,114,173,187,52,87,66,181,154,229,82,74,132,244,80,198,97,113,45,160,167,29,214,207,37,7,52,129,238,249,224,190,76,32,192,238,212,95,217,33,105,39,12,162,152,119,174,181,121,244,208,107,52,252,12,165,50,180,54,101,219,82,200,84,105,165,145,82,148,27,174,243,139,43,120,97,115,74,130,236,113,143,81,211,128,129,209,138,149,237,113,15,202,180,64,94,188,134,115,109,231,205,169,196,6,174,109,26,2,207,112,199,49,131,239,131,49,118,45,163,32,201,218,205,90,235,17,148,38,41,105,154,230,247,31,175,52,72,46,22,25,109,107,103,117,240,164,227,162,240,172,160,253,106,64,87,57,92,61,127,224,146,232,162,123,16,240,72,121,117,27,191,181,205,202,209,140,57,191,75,146,128,235,58,36,73,90,250,179,130,177,198,198,153,202,87,25,236,67,130,244,71,192,136,108,194,56,106,210,64,74,141,236,254,76,255,186,105,31,186,151,18,158,191,252,166,98,196,187,29,248,244,151,12,39,143,58,124,224,61,118,237,163,211,233,80,171,213,168,215,99,250,253,1,173,214,46,6,8,124,159,32,8,48,198,99,48,72,74,86,
186,93,90,12,74,251,205,32,8,16,174,67,160,53,145,167,153,143,20,239,254,206,136,68,193,75,143,181,14,84,6,185,7,5,208,63,178,212,231,68,99,3,97,36,198,88,112,160,240,25,45,140,142,149,202,136,227,152,126,191,111,215,184,131,26,194,9,38,100,152,70,228,178,166,56,121,79,221,253,81,98,76,53,117,50,161,188,243,151,64,191,249,170,155,231,46,193,167,191,164,184,243,4,28,61,4,113,28,211,235,245,74,40,219,234,60,216,118,118,48,232,51,63,191,96,125,133,242,129,170,214,154,90,45,202,101,139,237,198,171,17,18,47,53,120,142,41,147,232,244,123,98,82,45,56,243,149,237,3,148,64,7,128,81,235,185,134,187,79,180,185,243,164,204,87,19,162,210,139,168,64,218,236,172,195,101,119,119,183,228,135,121,97,60,92,150,83,99,198,185,35,191,138,17,223,208,61,23,234,166,38,152,253,122,209,106,227,92,217,252,246,128,42,6,158,122,30,62,243,165,140,31,254,126,69,20,90,196,109,99,99,195,182,100,249,130,93,24,134,185,189,138,25,86,225,28,226,207,50,159,56,142,243,234,104,23,232,28,105,112,165,193,119,135,149,232,
129,71,234,36,153,224,226,147,155,7,36,129,14,64,28,93,77,121,244,93,112,104,109,142,32,8,233,15,6,108,109,109,162,181,102,121,121,153,56,142,217,221,221,45,165,115,181,214,56,94,104,219,183,66,114,182,162,166,57,89,93,198,28,216,198,188,92,213,117,125,93,5,42,3,255,236,197,111,235,25,180,218,134,47,63,109,184,251,84,198,221,119,168,210,208,172,211,233,228,34,150,186,148,16,182,213,88,149,150,155,142,227,228,176,183,70,228,3,89,140,193,17,224,22,73,148,87,162,185,72,113,255,195,77,18,37,184,246,204,198,172,2,221,238,225,56,134,183,157,24,112,236,48,164,105,198,198,198,69,60,207,163,219,237,81,171,69,86,136,36,203,242,75,181,237,251,107,113,29,233,215,200,114,130,170,186,222,221,199,84,239,63,140,201,90,177,167,188,85,245,87,185,185,141,220,105,127,219,207,226,197,87,13,159,250,92,7,53,184,130,209,29,140,49,172,172,172,176,184,184,80,106,60,120,158,139,235,249,72,97,229,195,132,180,123,67,58,71,223,138,196,178,224,139,65,74,202,68,242,28,67,232,26,230,66,197,219,30,156,35,73,161,
245,252,181,253,125,191,222,239,239,16,43,11,41,39,143,108,209,222,93,103,99,99,163,116,118,115,156,220,0,216,115,73,114,165,31,41,37,205,102,19,215,179,194,36,106,204,196,56,171,182,106,21,37,77,85,177,119,31,249,48,163,21,106,26,24,161,51,131,119,230,194,91,114,22,73,42,120,241,213,128,205,157,144,102,179,201,218,218,90,110,228,229,148,42,175,174,235,33,5,165,30,132,209,166,220,33,170,10,172,20,238,16,2,131,148,166,108,231,60,87,19,122,154,185,80,113,242,129,69,194,59,230,247,123,5,218,191,156,38,41,225,158,83,41,119,159,18,165,4,112,113,255,41,44,24,123,61,187,38,80,48,16,194,40,38,158,91,193,200,10,170,102,70,239,60,69,59,55,161,46,106,242,100,49,99,224,193,152,169,110,181,170,57,235,151,17,189,254,91,118,38,151,55,60,158,127,81,34,205,37,124,79,226,186,46,135,14,29,98,113,113,177,60,35,11,115,203,210,208,203,243,60,130,192,31,177,85,201,178,12,99,172,144,189,4,164,200,19,40,255,40,218,185,35,167,15,113,54,53,168,155,232,99,58,171,64,223,100,44,205,41,238,190,99,64,92,179,
151,228,162,215,15,67,59,227,89,94,94,6,4,187,187,182,125,138,162,136,48,178,150,239,101,203,117,93,80,128,17,215,105,165,70,219,185,113,231,53,53,246,123,61,200,240,206,92,124,75,207,164,215,151,156,185,16,208,235,135,165,122,105,175,215,99,107,107,139,205,205,77,58,157,78,78,40,181,226,36,197,240,181,224,8,246,251,253,28,100,48,232,74,251,47,4,72,1,142,48,184,206,16,157,155,139,20,203,15,29,133,229,198,254,172,64,102,31,195,216,71,15,245,185,227,152,53,189,42,184,110,81,20,149,234,53,235,235,235,12,6,3,28,39,191,24,11,137,227,71,40,228,148,118,141,169,160,128,26,241,253,100,226,206,52,142,216,85,219,59,247,252,5,140,126,235,205,162,174,109,69,108,108,121,52,226,93,192,238,65,41,173,75,77,57,223,247,169,213,106,21,198,246,240,125,214,247,61,192,32,164,132,220,217,193,182,114,148,119,162,2,88,240,28,139,206,205,213,20,189,7,143,179,243,133,151,161,59,216,95,9,180,95,243,39,10,50,214,22,55,81,201,22,237,182,159,91,36,14,74,212,169,184,8,215,106,181,210,131,39,8,107,72,55,36,25,
171,62,163,15,254,216,224,212,92,71,44,254,58,0,130,105,119,113,46,94,189,41,99,184,86,199,231,202,86,147,187,79,165,4,129,103,5,235,115,230,65,97,219,82,64,217,85,51,101,91,141,138,54,78,98,176,254,66,166,4,183,139,118,206,66,220,94,165,18,53,27,30,253,7,79,49,248,210,139,214,124,117,255,192,216,251,51,131,142,31,202,120,240,237,14,139,139,115,249,86,101,88,170,115,6,65,128,214,214,89,187,104,235,252,32,196,241,106,19,213,39,219,19,138,102,58,178,54,134,202,101,227,238,107,249,61,201,61,119,241,166,169,218,36,169,100,183,19,129,240,115,9,47,175,92,247,78,146,132,56,142,105,54,155,35,236,236,130,133,80,36,84,170,135,54,40,134,202,143,34,140,173,68,2,28,9,158,51,132,184,235,139,1,201,189,199,48,207,159,157,37,208,45,253,67,57,134,99,135,187,44,206,15,144,210,45,255,225,1,210,44,99,123,123,59,31,150,186,37,77,63,174,55,145,94,64,162,167,13,68,71,97,231,241,246,45,155,218,178,85,28,242,212,168,235,154,104,237,226,92,189,185,51,146,221,78,68,166,66,180,78,73,18,235,251,218,108,54,
203,150,173,215,235,229,131,83,171,15,81,180,189,237,118,155,48,138,112,130,166,173,64,102,152,60,218,136,202,157,200,32,69,5,157,115,52,145,171,9,143,46,210,189,186,141,184,186,189,79,18,104,31,22,160,165,249,140,59,143,247,168,199,46,181,56,38,12,130,124,187,82,148,194,235,158,231,149,239,170,66,72,132,19,160,113,38,97,230,194,193,88,11,140,113,243,245,112,42,246,145,147,224,192,94,119,159,2,246,246,94,57,123,211,223,183,90,109,129,33,160,94,15,74,100,205,58,79,88,20,110,119,183,69,28,199,196,113,92,122,35,13,171,145,65,24,89,177,134,180,146,202,54,217,42,73,148,163,115,195,36,50,132,190,161,119,215,113,184,214,98,63,232,100,237,187,10,36,128,147,71,6,220,115,151,71,20,57,56,82,150,201,99,91,55,93,182,36,96,23,204,106,245,57,28,47,28,86,31,13,153,210,72,213,37,72,91,212,69,74,80,175,209,77,29,54,187,30,27,170,78,223,212,71,28,214,70,96,235,113,14,92,37,145,196,198,22,114,183,115,243,225,87,225,144,166,25,221,110,82,86,152,162,101,139,227,66,149,199,42,19,21,18,88,237,118,155,
110,183,75,211,143,48,200,161,177,86,222,194,21,149,200,76,32,115,224,230,224,130,239,24,130,70,64,239,200,50,242,181,203,179,4,186,213,162,30,107,222,118,71,70,189,166,72,179,225,59,167,85,24,181,182,135,133,53,188,239,251,36,105,74,24,47,32,132,59,68,221,148,194,244,54,169,201,46,90,183,81,89,74,183,99,87,156,23,20,120,178,73,198,17,186,122,101,20,121,43,173,10,25,109,253,202,74,101,240,95,57,195,173,112,230,90,27,60,191,201,242,178,221,139,26,12,18,235,183,154,155,18,23,231,228,186,46,113,28,211,104,52,73,146,129,93,123,80,224,8,57,98,7,105,242,68,210,57,162,96,140,40,127,204,162,18,185,149,74,212,59,182,6,23,174,112,187,207,33,247,29,149,231,232,170,226,222,187,32,8,114,129,140,212,90,63,90,8,214,199,243,188,92,140,61,35,77,18,226,122,19,55,24,186,122,167,201,128,180,125,13,79,237,208,233,183,115,157,4,147,183,49,130,40,16,200,100,147,21,186,116,141,166,163,143,140,204,121,166,163,111,57,101,231,202,213,183,116,104,122,253,10,100,64,119,217,222,78,216,217,217,201,5,84,44,
3,161,106,236,92,220,129,58,157,54,142,235,16,134,53,130,168,94,218,56,218,36,18,195,86,174,218,206,85,238,67,34,119,208,112,164,193,147,26,39,14,81,75,115,200,171,155,183,121,2,237,43,240,0,238,56,158,178,180,160,48,6,130,32,204,37,153,100,185,89,89,160,72,81,20,129,49,184,65,4,210,67,41,155,84,89,111,19,153,108,144,169,164,124,167,78,83,107,161,152,101,170,180,55,137,197,38,135,29,193,110,86,167,173,23,43,100,211,233,251,65,42,213,4,175,158,187,117,206,202,213,56,78,193,40,176,9,98,140,41,41,61,105,154,150,0,139,101,99,103,152,190,161,222,88,68,186,214,127,73,233,170,213,9,101,59,55,142,206,25,196,240,62,84,160,115,210,144,174,44,238,131,4,218,71,21,104,161,169,184,251,142,140,122,236,150,109,155,206,29,168,227,56,46,125,77,117,62,188,12,163,24,47,136,81,70,146,166,138,246,230,69,6,237,43,232,212,186,183,73,41,114,189,4,91,185,138,5,51,207,243,8,131,144,67,97,143,129,183,197,250,96,1,85,245,59,157,50,11,114,214,215,17,253,91,103,136,120,100,77,80,171,65,163,209,192,247,173,
21,100,81,109,6,131,65,78,223,9,202,123,34,8,226,122,157,48,158,67,27,39,55,7,206,121,128,122,152,76,102,34,121,134,191,14,239,69,22,88,96,49,231,201,221,198,207,224,190,170,64,119,158,48,28,59,162,73,83,77,150,169,188,37,177,186,104,253,190,125,240,7,131,1,131,65,159,78,167,195,226,242,33,130,166,79,166,12,221,221,13,178,238,6,58,237,91,121,95,1,142,227,114,236,216,241,92,55,64,148,80,174,101,53,4,72,41,168,167,219,156,105,247,120,169,223,152,62,47,50,160,82,69,112,230,252,45,5,243,199,81,135,90,100,181,179,11,245,157,194,123,181,86,171,161,181,42,217,215,189,94,15,223,15,240,252,16,199,11,73,199,237,234,43,134,91,106,74,75,55,14,242,20,224,130,12,60,116,179,142,220,217,157,129,8,55,59,2,207,176,186,220,195,247,122,24,227,87,108,222,93,242,86,158,245,245,117,118,118,90,100,89,74,20,197,28,62,222,64,35,25,244,58,144,180,168,215,124,220,166,165,175,132,97,88,90,131,20,58,209,182,162,153,124,82,175,233,247,51,178,172,203,15,191,253,26,31,123,170,198,55,90,114,234,188,200,125,237,
2,34,189,117,148,107,22,231,50,238,62,5,97,224,112,237,218,70,121,191,211,218,144,101,214,31,201,243,60,58,157,54,243,243,11,172,172,172,128,144,4,181,5,180,112,134,200,98,14,34,76,36,146,30,130,10,133,227,183,197,22,68,201,88,40,230,68,217,226,28,114,167,117,27,39,208,62,105,225,22,230,18,142,173,117,72,147,30,29,147,226,251,1,174,235,16,134,1,189,94,143,43,87,174,208,110,183,81,90,35,133,164,222,104,226,5,53,122,157,93,250,187,27,8,61,32,205,82,218,237,98,168,104,29,12,162,40,34,73,6,36,73,82,206,141,250,125,235,8,190,189,189,67,173,86,227,208,82,143,31,123,104,131,63,122,108,149,51,45,103,164,250,232,65,70,112,246,194,45,211,166,8,1,199,143,40,14,175,41,210,52,163,94,175,231,213,199,206,129,194,208,146,76,141,49,196,113,45,191,23,185,56,126,132,112,195,49,196,113,184,202,161,117,238,153,170,135,85,200,84,19,199,140,118,107,34,255,48,181,232,118,111,225,246,71,2,53,227,109,250,189,87,57,115,198,186,86,75,41,136,162,26,113,92,27,89,79,206,50,133,244,4,113,189,129,82,25,219,215,
46,177,117,237,34,190,231,17,199,53,146,196,66,221,59,59,219,184,174,199,252,252,124,41,121,171,181,213,79,72,211,172,116,46,24,12,6,12,122,93,26,141,140,15,61,116,141,63,250,210,26,103,146,161,13,165,115,241,34,168,91,71,124,112,190,145,113,247,169,93,142,30,137,169,199,139,104,109,74,7,138,165,165,165,146,35,88,188,89,104,99,16,194,5,55,34,53,114,18,28,209,88,40,223,140,183,115,133,249,176,40,61,86,39,230,68,0,158,199,237,252,12,238,11,38,130,239,105,14,175,166,44,206,187,72,89,47,197,2,211,44,161,213,202,114,165,25,251,131,198,113,204,242,242,50,245,122,131,157,205,203,168,193,46,205,70,157,52,205,202,129,171,235,186,212,106,49,158,231,50,24,244,217,221,109,229,126,57,1,126,190,116,86,160,87,82,58,164,131,30,65,83,211,8,51,126,252,244,85,254,248,203,107,188,220,146,232,65,74,112,230,181,91,230,249,144,210,112,252,112,155,163,107,59,108,92,235,208,222,13,152,155,155,67,41,77,163,81,47,103,102,182,234,72,64,224,8,105,21,89,141,87,209,114,24,174,113,140,220,251,10,231,238,178,
181,27,38,147,169,162,115,102,200,88,48,190,127,91,191,135,239,139,10,52,215,72,57,113,36,33,12,189,28,122,182,232,155,245,185,113,203,202,19,134,33,11,11,11,86,88,48,233,18,184,6,162,16,128,90,77,228,170,164,1,74,89,175,209,52,77,114,171,19,83,26,84,249,158,71,150,41,192,144,166,50,183,124,76,49,58,195,17,14,245,40,227,67,167,175,242,223,190,188,198,153,151,111,173,234,115,226,200,128,7,223,190,195,218,138,75,173,86,163,209,104,226,186,46,245,186,221,9,42,246,131,236,155,141,64,8,48,194,65,25,111,196,65,92,141,113,4,139,228,81,37,26,87,249,181,0,21,242,213,7,13,35,12,238,209,154,52,187,3,221,148,88,89,204,88,94,84,121,239,110,117,16,138,138,83,72,86,133,97,128,231,249,116,58,93,106,181,26,158,239,227,121,65,190,210,44,25,12,18,132,32,103,44,144,115,229,50,122,189,62,189,94,55,215,142,182,76,238,98,183,168,152,153,232,44,69,103,9,66,4,72,1,113,144,241,119,30,188,202,31,127,246,18,59,183,200,249,174,46,43,78,191,163,149,239,71,217,93,31,215,117,8,2,63,191,27,137,146,210,83,156,
27,194,193,136,192,58,255,41,65,170,198,102,92,83,148,136,84,113,55,50,98,164,2,149,149,168,68,231,242,180,73,210,25,140,125,83,219,18,1,135,86,5,71,14,55,113,156,180,148,105,42,132,66,180,214,180,90,214,182,196,138,102,120,244,122,93,58,157,118,57,235,40,252,80,165,148,4,97,196,238,110,139,126,191,79,179,57,71,24,6,249,16,54,41,33,93,107,149,232,148,173,162,239,111,113,34,104,18,46,212,203,97,97,28,40,126,228,167,143,240,231,31,61,207,238,214,205,173,66,11,115,138,247,62,212,225,225,119,165,96,4,151,46,173,179,188,188,194,78,171,197,226,130,21,20,73,211,140,221,221,22,245,122,157,122,189,142,227,120,224,132,100,56,83,28,207,39,55,116,71,22,10,139,22,110,228,94,52,58,116,45,230,67,66,221,222,226,244,183,253,70,170,231,41,2,111,131,157,157,22,81,20,114,249,242,149,220,89,205,234,31,164,169,29,126,246,122,61,54,55,55,16,66,16,134,33,141,70,35,55,144,106,145,36,3,171,3,231,251,204,205,187,116,186,93,6,185,184,188,148,146,165,165,197,146,197,96,7,172,67,227,41,215,117,1,77,167,181,
65,208,88,67,138,184,28,22,206,47,120,252,192,223,59,201,199,255,235,25,58,219,217,77,75,158,247,61,218,229,244,3,109,28,153,224,251,17,73,146,242,210,75,47,113,236,216,209,220,79,85,162,84,102,239,60,142,117,234,198,241,201,112,135,254,74,170,234,252,55,69,218,171,58,23,202,91,59,93,225,5,90,82,187,168,36,82,62,35,74,83,12,51,20,238,166,69,20,194,157,167,154,172,173,133,104,173,169,215,27,35,107,11,74,101,236,236,236,16,4,33,139,139,75,229,150,165,181,172,79,114,198,113,138,227,164,172,52,154,184,126,136,82,86,72,93,169,44,135,175,237,37,219,222,161,106,116,58,237,156,185,92,203,105,66,3,122,157,22,253,246,6,78,61,66,230,237,158,20,48,55,239,243,221,63,113,39,159,250,147,111,208,219,121,107,103,65,107,203,138,247,61,218,227,145,119,245,105,212,61,92,55,68,41,197,202,202,50,173,221,93,162,168,70,16,132,164,169,189,243,53,26,117,180,129,84,75,28,252,161,89,115,37,121,70,44,52,199,152,23,19,107,28,21,36,78,85,43,80,133,197,45,186,221,217,29,232,102,135,86,169,173,12,142,36,75,83,
172,153,148,75,150,217,207,199,113,61,95,101,80,249,195,98,31,228,193,96,128,235,186,4,129,192,15,66,230,23,150,241,162,38,245,230,2,190,231,150,137,54,72,6,116,58,246,31,186,211,233,226,121,30,81,20,150,213,168,94,183,246,241,170,191,131,12,230,113,228,156,157,180,11,43,249,212,156,247,121,239,7,223,198,23,255,199,203,244,119,190,253,2,236,174,3,167,78,164,188,251,161,62,15,189,83,81,139,138,165,194,172,156,235,212,227,58,95,253,234,179,248,126,192,220,92,131,56,142,17,82,178,184,124,8,227,68,21,241,251,226,254,51,172,60,105,142,196,165,35,42,171,114,207,13,94,149,207,137,138,4,171,178,184,101,107,119,118,7,186,169,201,163,109,3,80,60,236,197,61,7,204,80,101,212,113,105,181,90,244,251,189,92,223,217,183,255,120,142,196,113,28,230,231,231,168,55,231,137,155,139,40,225,227,71,77,250,221,86,174,147,230,148,82,88,74,169,146,230,50,24,36,196,177,213,83,200,178,140,78,167,99,61,72,181,68,54,61,92,217,24,82,86,4,212,231,125,222,245,183,238,230,169,63,127,137,164,245,237,73,34,1,52,
234,138,251,239,30,240,232,131,3,78,157,212,120,46,72,233,231,139,114,148,44,10,235,5,219,167,219,109,211,233,236,178,184,184,196,219,238,185,31,227,4,21,99,48,49,180,173,156,112,58,47,42,81,181,226,136,9,38,70,86,1,21,198,91,56,173,12,238,246,206,109,253,252,221,246,21,72,96,208,185,93,135,227,56,116,187,93,194,48,204,85,71,123,57,28,157,149,211,118,39,55,214,170,215,125,146,100,144,139,168,11,188,32,70,186,33,169,146,196,115,171,120,82,177,187,125,53,135,194,237,32,85,41,149,235,199,13,200,148,149,193,53,198,208,110,119,88,91,91,101,126,126,193,190,179,202,29,50,227,210,17,113,78,229,55,56,18,234,115,33,247,254,141,123,121,225,127,125,141,108,247,205,75,34,33,108,226,28,63,220,231,190,183,245,185,247,109,154,213,21,167,60,33,187,68,40,17,66,162,148,38,8,2,90,187,45,148,178,176,125,163,57,199,234,225,99,4,241,60,153,113,74,211,175,164,234,3,171,69,197,111,118,242,46,52,174,74,84,34,114,21,164,78,153,81,144,65,236,238,90,119,228,219,58,129,110,243,72,82,216,216,204,216,90,220,
204,185,92,246,178,191,188,188,76,24,6,184,174,166,211,237,146,165,41,66,64,28,215,115,143,28,197,194,194,34,81,20,218,228,241,235,164,133,57,177,8,105,245,37,97,88,67,228,90,209,66,72,171,27,23,6,204,207,207,19,69,33,221,110,143,36,73,88,91,91,195,243,252,82,168,62,27,108,226,171,30,145,94,162,203,60,82,212,114,201,39,67,109,46,228,228,15,189,157,51,31,127,30,213,254,214,146,40,240,53,139,243,154,195,171,3,78,157,232,115,199,137,1,135,86,61,130,160,208,122,176,109,104,146,38,184,142,155,123,34,105,182,182,182,112,164,229,251,45,175,172,178,122,248,56,205,133,21,50,227,14,29,243,244,208,146,178,76,148,194,219,168,242,223,35,136,220,20,112,97,124,70,84,128,12,74,11,196,206,206,237,254,248,221,254,32,66,154,26,174,94,83,156,60,170,240,60,147,11,98,116,185,114,229,114,110,20,28,230,72,156,206,119,91,58,212,235,117,180,182,204,131,122,99,14,233,213,208,194,205,31,0,208,194,199,137,87,73,59,41,129,232,161,181,166,223,239,179,180,180,152,39,105,86,234,4,216,215,136,8,2,235,100,29,4,
190,149,201,106,119,232,117,55,89,242,86,129,5,20,115,244,69,140,35,36,181,102,200,161,239,123,39,151,62,249,44,186,115,227,43,14,158,107,168,69,134,70,93,179,178,148,113,120,45,227,212,9,197,226,252,128,40,84,68,145,95,46,193,89,18,173,64,58,146,216,143,75,219,202,193,32,161,94,175,227,251,62,113,125,142,250,220,162,213,1,175,182,109,90,140,182,112,69,53,202,239,61,246,207,43,119,160,202,125,168,250,185,113,21,86,91,161,40,161,109,239,194,27,55,81,158,181,112,111,122,2,9,94,62,211,100,109,69,115,223,61,9,201,160,131,214,42,23,138,87,249,124,199,41,7,160,0,74,105,60,223,195,15,66,164,95,195,72,191,180,101,44,222,57,241,231,72,147,132,172,115,158,172,223,43,209,186,56,174,209,233,116,9,2,159,86,107,135,102,179,89,10,15,58,142,83,242,229,162,40,228,72,24,208,237,237,160,90,231,168,57,11,204,7,107,180,221,152,13,167,78,93,134,204,255,245,59,185,244,217,175,163,58,41,131,212,174,64,11,1,190,175,145,194,210,196,162,80,83,175,105,234,117,195,242,146,161,17,119,169,199,3,142,29,9,137,
66,131,49,182,178,38,73,74,167,147,149,92,54,207,203,240,125,175,212,129,232,116,58,12,6,9,198,192,246,246,14,43,107,71,168,53,151,16,126,45,79,14,145,59,137,87,221,244,170,173,92,197,84,121,252,94,52,181,250,200,9,101,215,42,127,142,118,7,209,218,157,85,160,91,33,46,94,246,249,127,95,104,112,225,210,14,223,241,238,58,97,96,119,126,60,233,228,85,193,43,101,105,29,71,226,122,62,11,141,57,234,115,203,72,175,86,62,32,213,30,95,25,73,230,173,66,160,241,76,21,64,208,204,207,207,51,24,12,136,227,58,74,41,206,159,63,159,207,137,52,113,92,195,247,253,92,184,222,179,58,107,190,97,206,221,102,62,219,196,139,235,244,99,31,77,64,127,21,122,39,4,253,141,1,189,158,41,153,0,82,244,112,28,77,16,8,234,177,67,16,24,2,223,0,41,89,106,87,194,155,141,32,95,185,112,232,118,59,249,250,134,133,222,11,141,107,99,12,221,110,23,207,179,85,49,138,34,82,101,56,121,215,125,52,230,151,193,241,72,178,170,49,114,37,49,212,120,21,146,99,149,73,218,21,246,74,162,141,87,33,85,77,164,170,58,145,17,56,151,46,178,
31,158,189,125,65,38,53,6,46,95,141,184,182,25,112,97,93,241,243,63,223,96,173,145,144,37,61,210,164,143,86,41,81,45,36,194,50,180,107,245,38,65,212,192,72,111,120,81,158,226,40,151,26,143,129,92,37,14,37,142,50,108,109,109,149,210,183,133,115,219,96,48,200,1,134,44,103,125,39,120,158,135,227,184,244,251,61,60,207,195,247,109,21,112,36,120,34,33,240,21,66,244,33,128,44,204,16,139,2,153,43,226,88,80,35,200,191,87,74,191,223,181,140,233,193,0,199,113,115,74,146,135,231,249,72,199,161,209,8,112,28,171,227,214,239,15,200,178,148,94,175,71,173,22,151,126,168,174,235,226,7,33,141,249,101,22,27,11,72,55,180,15,122,54,90,53,70,146,96,10,10,151,42,65,146,229,201,163,71,63,63,130,202,169,73,139,151,17,194,233,32,197,59,247,218,190,88,4,216,87,170,60,74,9,206,156,119,249,79,191,155,240,75,255,226,8,171,71,92,36,10,129,70,10,43,117,97,29,166,157,161,224,97,245,157,183,156,186,87,252,77,69,196,134,62,12,217,128,90,122,14,221,111,209,110,183,25,12,250,249,44,41,41,145,48,33,36,59,59,150,14,
179,186,58,87,218,130,24,163,115,134,119,84,65,198,84,206,169,243,40,137,155,166,224,160,129,209,26,207,115,243,85,116,85,178,43,10,221,130,130,57,237,56,14,181,90,140,116,156,138,243,158,173,100,74,27,130,48,34,174,207,225,71,117,252,176,142,50,146,129,18,35,204,234,116,204,53,111,104,150,76,89,121,202,42,93,25,174,14,207,76,86,206,78,142,122,195,170,73,177,21,121,121,29,145,238,15,67,226,125,105,176,117,241,98,198,175,255,218,69,62,252,75,199,88,93,9,112,114,255,26,33,64,106,32,223,152,172,78,206,171,15,81,58,198,253,74,140,79,18,220,69,91,197,196,142,131,175,47,149,91,171,81,84,43,87,29,10,110,157,235,90,219,143,52,29,222,67,10,8,185,16,53,241,60,183,100,117,203,188,213,148,82,228,243,26,85,146,87,179,44,203,181,9,76,238,32,71,238,46,110,147,182,219,237,230,109,106,64,38,178,124,133,221,37,174,55,17,174,143,235,71,56,94,132,50,146,68,141,74,18,167,83,180,236,170,212,157,84,79,130,10,197,231,147,188,130,165,213,106,163,166,59,240,85,129,5,61,72,241,94,124,137,253,242,220,237,
91,109,236,245,75,41,191,253,235,231,249,217,95,60,201,202,178,143,35,77,201,14,40,86,188,77,65,120,172,104,89,23,118,243,147,237,156,79,234,157,160,39,151,56,58,119,129,99,222,5,146,126,135,52,231,209,89,78,28,229,164,191,240,34,42,86,3,236,34,158,157,121,44,46,46,146,101,25,97,104,91,182,66,236,177,96,66,91,45,130,204,14,123,165,44,63,15,162,124,29,33,4,89,166,8,130,176,76,66,63,136,112,61,31,199,11,145,174,15,210,71,25,145,39,206,164,123,196,132,248,201,148,118,110,228,110,88,86,165,41,237,93,53,201,202,239,193,104,82,25,129,60,119,22,145,236,31,135,134,125,237,145,122,229,114,198,239,255,198,89,126,250,195,167,88,90,246,113,164,93,42,147,130,124,59,223,174,27,235,177,135,40,173,182,49,170,194,1,51,130,129,110,242,108,187,193,189,115,107,220,123,248,34,105,119,11,149,14,44,11,219,113,75,195,46,203,216,150,57,26,152,146,101,214,119,52,138,162,178,245,42,46,250,182,61,147,121,27,170,114,214,131,198,117,157,82,211,206,117,237,114,223,32,73,173,214,157,239,211,108,52,16,210,193,
243,2,164,231,143,46,189,34,0,0,12,48,73,68,65,84,35,164,143,17,14,122,66,32,127,204,93,220,140,37,210,216,125,165,72,150,2,170,30,185,243,140,85,162,84,201,178,189,171,66,218,105,78,239,73,43,159,51,173,54,222,55,190,177,175,158,49,231,200,201,239,251,7,192,209,253,154,68,189,142,230,197,231,91,28,187,103,30,225,123,195,22,45,255,7,30,114,187,228,30,239,168,149,73,124,254,53,137,114,56,223,169,163,153,227,232,74,72,92,31,114,237,180,214,132,185,20,110,209,174,217,93,35,91,61,250,253,62,113,28,147,36,73,169,61,80,80,144,10,213,159,52,77,9,195,160,164,32,21,9,100,114,16,36,140,98,252,32,194,11,234,120,81,3,225,214,48,50,176,236,105,237,148,15,246,16,57,147,22,130,46,126,22,37,243,4,25,7,9,100,229,163,24,164,90,180,109,188,202,140,160,115,123,254,94,150,237,94,150,129,251,244,19,57,121,116,255,220,22,92,246,191,203,61,91,87,82,254,244,63,191,194,143,252,236,221,204,47,5,184,162,168,68,166,180,232,211,80,178,134,139,246,163,120,0,170,239,190,213,150,228,177,75,117,122,153,203,35,
39,90,196,81,70,28,103,196,186,15,42,33,233,119,16,25,100,153,85,63,21,130,220,253,90,211,235,245,113,93,135,126,223,138,185,247,251,131,220,106,222,203,91,49,23,33,93,28,199,101,113,121,13,165,13,82,186,248,129,196,113,125,132,227,33,164,139,65,146,86,216,205,170,162,207,54,194,0,40,166,255,197,10,182,26,86,161,201,118,117,82,24,114,226,30,84,32,114,19,73,37,39,86,31,210,28,202,150,231,94,69,110,236,63,155,199,125,123,7,26,143,157,107,9,127,246,145,23,249,193,191,127,31,243,139,225,40,176,80,189,19,229,15,218,248,125,96,42,77,69,9,190,116,161,70,55,113,120,248,100,139,216,119,9,220,0,223,211,120,254,2,126,83,33,141,66,74,192,40,132,49,168,44,1,33,40,212,210,164,148,120,181,92,232,62,223,168,181,12,2,23,33,37,82,72,28,172,62,193,80,200,93,160,178,252,215,114,101,160,208,101,163,92,169,46,52,10,70,168,52,122,52,121,74,113,252,235,201,18,171,41,213,184,0,19,178,33,240,146,140,37,83,241,255,153,157,22,222,215,94,96,95,90,233,24,115,48,18,8,96,119,35,225,227,127,248,53,190,251,167,
222,206,220,66,184,39,176,160,205,232,206,255,36,43,121,8,115,43,157,39,81,42,121,248,68,139,216,215,4,174,198,115,12,174,116,113,165,65,26,107,125,40,37,8,127,248,90,66,228,59,49,222,176,10,142,152,85,105,202,245,103,93,249,187,21,235,208,101,229,169,50,156,43,9,53,89,125,24,17,2,153,6,44,40,51,102,8,54,182,15,148,170,209,57,81,54,94,137,178,226,247,246,222,163,250,41,222,227,143,97,148,218,151,207,148,203,1,139,206,86,194,167,254,248,57,222,251,19,15,208,92,8,113,36,101,34,85,129,133,226,93,59,43,56,96,197,125,98,98,210,110,31,184,47,190,86,163,151,72,30,202,147,40,116,53,158,107,221,8,28,81,188,70,14,63,67,57,151,18,98,250,96,184,200,161,170,137,149,85,182,169,38,84,117,187,147,178,117,211,102,216,142,86,185,103,186,162,164,51,14,44,168,241,170,164,39,53,16,70,24,11,101,34,201,9,180,174,172,86,25,184,207,62,133,200,101,131,247,105,2,153,131,150,67,244,182,19,190,240,177,175,242,208,135,30,164,190,16,86,30,112,70,43,81,105,93,63,254,0,13,209,185,234,3,246,249,188,157,123,232,
100,139,216,87,4,174,193,119,180,77,34,105,29,172,237,107,140,190,214,148,28,26,249,87,25,106,76,87,170,143,169,38,208,216,186,116,165,157,83,227,237,220,88,21,26,73,28,51,116,23,159,156,227,144,195,216,197,25,80,178,181,39,129,5,65,154,129,243,252,51,200,245,245,125,253,44,237,203,65,234,141,196,96,103,192,147,255,253,105,238,251,209,211,212,230,34,219,106,21,91,164,249,19,93,60,152,217,148,118,110,47,17,249,207,95,168,177,123,238,60,167,223,61,79,61,52,132,174,198,119,134,46,109,213,215,144,194,178,14,174,87,137,70,147,104,88,105,172,141,200,80,107,77,155,189,219,57,85,217,6,45,132,62,204,20,27,203,137,54,110,28,230,86,147,213,40,157,194,228,72,181,64,190,244,2,206,153,51,251,254,57,58,144,21,168,136,164,213,231,133,255,249,4,119,252,205,71,137,230,162,74,59,103,202,170,96,152,28,62,142,243,195,170,247,33,179,189,197,11,159,251,26,189,205,53,78,127,223,93,196,129,36,200,147,200,117,38,219,57,73,238,159,179,71,41,26,73,162,137,42,52,250,223,35,247,159,106,18,85,228,118,11,169,
169,241,221,156,108,228,30,196,196,32,89,141,189,89,164,5,19,161,152,25,21,109,174,2,241,141,151,113,94,122,241,64,60,67,238,1,206,31,0,210,157,1,223,248,139,175,112,248,175,189,135,176,89,43,31,238,137,118,206,76,210,126,210,108,140,246,163,192,121,254,171,160,13,103,190,184,78,170,4,239,248,158,187,169,135,154,192,53,120,121,21,42,16,192,145,118,46,175,66,123,181,115,85,89,220,106,34,13,189,120,70,219,55,61,118,63,26,71,231,212,148,118,110,2,157,211,123,65,221,123,208,126,50,131,243,245,231,112,94,126,229,192,60,63,7,186,2,21,161,118,251,92,252,223,143,49,255,253,223,65,144,39,145,35,152,172,68,85,116,174,74,241,207,63,196,107,231,144,27,67,247,237,11,95,190,72,170,4,119,191,255,158,178,157,179,232,156,153,64,0,171,149,104,106,59,55,158,68,121,11,87,200,228,234,234,127,155,33,77,169,218,206,141,206,136,166,163,115,85,147,228,105,180,159,116,143,86,78,245,19,220,167,190,130,188,114,229,64,61,59,7,246,14,52,30,122,183,199,214,95,126,129,224,123,190,11,191,17,79,84,9,24,206,93,
212,20,218,143,217,217,197,123,230,169,9,146,228,149,199,95,35,205,4,119,124,215,189,196,129,28,75,162,33,120,33,25,18,68,167,85,33,193,152,28,110,69,156,80,87,144,186,17,116,174,132,185,43,85,105,60,105,42,38,89,89,69,53,103,156,246,147,237,33,38,146,105,105,231,60,95,254,60,162,211,61,112,207,205,172,2,85,223,229,59,61,250,255,247,179,244,191,243,125,56,243,115,35,151,254,241,118,110,100,65,172,211,195,123,236,115,123,234,96,111,61,125,142,84,193,209,239,120,59,113,144,183,115,142,109,233,246,106,231,216,163,18,49,81,137,134,237,155,169,0,10,229,189,72,79,3,24,170,173,91,229,142,84,12,145,171,201,51,174,123,96,134,107,10,89,170,112,206,190,132,251,194,11,160,213,129,124,102,220,89,218,140,99,220,125,248,212,167,72,143,29,37,57,122,28,230,22,144,97,176,7,176,0,92,190,132,247,244,227,136,193,245,247,91,218,207,158,227,172,18,172,188,251,29,196,129,33,240,70,219,57,167,130,206,137,55,208,206,21,149,81,79,105,231,38,134,171,35,32,131,40,89,10,122,26,237,231,58,192,130,210,2,179,
113,13,239,153,39,172,178,206,1,142,89,5,154,218,207,41,228,185,115,112,238,28,8,129,169,213,80,139,139,152,185,5,76,189,97,159,234,78,7,247,220,171,136,237,237,27,254,182,253,23,206,112,49,51,204,61,252,78,234,145,91,97,44,152,9,4,176,160,24,9,204,117,208,57,49,90,137,42,45,220,208,25,110,180,10,77,75,164,17,81,248,220,85,33,27,155,17,21,240,182,238,118,113,95,124,30,121,246,204,236,57,153,161,112,55,210,215,25,68,187,131,104,119,128,111,221,231,84,189,120,150,205,118,159,238,123,30,33,142,93,66,111,20,157,179,106,166,195,228,17,175,51,39,50,99,85,169,10,115,151,128,2,21,57,221,234,124,168,194,94,24,229,206,13,239,72,101,197,217,221,69,190,242,53,252,215,206,219,76,155,197,172,2,221,180,184,184,78,255,227,255,135,193,163,143,16,28,94,157,64,231,190,217,118,238,122,232,156,30,103,45,232,81,116,110,148,238,51,252,28,219,91,56,175,190,132,60,127,142,25,224,52,67,225,110,157,232,118,49,159,254,12,189,227,199,232,223,247,118,188,249,38,158,212,184,142,165,252,140,195,220,101,37,154,
242,134,103,170,159,29,163,250,76,107,235,212,88,27,87,165,253,104,45,48,221,14,226,202,37,220,87,94,58,240,119,156,27,169,64,235,179,99,184,121,33,206,159,135,243,231,25,28,61,202,224,212,93,136,229,85,92,87,78,86,162,74,21,122,189,97,235,245,128,133,189,104,63,116,58,136,205,171,200,215,206,34,47,207,30,137,27,140,117,23,184,56,59,135,155,31,242,194,5,184,112,1,60,143,244,142,83,36,75,43,176,176,136,8,67,123,39,42,129,5,155,37,55,70,64,157,82,129,0,163,129,110,7,177,189,137,216,188,138,123,233,226,126,219,20,125,203,154,113,23,99,94,153,157,195,45,20,73,130,124,241,235,192,215,109,34,68,17,122,101,5,213,152,131,90,140,169,197,152,176,6,142,131,112,221,137,139,145,49,64,110,223,130,54,208,235,32,250,93,68,123,23,122,93,156,157,109,139,28,42,53,59,235,111,61,94,113,13,230,133,217,57,220,194,209,235,34,206,157,157,90,113,94,119,210,186,71,204,110,189,111,90,188,224,98,120,46,63,83,49,59,143,219,44,102,0,208,205,12,13,60,231,74,193,89,109,204,37,224,200,236,76,102,49,139,27,7,16,
164,16,103,229,87,30,251,85,13,124,110,118,30,179,152,197,27,138,207,125,229,177,95,213,185,156,166,254,36,240,227,179,51,153,197,44,110,56,62,9,148,178,104,159,0,102,176,204,44,102,113,99,161,242,156,25,2,7,15,63,242,207,31,3,222,61,59,155,89,204,226,117,227,203,79,60,254,239,222,83,173,64,0,127,50,59,151,89,204,226,134,162,204,149,202,62,144,249,24,240,111,129,96,118,62,179,152,197,158,49,0,62,86,252,166,240,66,231,210,165,47,238,30,62,252,29,167,129,251,103,103,52,139,89,236,25,127,246,196,19,255,254,35,83,42,16,128,249,13,224,131,204,134,170,179,152,197,180,48,192,111,86,63,81,189,3,225,56,226,211,192,231,103,231,52,139,89,76,141,207,231,57,194,68,11,7,112,241,226,23,57,124,232,189,23,128,159,154,85,161,89,204,98,162,250,252,195,199,31,255,15,47,87,63,57,33,42,34,165,248,132,214,250,147,192,15,204,206,108,22,179,40,227,147,82,202,79,140,127,114,106,149,121,248,161,95,124,8,120,12,240,102,231,54,139,89,144,2,239,126,226,169,223,124,122,252,15,156,105,95,125,105,253,177,245,
195,135,222,179,12,188,119,118,118,179,152,5,191,245,196,83,255,241,163,211,254,224,58,186,112,230,95,3,63,12,220,53,59,191,89,28,224,120,5,248,87,123,253,225,117,129,130,135,31,252,167,223,107,48,127,201,76,128,113,22,7,51,50,129,248,193,39,158,254,173,79,237,245,5,206,245,254,239,75,151,191,124,230,240,161,119,75,224,123,103,103,57,139,3,24,191,252,228,211,191,253,135,215,251,130,215,173,44,2,126,197,24,243,40,240,35,179,243,156,197,1,138,191,16,66,252,202,13,228,199,235,199,233,119,253,227,5,224,211,192,59,103,231,58,139,3,16,207,2,223,253,228,51,255,105,235,77,73,32,155,68,31,62,9,124,6,56,62,59,223,89,236,227,56,15,124,224,201,103,126,231,236,141,124,241,27,98,27,156,126,215,135,239,193,152,207,2,43,179,115,158,197,62,140,171,8,241,254,39,159,249,157,27,246,167,124,195,116,157,211,15,252,163,123,192,252,213,172,18,205,98,255,85,30,241,3,79,126,245,119,223,144,185,171,124,163,175,146,191,192,7,242,62,113,22,179,216,47,119,158,15,188,209,228,129,215,129,177,247,138,245,43,
143,239,28,94,125,248,99,192,59,128,123,102,231,63,139,219,56,254,2,248,219,79,62,251,123,223,148,32,184,243,205,190,234,250,149,39,250,71,214,30,249,83,64,131,121,255,55,83,205,102,49,139,155,24,25,136,95,22,130,127,242,228,179,191,247,77,11,131,191,41,43,11,167,223,249,11,223,139,225,247,153,209,126,102,113,123,196,43,8,126,225,201,103,127,255,83,223,234,55,114,222,140,191,205,250,149,39,206,28,94,61,253,95,128,24,120,248,205,250,190,179,152,197,155,28,41,240,91,192,79,62,249,220,71,94,124,51,190,225,155,190,52,119,250,29,63,247,32,240,107,204,246,137,102,113,107,197,95,1,255,242,201,231,254,224,233,55,243,155,126,91,182,78,31,121,224,231,133,86,230,7,129,127,3,230,125,204,182,91,103,113,115,194,128,248,60,240,203,210,17,127,249,248,87,63,242,166,171,241,127,91,31,236,71,31,248,57,161,148,249,0,240,207,176,92,186,153,100,214,44,222,138,24,96,209,181,223,112,92,241,153,175,60,243,7,223,54,27,139,183,172,50,156,190,255,103,142,2,127,23,248,73,224,17,102,168,221,44,222,220,80,
192,19,88,209,195,143,61,249,194,71,47,188,21,47,122,83,90,171,211,247,255,204,41,224,135,128,239,7,190,11,56,60,107,243,102,241,198,219,51,46,97,157,69,62,9,124,226,201,23,62,250,234,91,253,151,184,233,15,237,35,239,248,25,169,181,57,129,101,122,223,143,133,194,143,0,135,102,207,200,44,42,177,142,245,243,125,5,120,30,120,78,74,113,238,241,231,62,170,111,230,95,234,255,3,200,180,128,162,63,242,187,252,0,0,0,0,73,69,78,68,174,66,96,130);


//additional icons (B..D) are optional -----------------------------------------
//Note: Supported image format: tea
//Note: Each icon, if specified, must be 32w x 32h.  The icons form an animation of upto 10 cells in total.
//      When triggered, the app icon - (top-left) of window - will animate and cycle through each of the cells
//      in a continuos loop for a short time period of about 2 seconds.
//How To Use:
//      Use rootwin.xhead.aniAdd(xtep,xms) to add upto 10 cells, and rootwin.xhead.aniPlay to
//      trigger animation playback for ~2 seconds.  To extend playback, call rootwin.xhead.aniPlay
//      regularly.
//
//Example:
//to setup the animation ready for playback:
//      rootwin.xhead.aniAdd(program_icon32hB,100);
//      rootwin.xhead.aniAdd(program_icon32hC,250);
//      rootwin.xhead.aniAdd(program_icon32hD,200);
//
//to play the animation call:
//      rootwin.xhead.aniPlay;
//
//to clear the animation (e.g. to create a new animation) call:
//      rootwin.xhead.aniClear;
//
//Note: the examples above must be executed within "tprogram" for access to rootwin, see
//      the unit marked "main" for tprogram.

//accessed via "tepIcon32B"
program_icon32hB
:array[0..0] of byte=(0);


//accessed via "tepIcon32C"
program_icon32hC
:array[0..0] of byte=(0);

//accessed via "tepIcon32D"
program_icon32hD
:array[0..0] of byte=(0);


//help viewer banner images - optional -----------------------------------------
//.banner 1
programbanner
:array[0..0] of byte=(0);//disabled

//.banner 2
programbanner2
:array[0..0] of byte=(0);//disabled


//app help document(s) - optional ----------------------------------------------
//note: these help documents, if specified, are processed and merged into one large
//      document at runtime by the built-in help viewer, which supports documents in
//      the following 3 formats:
//
//      1. txt - plain text
//      2. bwd - enhanced text (Blaiz Enterprises format)
//      3. bwp - advanced text (Blaiz Enterprises format)
//
//      These documents can be compressed (using zip) or left uncompressed.


//app help - app specific help document, which appears above system help
apphelp
:array[0..0] of byte=(0);


//system help - information relating to the app's system settings and general behaviour
syshelp
:array[0..12716] of byte=(
120,1,236,157,235,114,27,87,150,165,171,38,230,23,35,250,29,50,24,209,97,169,155,212,133,146,108,151,34,186,43,40,138,178,56,37,137,10,146,178,218,83,83,63,146,64,130,68,9,64,162,112,17,197,122,140,121,159,121,183,249,214,218,231,100,38,32,202,150,123,106,58,44,27,14,87,73,0,50,207,217,103,95,215,190,100,250,201,219,167,247,127,199,63,195,201,160,254,223,252,57,42,39,253,121,175,156,86,143,139,123,255,180,53,191,158,47,170,241,188,119,89,141,227,139,171,89,57,157,47,174,71,124,186,255,79,91,131,122,178,152,148,250,233,160,94,206,134,213,172,120,85,93,197,215,243,225,223,117,205,94,124,234,213,163,122,230,21,117,139,63,237,61,46,246,30,61,74,23,199,138,108,120,126,145,46,189,255,245,55,223,60,122,184,151,238,23,133,139,234,195,226,255,140,126,247,187,63,47,254,114,112,89,78,46,170,98,113,89,21,190,124,56,185,40,234,129,63,151,211,233,87,243,226,187,55,71,91,207,102,245,216,95,45,234,105,177,168,235,209,121,57,43,122,163,97,239,93,81,79,138,237,63,47,170,233,227,122,186,24,214,
147,249,222,189,191,20,199,241,215,237,162,206,87,105,121,150,43,198,213,100,153,174,135,75,127,217,46,110,105,197,217,240,226,114,161,93,175,134,147,126,125,117,187,248,247,98,59,175,113,167,40,246,217,34,127,76,151,240,199,104,84,244,135,243,233,168,188,230,146,211,106,84,245,22,38,49,168,9,190,64,203,129,216,181,93,44,202,115,8,47,230,151,245,85,81,22,163,225,220,251,249,170,34,100,50,191,179,181,117,6,153,219,190,163,56,181,160,230,219,113,237,112,94,176,213,112,81,12,39,172,178,184,156,85,85,49,45,103,139,249,227,173,251,119,138,39,203,225,104,177,123,52,9,14,230,245,138,171,203,97,239,178,40,103,85,177,156,87,253,162,156,23,195,249,214,222,157,226,96,57,95,192,207,149,205,89,179,92,20,189,114,82,156,195,169,254,95,185,68,183,76,248,31,247,79,150,227,243,106,198,23,247,181,119,189,188,184,44,238,223,219,122,112,7,214,244,139,211,242,61,191,172,172,182,147,247,30,205,235,245,69,125,74,214,212,186,223,222,251,215,226,220,196,15,215,136,111,121,90,79,208,142,186,120,63,172,
174,138,225,130,239,207,102,215,197,246,147,81,217,123,183,93,12,144,240,112,50,95,148,147,94,197,79,111,203,133,78,60,183,32,26,245,145,228,71,195,42,190,13,58,123,214,58,24,50,41,102,85,57,90,12,199,21,236,223,47,88,118,248,247,226,112,178,168,102,211,217,112,94,205,191,90,57,88,113,235,95,238,156,247,230,183,97,36,223,143,125,73,223,234,122,85,77,22,215,113,173,246,129,151,58,223,172,154,79,209,201,225,249,168,50,169,222,92,26,94,189,175,56,69,57,159,74,107,214,213,93,103,188,170,125,131,244,118,48,195,44,119,138,201,16,70,248,188,227,105,61,227,196,222,162,204,123,246,202,209,8,49,156,13,23,236,229,125,230,59,150,159,239,27,215,80,163,155,161,122,140,201,252,29,174,242,123,186,233,148,213,250,229,44,9,81,138,120,88,194,199,27,37,83,92,74,143,22,24,102,125,53,41,150,147,225,223,150,85,49,175,90,117,158,67,254,126,209,251,88,199,10,40,172,175,58,82,224,175,181,212,45,132,209,215,177,209,22,228,177,64,59,110,90,97,7,213,158,213,50,60,237,189,168,175,68,179,88,84,161,134,137,
139,54,45,219,136,200,234,201,39,20,11,49,165,143,101,153,168,109,54,122,142,54,23,215,245,242,43,22,27,96,244,168,243,77,27,22,243,81,189,208,129,204,15,105,98,178,144,56,30,10,34,170,147,241,151,190,90,159,203,107,255,181,192,52,97,197,188,194,157,194,174,65,136,5,187,29,85,139,5,223,116,125,136,252,152,78,98,87,196,109,7,201,185,89,247,123,151,117,61,23,79,38,216,128,101,203,21,199,51,228,231,171,100,165,151,245,8,86,212,69,127,86,94,232,96,72,122,57,155,215,179,187,156,238,2,103,94,98,181,92,166,45,224,97,85,77,194,182,123,127,91,14,225,68,103,229,117,147,128,65,217,88,164,209,115,27,123,185,196,129,148,139,161,244,231,26,117,217,194,145,127,55,124,111,150,206,90,42,147,39,210,242,168,240,22,210,189,104,46,10,59,12,215,151,46,64,173,138,49,34,146,78,196,62,58,208,112,254,142,211,54,17,224,64,254,52,123,199,112,142,183,146,115,198,109,251,215,219,232,73,235,143,87,54,194,222,209,215,185,181,66,108,11,6,134,203,86,108,80,244,120,169,24,241,239,133,131,138,200,208,119,242,113,
197,254,252,206,157,59,210,158,179,235,169,121,198,161,204,198,88,69,188,221,214,133,219,88,206,98,81,79,184,242,7,75,194,36,167,163,90,232,28,80,122,138,78,34,20,164,211,220,218,223,110,148,54,233,243,199,231,77,252,126,78,36,129,63,184,246,144,183,88,188,234,134,219,176,249,241,34,197,71,76,91,181,45,206,98,75,90,78,22,195,145,54,144,159,196,39,88,129,146,89,197,142,62,114,191,107,84,179,36,189,21,206,175,158,27,214,36,171,65,230,156,66,30,58,43,210,1,65,232,168,168,250,210,6,12,201,10,183,182,212,226,178,94,46,240,68,239,229,75,185,125,86,237,234,58,20,232,143,91,63,84,50,216,180,122,88,66,151,255,131,12,37,18,221,63,205,239,27,88,37,213,49,129,98,135,105,195,190,59,6,172,16,52,171,108,91,114,16,251,19,124,61,183,96,45,43,198,180,98,70,171,42,223,93,97,167,168,70,195,241,112,130,193,233,184,108,57,169,16,53,231,174,62,16,216,122,120,183,224,211,170,102,200,41,151,197,57,113,242,34,140,127,56,46,47,176,194,75,249,62,217,242,195,71,157,232,187,126,221,220,20,87,131,1,194,38,
82,204,64,105,218,221,236,35,222,98,251,150,219,132,69,209,99,14,121,6,186,185,113,199,108,140,25,67,97,91,79,26,162,164,55,141,109,103,88,212,161,37,97,163,188,6,46,88,91,193,2,161,185,229,180,207,230,235,81,252,180,198,44,111,88,2,117,1,52,205,234,105,53,91,200,33,7,60,234,87,120,200,10,255,137,53,93,86,200,105,58,173,0,151,73,154,173,175,188,139,215,185,82,92,199,169,58,216,149,62,186,194,75,98,82,220,223,98,194,226,89,7,156,224,146,68,150,67,96,142,236,67,12,101,49,171,38,23,139,75,92,185,148,20,14,115,225,84,210,181,190,52,91,212,129,104,197,242,14,62,147,106,117,84,106,86,13,140,66,87,64,77,97,231,44,103,209,175,49,171,240,229,86,34,227,10,40,32,3,96,83,48,190,247,156,3,43,223,1,33,50,101,119,227,116,127,52,54,141,91,56,178,220,26,156,154,203,6,185,175,24,213,232,198,37,46,173,6,214,216,83,72,89,36,4,145,44,149,29,41,170,223,255,195,31,238,161,76,87,86,65,179,123,48,156,225,240,203,126,61,155,112,104,45,251,172,156,47,14,8,236,161,128,175,235,171,106,22,31,111,225,182,57,
109,203,24,110,32,92,40,8,17,150,185,225,54,250,143,106,92,35,100,180,114,54,148,85,84,51,209,199,90,16,48,35,207,168,202,249,245,238,162,222,189,152,13,167,50,130,210,194,0,167,13,255,158,141,75,154,197,101,220,46,254,218,108,65,177,101,31,153,112,152,37,78,16,215,220,175,122,245,12,43,192,203,11,55,6,99,18,56,24,151,253,138,224,46,199,142,6,76,202,217,76,135,16,21,242,163,115,160,251,192,64,150,188,34,228,202,1,176,175,126,61,22,160,64,254,33,129,96,188,17,71,41,28,221,17,252,78,49,46,223,137,94,124,228,57,145,63,118,154,47,207,193,57,192,2,118,5,96,10,218,142,107,187,72,46,3,159,18,233,97,137,80,32,80,229,178,156,97,8,232,221,168,42,39,162,206,122,111,28,189,181,245,10,207,122,33,129,33,188,142,217,62,19,18,109,60,125,155,198,52,64,177,163,82,176,28,23,51,133,179,236,156,28,68,131,215,206,107,226,227,216,87,44,64,186,243,145,152,53,15,210,156,123,100,89,120,65,176,230,26,79,164,3,210,216,143,121,111,73,194,68,8,47,241,186,86,107,251,172,123,211,15,197,173,9,168,90,103,184,
173,223,191,217,211,87,211,225,135,106,100,213,17,136,217,207,192,6,132,44,2,181,15,250,37,114,150,83,67,76,50,87,127,109,103,58,223,34,88,125,133,79,64,166,82,114,229,181,197,85,53,26,253,177,40,94,213,114,54,32,255,49,2,9,115,177,44,131,194,246,114,40,113,148,74,241,2,20,98,196,121,60,11,18,16,29,59,175,70,10,12,240,225,159,76,197,183,127,42,128,243,67,204,46,204,229,236,123,161,247,79,137,143,124,125,123,107,235,57,217,46,170,49,175,71,75,227,160,188,0,78,64,202,141,154,182,139,39,111,150,236,124,128,99,116,38,17,76,43,110,217,105,193,237,62,40,249,118,129,62,129,30,101,31,147,12,50,201,132,38,82,130,247,195,122,57,47,46,42,52,205,70,99,56,156,55,198,204,14,200,146,136,151,156,125,116,173,180,197,238,253,106,24,113,62,75,160,60,31,146,2,203,117,203,208,146,163,166,26,80,204,199,138,172,236,138,12,128,67,157,117,207,240,216,168,207,121,213,43,5,148,56,155,32,116,190,192,44,132,101,197,69,137,207,84,78,86,92,56,253,152,117,248,131,191,138,120,199,30,161,80,56,2,185,190,249,37,
254,250,157,240,178,85,81,97,137,180,144,127,175,46,9,35,108,130,78,199,65,50,168,45,149,7,34,111,29,136,164,92,165,12,12,89,41,171,148,167,21,9,34,60,150,198,172,42,227,96,57,137,116,166,95,195,130,5,155,65,89,171,156,90,66,174,139,51,54,208,67,174,73,121,42,206,112,46,175,173,20,196,249,95,226,64,103,79,42,9,123,127,42,254,13,23,189,119,239,170,248,64,66,244,237,189,75,62,23,123,59,247,190,121,176,243,245,189,123,69,72,125,11,237,248,183,226,193,183,15,125,217,222,253,175,227,178,111,119,246,254,240,112,231,97,123,25,170,249,111,197,55,95,127,235,203,30,62,216,243,101,15,30,236,220,255,230,155,238,106,80,200,130,183,150,163,197,172,36,130,160,154,142,200,200,185,158,220,206,146,18,202,149,123,128,41,74,213,231,197,173,135,31,244,163,60,140,237,23,118,160,18,78,75,57,197,173,193,18,125,248,104,177,30,41,144,18,123,234,38,242,236,93,177,218,131,221,168,116,87,245,146,204,42,201,26,121,61,186,247,207,226,163,183,146,220,187,174,184,63,28,12,134,61,142,34,193,66,178,227,7,62,222,
74,143,11,137,18,28,34,87,165,192,180,88,140,197,57,122,149,4,25,230,78,84,227,114,31,205,94,128,79,59,74,42,226,242,5,233,110,228,206,35,49,36,228,46,87,24,218,134,160,225,69,235,25,138,116,132,37,88,110,22,0,206,209,33,171,122,156,13,104,184,147,243,106,180,247,111,75,184,196,229,183,246,30,253,243,237,230,192,32,20,80,32,225,170,171,241,82,58,107,244,92,42,157,141,246,28,218,132,103,164,203,16,84,32,150,172,116,80,140,224,48,20,220,113,70,178,97,18,29,29,54,131,211,103,44,88,224,151,72,158,246,245,138,168,77,103,69,11,111,206,238,212,205,204,156,50,252,231,160,236,225,29,117,130,189,123,136,238,214,222,7,210,195,229,52,243,219,30,91,110,62,252,185,61,130,118,29,203,35,68,57,144,221,251,40,29,101,28,113,182,71,220,239,115,174,240,83,253,2,141,103,85,169,227,58,223,145,254,25,43,169,54,129,105,75,43,56,114,56,46,169,43,97,196,33,87,149,36,214,38,27,164,162,83,203,7,73,141,224,16,31,243,249,90,215,160,220,230,7,80,132,60,160,46,158,17,57,67,5,214,156,5,85,148,37,92,118,4,51,44,
119,64,171,7,20,114,161,120,199,220,216,41,30,136,122,216,163,83,40,112,212,139,234,241,214,41,229,9,233,159,248,224,187,222,151,35,138,60,232,116,247,114,159,183,43,86,169,53,84,11,140,36,185,129,121,19,236,194,41,217,215,189,83,142,70,210,187,156,203,23,114,150,35,149,122,225,203,165,152,49,193,163,9,34,233,112,66,14,242,114,228,212,207,246,182,139,119,130,230,138,188,215,114,0,90,140,223,17,108,58,188,43,197,56,142,18,54,43,2,42,150,31,180,149,101,75,89,186,131,107,32,8,90,141,110,235,156,40,102,243,69,152,198,215,90,123,239,33,164,253,88,20,77,124,53,220,6,76,9,138,132,180,37,19,5,35,111,134,210,121,231,20,69,9,148,40,85,230,77,170,170,136,7,68,16,37,7,170,6,14,49,174,92,208,140,227,203,188,196,218,180,136,192,18,213,106,66,145,1,173,33,166,227,159,216,46,248,193,22,61,50,28,233,111,94,80,56,23,214,54,14,4,126,219,222,250,113,100,81,68,181,200,26,103,186,201,227,164,0,240,241,84,60,163,54,198,29,137,187,161,37,78,101,117,109,192,188,249,114,170,154,36,7,196,149,233,248,98,
170,84,21,67,125,115,142,167,91,26,219,229,131,17,225,147,94,116,152,143,22,238,207,116,124,73,63,194,181,207,131,56,194,80,0,86,67,234,125,92,215,176,160,30,12,196,191,164,67,117,79,53,175,157,98,225,28,164,191,236,101,37,110,119,1,193,151,125,3,100,138,190,132,103,123,21,231,9,33,202,73,13,51,112,146,82,18,149,55,62,86,165,230,39,161,254,124,25,204,97,53,82,116,248,177,146,36,34,228,25,14,72,224,54,29,2,47,33,126,183,137,165,4,22,247,40,19,227,56,63,166,119,208,115,108,184,175,173,231,148,104,48,168,237,83,119,118,232,49,216,248,2,252,170,132,102,84,148,252,26,92,59,31,46,198,116,124,56,125,42,36,187,160,211,80,24,213,98,175,209,199,51,59,134,133,87,198,171,75,153,164,10,66,91,194,183,144,121,6,142,81,242,55,38,201,152,1,218,116,75,214,124,184,32,23,111,3,149,210,207,179,151,18,217,220,91,188,85,8,192,41,36,144,20,167,209,222,178,62,33,53,96,17,141,42,196,67,92,44,222,83,131,16,194,229,55,234,155,106,160,180,53,85,18,153,105,56,124,18,27,154,26,45,195,87,56,45,130,13,14,99,
171,230,96,62,12,122,30,245,194,228,13,36,249,214,52,248,73,201,84,66,78,186,223,170,33,245,14,133,149,91,47,46,234,154,234,219,101,61,236,17,71,57,25,110,142,239,149,5,74,189,186,246,49,174,213,252,89,3,5,136,197,187,112,167,80,182,51,103,254,254,214,13,169,121,241,135,71,72,30,61,239,18,40,43,54,217,21,26,157,161,251,246,211,234,175,229,247,75,10,150,19,122,71,14,108,2,192,18,206,10,17,210,193,117,26,138,91,237,118,58,2,118,88,125,40,199,211,145,242,165,75,149,140,201,22,93,136,158,146,217,124,64,179,200,16,161,2,121,89,200,139,170,236,67,230,235,106,134,76,34,217,77,229,1,59,34,160,81,199,98,208,40,236,197,133,35,45,221,41,161,166,42,125,202,141,209,214,158,253,125,196,118,241,181,158,132,174,198,61,124,81,26,191,163,29,169,189,246,76,50,10,222,40,102,71,24,71,92,7,81,71,119,186,213,200,177,21,180,203,79,156,236,61,66,139,2,76,135,170,227,63,53,101,93,212,133,250,35,168,208,169,52,89,166,84,57,105,155,188,53,217,134,220,249,114,194,247,125,99,126,172,15,189,180,114,235,187,
162,28,8,91,185,172,47,31,21,229,247,150,162,93,157,82,110,48,162,162,49,21,23,157,115,167,46,146,251,100,235,106,120,49,193,141,78,46,150,96,183,244,3,27,97,28,215,99,138,2,170,72,162,122,94,53,252,4,210,189,16,116,65,49,118,67,160,243,33,210,85,189,228,163,88,11,51,127,50,192,118,113,130,183,25,0,58,228,62,101,48,35,43,159,191,110,164,79,207,10,7,63,164,182,50,185,216,122,6,173,227,18,45,90,170,21,73,142,178,24,58,191,195,149,168,38,160,175,232,147,216,122,42,32,187,116,173,123,127,2,211,17,127,42,174,173,175,195,243,37,8,2,139,18,53,157,214,71,213,135,83,57,42,183,174,2,243,169,145,8,157,50,131,30,234,114,254,40,153,205,201,102,151,11,10,0,220,55,41,94,28,60,77,158,251,167,210,108,236,128,238,207,51,41,226,179,160,67,103,118,134,24,53,31,131,193,220,115,138,244,195,225,46,81,109,82,170,222,101,244,215,4,23,177,98,186,109,192,139,185,19,81,20,141,158,166,85,138,106,10,205,58,123,119,139,155,244,200,53,161,219,22,65,118,158,18,5,191,144,255,86,179,219,24,195,145,2,145,92,20,
216,66,54,20,205,57,171,52,232,95,173,117,121,143,62,69,35,53,182,133,44,58,164,133,132,81,18,197,25,96,20,214,140,98,187,143,106,109,85,121,94,46,198,240,62,214,180,64,113,231,66,9,18,61,72,109,184,11,234,37,121,168,22,132,24,12,175,135,26,138,50,81,3,116,188,170,103,239,92,87,87,111,107,221,89,41,208,170,189,125,137,81,144,71,36,231,38,187,224,52,142,240,200,43,206,108,176,221,175,85,168,73,254,40,157,228,166,203,168,15,219,199,12,112,182,56,17,197,80,52,218,80,71,46,24,210,82,51,89,222,81,113,33,39,58,169,12,76,81,171,233,180,101,117,139,206,137,88,216,232,92,151,99,10,36,206,86,181,81,194,222,169,84,34,124,165,82,44,229,85,126,140,138,160,29,153,135,38,20,149,83,1,25,92,243,142,139,83,205,112,56,166,23,52,132,213,110,170,196,226,74,233,40,159,40,245,28,79,151,242,63,57,187,16,186,180,175,72,117,3,182,220,126,81,95,169,21,101,28,232,110,254,72,101,90,234,188,170,100,226,25,114,241,168,79,105,7,255,108,7,67,37,37,55,254,229,188,0,172,68,109,120,40,103,152,83,230,148,174,71,
174,144,155,143,202,212,59,103,231,218,237,151,208,191,28,123,130,99,91,5,171,104,245,159,131,249,181,123,66,249,204,50,216,194,78,5,156,21,94,246,187,14,198,198,54,174,168,33,41,1,243,0,64,114,210,82,11,129,137,228,235,173,169,29,229,214,252,204,76,216,195,45,60,163,203,240,175,168,143,147,214,246,90,124,149,162,215,68,144,42,119,184,146,101,34,166,51,100,18,139,107,195,0,11,86,208,52,177,176,35,45,72,181,65,175,212,53,177,14,21,184,9,76,87,54,37,149,52,36,223,179,117,158,87,8,132,230,140,129,159,92,134,203,186,173,150,217,122,2,106,162,188,103,170,98,107,178,163,161,9,159,210,158,165,213,165,8,157,136,59,18,191,243,106,113,165,142,241,246,83,10,211,140,204,184,186,146,21,207,165,212,237,23,202,73,248,137,98,50,203,55,191,177,169,171,170,170,16,44,40,40,96,230,238,55,184,153,160,80,41,61,73,46,4,121,248,26,152,9,243,169,181,81,89,25,210,0,81,77,92,69,22,34,133,203,227,24,184,8,72,167,50,14,109,78,101,72,148,116,118,114,115,13,251,52,116,122,190,13,109,77,227,233,84,196,21,167,
2,224,40,125,84,217,50,19,114,145,190,216,85,126,44,210,200,144,125,189,28,156,14,33,168,212,130,12,171,29,132,232,215,148,51,25,230,178,223,203,124,158,245,21,46,135,253,62,12,118,161,218,131,46,40,170,81,202,162,156,191,99,214,73,247,102,6,172,223,219,112,102,135,182,194,200,165,106,19,246,190,28,142,12,62,228,70,163,213,161,200,7,85,141,66,60,107,248,184,190,40,122,217,50,57,147,239,164,26,55,239,226,128,170,255,84,63,145,90,102,67,166,57,152,19,45,240,157,226,105,53,127,167,25,43,5,147,182,186,238,107,150,211,21,61,136,201,15,137,154,33,39,165,175,186,197,45,12,249,151,9,161,64,182,3,91,176,172,79,228,72,93,225,158,121,72,202,68,42,203,8,160,208,96,96,207,77,117,41,213,96,84,162,213,131,77,77,57,37,147,170,120,126,6,247,186,55,153,46,247,179,240,196,13,22,111,234,182,14,212,113,44,182,231,52,249,104,82,152,237,63,227,126,46,232,70,40,219,248,139,18,103,15,31,29,182,179,71,119,240,212,154,255,130,205,183,64,182,179,5,110,192,101,38,171,70,208,161,97,5,121,26,193,53,154,61,
225,110,124,203,146,138,122,51,148,22,152,3,53,226,148,58,68,150,138,175,76,128,36,34,172,24,197,191,231,172,69,115,168,145,118,135,120,249,153,36,253,44,242,188,92,154,8,248,204,147,209,6,140,100,184,69,68,153,137,63,231,72,196,100,184,35,60,142,39,33,209,17,40,114,121,141,252,88,109,73,142,83,209,73,32,192,124,188,143,193,10,170,150,116,56,156,176,152,162,212,141,58,6,43,102,153,177,236,173,85,201,50,117,16,194,37,251,25,4,212,57,175,168,46,26,22,240,13,139,94,127,69,26,60,46,39,132,94,112,54,185,32,136,86,109,206,133,51,226,100,143,248,16,36,243,128,105,186,117,165,75,211,80,243,187,153,8,41,142,101,150,104,158,39,175,58,170,1,86,202,117,88,210,218,145,131,124,14,200,64,1,50,130,156,223,53,190,54,157,187,109,53,136,206,159,195,252,87,174,24,42,51,37,15,74,231,9,254,89,133,220,226,203,66,181,9,64,157,191,100,112,114,18,128,123,69,117,229,79,237,6,215,78,161,219,146,148,27,197,134,86,11,46,196,138,123,80,47,57,69,228,142,53,176,36,64,79,10,112,69,0,105,120,160,208,115,225,10,
32,168,72,67,115,81,94,146,153,2,143,188,112,28,196,185,56,252,54,142,233,149,234,68,228,34,119,98,31,97,116,56,121,95,143,222,51,90,75,125,35,5,61,66,43,165,10,133,62,215,103,50,154,66,27,153,218,192,191,85,125,187,191,113,249,87,202,234,224,178,86,27,88,111,253,158,20,40,105,129,64,31,196,8,112,100,161,127,158,63,220,111,2,25,193,201,37,103,42,181,40,227,118,61,185,91,77,20,41,250,119,179,164,182,1,215,216,166,6,78,151,48,79,60,217,166,214,118,23,72,23,23,102,25,84,12,44,249,210,229,132,139,57,249,193,146,134,123,159,126,30,253,252,25,61,165,19,19,76,205,92,31,237,192,35,27,71,145,89,20,50,192,182,35,37,83,167,164,92,76,189,81,94,120,188,213,216,65,56,208,168,57,16,149,113,111,160,218,81,125,145,162,237,156,60,182,186,115,113,199,227,89,59,140,253,86,84,6,140,8,171,69,143,223,76,153,138,22,30,20,166,62,26,221,123,151,9,215,141,48,21,9,32,164,28,48,234,133,227,123,188,117,56,153,83,67,111,202,176,136,37,174,146,175,69,128,115,134,82,99,182,19,195,203,5,61,229,46,168,165,186,
84,193,56,183,161,151,231,13,201,196,176,56,4,44,192,57,228,37,164,82,173,35,114,188,70,174,251,154,28,98,88,112,60,53,96,245,116,95,198,26,6,132,40,141,70,115,240,251,180,102,200,17,196,215,214,154,139,105,61,119,39,13,78,83,223,53,176,209,170,204,32,206,231,238,167,132,106,218,95,74,39,52,86,138,163,162,135,210,179,11,212,56,116,187,136,67,88,180,155,13,67,89,234,52,42,91,150,172,210,122,236,200,87,57,187,203,9,6,43,15,134,23,203,212,250,149,176,53,110,115,138,21,204,47,31,111,61,141,41,106,83,222,128,222,247,213,93,32,25,25,4,168,94,67,214,228,225,137,195,240,218,70,21,158,15,18,222,52,129,206,211,130,82,80,182,56,201,233,232,243,106,52,5,222,196,224,232,37,31,48,159,6,223,155,88,248,14,188,198,95,9,96,103,157,236,76,230,197,36,165,146,214,52,76,25,122,164,170,58,253,160,89,157,250,20,66,57,201,134,115,53,61,169,11,119,226,24,150,80,245,92,91,61,222,122,174,54,65,52,123,218,13,229,148,197,23,211,72,194,226,76,185,75,43,234,81,34,140,41,40,250,124,121,30,199,60,147,74,63,222,
58,168,199,156,137,33,115,132,87,77,98,212,37,27,87,8,132,253,195,254,18,241,61,37,219,96,121,100,6,41,11,10,118,26,159,121,90,47,89,55,166,79,161,243,212,169,91,154,61,50,142,116,6,38,93,133,148,126,92,108,243,186,203,10,86,2,203,186,205,158,140,134,83,220,77,224,43,236,137,118,47,19,126,132,44,234,187,221,133,2,108,50,20,6,211,82,245,145,218,114,96,249,64,30,56,161,119,212,129,165,190,209,39,93,165,68,144,52,213,10,115,226,50,112,57,68,94,230,120,2,84,146,58,224,248,155,216,39,172,99,171,141,226,191,180,43,57,41,238,56,228,64,245,248,250,113,194,254,214,189,84,139,64,19,229,150,85,174,86,102,236,169,176,169,192,107,209,187,102,172,70,10,141,39,124,253,6,153,145,53,131,11,82,63,6,25,129,14,220,224,108,51,55,144,224,148,130,70,220,20,105,188,221,52,96,123,201,236,4,247,176,157,72,78,232,157,153,228,160,204,12,227,151,25,51,53,218,212,225,10,95,162,186,172,10,131,125,158,230,0,5,81,111,30,214,180,141,209,80,10,17,74,24,137,35,253,17,19,25,115,213,158,229,69,51,30,195,43,113,55,
69,149,84,252,17,67,232,191,157,215,42,97,14,39,68,71,23,78,168,222,70,113,104,12,125,238,32,49,26,7,53,17,5,187,230,130,114,97,167,146,168,91,246,93,157,102,102,77,234,23,89,196,118,247,72,244,51,234,233,176,135,8,30,236,81,220,42,190,75,12,146,36,168,192,215,120,134,74,182,110,190,212,253,242,26,247,108,70,147,184,96,196,81,227,136,80,45,190,81,212,139,117,146,83,226,208,44,138,189,129,214,40,197,34,71,208,153,202,107,200,50,58,39,112,204,126,66,245,103,234,164,212,133,29,222,181,159,245,169,179,201,108,25,88,102,239,161,40,205,162,132,116,79,76,21,221,220,77,22,158,53,47,198,165,204,246,38,139,131,81,103,72,57,126,66,12,229,136,2,29,253,209,200,16,169,121,169,16,131,39,248,56,61,59,29,85,213,59,38,163,53,33,79,206,40,243,213,102,169,197,226,92,154,2,80,120,212,230,34,104,81,91,21,145,171,92,163,94,149,80,228,128,9,113,17,210,177,81,212,46,173,27,87,211,135,81,223,202,8,30,50,91,104,221,66,3,206,159,104,138,249,174,31,35,40,77,128,125,54,53,233,122,19,254,153,164,40,174,63,
105,6,79,201,227,48,62,70,47,129,27,25,25,225,138,100,61,221,113,89,50,175,24,118,69,121,99,226,179,234,223,238,148,45,224,18,224,215,118,153,43,113,142,1,176,196,157,55,89,18,101,52,116,185,142,129,20,93,202,35,77,121,137,110,91,192,162,111,121,169,153,95,226,146,110,232,80,149,107,43,178,25,52,85,135,178,238,80,69,143,162,44,219,211,225,103,173,54,46,202,25,36,1,113,23,122,205,194,94,87,74,148,240,3,183,221,180,203,173,123,187,60,218,229,122,113,28,83,180,71,131,67,77,251,232,105,200,252,225,79,219,240,216,185,169,165,240,51,218,247,251,160,19,143,199,135,54,11,70,38,172,31,190,6,189,163,193,32,71,111,173,212,220,137,124,173,31,11,81,130,132,137,56,70,141,137,95,52,159,99,144,239,130,225,191,229,12,118,50,200,171,0,134,179,116,193,148,184,137,166,190,52,98,121,25,232,6,77,157,226,17,92,163,166,11,129,13,165,25,187,85,91,213,161,111,52,197,23,158,53,245,179,56,73,233,161,202,223,37,68,112,73,23,168,161,195,63,184,194,174,67,12,113,235,208,115,0,225,92,145,214,72,159,220,152,
100,199,149,85,184,120,127,52,218,61,154,236,30,79,52,189,209,241,48,184,68,1,85,105,159,31,153,211,95,81,167,213,219,187,154,162,92,12,31,104,176,169,43,187,81,58,47,226,162,227,77,235,108,109,189,117,187,146,16,27,219,237,22,47,170,193,226,241,150,254,31,71,166,126,85,94,196,169,21,148,127,116,71,156,20,68,19,231,255,201,235,79,84,121,68,65,244,199,39,246,56,240,252,255,129,114,13,170,147,2,75,241,55,121,117,129,38,2,54,38,170,170,86,68,95,135,56,35,112,65,134,195,9,115,36,189,170,143,159,208,67,10,17,194,202,254,123,127,41,248,78,110,223,140,128,227,59,83,213,69,118,34,132,168,37,82,82,116,74,175,130,77,242,66,32,191,72,150,136,23,253,33,199,85,245,86,211,60,181,29,68,190,249,121,57,147,250,97,98,90,242,72,51,252,184,246,253,40,228,230,169,113,133,117,253,156,186,253,44,129,109,166,219,2,173,17,195,125,49,38,163,39,64,161,234,59,106,199,45,45,23,124,218,117,25,95,84,8,49,172,209,113,72,83,17,131,57,3,61,144,25,197,135,150,129,218,92,42,44,31,166,70,7,152,129,49,122,16,12,21,
225,25,122,108,192,155,140,128,6,130,83,150,85,151,99,234,66,0,230,3,1,186,29,114,134,143,122,36,21,146,96,169,154,204,226,101,5,164,224,65,44,169,188,62,180,196,132,8,20,200,204,196,166,57,62,208,229,224,158,168,77,198,94,118,22,12,104,75,78,106,52,120,186,166,216,23,38,68,171,42,23,34,213,159,136,239,101,160,129,18,219,221,116,116,63,79,23,85,179,117,135,109,145,176,248,19,18,180,203,133,224,86,35,189,243,230,171,168,121,124,125,175,184,197,115,120,239,104,208,233,168,247,31,240,57,174,137,150,221,211,24,112,82,76,193,197,147,224,130,209,232,40,129,224,89,255,13,89,77,28,239,120,90,242,76,8,144,85,40,87,224,173,142,47,34,92,131,156,0,234,113,37,155,60,176,131,71,108,47,25,75,64,189,177,145,137,166,173,165,143,183,30,220,139,30,162,226,4,0,116,90,50,162,123,87,216,42,117,102,115,242,202,148,160,99,196,241,105,211,136,203,51,168,78,10,12,71,219,8,164,76,66,50,244,131,14,60,136,100,114,133,54,24,20,49,254,240,47,183,93,30,1,51,75,98,215,16,175,118,31,20,39,112,159,15,213,130,252,
56,147,68,180,204,188,224,92,177,75,104,156,24,183,123,95,193,241,84,157,44,194,196,173,251,233,132,120,6,62,223,141,17,37,125,127,79,249,144,21,140,253,19,141,159,96,105,135,157,143,50,59,79,171,241,112,119,133,153,143,254,191,50,19,31,3,252,198,185,197,140,131,107,104,224,131,230,217,195,102,70,63,34,232,180,38,79,81,185,192,136,43,198,97,124,79,96,95,216,236,120,5,167,246,91,107,77,80,40,89,170,102,9,79,212,155,57,54,115,119,138,215,212,77,119,138,31,168,52,170,41,245,122,57,67,77,118,138,125,250,142,59,197,19,38,8,119,192,240,244,145,252,7,221,29,63,194,187,195,40,208,112,161,145,25,215,106,237,171,178,154,75,146,7,126,100,19,73,232,137,216,254,53,1,48,30,58,12,103,134,100,240,161,156,27,91,6,194,186,107,204,4,250,104,73,118,243,184,216,222,239,151,228,174,36,119,187,133,51,238,24,136,233,126,237,240,234,71,250,60,28,132,178,121,2,175,89,52,61,31,73,40,36,127,104,156,173,25,165,240,200,117,54,148,53,207,122,230,159,232,126,142,51,236,106,82,223,204,66,83,93,108,223,97,133,
160,42,131,203,116,32,126,226,27,186,158,67,224,135,211,16,207,211,157,70,73,63,63,201,42,115,192,163,69,161,41,202,92,237,44,76,92,10,140,81,190,199,168,27,89,145,119,149,90,235,33,8,44,195,15,154,132,82,235,56,82,9,153,96,83,139,68,176,60,149,98,199,174,97,210,4,31,34,55,145,116,214,129,68,71,87,112,93,84,12,237,199,246,248,59,176,149,90,188,31,156,110,122,48,45,33,180,52,31,231,94,16,152,37,54,112,163,51,213,61,155,39,210,205,122,214,83,199,213,139,127,179,71,215,81,8,74,230,218,36,63,197,169,151,204,105,62,99,88,0,62,208,26,114,20,78,32,242,168,74,215,230,52,242,8,81,201,66,147,90,133,127,196,251,1,168,14,221,165,46,51,163,245,2,183,181,157,134,186,168,119,140,70,218,18,0,67,189,4,151,72,253,61,230,87,112,239,237,44,69,52,191,129,220,46,207,99,110,49,50,145,26,214,172,129,199,189,170,232,19,199,52,81,91,89,32,120,189,32,245,255,96,96,251,178,236,65,33,240,46,66,89,123,21,14,141,186,243,18,97,18,6,250,128,42,210,248,155,19,109,214,51,169,221,132,27,157,190,170,206,17,56,183,
47,22,211,249,227,187,119,175,174,174,238,32,213,234,242,111,119,234,217,69,193,106,79,105,89,68,86,8,215,188,4,155,158,83,6,39,18,6,156,140,135,124,200,146,185,32,234,50,219,255,243,241,255,82,131,245,36,205,232,38,139,86,189,246,137,31,141,197,79,185,40,43,173,139,167,111,161,139,82,235,165,30,182,93,191,75,79,221,166,152,173,6,184,238,73,15,16,177,161,62,29,231,10,85,192,79,120,204,82,55,15,7,183,72,239,214,90,137,93,57,206,126,119,40,244,199,103,145,209,126,128,58,45,135,49,231,36,131,84,156,93,92,83,176,176,76,53,40,208,96,74,204,134,167,199,34,178,65,27,20,203,100,35,158,201,109,41,34,183,183,38,210,211,100,28,179,131,77,111,171,49,130,247,67,230,88,57,183,246,36,69,172,70,3,104,80,119,246,53,111,69,136,22,160,126,138,14,76,192,21,100,74,118,164,201,32,97,240,233,237,14,255,117,169,202,147,153,197,126,240,153,26,205,95,58,47,199,136,32,73,201,229,29,207,131,185,134,38,167,185,198,174,132,124,59,15,140,97,127,134,213,225,226,210,239,162,60,47,146,252,99,34,255,185,106,35,
26,203,80,7,45,4,189,90,251,181,245,83,168,160,32,124,45,136,202,97,68,61,78,117,182,216,122,162,6,155,39,192,205,156,213,59,209,217,116,31,122,27,136,24,36,175,236,144,103,99,48,194,169,159,15,98,61,175,181,156,114,186,31,210,36,58,115,244,210,115,86,208,172,132,252,32,142,77,136,228,130,24,106,152,252,201,19,211,118,182,23,246,117,58,182,147,179,83,215,179,153,109,177,218,166,179,251,151,125,14,243,204,197,37,42,177,154,87,122,55,129,37,36,157,108,106,10,116,90,8,113,231,39,12,208,125,50,39,226,174,139,226,227,232,130,112,10,68,197,67,104,173,149,125,190,148,179,24,173,7,81,58,245,35,240,202,43,91,2,45,127,197,22,38,239,4,240,67,193,248,3,191,154,56,29,124,78,138,138,91,63,231,209,17,70,179,121,135,70,245,1,231,173,0,34,43,141,233,69,79,53,11,140,243,172,96,40,115,183,24,184,214,18,162,111,181,68,209,207,213,26,153,93,223,117,217,79,230,56,95,210,40,49,238,23,116,120,253,230,110,42,197,193,176,82,181,207,52,85,145,171,131,1,136,187,251,136,185,84,133,32,41,6,64,27,43,131,231,
74,98,209,78,21,77,13,106,169,197,187,166,42,183,151,95,32,226,185,78,38,53,121,227,3,21,94,93,217,94,115,255,30,53,184,127,109,12,55,206,64,205,178,91,49,78,47,182,32,6,229,162,78,252,236,241,71,246,217,27,184,148,186,207,241,98,134,244,129,23,109,159,220,185,31,23,28,9,220,41,228,167,169,58,41,96,240,192,2,50,80,234,186,28,177,115,135,43,168,83,235,82,21,173,251,244,184,180,13,255,187,129,191,20,86,193,121,72,106,159,78,144,219,62,77,133,88,161,158,185,167,40,14,139,143,97,201,82,64,180,147,73,233,81,125,14,101,169,106,188,218,155,75,240,27,131,68,135,66,16,81,1,171,144,46,101,120,141,156,139,64,193,40,252,31,180,205,24,30,156,209,138,203,146,66,66,174,106,53,49,18,26,207,112,186,50,226,21,73,211,246,196,142,5,126,60,37,241,73,27,238,122,173,180,64,54,93,169,195,199,99,201,217,232,85,95,230,2,239,204,95,217,44,155,186,186,42,4,85,134,59,53,221,238,58,95,130,7,14,104,232,32,204,50,30,250,142,148,27,168,54,3,97,56,221,165,251,235,43,9,164,154,27,123,8,170,105,31,170,196,2,250,
149,34,51,191,70,116,177,224,196,155,88,210,243,107,231,26,229,130,181,4,121,247,127,237,12,121,126,58,216,41,24,83,165,137,235,244,60,94,83,86,204,3,132,193,118,230,120,3,239,72,9,176,45,200,209,254,178,32,180,85,85,182,244,114,24,107,209,200,83,239,184,219,120,8,153,84,77,232,216,73,137,59,246,218,158,255,25,46,221,204,154,56,17,37,1,252,47,123,193,33,117,221,101,202,144,172,62,128,15,226,5,4,120,221,224,72,14,27,234,6,232,155,159,199,76,122,33,29,138,23,98,73,63,12,254,187,114,80,213,12,37,68,233,120,150,38,80,142,139,156,131,226,205,217,179,221,111,173,121,250,219,253,175,97,37,199,150,78,74,118,236,28,96,220,141,14,167,19,204,37,26,18,8,201,171,126,231,231,6,100,18,48,10,53,86,235,54,133,242,152,119,245,49,244,213,168,186,40,123,215,121,94,97,247,254,222,163,189,118,178,175,221,150,228,64,112,136,212,88,117,151,142,189,139,239,221,77,207,180,163,248,23,194,146,61,46,221,247,151,150,26,62,218,175,173,142,149,123,209,143,87,10,236,1,56,23,118,145,99,145,105,251,113,16,237,
152,186,46,205,230,156,16,39,224,217,219,156,97,177,164,222,168,0,241,222,175,153,139,141,166,185,126,98,156,233,175,16,12,120,82,21,92,156,35,38,51,128,231,202,57,246,164,66,16,141,43,189,38,132,47,61,53,103,98,51,255,212,146,34,46,198,211,55,6,43,84,140,197,162,149,211,88,235,4,185,102,67,30,211,241,56,53,182,65,28,186,44,246,79,15,142,142,82,139,81,242,0,251,10,66,133,32,26,169,35,66,191,59,9,53,58,106,113,158,38,202,53,245,154,128,169,182,196,249,67,103,227,150,36,138,107,67,191,152,207,243,88,8,64,91,9,53,215,169,88,78,36,37,98,125,164,176,169,0,5,79,39,197,203,33,5,112,13,175,103,234,56,232,25,128,145,199,104,149,248,177,163,220,108,81,242,255,0,42,105,168,158,158,19,57,180,24,201,105,236,17,46,52,76,66,238,215,22,13,165,206,86,193,186,142,49,240,1,245,118,30,32,171,144,33,79,114,171,21,18,51,181,201,5,120,229,164,197,169,35,222,212,206,7,163,242,61,183,216,6,63,34,119,103,53,201,113,79,14,161,75,171,82,227,139,9,134,152,177,128,60,102,156,40,1,169,64,205,115,13,140,55,
10,139,185,144,145,250,145,193,244,153,28,73,204,233,216,91,160,32,102,49,166,65,48,214,92,169,30,43,135,67,87,126,56,179,130,60,14,20,109,54,54,225,53,25,58,161,55,81,183,91,238,141,211,162,135,123,247,246,30,53,126,206,126,214,38,44,196,147,27,128,10,138,18,154,91,141,194,144,154,2,201,31,222,202,10,12,199,17,190,243,80,189,55,64,211,118,157,24,64,98,128,27,204,223,243,66,143,15,114,110,154,20,6,106,41,59,215,92,158,216,159,30,45,226,213,25,83,41,46,144,138,241,64,97,31,252,225,165,134,250,195,31,118,230,51,136,231,0,93,230,10,84,79,80,189,83,41,131,137,226,28,154,44,240,0,65,152,182,230,173,152,61,253,35,241,125,229,123,95,121,62,4,77,84,209,240,247,59,29,228,131,146,67,78,241,72,79,136,1,13,242,139,197,248,157,90,88,110,248,227,89,59,1,72,142,40,85,11,205,10,100,143,162,166,42,129,248,46,77,20,201,250,122,52,60,71,190,188,3,0,200,83,46,120,200,67,238,6,238,184,44,142,213,245,120,175,135,222,87,163,1,32,113,201,90,172,126,208,133,30,154,207,239,100,242,224,151,126,34,95,19,
162,135,216,83,217,107,247,168,242,146,70,46,10,75,126,243,72,170,44,177,38,92,224,169,70,193,59,72,162,229,203,134,172,70,111,128,136,202,225,8,245,246,137,104,158,205,10,249,50,159,167,167,34,133,114,205,153,62,72,85,55,235,177,177,244,118,48,189,88,70,82,121,43,112,32,210,1,23,210,131,21,170,196,15,198,230,5,126,128,72,249,57,97,23,167,89,247,88,138,203,76,146,220,134,30,22,235,158,71,129,25,104,66,19,70,110,78,234,199,124,167,94,254,193,220,176,94,39,168,147,64,117,138,95,114,62,102,112,36,31,141,21,178,72,46,176,37,132,199,121,165,105,67,214,193,139,46,205,79,156,131,245,219,167,183,248,74,32,113,79,123,232,147,36,30,121,107,168,114,67,86,83,88,163,127,93,237,50,187,15,211,232,237,49,45,145,203,201,240,39,249,55,45,100,80,209,86,226,51,67,148,26,164,153,117,74,160,89,7,59,10,104,10,164,30,29,22,225,4,209,35,129,37,249,222,85,214,25,52,203,41,25,159,134,137,59,241,202,153,4,188,119,120,229,126,66,12,227,97,82,131,134,48,78,25,0,53,221,30,16,46,133,106,237,25,143,27,129,13,
230,120,39,209,165,178,23,101,76,165,55,98,192,202,94,74,61,165,62,114,210,210,172,48,151,5,143,247,71,200,208,12,131,152,147,226,85,148,16,27,209,36,215,125,129,77,204,244,198,173,253,79,156,20,55,40,61,207,117,138,119,85,21,143,244,9,229,165,231,71,172,61,177,94,154,127,152,143,107,33,17,157,96,64,65,93,199,198,6,162,130,1,139,212,162,224,33,0,158,186,21,123,44,60,197,46,92,136,97,163,24,220,168,130,189,87,163,191,104,61,241,51,215,68,60,84,171,103,191,245,18,28,217,73,106,44,201,41,189,187,6,13,125,176,54,11,55,56,74,90,219,27,151,3,223,100,130,208,216,188,22,100,149,7,8,164,35,107,172,5,115,90,145,128,195,20,46,223,46,162,121,182,85,193,22,125,157,247,8,51,89,211,215,131,119,72,55,109,128,83,80,221,207,57,159,28,100,122,156,43,189,27,72,190,139,208,157,10,160,26,171,81,98,204,171,231,18,158,188,73,69,1,50,122,210,22,122,203,226,205,233,147,182,20,160,103,68,88,194,243,50,126,52,40,71,76,236,35,213,188,195,57,197,189,13,223,155,194,66,86,240,192,143,8,149,142,28,165,75,148,
68,128,220,118,43,20,209,232,134,126,65,7,9,90,201,161,24,62,75,53,165,28,234,6,90,6,216,8,53,24,82,172,107,63,107,98,250,228,141,168,58,7,171,4,163,228,92,80,117,128,160,6,20,253,154,75,121,16,113,198,143,45,245,129,130,10,14,176,135,234,34,71,87,215,67,176,167,77,36,46,151,51,121,235,252,34,22,237,15,169,57,143,199,109,65,64,115,104,45,14,253,204,126,167,57,24,233,138,221,2,130,211,169,46,121,29,42,171,165,2,31,7,113,152,95,19,72,222,203,103,98,185,132,176,227,197,33,185,221,140,164,252,5,239,179,100,153,163,246,253,135,249,46,161,92,237,57,14,30,171,198,227,231,60,228,24,244,53,62,92,179,154,230,106,154,241,140,203,61,169,144,189,102,240,242,138,49,99,103,27,36,94,233,205,92,90,79,130,192,165,201,224,82,196,139,17,196,228,172,147,27,249,10,13,10,167,33,120,26,69,197,117,237,198,122,129,40,60,201,130,205,231,80,160,136,182,191,46,186,182,244,128,16,41,115,177,226,149,235,93,201,235,136,23,200,218,8,31,93,107,159,222,202,62,77,74,36,73,52,52,193,96,224,141,178,169,85,6,91,219,
184,146,65,141,166,217,239,184,134,240,148,137,157,201,198,216,34,30,159,139,140,151,139,155,156,183,85,33,169,54,165,240,148,27,87,180,204,48,115,185,72,10,32,139,165,93,58,71,125,174,82,29,223,9,66,230,238,80,19,129,12,147,86,244,236,241,214,214,191,20,39,241,166,64,156,78,214,240,8,16,112,5,42,121,74,102,229,146,92,74,198,213,60,125,241,162,5,68,82,89,124,146,53,1,156,107,192,100,94,160,22,104,114,122,121,16,107,189,148,197,178,151,223,128,16,59,113,171,184,121,121,211,147,233,225,41,112,165,73,221,9,9,9,116,53,88,76,242,91,217,133,107,248,74,75,102,129,101,65,241,238,149,137,7,111,224,185,72,52,240,212,195,87,92,207,96,51,175,49,109,124,39,102,72,209,112,101,221,208,99,214,5,108,216,244,173,229,60,85,197,115,197,2,193,68,70,109,138,175,153,113,208,39,4,8,217,105,98,204,182,180,59,41,53,33,98,123,149,173,18,47,175,151,210,139,118,200,250,241,15,66,81,130,221,118,57,171,2,209,42,25,159,182,138,206,181,156,66,99,61,108,24,112,28,68,81,125,232,85,12,111,75,244,38,54,30,212,87,
110,246,126,72,75,76,21,104,109,8,194,92,240,80,38,236,80,77,53,67,121,207,229,203,249,117,174,6,102,165,215,116,105,116,120,236,34,157,251,204,0,123,1,63,206,222,62,146,9,251,171,224,68,198,120,127,31,50,153,225,116,221,54,236,71,34,112,210,174,22,226,4,3,214,194,73,138,116,29,35,22,137,26,133,16,45,17,40,178,26,88,223,4,129,217,230,24,189,83,93,14,42,44,227,102,28,83,97,196,81,30,206,12,232,246,243,172,128,175,243,245,70,171,138,88,231,51,21,18,20,143,112,30,70,251,18,138,30,85,213,226,175,73,4,53,177,69,172,215,31,81,158,20,61,13,132,40,167,67,61,15,31,239,60,151,16,58,91,181,60,117,112,140,173,98,40,0,97,174,59,50,137,1,74,50,54,233,178,183,35,9,81,213,177,221,28,72,155,219,90,251,32,148,68,147,204,163,155,141,146,96,174,173,52,239,188,58,60,147,21,252,143,253,239,247,27,43,105,29,37,247,239,182,241,143,67,72,209,105,94,232,17,150,117,242,181,76,123,224,14,197,16,252,10,144,149,194,130,116,13,132,142,232,89,3,1,79,82,159,47,236,165,165,129,141,58,191,226,220,114,88,49,143,
151,35,220,1,165,21,174,186,209,98,91,109,165,215,104,237,180,113,118,24,39,0,228,226,52,230,221,231,57,237,240,30,201,99,132,82,119,77,11,174,73,29,226,61,13,17,170,36,173,62,51,45,238,231,216,10,148,130,161,251,100,67,204,232,71,157,17,246,185,76,148,222,144,136,175,112,197,15,99,200,250,79,254,198,8,74,43,18,120,197,171,7,250,236,134,43,1,164,12,118,147,25,112,143,241,169,178,36,184,134,62,170,177,145,220,98,19,94,18,130,241,27,52,84,235,195,15,199,125,16,98,207,28,204,23,102,204,209,50,237,29,57,72,140,232,91,119,210,59,41,80,2,198,165,113,106,242,115,60,103,174,183,165,197,12,118,227,41,198,212,149,153,28,152,143,165,157,167,218,115,39,94,14,45,30,165,16,217,156,87,72,39,187,117,171,188,60,103,228,125,208,152,211,86,222,43,185,27,70,159,253,47,25,82,251,165,128,146,230,179,32,10,240,73,133,119,64,101,24,183,11,248,215,168,96,188,55,22,157,74,26,210,145,157,94,146,231,161,35,216,154,223,128,5,73,76,140,105,184,206,4,169,232,65,186,159,162,110,118,238,221,199,46,84,7,33,213,
104,50,212,159,48,234,27,237,66,188,250,222,47,185,18,48,82,73,67,129,167,211,211,143,131,115,208,28,80,52,40,205,75,46,200,98,20,77,83,109,216,98,139,217,240,198,227,117,29,137,142,222,120,49,175,223,3,29,59,235,222,181,127,30,144,62,241,242,210,201,34,106,51,169,31,186,250,44,155,217,226,23,6,169,70,147,186,195,224,38,63,253,166,74,252,26,14,245,219,2,59,249,12,170,39,85,150,147,94,73,106,36,31,128,66,126,236,81,0,161,121,28,145,74,126,196,65,92,141,205,43,26,117,138,120,41,192,27,74,217,3,52,32,59,200,182,210,249,241,71,46,17,60,55,100,194,137,136,164,230,133,121,66,78,49,138,47,116,161,87,194,146,21,168,188,7,81,26,46,78,117,212,180,109,76,160,42,107,108,135,205,209,53,98,172,252,44,175,145,160,42,236,36,239,204,229,188,200,99,127,250,121,112,30,240,61,85,39,25,119,161,215,119,227,30,38,239,58,143,5,199,231,27,31,211,244,149,122,63,79,144,171,143,200,1,106,116,200,204,135,246,241,68,105,141,188,143,31,189,233,199,171,213,164,218,181,167,4,84,167,242,164,133,170,205,150,118,
130,113,26,187,251,128,189,130,43,53,163,195,73,23,53,147,71,113,205,212,179,251,184,34,88,105,66,96,177,204,91,127,244,201,157,213,89,149,255,193,237,149,197,3,230,182,245,26,68,250,105,157,7,192,242,64,68,51,112,128,90,3,179,53,77,145,30,45,142,53,133,206,121,222,181,70,119,161,186,251,238,30,109,136,15,110,70,9,98,180,67,179,4,221,255,210,70,106,253,166,190,219,207,107,51,167,44,245,199,218,204,97,225,54,212,79,183,154,225,146,113,176,149,76,117,81,123,109,252,107,47,50,71,191,148,213,213,113,247,203,228,22,224,5,165,24,66,171,115,113,87,7,19,154,228,216,32,213,181,94,246,77,250,248,86,236,194,234,84,192,80,102,71,181,39,222,168,36,233,139,121,242,22,81,58,139,105,46,180,208,194,63,252,143,67,255,214,105,70,62,133,127,194,90,54,141,16,9,150,207,219,205,65,155,44,165,233,91,67,89,141,168,132,165,43,220,224,158,133,29,176,11,223,206,125,39,228,108,248,115,1,84,81,177,122,10,216,116,150,72,179,201,94,181,218,172,247,168,175,56,144,157,213,146,131,56,37,47,136,145,147,99,38,135,
166,199,239,232,226,234,168,242,75,202,253,70,234,49,196,153,227,53,104,161,126,71,92,240,71,105,178,8,115,51,5,134,233,45,75,222,179,187,64,28,54,150,112,222,193,21,28,5,27,204,172,86,11,22,233,113,51,107,129,12,98,189,172,238,145,139,203,232,125,61,227,130,178,90,43,70,244,28,93,25,212,119,12,163,171,149,160,183,157,105,15,21,32,62,99,208,8,39,169,23,26,185,96,130,17,210,192,79,111,158,64,237,72,9,80,5,93,145,184,44,152,24,69,134,230,181,135,18,86,140,188,248,170,237,147,52,219,148,135,170,120,2,215,157,41,100,217,213,47,31,0,50,27,93,147,212,147,119,148,218,105,150,71,187,222,176,94,242,127,182,124,195,150,76,30,90,158,71,108,50,108,96,215,51,37,193,182,72,136,215,179,46,113,150,206,197,77,227,40,213,161,236,215,87,156,237,221,167,63,246,158,8,187,94,212,217,230,145,30,80,96,147,238,216,37,190,8,88,227,199,82,9,33,100,43,110,25,170,15,144,116,239,229,209,25,205,166,158,170,77,60,1,48,189,14,149,115,79,231,163,255,234,75,113,203,3,113,105,30,238,92,255,81,24,44,39,255,55,97,
244,94,134,226,182,95,116,198,43,73,92,109,135,1,146,36,206,149,137,19,174,164,137,151,19,46,53,33,245,110,85,184,233,254,11,217,140,20,241,60,167,83,202,226,166,105,226,146,101,154,236,65,103,229,41,221,154,129,84,165,182,171,240,214,80,83,195,137,154,41,74,105,202,54,175,30,144,174,240,224,107,214,168,252,147,209,170,210,95,169,171,58,157,41,183,213,164,172,82,168,92,251,105,91,224,22,162,89,132,54,166,33,83,209,201,80,62,13,139,129,254,172,124,172,41,15,140,210,45,165,29,163,138,242,16,213,225,172,128,67,244,75,172,182,204,212,206,197,115,141,116,210,212,236,16,229,153,186,132,42,155,39,147,64,124,176,200,251,82,16,136,255,240,83,190,86,241,140,167,120,8,103,151,17,155,64,62,243,218,59,254,149,244,69,180,106,105,194,4,195,44,58,26,208,50,218,78,140,221,135,47,243,227,158,58,75,104,0,134,173,55,24,137,221,134,38,236,158,165,154,126,226,113,4,104,7,252,53,157,15,129,227,206,113,56,221,242,92,85,30,189,222,204,245,29,248,235,40,222,61,166,124,233,243,195,226,244,248,217,217,219,
253,147,195,226,232,180,120,125,114,252,253,209,211,195,167,140,42,159,242,121,155,105,232,163,179,231,199,111,206,10,174,56,217,127,117,246,67,113,252,172,216,127,245,67,241,167,163,87,79,119,138,195,255,120,125,114,120,122,90,28,159,20,71,47,95,191,56,58,228,187,163,87,7,47,222,60,61,122,245,93,241,132,251,94,29,163,229,71,232,58,139,158,29,23,218,48,45,117,116,200,125,207,138,151,135,39,7,207,89,121,255,201,209,139,163,179,31,120,94,254,232,236,149,214,124,198,162,251,197,235,253,147,179,163,131,55,47,246,79,138,215,111,78,94,31,159,30,178,253,83,150,125,117,244,234,217,9,187,28,190,60,124,117,118,135,93,249,174,56,252,158,15,197,233,243,125,10,81,218,106,255,13,212,159,152,190,131,227,215,63,156,28,125,247,252,172,120,126,252,226,233,33,95,62,57,132,178,253,39,47,14,99,43,14,117,240,98,255,232,37,175,136,217,127,185,255,157,168,59,41,142,89,229,196,151,37,234,222,62,63,244,87,236,183,207,191,7,103,71,199,175,116,140,131,227,87,103,39,124,220,225,148,39,103,205,173,111,143,
78,15,25,57,63,57,58,21,67,158,157,28,179,188,216,201,29,226,217,43,221,247,234,48,86,17,171,77,117,35,17,46,209,41,222,112,232,134,150,167,135,251,47,88,11,241,188,90,185,248,206,150,222,100,164,255,136,217,239,63,243,31,253,135,207,54,255,108,56,176,225,192,134,3,27,14,252,2,57,240,89,126,252,23,72,247,151,74,210,103,241,251,247,95,224,233,62,239,96,63,118,213,23,120,232,127,36,201,63,198,26,255,246,143,220,108,179,214,151,192,129,159,84,137,207,186,224,75,56,233,134,198,13,7,254,243,28,248,44,51,88,187,232,63,191,219,230,206,13,7,54,28,216,112,96,195,129,13,7,54,28,248,71,115,96,45,76,223,248,241,31,189,231,102,189,95,37,7,110,212,29,190,252,85,30,118,115,168,13,7,54,28,216,112,224,39,57,240,41,175,248,217,223,255,228,14,191,130,11,254,251,218,63,191,130,35,109,142,176,225,192,47,136,3,107,6,214,249,248,11,34,242,55,77,202,77,1,225,55,205,144,47,247,240,55,137,242,255,233,187,47,151,21,27,202,55,28,216,112,224,119,191,251,111,252,179,225,195,71,28,248,76,175,248,209,125,95,
250,23,155,162,216,151,46,193,13,253,27,14,108,56,176,225,192,134,3,27,14,108,56,176,225,192,134,3,27,14,108,56,176,225,192,134,3,27,14,108,56,176,225,192,134,3,27,14,108,56,176,225,192,134,3,191,52,14,124,102,207,33,93,246,75,163,254,179,223,5,242,201,99,254,226,78,244,249,4,221,112,166,207,191,249,87,121,229,58,71,126,149,135,220,28,234,183,199,129,117,197,254,244,231,223,30,111,54,39,222,112,96,195,129,13,7,54,28,248,47,226,192,167,131,79,243,203,127,17,37,155,109,54,28,216,112,96,195,129,13,7,54,28,216,112,96,195,129,13,7,54,28,216,112,96,195,129,13,7,54,28,216,112,96,195,129,223,30,7,154,10,204,207,250,203,111,143,79,155,19,111,56,176,225,192,23,192,129,159,229,199,210,197,95,192,177,54,36,126,1,28,88,213,189,47,128,224,13,137,27,14,108,56,240,75,230,192,239,255,175,0,0,0,0,255,255,3,0,37,231,137,29);


//additional program support files ---------------------------------------------
template_squircle_128px
:array[0..500] of byte=(
137,80,78,71,13,10,26,10,0,0,0,13,73,72,68,82,0,0,0,128,0,0,0,128,8,3,0,0,0,244,224,145,249,0,0,0,23,116,69,88,116,83,111,102,116,119,97,114,101,0,68,97,110,105,32,118,49,46,48,48,46,50,54,48,20,195,73,175,0,0,0,30,116,69,88,116,98,101,46,112,110,103,46,115,101,116,116,105,110,103,115,0,53,51,54,56,55,48,57,49,49,46,45,49,46,53,41,132,140,74,0,0,0,6,80,76,84,69,0,255,255,255,0,0,15,158,76,95,0,0,0,2,116,82,78,83,0,255,91,145,34,181,0,0,1,79,73,68,65,84,120,1,237,155,59,2,132,32,12,5,209,189,255,157,23,249,8,18,252,20,132,80,140,213,110,192,204,99,80,43,117,110,197,99,83,58,122,107,221,69,209,195,69,109,80,161,215,186,13,160,71,143,139,16,253,175,1,196,240,160,165,215,109,26,70,29,160,25,170,207,26,250,251,194,169,2,168,109,189,76,95,161,74,128,170,40,207,24,93,41,176,51,64,41,141,134,117,251,157,184,28,224,44,116,167,43,20,51,48,5,200,127,21,72,119,45,19,50,6,48,224,59,23,161,121,11,238,114,170,215,67,0,19,1,73,193,18,6,140,4,68,5,43,24,48,19,16,20,172,96,64,253,78,123,4,236,
233,121,240,56,73,111,112,115,108,1,6,48,128,1,12,96,0,3,24,192,0,6,48,128,1,12,96,0,3,24,192,0,6,48,128,1,12,96,0,3,24,192,0,6,48,128,1,12,96,0,3,24,192,0,6,48,128,1,12,96,0,3,24,192,0,6,48,96,110,192,191,50,172,244,93,215,167,182,142,247,138,195,75,219,159,100,169,76,242,120,243,139,240,119,56,48,252,194,32,108,129,217,125,16,233,65,129,202,14,191,53,13,124,243,107,32,89,120,11,171,49,94,54,192,102,19,174,252,249,15,228,150,63,59,129,228,207,77,208,227,207,76,208,231,251,170,198,197,46,123,222,226,143,1,57,125,120,229,145,175,30,225,141,30,199,135,47,58,53,252,70,159,60,235,15,222,143,7,92,119,7,6,184,0,0,0,0,73,69,78,68,174,66,96,130);


template_squircle_2560px
:array[0..43086] of byte=(
137,80,78,71,13,10,26,10,0,0,0,13,73,72,68,82,0,0,10,0,0,0,10,0,8,3,0,0,0,74,138,139,234,0,0,0,23,116,69,88,116,83,111,102,116,119,97,114,101,0,68,97,110,105,32,118,49,46,48,48,46,50,54,48,20,195,73,175,0,0,0,30,116,69,88,116,98,101,46,112,110,103,46,115,101,116,116,105,110,103,115,0,53,51,54,56,55,48,57,49,49,46,45,49,46,53,41,132,140,74,0,0,0,6,80,76,84,69,0,255,255,255,0,0,15,158,76,95,0,0,0,2,116,82,78,83,0,255,91,145,34,181,0,0,167,169,73,68,65,84,120,1,236,221,219,154,20,201,145,133,209,70,239,255,206,51,64,55,80,84,229,57,125,71,108,119,95,115,163,22,7,75,139,101,89,95,254,20,146,230,219,63,254,111,105,129,111,75,63,157,135,35,64,128,0,129,148,192,255,165,6,155,91,33,240,191,138,45,44,49,82,224,219,199,255,27,57,216,44,2,4,8,16,216,71,224,227,103,137,111,38,172,119,119,1,184,202,77,255,124,165,174,242,68,158,131,0,1,2,4,90,4,124,198,180,92,98,216,30,2,112,24,229,57,131,126,127,77,158,243,242,94,149,0,1,2,4,246,18,240,177,179,200,189,5,224,172,135,252,239,75,112,214,245,
237,77,128,0,1,2,115,11,248,24,154,251,126,2,112,186,251,249,146,155,238,100,22,38,64,128,192,186,2,62,148,38,189,173,0,156,232,112,255,126,149,77,180,176,85,9,16,32,64,96,19,1,159,80,179,29,90,0,78,113,49,95,88,83,156,201,146,4,8,16,216,92,192,167,213,60,111,0,1,88,126,43,95,76,229,7,178,30,1,2,4,8,124,18,240,201,245,9,164,242,223,10,192,202,179,252,92,234,231,87,80,239,122,54,35,64,128,0,1,2,215,5,124,136,93,183,105,248,25,1,216,112,133,47,59,248,178,249,66,226,7,8,16,32,64,96,62,1,31,103,181,55,19,128,117,167,249,241,213,82,183,148,133,8,16,32,64,128,192,139,2,62,215,94,132,139,254,54,1,24,229,125,114,184,63,41,61,9,230,151,19,32,64,128,192,28,2,62,224,218,238,36,0,91,46,226,15,72,45,151,176,7,1,2,4,8,100,4,124,210,101,92,95,154,42,0,95,98,27,252,155,124,73,12,6,53,142,0,1,2,4,74,5,124,226,149,28,70,0,158,125,8,95,10,103,95,192,235,19,32,64,128,192,177,2,62,249,142,245,190,248,106,2,240,34,203,65,63,232,75,224,32,104,47,67,128,0,1,2,101,2,62,1,79,62,136,0,60,235,0,222,250,
103,201,123,93,2,4,8,16,232,16,240,73,120,226,29,4,224,41,248,223,223,243,167,188,174,23,37,64,128,0,1,2,85,2,62,16,79,58,135,0,60,28,222,31,120,14,39,247,130,4,8,16,32,80,44,224,115,241,140,227,8,192,99,213,253,73,231,88,111,175,70,128,0,1,2,83,8,248,120,60,250,76,2,240,56,113,127,196,57,206,218,43,17,32,64,128,192,108,2,62,37,15,189,152,0,60,136,219,159,109,14,130,246,50,4,8,16,32,48,175,128,15,203,195,110,39,0,143,160,246,134,62,66,217,107,16,32,64,128,192,2,2,62,50,143,57,162,0,140,59,123,43,199,137,189,0,1,2,4,8,172,36,224,131,243,128,107,10,192,44,178,55,113,214,215,116,2,4,8,16,88,82,192,199,103,250,172,2,48,40,236,237,27,196,53,154,0,1,2,4,214,22,240,33,26,189,175,0,76,241,122,227,166,100,205,37,64,128,0,129,77,4,124,148,230,14,45,0,35,182,222,178,17,86,67,9,16,32,64,96,55,1,31,168,161,139,11,192,241,176,222,172,227,77,77,36,64,128,0,129,109,5,124,172,38,78,47,0,7,171,122,155,14,6,53,142,0,1,2,4,8,248,112,29,254,30,16,128,67,73,191,125,27,58,206,48,2,4,8,16,32,64,224,
167,128,79,216,177,111,4,1,56,206,211,159,79,198,89,154,68,128,0,1,2,4,62,9,248,152,253,4,242,214,191,21,128,111,241,253,249,205,222,150,127,44,252,19,1,2,4,8,16,136,8,248,176,29,198,42,0,135,80,250,198,244,16,70,67,8,16,32,64,128,192,29,1,159,184,119,128,30,252,105,1,248,32,212,141,95,230,207,35,55,112,252,20,1,2,4,8,16,24,43,224,99,119,132,167,0,124,87,209,31,69,222,21,244,251,9,16,32,64,128,192,115,2,62,123,159,243,186,240,171,5,224,5,148,199,127,200,159,66,30,183,242,43,9,16,32,64,128,192,48,1,31,192,111,82,10,192,55,0,253,1,228,13,60,191,149,0,1,2,4,8,188,37,224,83,248,29,62,1,248,170,158,63,123,188,42,231,247,17,32,64,128,0,129,33,2,62,138,95,103,20,128,175,217,249,99,199,107,110,126,23,1,2,4,8,16,24,41,224,243,248,69,77,1,248,10,156,183,219,43,106,126,15,1,2,4,8,16,24,47,224,51,249,37,83,1,248,52,155,111,56,63,77,230,55,16,32,64,128,0,129,156,128,15,230,23,108,5,224,147,104,254,160,241,36,152,95,78,128,0,1,2,4,226,2,62,157,159,37,22,128,79,137,121,131,61,197,229,23,19,
32,64,128,0,129,131,4,124,66,63,7,45,0,159,240,242,230,122,2,203,47,37,64,128,0,1,2,135,10,248,148,126,134,91,0,62,170,229,63,97,240,168,148,95,71,128,0,1,2,4,78,17,240,81,253,56,187,0,124,204,202,31,43,30,115,242,171,8,16,32,64,128,192,153,2,62,175,31,212,23,128,143,64,121,59,61,162,228,215,16,32,64,128,0,129,243,5,124,102,63,116,3,1,120,159,201,91,233,190,145,95,65,128,0,1,2,4,90,4,124,110,63,112,9,1,120,15,201,219,232,158,144,159,39,64,128,0,1,2,93,2,62,187,239,222,67,0,222,38,242,22,186,237,227,103,9,16,32,64,128,64,163,128,207,239,59,87,17,128,183,128,188,125,110,233,248,57,2,4,8,16,32,208,43,224,51,252,230,109,4,224,117,30,111,157,235,54,126,134,0,1,2,4,8,180,11,248,28,191,113,33,1,120,13,199,219,230,154,140,31,39,64,128,0,1,2,115,8,248,44,191,122,39,1,120,153,198,91,230,178,139,31,37,64,128,0,1,2,51,9,248,60,191,114,45,1,120,9,198,219,229,146,138,31,35,64,128,0,1,2,243,9,248,76,191,120,51,1,248,149,197,91,229,171,137,31,33,64,128,0,1,2,179,10,248,92,191,112,57,1,248,25,
197,219,228,179,136,127,79,128,0,1,2,4,230,22,240,217,254,229,126,2,240,111,18,111,145,191,61,252,59,2,4,8,16,32,176,130,128,207,247,79,87,20,128,31,65,188,61,62,106,248,103,2,4,8,16,32,176,142,128,207,248,191,110,41,0,63,112,124,251,240,207,254,145,0,1,2,4,8,16,88,74,192,199,252,135,115,10,192,223,24,254,104,240,155,194,63,16,32,64,128,0,129,5,5,124,210,255,57,170,0,252,207,194,155,226,207,155,194,63,17,32,64,128,0,129,53,5,124,218,255,186,171,0,252,41,225,13,241,235,13,225,95,9,16,32,64,128,192,202,2,62,241,255,189,174,0,252,238,224,205,176,242,151,186,103,35,64,128,0,1,2,31,5,124,234,255,208,16,128,223,251,239,227,219,194,63,19,32,64,128,0,1,2,107,11,248,224,23,128,190,253,183,246,215,184,167,35,64,128,0,1,2,95,5,124,19,112,251,239,0,122,11,124,253,178,240,35,4,8,16,32,64,96,117,129,237,63,255,247,254,43,224,237,207,191,250,215,183,231,35,64,128,0,1,2,87,4,54,111,128,173,3,208,127,6,224,202,23,133,31,38,64,128,0,1,2,235,11,108,157,1,27,7,224,230,233,191,254,23,182,39,36,64,
128,0,1,2,55,5,118,46,129,109,3,112,231,163,223,252,106,240,147,4,8,16,32,64,96,27,129,125,107,96,215,0,220,250,219,190,219,124,93,123,80,2,4,8,16,32,112,71,96,215,32,216,51,0,247,13,254,59,95,6,126,154,0,1,2,4,8,108,38,176,105,19,236,24,128,155,158,122,179,47,104,143,75,128,0,1,2,4,30,19,216,178,11,54,12,192,93,191,217,251,216,87,129,95,69,128,0,1,2,4,182,19,216,48,13,182,11,192,45,51,127,187,175,100,15,76,128,0,1,2,4,158,17,216,175,14,54,11,192,253,14,252,204,219,223,175,37,64,128,0,1,2,187,10,236,86,8,123,5,224,134,223,226,221,245,11,217,115,19,32,64,128,0,129,231,4,246,138,132,157,2,112,183,184,127,238,125,239,87,19,32,64,128,0,129,189,5,182,234,132,141,2,112,175,178,223,251,107,216,211,19,32,64,128,0,129,23,4,54,74,133,109,2,112,171,172,127,225,61,239,183,16,32,64,128,0,1,2,251,212,194,46,1,184,81,211,251,242,37,64,128,0,1,2,4,94,21,216,37,24,246,8,192,125,130,254,213,247,187,223,71,128,0,1,2,4,8,252,16,216,164,25,182,8,192,93,106,222,87,46,1,2,4,8,16,32,240,182,192,22,217,
176,65,0,110,146,242,111,191,223,13,32,64,128,0,1,2,4,126,8,236,80,14,235,7,224,22,29,239,11,150,0,1,2,4,8,16,24,39,176,126,60,172,30,128,59,68,252,184,247,187,73,4,8,16,32,64,128,192,15,129,229,251,97,241,0,92,191,224,125,157,18,32,64,128,0,1,2,1,129,197,19,98,233,0,92,62,223,3,239,119,35,9,16,32,64,128,0,129,31,2,107,87,196,202,1,184,120,187,251,242,36,64,128,0,1,2,4,146,2,43,135,196,186,1,184,118,184,39,223,239,102,19,32,64,128,0,1,2,63,4,22,110,137,101,3,112,229,106,247,85,73,128,0,1,2,4,8,28,34,176,108,78,172,26,128,203,30,236,144,183,187,23,33,64,128,0,1,2,4,126,10,172,26,20,107,6,224,194,223,178,245,245,72,128,0,1,2,4,8,28,40,176,104,83,44,25,128,171,214,250,129,111,119,47,69,128,0,1,2,4,8,252,43,176,100,86,44,24,128,139,166,186,47,67,2,4,8,16,32,64,224,20,129,21,203,98,189,0,92,178,211,79,121,191,123,81,2,4,8,16,32,64,224,167,192,122,113,177,92,0,174,119,34,95,123,4,8,16,32,64,128,192,201,2,203,229,197,98,1,184,226,55,105,79,126,203,123,121,2,4,8,16,32,64,96,185,255,73,
192,181,2,112,185,62,247,21,71,128,0,1,2,4,8,116,8,172,21,25,75,5,224,90,167,233,120,187,219,130,0,1,2,4,8,16,248,41,176,84,102,44,20,128,254,250,215,23,40,1,2,4,8,16,32,144,19,88,169,52,214,9,192,165,186,60,247,230,53,153,0,1,2,4,8,16,120,85,96,157,216,88,38,0,215,57,201,171,111,74,191,143,0,1,2,4,8,16,8,11,44,147,27,139,4,224,74,223,148,13,191,117,141,39,64,128,0,1,2,4,94,22,88,165,56,214,8,192,101,122,252,229,247,163,223,72,128,0,1,2,4,8,28,34,176,70,116,44,17,128,107,156,226,144,119,173,23,33,64,128,0,1,2,4,222,19,88,34,59,86,8,192,37,14,241,222,123,209,239,38,64,128,0,1,2,4,142,18,88,33,60,230,15,192,85,254,50,254,168,119,173,215,33,64,128,0,1,2,4,222,19,88,160,61,166,15,192,21,42,252,189,119,161,223,77,128,0,1,2,4,8,28,44,48,125,126,204,30,128,211,31,224,224,55,172,151,35,64,128,0,1,2,4,6,8,204,30,32,147,7,224,236,252,3,222,129,70,16,32,64,128,0,1,2,199,11,76,158,32,83,7,224,2,127,5,127,252,27,214,43,18,32,64,128,0,1,2,3,4,230,174,144,153,3,112,242,246,30,240,222,51,130,
0,1,2,4,8,16,56,77,96,230,16,153,56,0,103,102,63,237,189,234,133,9,16,32,64,128,0,129,81,2,19,167,200,188,1,56,49,250,168,247,157,57,4,8,16,32,64,128,192,153,2,243,198,200,172,1,56,247,95,188,159,249,94,245,218,4,8,16,32,64,128,192,40,129,105,123,100,210,0,156,183,184,71,189,227,204,33,64,128,0,1,2,4,10,4,38,77,146,57,3,112,82,236,130,183,169,21,8,16,32,64,128,0,129,161,2,115,70,201,148,1,56,39,245,208,119,155,97,4,8,16,32,64,128,64,135,192,148,89,50,99,0,78,9,221,241,30,181,5,1,2,4,8,16,32,48,90,96,198,48,153,48,0,103,100,30,253,86,51,143,0,1,2,4,8,16,168,17,152,48,77,166,11,192,105,255,235,54,53,239,82,139,16,32,64,128,0,1,2,99,5,230,171,147,217,2,112,194,198,30,251,22,51,141,0,1,2,4,8,16,232,19,152,45,80,38,11,192,217,120,251,222,160,54,34,64,128,0,1,2,4,2,2,147,37,202,92,1,56,25,110,224,237,101,36,1,2,4,8,16,32,80,41,48,87,164,76,21,128,115,209,86,190,59,45,69,128,0,1,2,4,8,100,4,166,202,148,153,2,112,42,216,204,123,203,84,2,4,8,16,32,64,160,85,96,166,80,153,40,0,103,98,109,
125,107,218,139,0,1,2,4,8,16,136,9,76,148,42,211,4,224,124,255,5,235,216,219,203,96,2,4,8,16,32,64,160,82,96,158,90,153,37,0,39,106,234,202,119,164,165,8,16,32,64,128,0,129,3,4,102,9,150,73,2,112,22,206,3,222,89,94,130,0,1,2,4,8,16,232,21,152,36,89,230,8,192,73,48,123,223,141,54,35,64,128,0,1,2,4,142,17,152,35,90,166,8,192,57,40,143,121,91,121,21,2,4,8,16,32,64,160,90,96,138,108,153,33,0,167,128,172,126,43,90,142,0,1,2,4,8,16,56,76,96,134,112,153,32,0,103,96,60,236,61,229,133,8,16,32,64,128,0,129,118,129,9,210,165,63,0,39,64,108,127,31,218,143,0,1,2,4,8,16,56,82,160,63,94,234,3,176,159,240,200,55,148,215,34,64,128,0,1,2,4,38,16,168,207,151,246,0,172,7,156,224,77,104,69,2,4,8,16,32,64,224,96,129,246,128,41,15,192,118,190,131,223,77,94,142,0,1,2,4,8,16,152,67,160,60,97,186,3,176,28,111,142,119,160,45,9,16,32,64,128,0,129,227,5,186,35,166,58,0,187,233,142,127,43,121,69,2,4,8,16,32,64,96,26,129,234,140,105,14,192,106,184,105,222,126,22,37,64,128,0,1,2,4,78,17,104,14,153,222,0,252,
214,204,118,202,251,200,139,18,32,64,128,0,1,2,51,9,20,183,76,109,0,202,191,153,222,225,118,37,64,128,0,1,2,4,46,8,212,230,76,107,0,214,130,93,56,174,31,34,64,128,0,1,2,4,8,92,20,104,13,154,210,0,108,229,186,120,91,63,72,128,0,1,2,4,8,16,184,44,80,154,52,157,1,88,138,117,249,178,126,148,0,1,2,4,8,16,32,112,77,160,51,106,42,3,176,147,234,218,97,253,56,1,2,4,8,16,32,64,224,170,64,101,214,52,6,96,37,212,213,179,250,9,2,4,8,16,32,64,128,192,13,129,198,176,41,12,192,70,166,27,87,245,83,4,8,16,32,64,128,0,129,91,2,133,105,211,23,128,133,72,183,110,234,231,8,16,32,64,128,0,1,2,183,5,250,226,166,47,0,111,11,250,89,2,4,8,16,32,64,128,0,129,55,5,234,2,176,175,145,223,20,246,219,9,16,32,64,128,0,129,221,5,234,242,166,45,0,235,128,118,127,199,122,126,2,4,8,16,32,64,224,125,129,182,192,41,11,192,54,158,247,15,110,2,1,2,4,8,16,32,64,224,159,178,196,233,10,192,50,28,111,87,2,4,8,16,32,64,128,192,24,129,174,200,169,10,192,46,154,49,231,54,133,0,1,2,4,8,16,32,240,93,160,42,115,154,2,176,10,198,
91,149,0,1,2,4,8,16,32,48,82,160,41,116,138,2,176,137,101,228,185,205,34,64,128,0,1,2,4,8,124,23,40,74,157,158,0,44,66,241,38,37,64,128,0,1,2,4,8,140,23,232,137,157,154,0,236,33,25,127,110,19,9,16,32,64,128,0,1,2,223,5,106,114,167,37,0,107,64,188,61,9,16,32,64,128,0,1,2,41,129,150,224,41,9,192,22,142,212,185,205,37,64,128,0,1,2,4,8,124,23,40,73,158,142,0,44,193,240,198,36,64,128,0,1,2,4,8,100,5,58,162,167,34,0,59,40,178,231,54,157,0,1,2,4,8,16,32,240,93,160,34,123,26,2,176,2,194,91,146,0,1,2,4,8,16,32,112,132,64,67,248,52,4,224,17,214,94,131,0,1,2,4,8,16,32,64,224,63,129,130,0,108,232,96,239,7,2,4,8,16,32,64,128,192,65,2,5,233,115,126,0,22,32,28,116,110,47,67,128,0,1,2,4,8,16,248,46,112,126,252,156,30,128,231,19,120,39,18,32,64,128,0,1,2,4,14,21,56,61,127,206,14,192,211,1,14,61,183,23,35,64,128,0,1,2,4,8,124,23,56,59,128,78,14,192,179,31,223,123,144,0,1,2,4,8,16,32,112,130,192,201,9,116,110,0,158,252,240,39,156,219,75,18,32,64,128,0,1,2,4,190,11,156,27,65,167,6,224,185,143,238,
221,71,128,0,1,2,4,8,16,56,77,224,212,12,58,53,0,79,35,247,194,4,8,16,32,64,128,0,129,141,5,206,12,192,83,203,119,227,155,123,116,2,4,8,16,32,64,160,64,224,204,16,58,49,0,207,124,236,130,171,91,129,0,1,2,4,8,16,216,91,224,196,20,58,47,0,79,124,232,189,223,109,158,158,0,1,2,4,8,16,232,16,56,47,134,78,11,192,243,30,185,227,228,182,32,64,128,0,1,2,4,182,23,56,45,135,206,10,192,211,30,120,251,183,26,0,2,4,8,16,32,64,160,70,224,172,32,58,41,0,207,122,220,154,123,91,132,0,1,2,4,8,16,32,112,218,255,28,224,73,1,232,226,4,8,16,32,64,128,0,1,2,103,9,156,19,128,190,1,120,214,189,189,46,1,2,4,8,16,32,80,37,112,78,20,157,18,128,231,60,106,213,181,45,67,128,0,1,2,4,8,16,248,33,112,74,22,157,17,128,167,60,168,247,24,1,2,4,8,16,32,64,160,81,224,140,48,58,33,0,207,120,204,198,115,219,137,0,1,2,4,8,16,32,240,93,224,132,52,58,33,0,157,154,0,1,2,4,8,16,32,64,224,76,129,227,3,240,132,202,61,19,216,107,19,32,64,128,0,1,2,4,110,11,28,31,71,135,7,224,241,143,120,155,220,207,18,32,64,128,0,1,2,4,78,22,
56,60,143,142,14,192,195,31,240,228,131,122,121,2,4,8,16,32,64,128,192,93,129,163,3,233,224,0,60,250,241,238,122,251,5,4,8,16,32,64,128,0,129,243,5,14,78,164,131,3,240,124,95,27,16,32,64,128,0,1,2,4,118,23,56,54,0,15,174,219,221,143,235,249,9,16,32,64,128,0,129,89,4,142,141,164,67,3,240,216,71,155,229,224,246,36,64,128,0,1,2,4,8,28,251,191,6,120,100,0,234,63,239,110,2,4,8,16,32,64,128,192,21,129,35,67,233,192,0,60,242,177,174,200,250,97,2,4,8,16,32,64,128,64,171,192,129,169,116,96,0,182,106,219,139,0,1,2,4,8,16,32,176,151,192,113,1,120,96,213,238,117,66,79,75,128,0,1,2,4,8,172,33,112,92,44,29,22,128,199,61,210,26,111,1,79,65,128,0,1,2,4,8,108,39,112,88,46,29,21,128,135,61,208,118,111,21,15,76,128,0,1,2,4,8,44,35,112,84,48,29,21,128,203,28,198,131,16,32,64,128,0,1,2,4,102,23,56,40,0,143,234,217,217,207,97,127,2,4,8,16,32,64,96,107,129,131,146,233,152,0,60,232,97,182,126,195,120,120,2,4,8,16,32,64,96,1,129,99,162,233,144,0,60,230,81,22,184,185,71,32,64,128,0,1,2,4,118,23,56,36,
155,14,9,192,221,47,233,249,9,16,32,64,128,0,1,2,77,2,71,4,224,33,37,219,132,106,23,2,4,8,16,32,64,128,192,171,2,71,132,211,1,1,120,196,99,188,74,236,247,17,32,64,128,0,1,2,4,202,4,14,72,167,124,0,30,240,16,101,103,179,14,1,2,4,8,16,32,64,224,13,129,124,60,229,3,240,141,199,247,91,9,16,32,64,128,0,1,2,4,198,11,196,3,48,223,176,227,81,76,36,64,128,0,1,2,4,8,156,40,16,207,167,116,0,198,31,224,196,227,120,105,2,4,8,16,32,64,128,64,68,32,29,80,233,0,140,160,24,74,128,0,1,2,4,8,16,32,240,186,64,56,0,211,253,250,250,131,251,157,4,8,16,32,64,128,0,129,90,129,112,66,101,3,48,188,124,237,209,44,70,128,0,1,2,4,8,16,120,75,32,27,81,209,0,204,174,254,150,170,223,76,128,0,1,2,4,8,16,104,22,136,102,84,52,0,155,85,237,70,128,0,1,2,4,8,16,216,85,32,25,128,209,114,221,245,96,158,155,0,1,2,4,8,16,216,67,32,25,82,193,0,76,174,189,199,225,61,37,1,2,4,8,16,32,176,177,64,48,165,130,1,184,241,193,60,58,1,2,4,8,16,32,64,160,88,32,23,128,193,106,45,246,180,26,1,2,4,8,16,32,64,96,144,64,46,166,98,1,152,
91,121,144,169,49,4,8,16,32,64,128,0,129,110,129,88,78,197,2,176,219,211,118,4,8,16,32,64,128,0,129,125,5,82,1,24,43,214,125,79,229,201,9,16,32,64,128,0,129,221,4,82,65,21,10,192,212,186,187,157,221,243,18,32,64,128,0,1,2,91,11,132,146,42,20,128,91,159,202,195,19,32,64,128,0,1,2,4,170,5,50,1,24,170,213,106,73,203,17,32,64,128,0,1,2,4,134,11,100,162,42,18,128,153,85,135,139,26,72,128,0,1,2,4,8,16,104,23,136,100,85,36,0,219,37,237,71,128,0,1,2,4,8,16,216,89,32,17,128,145,82,221,249,72,158,157,0,1,2,4,8,16,216,87,32,17,86,129,0,76,172,185,239,209,61,57,1,2,4,8,16,32,176,185,64,32,173,2,1,184,249,145,60,62,1,2,4,8,16,32,64,160,92,96,124,0,6,42,181,220,208,122,4,8,16,32,64,128,0,129,160,192,248,184,26,30,128,227,87,12,122,26,77,128,0,1,2,4,8,16,232,23,24,158,87,195,3,176,223,208,134,4,8,16,32,64,128,0,129,189,5,70,7,224,240,66,221,251,60,158,158,0,1,2,4,8,16,32,240,207,63,163,3,107,112,0,142,94,207,201,9,16,32,64,128,0,1,2,4,70,23,224,224,0,116,32,2,4,8,16,32,64,128,0,129,118,129,
177,1,232,27,128,237,247,182,31,1,2,4,8,16,32,48,165,192,216,200,26,27,128,83,130,90,154,0,1,2,4,8,16,32,176,151,192,208,0,28,219,166,123,29,194,211,18,32,64,128,0,1,2,4,110,8,12,205,172,145,1,56,116,177,27,0,126,138,0,1,2,4,8,16,32,176,157,192,200,208,26,25,128,219,29,194,3,19,32,64,128,0,1,2,4,102,20,24,24,128,35,187,116,70,74,59,19,32,64,128,0,1,2,4,130,2,3,83,107,96,0,6,31,216,104,2,4,8,16,32,64,128,0,129,97,2,227,2,112,96,149,14,123,58,131,8,16,32,64,128,0,1,2,203,8,140,139,173,97,1,56,110,165,101,174,228,65,8,16,32,64,128,0,1,2,35,5,134,229,214,176,0,28,249,116,102,17,32,64,128,0,1,2,4,8,228,4,70,5,224,176,34,205,61,170,201,4,8,16,32,64,128,0,129,185,5,70,5,215,168,0,156,91,211,246,4,8,16,32,64,128,0,129,141,4,6,5,224,168,30,221,72,222,163,18,32,64,128,0,1,2,4,158,21,24,148,92,99,2,112,208,50,207,26,248,245,4,8,16,32,64,128,0,129,189,4,198,68,215,152,0,220,75,222,211,18,32,64,128,0,1,2,4,166,22,24,18,128,99,90,116,106,71,203,19,32,64,128,0,1,2,4,142,16,24,146,93,67,2,240,
136,167,245,26,4,8,16,32,64,128,0,1,2,99,4,70,4,224,144,18,29,243,56,166,16,32,64,128,0,1,2,4,214,22,24,17,94,35,2,112,109,101,79,71,128,0,1,2,4,8,16,88,76,96,64,0,142,232,208,197,84,61,14,1,2,4,8,16,32,64,32,37,48,32,189,222,15,192,1,75,164,124,204,37,64,128,0,1,2,4,8,172,39,240,126,124,189,31,128,235,169,122,34,2,4,8,16,32,64,128,192,210,2,111,7,224,251,13,186,180,175,135,35,64,128,0,1,2,4,8,140,22,120,59,191,222,14,192,209,79,100,30,1,2,4,8,16,32,64,128,64,86,224,221,0,124,187,64,179,143,103,58,1,2,4,8,16,32,64,96,61,129,119,3,236,221,0,92,79,212,19,17,32,64,128,0,1,2,4,22,23,120,51,0,223,237,207,197,117,61,30,1,2,4,8,16,32,64,32,33,240,102,130,189,25,128,137,39,50,147,0,1,2,4,8,16,32,64,32,41,240,94,0,190,89,159,201,7,51,155,0,1,2,4,8,16,32,176,174,192,123,17,246,86,0,190,247,210,235,158,196,147,17,32,64,128,0,1,2,4,194,2,111,101,216,91,1,24,126,48,227,9,16,32,64,128,0,1,2,4,2,2,239,4,224,91,229,25,120,22,35,9,16,32,64,128,0,1,2,219,8,188,19,98,239,4,224,54,192,30,148,0,1,
2,4,8,16,32,176,146,192,27,1,248,78,119,174,68,232,89,8,16,32,64,128,0,1,2,39,8,188,145,98,111,4,224,9,15,234,37,9,16,32,64,128,0,1,2,4,222,22,120,61,0,223,168,206,183,183,54,128,0,1,2,4,8,16,32,176,189,192,235,49,246,122,0,110,143,14,128,0,1,2,4,8,16,32,48,167,192,203,1,248,122,115,206,9,101,107,2,4,8,16,32,64,128,64,153,192,203,57,246,114,0,150,1,88,135,0,1,2,4,8,16,32,64,224,65,129,87,3,240,229,226,124,112,47,191,140,0,1,2,4,8,16,32,64,224,142,192,171,65,246,106,0,222,89,199,79,19,32,64,128,0,1,2,4,8,180,10,188,24,128,175,246,102,43,131,189,8,16,32,64,128,0,1,2,19,10,188,152,100,47,6,224,132,64,86,38,64,128,0,1,2,4,8,16,248,41,240,90,0,190,88,155,204,9,16,32,64,128,0,1,2,4,70,10,188,22,101,175,5,224,200,189,205,34,64,128,0,1,2,4,8,16,56,84,224,165,0,124,173,53,15,125,46,47,70,128,0,1,2,4,8,16,216,65,224,165,44,123,41,0,119,208,244,140,4,8,16,32,64,128,0,129,85,5,94,9,192,151,74,115,85,64,207,69,128,0,1,2,4,8,16,56,83,224,149,48,123,37,0,207,124,70,175,77,128,0,1,2,4,8,16,32,
240,166,192,11,1,248,74,103,190,185,165,223,78,128,0,1,2,4,8,16,32,112,89,224,133,52,123,33,0,47,191,182,31,37,64,128,0,1,2,4,8,16,152,67,224,249,0,124,161,50,231,160,176,37,1,2,4,8,16,32,64,96,70,129,231,227,236,249,0,156,209,197,206,4,8,16,32,64,128,0,1,2,191,5,158,14,192,231,27,243,247,107,249,7,2,4,8,16,32,64,128,0,129,241,2,79,231,217,211,1,56,126,103,19,9,16,32,64,128,0,1,2,4,142,20,120,54,0,159,46,204,35,31,198,107,17,32,64,128,0,1,2,4,118,20,120,54,208,158,13,192,29,77,61,51,1,2,4,8,16,32,64,96,41,129,39,3,240,217,190,92,202,202,195,16,32,64,128,0,1,2,4,58,5,158,76,180,39,3,176,243,153,109,69,128,0,1,2,4,8,16,32,240,184,128,0,124,220,202,175,36,64,128,0,1,2,4,8,44,33,240,92,0,62,249,237,197,37,132,60,4,1,2,4,8,16,32,64,160,94,224,185,72,123,46,0,235,31,222,130,4,8,16,32,64,128,0,1,2,247,4,158,10,192,231,218,242,222,75,251,121,2,4,8,16,32,64,128,0,129,65,2,79,101,218,83,1,56,104,65,99,8,16,32,64,128,0,1,2,4,78,20,120,38,0,159,42,203,19,159,201,75,19,32,64,128,0,1,2,4,182,
19,120,38,212,158,9,192,237,32,61,48,1,2,4,8,16,32,64,96,69,129,39,2,240,153,174,92,145,202,51,17,32,64,128,0,1,2,4,138,5,158,72,181,39,2,176,248,129,173,70,128,0,1,2,4,8,16,32,240,176,128,0,124,152,202,47,36,64,128,0,1,2,4,8,172,33,240,120,0,62,241,109,197,53,104,60,5,1,2,4,8,16,32,64,96,38,129,199,99,237,241,0,156,233,249,237,74,128,0,1,2,4,8,16,32,112,85,224,225,0,124,188,41,175,190,150,159,32,64,128,0,1,2,4,8,16,200,9,60,156,107,15,7,96,110,87,147,9,16,32,64,128,0,1,2,4,142,20,120,52,0,31,46,202,35,151,247,90,4,8,16,32,64,128,0,1,2,127,4,30,13,182,71,3,240,207,100,255,68,128,0,1,2,4,8,16,32,48,181,128,0,156,250,124,150,39,64,128,0,1,2,4,8,60,47,240,96,0,62,250,13,197,231,23,240,59,8,16,32,64,128,0,1,2,4,6,9,60,152,108,15,6,224,160,165,140,33,64,128,0,1,2,4,8,16,56,93,224,177,0,124,176,38,79,127,26,11,16,32,64,128,0,1,2,4,182,22,120,44,218,30,11,192,173,33,61,60,1,2,4,8,16,32,64,96,45,1,1,184,214,61,61,13,1,2,4,8,16,32,64,224,174,192,67,1,248,216,55,19,239,190,150,95,64,128,
0,1,2,4,8,16,32,144,21,120,40,219,30,10,192,236,158,166,19,32,64,128,0,1,2,4,8,28,41,240,72,0,62,84,146,71,46,237,181,8,16,32,64,128,0,1,2,4,46,11,60,18,110,143,4,224,229,233,126,148,0,1,2,4,8,16,32,64,96,74,1,1,56,229,217,44,77,128,0,1,2,4,8,16,120,93,224,129,0,124,228,27,137,175,47,224,119,18,32,64,128,0,1,2,4,8,12,20,120,32,221,30,8,192,129,11,25,69,128,0,1,2,4,8,16,32,112,186,192,253,0,124,160,34,79,127,10,11,16,32,64,128,0,1,2,4,8,252,39,112,63,222,238,7,32,76,2,4,8,16,32,64,128,0,129,165,4,4,224,82,231,244,48,4,8,16,32,64,128,0,129,251,2,119,3,240,254,55,17,239,191,136,95,65,128,0,1,2,4,8,16,32,112,152,192,221,124,187,27,128,135,173,234,133,8,16,32,64,128,0,1,2,4,14,17,16,128,135,48,123,17,2,4,8,16,32,64,128,64,143,192,189,0,188,251,45,196,158,71,177,9,1,2,4,8,16,32,64,128,192,15,129,123,1,119,47,0,41,18,32,64,128,0,1,2,4,8,44,38,112,39,0,239,245,227,98,26,30,135,0,1,2,4,8,16,32,176,130,192,157,132,187,19,128,43,8,120,6,2,4,8,16,32,64,128,0,129,143,2,2,240,163,134,127,38,
64,128,0,1,2,4,8,108,32,112,59,0,239,124,251,112,3,31,143,72,128,0,1,2,4,8,16,152,80,224,118,196,221,14,192,9,31,215,202,4,8,16,32,64,128,0,1,2,183,5,4,224,109,31,63,75,128,0,1,2,4,8,16,88,78,224,102,0,222,254,230,225,114,22,30,136,0,1,2,4,8,16,32,176,138,192,205,140,187,25,128,171,8,120,14,2,4,8,16,32,64,128,0,129,63,2,2,240,143,133,127,34,64,128,0,1,2,4,8,108,33,112,43,0,111,126,235,112,11,29,15,73,128,0,1,2,4,8,16,152,84,224,86,200,221,10,192,73,31,215,218,4,8,16,32,64,128,0,1,2,183,4,4,224,45,29,63,71,128,0,1,2,4,8,16,88,80,224,70,0,222,250,198,225,130,18,30,137,0,1,2,4,8,16,32,176,146,192,141,148,187,17,128,43,9,120,22,2,4,8,16,32,64,128,0,129,95,2,2,240,151,132,127,37,64,128,0,1,2,4,8,108,34,112,61,0,111,124,219,112,19,27,143,73,128,0,1,2,4,8,16,152,88,224,122,204,93,15,192,137,31,215,234,4,8,16,32,64,128,0,1,2,215,5,4,224,117,27,63,67,128,0,1,2,4,8,16,88,82,224,106,0,94,255,166,225,146,14,30,138,0,1,2,4,8,16,32,176,154,192,213,156,187,26,128,171,9,120,30,2,4,8,16,32,64,
128,0,129,127,5,4,160,119,2,1,2,4,8,16,32,64,96,51,129,107,1,120,245,91,134,155,249,120,92,2,4,8,16,32,64,128,192,180,2,215,130,238,90,0,78,251,160,22,39,64,128,0,1,2,4,8,16,184,45,32,0,111,251,248,89,2,4,8,16,32,64,128,192,114,2,87,2,240,218,55,12,151,123,126,15,68,128,0,1,2,4,8,16,88,87,224,74,210,93,9,192,117,29,60,25,1,2,4,8,16,32,64,96,119,1,1,184,251,59,192,243,19,32,64,128,0,1,2,219,9,92,14,192,43,223,46,220,78,199,3,19,32,64,128,0,1,2,4,166,22,184,28,117,151,3,112,234,7,181,60,1,2,4,8,16,32,64,128,192,45,1,1,120,75,199,207,17,32,64,128,0,1,2,4,22,20,16,128,11,30,213,35,17,32,64,128,0,1,2,4,110,9,92,12,192,203,127,91,124,107,140,159,35,64,128,0,1,2,4,8,16,40,20,184,152,117,23,3,176,112,121,43,17,32,64,128,0,1,2,4,8,12,18,16,128,131,32,141,33,64,128,0,1,2,4,8,204,34,112,41,0,47,126,171,112,150,7,178,39,1,2,4,8,16,32,64,128,192,31,129,75,97,119,41,0,255,252,14,255,68,128,0,1,2,4,8,16,32,176,156,128,0,92,238,164,30,136,0,1,2,4,8,16,32,112,91,64,0,222,246,241,179,4,8,16,32,
64,128,0,129,229,4,46,4,224,165,191,41,94,238,185,61,16,1,2,4,8,16,32,64,96,15,129,11,105,119,33,0,247,176,240,148,4,8,16,32,64,128,0,129,93,5,4,224,174,151,247,220,4,8,16,32,64,128,192,182,2,95,3,240,194,183,9,183,213,241,224,4,8,16,32,64,128,0,129,233,5,190,198,221,215,0,156,254,33,61,0,1,2,4,8,16,32,64,128,192,45,1,1,120,75,199,207,17,32,64,128,0,1,2,4,22,20,16,128,11,30,213,35,17,32,64,128,0,1,2,4,110,9,124,9,192,175,127,75,124,235,183,251,57,2,4,8,16,32,64,128,0,129,114,129,47,121,247,37,0,203,31,192,122,4,8,16,32,64,128,0,1,2,111,10,8,192,55,1,253,118,2,4,8,16,32,64,128,192,108,2,2,112,182,139,217,151,0,1,2,4,8,16,32,240,166,192,231,0,252,242,119,196,111,206,247,219,9,16,32,64,128,0,1,2,4,78,22,248,28,120,159,3,240,228,245,188,60,1,2,4,8,16,32,64,128,64,90,64,0,166,133,205,39,64,128,0,1,2,4,8,148,9,8,192,178,131,88,135,0,1,2,4,8,16,32,144,22,248,20,128,159,255,134,56,253,242,230,19,32,64,128,0,1,2,4,8,196,5,62,37,222,167,0,140,191,188,23,32,64,128,0,1,2,4,8,16,56,89,64,
0,158,124,0,47,79,128,0,1,2,4,8,16,56,90,64,0,30,45,238,245,8,16,32,64,128,0,1,2,39,11,252,29,128,159,254,126,248,228,221,188,60,1,2,4,8,16,32,64,128,192,16,129,191,35,239,239,0,28,242,2,134,16,32,64,128,0,1,2,4,8,52,11,8,192,230,235,216,141,0,1,2,4,8,16,32,16,16,16,128,1,84,35,9,16,32,64,128,0,1,2,205,2,127,5,224,223,127,59,220,188,182,221,8,16,32,64,128,0,1,2,4,158,16,248,43,243,254,10,192,39,134,248,165,4,8,16,32,64,128,0,1,2,147,10,8,192,73,15,103,109,2,4,8,16,32,64,128,192,171,2,2,240,85,57,191,143,0,1,2,4,8,16,32,48,169,128,0,156,244,112,214,38,64,128,0,1,2,4,8,188,42,240,49,0,255,250,15,7,190,58,208,239,35,64,128,0,1,2,4,8,16,232,19,248,24,122,31,3,176,111,83,27,17,32,64,128,0,1,2,4,8,12,23,16,128,195,73,13,36,64,128,0,1,2,4,8,116,11,8,192,238,251,216,142,0,1,2,4,8,16,32,48,92,224,67,0,126,252,155,225,225,175,99,32,1,2,4,8,16,32,64,128,192,153,2,31,82,239,67,0,158,185,145,215,38,64,128,0,1,2,4,8,16,56,74,64,0,30,37,237,117,8,16,32,64,128,0,1,2,37,2,2,176,228,16,214,32,
64,128,0,1,2,4,8,28,37,32,0,143,146,246,58,4,8,16,32,64,128,0,129,18,129,63,1,248,225,63,24,88,178,155,53,8,16,32,64,128,0,1,2,4,134,9,252,137,189,63,1,56,108,184,65,4,8,16,32,64,128,0,1,2,205,2,2,176,249,58,118,35,64,128,0,1,2,4,8,4,4,4,96,0,213,72,2,4,8,16,32,64,128,64,179,128,0,108,190,142,221,8,16,32,64,128,0,1,2,1,129,223,1,248,231,63,22,24,120,21,35,9,16,32,64,128,0,1,2,4,206,22,248,157,123,191,3,240,236,141,188,62,1,2,4,8,16,32,64,128,192,49,2,2,240,24,103,175,66,128,0,1,2,4,8,16,168,17,16,128,53,167,176,8,1,2,4,8,16,32,64,224,24,1,1,120,140,179,87,33,64,128,0,1,2,4,8,212,8,8,192,154,83,88,132,0,1,2,4,8,16,32,112,140,192,175,0,252,253,223,10,57,230,101,189,10,1,2,4,8,16,32,64,128,192,209,2,191,130,239,87,0,30,253,250,94,143,0,1,2,4,8,16,32,64,224,36,1,1,120,18,188,151,37,64,128,0,1,2,4,8,156,37,32,0,207,146,247,186,4,8,16,32,64,128,0,129,147,4,4,224,73,240,94,150,0,1,2,4,8,16,32,112,150,128,0,60,75,222,235,18,32,64,128,0,1,2,4,78,18,248,47,0,127,253,119,66,78,218,194,203,
18,32,64,128,0,1,2,4,8,228,5,254,75,62,223,1,204,83,123,5,2,4,8,16,32,64,128,64,149,128,0,172,58,135,101,8,16,32,64,128,0,1,2,121,1,1,152,55,246,10,4,8,16,32,64,128,0,129,42,1,1,88,117,14,203,16,32,64,128,0,1,2,4,242,2,2,48,111,236,21,8,16,32,64,128,0,1,2,85,2,255,6,160,255,18,112,213,81,44,67,128,0,1,2,4,8,16,200,8,252,27,125,190,3,152,209,53,149,0,1,2,4,8,16,32,80,43,32,0,107,79,99,49,2,4,8,16,32,64,128,64,70,64,0,102,92,77,37,64,128,0,1,2,4,8,212,10,8,192,218,211,88,140,0,1,2,4,8,16,32,144,17,16,128,25,87,83,9,16,32,64,128,0,1,2,181,2,2,176,246,52,22,35,64,128,0,1,2,4,8,100,4,126,6,160,255,21,152,12,174,169,4,8,16,32,64,128,0,129,50,129,159,217,231,59,128,101,87,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,224,71,0,250,95,129,41,59,138,117,8,16,32,64,128,0,1,2,41,129,31,225,231,
59,128,41,93,115,9,16,32,64,128,0,1,2,165,2,2,176,244,48,214,34,64,128,0,1,2,4,8,164,4,4,96,74,214,92,2,4,8,16,32,64,128,64,169,128,0,44,61,140,181,8,16,32,64,128,0,1,2,41,1,1,152,146,53,151,0,1,2,4,8,16,32,80,42,32,0,75,15,99,45,2,4,8,16,32,64,128,64,74,64,0,166,100,205,37,64,128,0,1,2,4,8,148,10,8,192,210,195,88,139,0,1,2,4,8,16,32,144,18,248,30,128,254,119,160,83,184,230,18,32,64,128,0,1,2,4,234,4,190,167,159,239,0,214,93,197,66,4,8,16,32,64,128,0,129,172,128,0,204,250,154,78,128,0,1,2,4,8,16,168,19,16,128,117,39,177,16,1,2,4,8,16,32,64,32,43,32,0,179,190,166,19,32,64,128,0,1,2,4,234,4,4,96,221,73,44,68,128,0,1,2,4,8,16,200,10,8,192,172,175,233,4,8,16,32,64,128,0,129,58,1,1,88,119,18,11,17,32,64,128,0,1,2,4,178,2,2,48,235,107,58,1,2,4,8,16,32,64,160,78,64,0,214,157,196,66,4,8,16,32,64,128,0,129,172,192,255,252,63,2,201,2,155,78,128,0,1,2,4,8,16,232,18,248,230,255,19,72,215,65,108,67,128,0,1,2,4,8,16,200,11,248,43,224,188,177,87,32,64,128,0,1,2,4,8,84,9,8,192,170,115,88,134,
0,1,2,4,8,16,32,144,23,16,128,121,99,175,64,128,0,1,2,4,8,16,168,18,16,128,85,231,176,12,1,2,4,8,16,32,64,32,47,32,0,243,198,94,129,0,1,2,4,8,16,32,80,37,32,0,171,206,97,25,2,4,8,16,32,64,128,64,94,64,0,230,141,189,2,1,2,4,8,16,32,64,160,74,64,0,86,157,195,50,4,8,16,32,64,128,0,129,188,128,0,204,27,123,5,2,4,8,16,32,64,128,64,149,128,0,172,58,135,101,8,16,32,64,128,0,1,2,121,1,1,152,55,246,10,4,8,16,32,64,128,0,129,42,129,111,223,170,214,177,12,1,2,4,8,16,32,64,128,64,90,192,119,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,
2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,
0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,
16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,
1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,
32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,
4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,
128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,
32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,
128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,
64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,
1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,
128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,
4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,
0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,
32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,
8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,
32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,
8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,
128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,
32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,
1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,
128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,
8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,
1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,
16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,
4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,
67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,
19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,
14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,
79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,
4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,
1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,
16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,
4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,
67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,
19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,
14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,
79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,
4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,
1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,
16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,19,32,64,128,0,1,2,4,202,4,4,96,217,65,172,67,128,0,1,2,4,8,16,72,11,8,192,180,176,249,
4,8,16,32,64,128,0,129,50,1,1,88,118,16,235,16,32,64,128,0,1,2,4,210,2,2,48,45,108,62,1,2,4,8,16,32,64,160,76,64,0,150,29,196,58,4,8,16,32,64,128,0,129,180,128,0,76,11,155,79,128,0,1,2,4,8,16,40,19,16,128,101,7,177,14,1,2,4,8,16,32,64,32,45,32,0,211,194,230,255,127,123,247,162,27,57,142,44,1,180,247,254,255,63,239,117,247,142,123,252,46,73,165,144,130,228,89,44,208,126,148,82,201,147,42,32,64,218,30,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,
210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,
64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,
16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,
88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,
128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,
1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,
16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,
237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,
96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,
153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,
0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,
8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,
16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,
2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,
64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,
128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,
2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,
54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,
2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,
64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,
128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,
2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,
54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,
2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,
64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,
128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,
2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,
54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,128,0,88,54,16,237,16,32,64,128,0,1,2,4,210,2,2,96,90,88,125,2,4,8,16,32,64,128,64,153,192,127,126,253,167,172,35,237,16,32,64,128,0,1,2,4,8,36,5,254,107,7,48,201,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,0,1,2,73,1,1,48,169,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,0,1,2,73,1,1,48,169,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,0,1,2,73,1,1,48,169,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,0,1,2,73,1,1,48,169,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,0,1,2,73,1,1,48,169,171,54,1,2,4,8,16,32,64,160,80,64,0,44,28,138,150,8,16,32,64,128,
0,1,2,73,129,255,252,250,245,242,127,255,35,64,128,0,1,2,4,8,16,88,68,224,191,191,236,0,46,50,106,203,36,64,128,0,1,2,4,8,188,10,8,128,175,18,254,37,64,128,0,1,2,4,8,44,34,32,0,46,50,104,203,36,64,128,0,1,2,4,8,188,10,8,128,175,18,254,37,64,128,0,1,2,4,8,44,34,32,0,46,50,104,203,36,64,128,0,1,2,4,8,188,10,8,128,175,18,254,37,64,128,0,1,2,4,8,44,34,32,0,46,50,104,203,36,64,128,0,1,2,4,8,188,10,8,128,175,18,254,37,64,128,0,1,2,4,8,44,34,32,0,46,50,104,203,36,64,128,0,1,2,4,8,188,10,252,254,207,128,248,79,129,188,106,248,151,0,1,2,4,8,16,32,48,187,192,127,127,249,47,129,204,62,99,235,35,64,128,0,1,2,4,8,124,20,112,4,252,81,196,231,4,8,16,32,64,128,0,129,201,5,4,192,201,7,108,121,4,8,16,32,64,128,0,129,143,2,2,224,71,17,159,19,32,64,128,0,1,2,4,38,23,16,0,39,31,176,229,17,32,64,128,0,1,2,4,62,10,8,128,31,69,124,78,128,0,1,2,4,8,16,152,92,64,0,156,124,192,150,71,128,0,1,2,4,8,16,248,40,32,0,126,20,241,57,1,2,4,8,16,32,64,96,114,129,63,127,4,218,95,130,158,124,202,150,71,128,0,1,2,
4,8,16,248,71,224,229,239,64,251,67,208,158,6,2,4,8,16,32,64,128,192,106,2,142,128,87,155,184,245,18,32,64,128,0,1,2,203,11,8,128,203,63,2,0,8,16,32,64,128,0,129,213,4,4,192,213,38,110,189,4,8,16,32,64,128,192,242,2,2,224,242,143,0,0,2,4,8,16,32,64,96,53,1,1,112,181,137,91,47,1,2,4,8,16,32,176,188,192,255,254,2,140,191,3,179,252,131,0,128,0,1,2,4,8,16,88,66,224,247,95,129,241,103,96,150,24,181,69,18,32,64,128,0,1,2,4,222,8,56,2,126,131,225,67,2,4,8,16,32,64,128,192,10,2,2,224,10,83,182,70,2,4,8,16,32,64,128,192,27,1,1,240,13,134,15,9,16,32,64,128,0,1,2,43,8,8,128,43,76,217,26,9,16,32,64,128,0,1,2,111,4,4,192,55,24,62,36,64,128,0,1,2,4,8,172,32,240,207,31,128,241,119,96,86,24,182,53,18,32,64,128,0,1,2,171,11,252,249,43,48,254,12,204,234,143,129,245,19,32,64,128,0,1,2,235,9,56,2,94,111,230,86,76,128,0,1,2,4,8,44,46,32,0,46,254,0,88,62,1,2,4,8,16,32,176,158,128,0,184,222,204,173,152,0,1,2,4,8,16,88,92,64,0,92,252,1,176,124,2,4,8,16,32,64,96,61,129,215,95,255,125,253,119,61,1,43,
38,64,128,0,1,2,4,8,172,34,240,191,95,2,246,91,192,171,204,219,58,9,16,32,64,128,0,1,2,175,2,142,128,95,37,252,75,128,0,1,2,4,8,16,88,68,64,0,92,100,208,150,73,128,0,1,2,4,8,16,120,21,16,0,95,37,252,75,128,0,1,2,4,8,16,88,68,64,0,92,100,208,150,73,128,0,1,2,4,8,16,120,21,248,251,219,191,127,63,120,253,142,127,9,16,32,64,128,0,1,2,4,166,18,248,231,151,128,253,22,240,84,83,181,24,2,4,8,16,32,64,128,192,6,1,71,192,27,144,188,132,0,1,2,4,8,16,32,48,147,128,0,56,211,52,173,133,0,1,2,4,8,16,32,176,65,64,0,220,128,228,37,4,8,16,32,64,128,0,129,153,4,4,192,153,166,105,45,4,8,16,32,64,128,0,129,13,2,255,254,242,239,191,31,109,184,204,75,8,16,32,64,128,0,1,2,4,6,19,120,253,37,96,191,5,60,216,224,180,75,128,0,1,2,4,8,16,120,90,192,17,240,211,132,10,16,32,64,128,0,1,2,4,198,18,16,0,199,154,151,110,9,16,32,64,128,0,1,2,79,11,8,128,79,19,42,64,128,0,1,2,4,8,16,24,75,224,205,175,126,188,249,112,172,53,232,150,0,1,2,4,8,16,32,64,224,161,192,223,223,1,241,75,32,15,173,188,128,0,1,2,4,8,16,32,
48,153,128,35,224,201,6,106,57,4,8,16,32,64,128,0,129,71,2,2,224,35,33,223,39,64,128,0,1,2,4,8,76,38,32,0,78,54,80,203,33,64,128,0,1,2,4,8,60,18,120,251,155,31,111,63,126,116,157,239,19,32,64,128,0,1,2,4,8,140,36,240,239,239,128,248,37,144,145,230,166,87,2,4,8,16,32,64,128,192,25,2,142,128,207,80,84,131,0,1,2,4,8,16,32,48,144,128,0,56,208,176,180,74,128,0,1,2,4,8,16,56,67,224,221,207,253,189,251,228,140,234,106,16,32,64,128,0,1,2,4,8,84,8,188,249,17,64,63,3,88,49,17,77,16,32,64,128,0,1,2,4,46,20,112,4,124,33,182,91,17,32,64,128,0,1,2,4,26,4,4,192,134,41,232,129,0,1,2,4,8,16,32,112,161,128,0,120,33,182,91,17,32,64,128,0,1,2,4,26,4,222,255,222,199,251,207,26,250,211,3,1,2,4,8,16,32,64,128,192,243,2,111,127,7,196,47,129,60,239,169,2,1,2,4,8,16,32,64,96,44,1,71,192,99,205,75,183,4,8,16,32,64,128,0,129,167,5,4,192,167,9,21,32,64,128,0,1,2,4,8,140,37,240,225,167,254,62,124,58,214,90,116,75,128,0,1,2,4,8,16,32,240,165,192,187,31,1,244,51,128,95,26,249,34,1,2,4,8,16,32,64,96,98,1,71,
192,19,15,215,210,8,16,32,64,128,0,1,2,95,9,8,128,95,169,248,26,1,2,4,8,16,32,64,96,98,129,143,63,244,247,241,243,137,151,110,105,4,8,16,32,64,128,0,129,69,4,222,255,8,160,159,1,92,100,236,150,73,128,0,1,2,4,8,16,248,43,224,8,248,47,133,15,8,16,32,64,128,0,1,2,107,8,8,128,107,204,217,42,9,16,32,64,128,0,1,2,127,5,62,253,204,223,167,47,252,125,169,15,8,16,32,64,128,0,1,2,4,70,20,248,240,35,128,126,6,112,196,33,234,153,0,1,2,4,8,16,32,240,140,128,35,224,103,244,92,75,128,0,1,2,4,8,16,24,80,64,0,28,112,104,90,38,64,128,0,1,2,4,8,60,35,240,249,71,254,62,127,229,153,250,174,37,64,128,0,1,2,4,8,16,184,87,224,227,143,0,250,25,192,123,231,225,238,4,8,16,32,64,128,0,129,235,5,28,1,95,111,238,142,4,8,16,32,64,128,0,129,91,5,4,192,91,249,221,156,0,1,2,4,8,16,32,112,189,192,23,63,241,247,197,151,174,239,203,29,9,16,32,64,128,0,1,2,4,78,17,248,244,35,128,126,6,240,20,87,69,8,16,32,64,128,0,1,2,3,9,56,2,30,104,88,90,37,64,128,0,1,2,4,8,156,33,240,213,121,239,87,95,59,227,94,106,16,32,64,128,
0,1,2,4,8,92,45,240,249,4,216,17,240,213,51,112,63,2,4,8,16,32,64,128,192,221,2,142,128,239,158,128,251,19,32,64,128,0,1,2,4,46,22,16,0,47,6,119,59,2,4,8,16,32,64,128,192,221,2,95,254,188,223,151,95,188,187,83,247,39,64,128,0,1,2,4,8,16,216,45,240,197,143,0,250,25,192,221,138,46,32,64,128,0,1,2,4,8,12,46,224,8,120,240,1,106,159,0,1,2,4,8,16,32,176,87,224,235,211,222,175,191,186,183,182,215,19,32,64,128,0,1,2,4,8,220,43,240,213,9,176,35,224,123,103,226,238,4,8,16,32,64,128,0,129,235,5,28,1,95,111,238,142,4,8,16,32,64,128,0,129,91,5,4,192,91,249,221,156,0,1,2,4,8,16,32,112,189,192,55,63,237,247,205,151,175,239,207,29,9,16,32,64,128,0,1,2,4,14,11,124,249,35,128,126,6,240,176,167,11,9,16,32,64,128,0,1,2,131,10,56,2,30,116,112,218,38,64,128,0,1,2,4,8,28,21,248,238,172,247,187,175,31,189,143,235,8,16,32,64,128,0,1,2,4,174,22,248,250,4,216,17,240,213,115,112,63,2,4,8,16,32,64,128,192,221,2,142,128,239,158,128,251,19,32,64,128,0,1,2,4,46,22,248,246,168,247,219,111,92,220,160,219,17,32,
64,128,0,1,2,4,8,28,19,248,230,4,216,17,240,49,78,87,17,32,64,128,0,1,2,4,198,21,112,4,60,238,236,116,78,128,0,1,2,4,8,16,56,36,240,253,73,239,247,223,57,116,35,23,17,32,64,128,0,1,2,4,8,92,42,240,221,9,176,35,224,75,199,224,102,4,8,16,32,64,128,0,129,2,1,71,192,5,67,208,2,1,2,4,8,16,32,64,224,74,129,31,14,122,127,248,214,149,29,186,23,1,2,4,8,16,32,64,128,192,1,129,111,79,128,29,1,31,208,116,9,1,2,4,8,16,32,64,96,104,1,71,192,67,143,79,243,4,8,16,32,64,128,0,129,253,2,63,157,243,254,244,189,253,119,114,5,1,2,4,8,16,32,64,128,192,117,2,223,159,0,59,2,190,110,10,238,68,128,0,1,2,4,8,16,232,16,112,4,220,49,7,93,16,32,64,128,0,1,2,4,46,19,248,241,152,247,199,111,94,214,162,27,17,32,64,128,0,1,2,4,8,236,21,248,225,4,216,17,240,94,76,175,39,64,128,0,1,2,4,8,140,46,224,8,120,244,9,234,159,0,1,2,4,8,16,32,176,83,224,231,83,222,159,191,187,243,86,94,78,128,0,1,2,4,8,16,32,112,145,192,79,39,192,142,128,47,26,130,219,16,32,64,128,0,1,2,4,106,4,28,1,215,140,66,35,4,8,16,32,64,128,0,129,
107,4,30,28,242,62,248,246,53,61,186,11,1,2,4,8,16,32,64,128,192,46,129,31,79,128,29,1,239,178,244,98,2,4,8,16,32,64,128,192,4,2,142,128,39,24,162,37,16,32,64,128,0,1,2,4,246,8,60,58,227,125,244,253,61,247,242,90,2,4,8,16,32,64,128,0,129,43,4,126,62,1,118,4,124,197,12,220,131,0,1,2,4,8,16,32,208,36,240,112,135,239,225,11,154,86,163,23,2,4,8,16,32,64,128,0,129,95,15,54,0,237,0,122,70,8,16,32,64,128,0,1,2,171,9,248,37,144,213,38,110,189,4,8,16,32,64,128,192,242,2,143,79,120,31,191,98,121,68,0,4,8,16,32,64,128,0,129,34,129,71,39,192,142,128,139,134,165,21,2,4,8,16,32,64,128,192,37,2,142,128,47,97,118,19,2,4,8,16,32,64,128,64,143,192,134,3,222,13,47,233,89,143,78,8,16,32,64,128,0,1,2,139,11,60,60,1,118,4,188,248,19,98,249,4,8,16,32,64,128,192,130,2,91,182,247,182,188,102,65,58,75,38,64,128,0,1,2,4,8,20,10,60,222,0,180,3,88,56,54,45,17,32,64,128,0,1,2,4,162,2,126,9,36,202,171,56,1,2,4,8,16,32,64,160,79,96,211,241,238,166,23,245,173,77,71,4,8,16,32,64,128,0,129,229,4,54,156,0,59,2,
94,238,169,176,96,2,4,8,16,32,64,96,121,129,109,155,123,219,94,181,60,38,0,2,4,8,16,32,64,128,192,205,2,91,54,0,237,0,222,60,36,183,39,64,128,0,1,2,4,8,92,46,224,151,64,46,39,119,67,2,4,8,16,32,64,128,192,189,2,27,15,119,55,190,236,222,181,184,59,1,2,4,8,16,32,64,96,113,129,77,39,192,142,128,23,127,74,44,159,0,1,2,4,8,16,88,80,96,235,214,222,214,215,45,72,104,201,4,8,16,32,64,128,0,129,18,129,109,27,128,118,0,75,198,165,13,2,4,8,16,32,64,128,192,101,2,126,9,228,50,106,55,34,64,128,0,1,2,4,8,116,8,108,62,218,221,252,194,142,117,233,130,0,1,2,4,8,16,32,176,156,192,198,19,96,71,192,203,61,25,22,76,128,0,1,2,4,8,44,47,176,125,99,111,251,43,151,71,5,64,128,0,1,2,4,8,16,184,65,96,235,6,160,29,192,27,134,227,150,4,8,16,32,64,128,0,129,91,5,118,236,235,237,120,233,173,75,114,115,2,4,8,16,32,64,128,192,138,2,155,55,0,237,0,174,248,120,88,51,1,2,4,8,16,32,176,182,128,63,3,179,246,252,173,158,0,1,2,4,8,16,88,80,96,207,185,238,158,215,46,72,105,201,4,8,16,32,64,128,0,129,27,5,182,159,0,59,
2,190,113,76,110,77,128,0,1,2,4,8,16,184,69,96,215,174,222,174,23,223,178,28,55,37,64,128,0,1,2,4,8,172,41,176,99,3,208,14,224,154,143,136,85,19,32,64,128,0,1,2,43,11,236,219,212,219,247,234,149,93,173,157,0,1,2,4,8,16,32,112,165,192,158,13,64,59,128,87,78,198,189,8,16,32,64,128,0,1,2,13,2,59,247,244,118,190,188,97,133,122,32,64,128,0,1,2,4,8,76,47,176,107,3,208,14,224,244,207,131,5,18,32,64,128,0,1,2,4,62,8,248,67,208,31,64,124,74,128,0,1,2,4,8,16,152,93,96,239,153,238,222,215,207,238,103,125,4,8,16,32,64,128,0,129,251,5,246,157,0,59,2,190,127,98,58,32,64,128,0,1,2,4,8,92,43,176,123,71,111,247,5,215,174,199,221,8,16,32,64,128,0,1,2,203,9,236,220,0,180,3,184,220,19,98,193,4,8,16,32,64,128,192,242,2,251,55,244,246,95,177,60,50,0,2,4,8,16,32,64,128,64,80,96,239,6,160,29,192,224,48,148,38,64,128,0,1,2,4,8,84,10,28,216,207,59,112,73,229,210,53,69,128,0,1,2,4,8,16,152,65,96,247,6,160,29,192,25,198,110,13,4,8,16,32,64,128,0,129,61,2,71,182,243,142,92,179,167,39,175,37,64,128,0,1,2,
4,8,16,216,42,176,127,3,208,14,224,86,91,175,35,64,128,0,1,2,4,8,204,34,112,104,55,239,208,69,179,136,89,7,1,2,4,8,16,32,64,160,72,224,192,6,160,29,192,162,249,105,133,0,1,2,4,8,16,32,112,137,192,177,205,188,99,87,93,178,32,55,33,64,128,0,1,2,4,8,44,36,112,100,3,208,14,224,66,15,136,165,18,32,64,128,0,1,2,4,254,8,28,220,203,59,120,25,116,2,4,8,16,32,64,128,0,129,19,5,14,109,0,218,1,60,113,2,74,17,32,64,128,0,1,2,4,134,16,56,186,149,119,244,186,33,80,52,73,128,0,1,2,4,8,16,24,66,224,216,6,160,29,192,33,134,171,73,2,4,8,16,32,64,128,192,137,2,135,119,242,14,95,120,98,243,74,17,32,64,128,0,1,2,4,86,22,56,184,1,104,7,112,229,135,198,218,9,16,32,64,128,0,129,53,5,142,111,228,29,191,114,77,105,171,38,64,128,0,1,2,4,8,156,43,112,116,3,208,14,224,185,115,80,141,0,1,2,4,8,16,32,208,47,240,196,62,222,19,151,246,187,232,144,0,1,2,4,8,16,32,80,46,112,120,3,208,14,96,249,100,181,71,128,0,1,2,4,8,16,56,93,224,153,109,188,103,174,61,125,33,10,18,32,64,128,0,1,2,4,150,18,56,190,1,104,7,112,169,
7,197,98,9,16,32,64,128,0,1,2,47,2,79,237,226,61,117,49,126,2,4,8,16,32,64,128,0,129,195,2,79,108,0,218,1,60,172,238,66,2,4,8,16,32,64,128,192,160,2,207,109,226,61,119,245,160,100,218,38,64,128,0,1,2,4,8,220,46,240,204,6,224,115,71,192,79,158,32,223,46,167,1,2,4,8,16,32,64,128,192,152,2,79,229,63,71,192,99,14,93,215,4,8,16,32,64,128,0,129,227,2,207,30,226,62,123,253,241,206,93,73,128,0,1,2,4,8,16,88,85,224,185,13,64,59,128,171,62,55,214,77,128,0,1,2,4,8,172,43,240,244,14,222,211,5,214,181,183,114,2,4,8,16,32,64,128,192,33,129,39,55,0,237,0,30,82,119,17,1,2,4,8,16,32,64,96,96,129,231,55,240,158,175,48,48,159,214,9,16,32,64,128,0,1,2,151,11,60,187,1,104,7,240,242,145,185,33,1,2,4,8,16,32,64,224,102,129,19,246,239,78,40,113,51,130,219,19,32,64,128,0,1,2,4,198,17,120,122,3,240,217,63,4,253,135,74,2,28,231,137,209,41,1,2,4,8,16,32,48,186,192,243,249,207,17,240,232,207,128,254,9,16,32,64,128,0,1,2,123,5,78,217,189,59,165,200,222,206,189,158,0,1,2,4,8,16,32,176,160,192,9,27,128,118,
0,23,124,110,44,153,0,1,2,4,8,16,88,92,224,156,205,187,115,170,44,62,10,203,39,64,128,0,1,2,4,8,60,20,56,99,3,208,14,224,67,102,47,32,64,128,0,1,2,4,8,76,38,112,210,222,221,73,101,38,195,181,28,2,4,8,16,32,64,128,192,185,2,167,108,0,158,242,103,96,126,175,75,2,60,119,186,170,17,32,64,128,0,1,2,4,62,11,156,147,255,28,1,127,150,245,21,2,4,8,16,32,64,128,192,220,2,167,237,220,157,86,104,110,111,171,35,64,128,0,1,2,4,8,28,22,56,105,3,208,14,224,225,9,184,144,0,1,2,4,8,16,32,48,168,192,121,27,119,231,85,26,148,82,219,4,8,16,32,64,128,0,129,168,192,89,27,128,103,254,242,134,4,24,29,185,226,4,8,16,32,64,128,192,226,2,167,229,63,71,192,139,63,73,150,79,128,0,1,2,4,8,44,40,112,230,182,221,153,181,22,28,133,37,19,32,64,128,0,1,2,4,126,16,56,111,3,208,14,224,15,204,190,69,128,0,1,2,4,8,16,152,82,224,212,93,187,83,139,77,201,109,81,4,8,16,32,64,128,0,129,99,2,39,110,0,158,249,75,32,47,139,145,0,143,77,212,85,4,8,16,32,64,128,0,129,159,5,206,204,127,142,128,127,182,246,93,2,4,8,16,32,64,128,
192,124,2,39,239,217,157,92,110,62,111,43,34,64,128,0,1,2,4,8,28,16,56,117,3,208,14,224,129,9,184,132,0,1,2,4,8,16,32,48,180,192,217,91,118,103,215,27,26,87,243,4,8,16,32,64,128,0,129,83,4,206,221,0,60,255,215,54,36,192,83,198,172,8,1,2,4,8,16,32,64,224,175,192,201,249,207,17,240,95,89,31,16,32,64,128,0,1,2,4,22,17,56,127,195,238,252,138,139,140,194,50,9,16,32,64,128,0,1,2,95,10,156,189,1,120,254,17,176,63,6,248,229,224,124,145,0,1,2,4,8,16,32,112,80,224,244,252,231,8,248,224,36,92,70,128,0,1,2,4,8,16,24,86,32,113,96,155,168,57,44,176,198,9,16,32,64,128,0,1,2,79,9,156,191,1,152,56,2,118,8,252,212,144,93,76,128,0,1,2,4,8,16,120,35,16,200,127,142,128,223,248,250,144,0,1,2,4,8,16,32,176,132,64,230,184,54,83,117,137,129,88,36,1,2,4,8,16,32,64,224,141,64,98,3,48,115,4,236,16,248,205,216,124,72,128,0,1,2,4,8,16,56,44,16,201,127,142,128,15,207,195,133,4,8,16,32,64,128,0,129,65,5,82,135,181,169,186,131,50,107,155,0,1,2,4,8,16,32,112,64,32,179,1,152,58,2,118,8,124,96,196,46,33,64,128,
0,1,2,4,8,188,19,8,229,63,71,192,239,148,125,66,128,0,1,2,4,8,16,88,64,32,119,84,155,171,188,192,88,44,145,0,1,2,4,8,16,32,240,43,181,1,152,59,2,118,8,236,177,37,64,128,0,1,2,4,8,60,35,16,203,127,142,128,159,25,139,107,9,16,32,64,128,0,1,2,35,10,36,15,106,147,181,71,180,214,51,1,2,4,8,16,32,64,96,187,64,110,3,48,121,4,236,16,120,251,132,189,146,0,1,2,4,8,16,32,240,94,32,152,255,28,1,191,167,246,25,1,2,4,8,16,32,64,96,126,129,236,49,109,182,250,252,211,177,66,2,4,8,16,32,64,96,85,129,228,6,96,246,8,216,33,240,170,207,172,117,19,32,64,128,0,1,2,207,9,68,243,95,58,0,198,235,63,103,235,106,2,4,8,16,32,64,128,64,163,64,54,255,249,25,192,198,153,235,137,0,1,2,4,8,16,32,144,20,136,255,148,94,252,6,73,29,181,9,16,32,64,128,0,1,2,55,8,132,55,0,47,56,162,149,0,111,120,108,220,146,0,1,2,4,8,16,24,88,32,157,255,28,1,15,252,112,104,157,0,1,2,4,8,16,32,112,72,224,130,253,185,11,110,113,104,233,46,34,64,128,0,1,2,4,8,52,10,196,55,0,47,56,2,246,183,96,26,159,44,61,17,32,64,128,0,1,2,173,2,249,
252,119,73,0,188,230,38,173,67,212,23,1,2,4,8,16,32,64,96,135,192,5,249,207,207,0,238,152,135,151,18,32,64,128,0,1,2,4,166,16,184,230,7,244,174,185,203,20,3,177,8,2,4,8,16,32,64,96,105,129,43,54,0,175,58,157,149,0,151,126,148,45,158,0,1,2,4,8,16,216,40,112,73,254,187,42,0,94,118,159,141,184,94,70,128,0,1,2,4,8,16,40,20,184,38,255,249,25,192,194,209,107,137,0,1,2,4,8,16,32,16,21,184,236,108,246,178,27,69,185,20,39,64,128,0,1,2,4,8,228,4,46,218,0,188,240,104,86,2,204,61,45,42,19,32,64,128,0,1,2,51,8,92,149,255,46,12,128,87,222,106,134,71,192,26,8,16,32,64,128,0,129,197,4,46,203,127,126,6,112,177,39,203,114,9,16,32,64,128,0,1,2,151,110,203,57,4,246,192,17,32,64,128,0,1,2,4,190,19,184,110,3,240,210,0,120,237,205,190,195,245,117,2,4,8,16,32,64,128,64,161,192,133,249,239,226,76,102,15,176,240,113,211,18,1,2,4,8,16,32,80,32,112,101,254,187,56,0,94,125,187,130,105,106,129,0,1,2,4,8,16,32,240,88,224,210,252,231,151,64,30,15,196,43,8,16,32,64,128,0,1,2,115,9,92,125,40,123,245,253,230,154,
150,213,16,32,64,128,0,1,2,115,10,92,187,1,120,253,153,172,4,56,231,115,107,85,4,8,16,32,64,128,192,113,129,139,243,223,245,1,240,134,59,30,159,134,43,9,16,32,64,128,0,1,2,121,129,171,243,223,29,113,204,30,96,254,57,114,7,2,4,8,16,32,64,96,28,129,203,243,159,95,2,25,231,225,208,41,1,2,4,8,16,32,64,224,28,129,59,182,227,238,184,231,57,90,170,16,32,64,128,0,1,2,4,206,22,184,126,3,240,142,35,224,95,247,220,244,236,97,169,71,128,0,1,2,4,8,16,56,65,224,134,252,119,83,22,179,7,120,194,227,162,4,1,2,4,8,16,32,48,129,192,29,249,239,166,0,120,215,109,39,120,74,44,129,0,1,2,4,8,16,152,73,224,150,252,231,151,64,102,122,132,172,133,0,1,2,4,8,16,32,176,69,224,174,195,216,187,238,187,197,196,107,8,16,32,64,128,0,1,2,215,8,220,179,1,120,223,89,172,4,120,205,115,229,46,4,8,16,32,64,128,64,175,192,77,249,239,190,0,120,227,157,123,159,2,157,17,32,64,128,0,1,2,43,9,220,149,255,238,140,97,246,0,87,122,194,173,149,0,1,2,4,8,16,248,40,112,91,254,187,51,0,222,122,239,143,19,240,57,1,2,4,8,16,32,64,
224,90,129,251,242,223,189,33,204,30,224,181,207,153,187,17,32,64,128,0,1,2,61,2,55,230,63,127,6,166,231,49,208,9,1,2,4,8,16,32,64,224,26,129,123,55,225,238,189,251,53,194,238,66,128,0,1,2,4,8,16,248,44,112,231,6,224,189,71,192,254,171,192,159,159,6,95,33,64,128,0,1,2,4,86,16,184,53,255,221,29,0,111,191,255,10,79,152,53,18,32,64,128,0,1,2,109,2,247,230,191,251,3,152,83,224,182,39,82,63,4,8,16,32,64,128,64,90,224,230,252,119,127,0,44,232,32,61,99,245,9,16,32,64,128,0,1,2,111,5,238,206,127,13,241,203,30,224,219,39,194,199,4,8,16,32,64,128,192,236,2,183,231,191,134,0,88,209,195,236,79,154,245,17,32,64,128,0,1,2,45,2,247,231,63,127,7,176,229,89,208,7,1,2,4,8,16,32,64,224,42,129,138,243,215,138,38,174,18,119,31,2,4,8,16,32,64,96,105,129,130,13,192,146,227,87,9,112,233,55,130,197,19,32,64,128,0,129,133,4,26,242,95,73,0,108,105,99,161,167,207,82,9,16,32,64,128,0,129,59,4,42,242,95,77,242,178,7,120,199,51,232,158,4,8,16,32,64,128,192,181,2,29,249,175,38,0,246,52,114,237,99,224,110,4,
8,16,32,64,128,192,66,2,37,249,175,40,119,217,3,92,232,241,183,84,2,4,8,16,32,176,164,64,75,254,43,10,128,77,173,44,249,76,90,52,1,2,4,8,16,32,144,21,168,201,127,85,169,203,30,96,246,169,83,157,0,1,2,4,8,16,184,83,160,39,255,85,5,192,174,102,238,124,64,220,155,0,1,2,4,8,16,152,78,160,40,255,149,101,46,123,128,211,61,236,22,68,128,0,1,2,4,8,252,17,104,202,127,101,1,176,173,29,79,44,1,2,4,8,16,32,64,224,20,129,170,252,87,151,184,236,1,158,242,144,41,66,128,0,1,2,4,8,84,9,116,229,191,186,0,216,215,80,213,211,163,25,2,4,8,16,32,64,96,68,129,178,252,87,152,183,236,1,142,248,92,235,153,0,1,2,4,8,16,248,94,160,45,255,253,250,191,239,123,245,29,2,4,8,16,32,64,128,0,129,25,5,10,247,219,10,91,154,113,242,214,68,128,0,1,2,4,8,92,36,80,183,1,88,120,4,252,171,178,167,139,30,16,183,33,64,128,0,1,2,4,166,19,232,203,127,157,97,203,30,224,116,143,190,5,17,32,64,128,0,129,101,5,10,243,95,103,0,44,237,106,217,7,215,194,9,16,32,64,128,0,129,195,2,141,249,175,53,106,217,3,60,252,152,185,144,0,1,2,
4,8,16,40,18,168,204,127,173,1,176,182,175,162,7,74,43,4,8,16,32,64,128,64,189,64,103,254,235,13,90,246,0,235,31,105,13,18,32,64,128,0,1,2,15,4,74,243,95,111,0,44,238,236,193,168,125,155,0,1,2,4,8,16,32,240,71,160,53,255,85,199,44,155,128,222,61,4,8,16,32,64,128,192,184,2,181,241,175,252,111,238,73,128,227,62,243,58,39,64,128,0,1,2,171,11,20,231,191,234,29,192,242,120,186,250,99,109,253,4,8,16,32,64,128,192,15,2,205,249,175,60,0,182,183,247,195,212,125,139,0,1,2,4,8,16,88,89,160,58,255,213,39,44,167,192,43,191,119,172,157,0,1,2,4,8,140,42,208,157,255,234,3,96,127,131,163,62,152,250,38,64,128,0,1,2,4,98,2,229,249,111,128,124,101,15,48,246,112,42,76,128,0,1,2,4,8,68,4,218,243,223,0,1,112,132,22,35,207,142,162,4,8,16,32,64,128,192,152,2,245,249,111,136,116,101,15,112,204,167,95,215,4,8,16,32,64,96,77,129,254,252,55,68,0,28,163,201,53,31,113,171,38,64,128,0,1,2,4,62,8,12,144,255,6,201,86,246,0,63,60,90,62,37,64,128,0,1,2,4,74,5,70,200,127,131,4,192,81,218,44,125,18,181,69,128,0,1,
2,4,8,92,37,48,68,254,27,38,89,217,3,188,234,185,117,31,2,4,8,16,32,64,224,184,192,24,249,111,152,0,56,78,163,199,31,25,87,18,32,64,128,0,1,2,131,11,12,146,255,70,202,85,54,1,7,127,79,104,159,0,1,2,4,8,76,46,48,74,252,251,53,82,0,28,170,215,201,31,112,203,35,64,128,0,1,2,4,62,9,140,147,255,198,10,85,246,0,63,61,106,190,64,128,0,1,2,4,8,148,8,12,148,255,198,10,128,131,117,91,242,56,106,131,0,1,2,4,8,16,184,64,96,164,252,55,90,164,178,7,120,193,3,236,22,4,8,16,32,64,128,192,110,129,161,242,223,104,1,112,184,126,119,63,62,46,32,64,128,0,1,2,4,6,20,24,43,255,141,23,168,236,1,14,248,166,208,50,1,2,4,8,16,152,92,96,176,252,55,94,0,28,235,23,151,39,127,218,45,143,0,1,2,4,8,16,120,17,24,45,254,141,153,166,108,2,122,179,17,32,64,128,0,1,2,61,2,227,229,191,17,119,0,199,76,173,61,79,169,78,8,16,32,64,128,0,129,51,5,6,204,127,99,6,192,65,187,62,243,89,83,139,0,1,2,4,8,16,232,16,24,49,255,141,26,165,156,2,119,60,243,186,32,64,128,0,1,2,171,11,12,153,255,70,13,128,195,246,189,250,187,196,250,
9,16,32,64,128,192,92,2,99,230,191,129,131,148,77,192,185,222,64,86,67,128,0,1,2,4,198,19,24,52,254,13,253,251,20,18,224,120,239,19,29,19,32,64,128,0,129,153,4,134,205,127,3,239,0,14,29,94,103,122,248,173,133,0,1,2,4,8,44,42,48,110,254,27,58,0,142,221,252,162,239,21,203,38,64,128,0,1,2,179,8,12,156,255,70,207,80,142,129,103,121,19,89,7,1,2,4,8,16,24,75,96,228,248,55,254,49,170,4,56,214,187,69,183,4,8,16,32,64,96,14,129,177,243,223,232,59,128,227,39,216,57,222,5,86,65,128,0,1,2,4,214,18,24,60,255,141,31,0,39,88,193,90,239,24,171,37,64,128,0,1,2,227,11,140,158,255,166,136,79,142,129,199,127,35,89,1,1,2,4,8,16,24,71,96,248,248,55,201,9,170,4,56,206,123,70,167,4,8,16,32,64,96,116,129,9,242,223,20,59,128,147,196,216,209,223,14,250,39,64,128,0,1,2,75,8,204,144,255,38,9,128,179,44,99,137,247,141,69,18,32,64,128,0,129,145,5,166,200,127,243,36,39,199,192,35,191,153,244,78,128,0,1,2,4,198,16,152,35,254,205,116,120,42,1,142,241,206,209,37,1,2,4,8,16,24,87,96,150,252,55,207,14,224,76,89,
118,220,247,133,206,9,16,32,64,128,192,204,2,211,228,191,153,2,160,8,56,243,91,206,218,8,16,32,64,128,192,221,2,243,196,191,217,50,147,99,224,187,223,27,238,79,128,0,1,2,4,102,21,152,41,255,205,181,3,56,91,158,157,245,29,100,93,4,8,16,32,64,96,60,129,169,242,223,108,1,80,4,28,239,13,165,99,2,4,8,16,32,208,47,48,87,252,155,49,47,57,6,238,127,23,233,144,0,1,2,4,8,140,37,48,91,254,155,111,7,112,198,76,59,214,123,68,183,4,8,16,32,64,96,54,129,233,242,223,140,1,80,4,156,237,109,103,61,4,8,16,32,64,224,78,129,249,226,223,172,89,201,49,240,157,239,19,247,38,64,128,0,1,2,51,9,204,152,255,230,220,1,124,121,234,68,192,153,222,122,214,66,128,0,1,2,4,238,18,152,50,254,77,28,148,36,192,187,222,41,238,75,128,0,1,2,4,230,17,152,52,255,77,188,83,38,1,206,243,238,179,18,2,4,8,16,32,112,143,192,172,249,111,226,0,56,241,238,230,61,239,1,119,37,64,128,0,1,2,139,9,76,27,255,38,15,73,54,1,23,123,163,90,46,1,2,4,8,16,56,81,96,226,252,55,245,14,224,203,35,32,2,158,248,62,80,138,0,1,2,4,8,44,36,48,115,
252,155,63,33,73,128,11,189,85,45,149,0,1,2,4,8,156,38,48,119,254,91,96,139,76,4,60,237,189,160,16,1,2,4,8,16,88,68,96,242,248,55,255,14,224,203,115,42,1,46,242,102,181,76,2,4,8,16,32,112,146,192,244,249,111,141,116,36,2,158,244,126,80,134,0,1,2,4,8,44,32,48,127,252,91,101,123,76,2,92,224,237,106,137,4,8,16,32,64,224,20,129,21,242,223,26,59,128,47,143,131,8,120,202,123,66,17,2,4,8,16,32,48,185,192,18,241,111,161,96,36,1,78,254,134,181,60,2,4,8,16,32,112,130,192,34,249,111,165,157,49,17,240,132,247,133,18,4,8,16,32,64,96,98,129,85,226,223,66,59,128,47,79,171,4,56,241,91,214,210,8,16,32,64,128,192,211,2,235,228,191,197,66,145,8,248,244,123,67,1,2,4,8,16,32,48,169,192,66,241,111,185,93,49,9,112,210,55,173,101,17,32,64,128,0,129,39,5,150,202,127,139,237,0,190,60,26,34,224,147,239,15,151,19,32,64,128,0,129,9,5,214,138,127,75,230,33,17,112,194,247,173,37,17,32,64,128,0,129,39,4,86,139,127,75,6,64,155,128,79,188,67,92,74,128,0,1,2,4,230,19,88,47,255,45,26,134,108,2,206,247,230,181,34,
2,4,8,16,32,112,76,96,193,248,183,230,14,224,239,199,67,4,60,246,38,113,21,1,2,4,8,16,152,75,96,201,248,183,112,16,146,0,231,122,255,90,13,1,2,4,8,16,56,34,176,104,254,91,121,39,76,4,60,242,70,113,13,1,2,4,8,16,152,71,96,213,248,183,240,14,224,239,135,87,4,156,231,45,108,37,4,8,16,32,64,96,175,192,186,241,111,245,12,36,1,238,125,175,120,61,1,2,4,8,16,152,69,96,229,252,183,252,38,152,8,56,203,219,216,58,8,16,32,64,128,192,30,129,165,227,223,234,59,128,191,31,20,17,112,207,219,197,107,9,16,32,64,128,192,12,2,139,199,63,241,231,247,67,44,2,206,240,86,182,6,2,4,8,16,32,176,85,96,249,248,39,252,252,121,84,36,192,173,239,24,175,35,64,128,0,1,2,227,11,200,127,2,224,63,79,177,8,56,254,219,217,10,8,16,32,64,128,192,22,1,241,239,183,146,228,243,207,179,2,98,203,155,198,107,8,16,32,64,128,192,216,2,226,223,255,230,39,247,252,125,142,81,252,165,240,1,1,2,4,8,16,152,82,64,252,123,29,171,212,243,42,241,242,47,140,55,24,62,36,64,128,0,1,2,147,9,136,127,255,14,84,230,249,215,66,2,124,107,225,
99,2,4,8,16,32,48,151,128,252,247,102,158,2,224,27,140,151,15,121,188,247,240,25,1,2,4,8,16,152,67,64,252,123,55,71,129,231,29,199,203,39,68,62,138,248,156,0,1,2,4,8,140,46,32,254,125,152,160,184,243,1,228,229,83,38,159,77,124,133,0,1,2,4,8,140,43,32,254,125,154,157,176,243,137,228,229,11,84,190,82,241,53,2,4,8,16,32,48,162,128,248,247,197,212,68,157,47,80,94,190,196,229,107,23,95,37,64,128,0,1,2,99,9,136,127,95,206,75,208,249,146,229,229,139,100,190,147,241,117,2,4,8,16,32,48,138,128,248,247,205,164,196,156,111,96,94,190,204,230,123,27,223,33,64,128,0,1,2,253,2,226,223,183,51,18,114,190,165,121,249,6,157,159,116,124,143,0,1,2,4,8,52,11,136,127,63,76,71,196,249,1,231,229,91,124,126,246,241,93,2,4,8,16,32,208,41,32,254,253,56,23,1,231,71,158,151,111,18,122,36,228,251,4,8,16,32,64,160,77,64,252,123,48,17,241,230,1,208,203,183,25,61,54,242,10,2,4,8,16,32,208,35,32,254,61,156,133,112,243,144,232,229,5,148,182,40,121,13,1,2,4,8,16,104,16,16,255,54,76,65,180,217,128,244,242,18,78,219,
156,188,138,0,1,2,4,8,220,43,32,254,109,242,23,108,54,49,189,188,136,212,86,41,175,35,64,128,0,1,2,119,9,136,127,27,229,197,154,141,80,191,95,6,107,7,150,151,18,32,64,128,0,129,139,5,164,191,237,224,50,205,118,171,151,87,226,218,197,229,197,4,8,16,32,64,224,50,1,241,111,15,181,68,179,71,235,229,181,192,118,130,121,57,1,2,4,8,16,184,64,64,252,219,135,44,207,236,243,122,121,53,178,221,100,46,32,64,128,0,1,2,81,1,241,111,47,175,52,179,87,236,247,235,169,29,81,115,13,1,2,4,8,16,72,8,72,127,7,84,69,153,3,104,47,151,112,59,230,230,42,2,4,8,16,32,112,174,128,248,119,200,83,144,57,196,246,114,17,185,163,114,174,35,64,128,0,1,2,103,9,136,127,7,37,197,152,131,112,191,47,131,247,4,158,75,9,16,32,64,128,192,147,2,210,223,113,64,25,230,184,221,203,149,248,158,226,115,49,1,2,4,8,16,56,44,32,254,29,166,123,185,80,130,121,70,239,247,181,4,159,21,116,61,1,2,4,8,16,216,43,32,253,237,21,251,240,122,241,229,3,200,129,79,25,30,64,115,9,1,2,4,8,16,56,44,32,254,29,166,123,189,80,120,121,149,120,234,
95,140,79,241,185,152,0,1,2,4,8,108,22,144,254,54,83,253,240,66,201,229,7,156,61,223,2,185,71,203,107,9,16,32,64,128,192,49,1,241,239,152,219,199,171,228,150,143,34,199,63,103,121,220,206,149,4,8,16,32,64,224,177,128,244,247,216,104,227,43,132,150,141,80,219,94,134,115,155,147,87,17,32,64,128,0,129,189,2,210,223,94,177,159,94,47,177,252,164,115,224,123,64,15,160,185,132,0,1,2,4,8,60,16,16,255,30,0,237,252,182,188,178,19,108,195,203,153,110,64,242,18,2,4,8,16,32,176,89,64,250,219,76,181,245,133,194,202,86,169,93,175,195,186,139,203,139,9,16,32,64,128,192,183,2,210,223,183,52,79,124,67,82,121,2,239,199,75,201,254,200,227,155,4,8,16,32,64,96,131,128,244,183,1,233,200,75,196,148,35,106,27,175,129,187,17,202,203,8,16,32,64,128,192,23,2,210,223,23,40,39,125,73,70,57,9,242,155,50,124,191,129,241,101,2,4,8,16,32,240,163,128,244,247,35,207,179,223,20,80,158,21,124,120,61,226,135,68,94,64,128,0,1,2,4,222,9,72,127,239,56,2,159,72,39,1,212,79,37,41,127,34,241,5,2,4,8,16,32,240,141,128,244,
247,13,204,153,95,22,77,206,212,252,161,22,232,31,112,124,139,0,1,2,4,8,252,35,32,253,93,243,40,200,37,215,56,255,190,11,235,235,172,221,137,0,1,2,4,70,20,144,254,46,155,154,80,114,25,245,159,27,241,190,214,219,221,8,16,32,64,96,20,1,225,239,210,73,9,36,151,114,255,190,25,242,203,201,221,144,0,1,2,4,202,5,164,191,171,7,36,141,92,45,254,231,126,216,111,97,119,83,2,4,8,16,40,20,16,254,238,24,138,36,114,135,250,239,123,146,191,75,222,125,9,16,32,64,160,71,64,250,187,105,22,98,200,77,240,127,110,75,255,78,125,247,38,64,128,0,129,123,5,132,191,27,253,69,144,27,241,255,220,218,4,238,158,128,251,19,32,64,128,192,245,2,194,223,245,230,239,238,40,126,188,227,184,233,19,83,184,9,222,109,9,16,32,64,224,6,1,225,239,6,244,143,183,20,61,62,138,220,245,185,73,220,37,239,190,4,8,16,32,112,157,128,240,119,157,245,143,119,18,59,126,228,185,248,155,166,113,49,184,219,17,32,64,128,192,133,2,194,223,133,216,143,110,37,114,60,18,186,252,251,70,114,57,185,27,18,32,64,128,64,88,64,246,11,3,239,46,47,
109,236,38,187,226,2,99,185,66,217,61,8,16,32,64,224,10,1,225,239,10,229,189,247,144,52,246,138,93,247,122,179,185,206,218,157,8,16,32,64,32,33,32,251,37,84,79,169,41,100,156,194,152,43,98,64,57,91,149,9,16,32,64,32,39,32,251,229,108,207,168,44,95,156,161,24,175,97,76,113,98,55,32,64,128,0,129,147,4,68,191,147,32,163,101,36,139,40,239,185,197,13,235,92,79,213,8,16,32,64,224,92,1,209,239,92,207,100,53,153,34,169,27,169,109,100,17,86,69,9,16,32,64,224,9,1,209,239,9,188,91,46,149,38,110,97,63,225,166,38,119,2,162,18,4,8,16,32,240,164,128,228,247,36,224,93,151,139,17,119,201,159,116,95,3,60,9,82,25,2,4,8,16,216,37,32,249,237,226,170,123,177,252,80,55,146,131,13,153,228,65,56,151,17,32,64,128,192,14,1,185,111,7,86,243,75,197,134,230,233,28,235,205,76,143,185,185,138,0,1,2,4,190,19,16,251,190,147,25,246,235,194,194,176,163,219,214,184,1,111,115,242,42,2,4,8,16,120,47,32,243,189,247,152,237,179,255,7,14,215,65,163,253,149,199,243,0,0,0,0,73,69,78,68,174,66,96,130);


template_circle_2560px
:array[0..50938] of byte=(
137,80,78,71,13,10,26,10,0,0,0,13,73,72,68,82,0,0,10,0,0,0,10,0,8,3,0,0,0,74,138,139,234,0,0,0,23,116,69,88,116,83,111,102,116,119,97,114,101,0,68,97,110,105,32,118,49,46,48,48,46,50,54,48,20,195,73,175,0,0,0,30,116,69,88,116,98,101,46,112,110,103,46,115,101,116,116,105,110,103,115,0,53,51,54,56,55,48,57,49,49,46,45,49,46,53,41,132,140,74,0,0,0,6,80,76,84,69,255,0,0,0,0,0,65,163,18,3,0,0,0,2,116,82,78,83,0,255,91,145,34,181,0,0,198,85,73,68,65,84,120,1,236,221,233,98,219,184,146,6,208,244,188,255,59,223,113,146,110,91,78,180,144,34,150,90,206,252,25,217,150,0,212,41,144,248,36,59,125,127,252,240,127,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,224,130,192,63,47,255,239,194,224,94,74,128,0,129,76,2,255,151,105,177,214,74,128,0,129,7,2,47,179,221,199,19,30,188,
244,230,219,99,70,185,25,208,67,2,4,8,196,20,16,0,99,246,197,170,8,16,120,44,112,47,166,61,126,246,232,159,236,157,125,116,53,198,35,64,160,169,128,0,216,180,241,202,38,144,72,224,207,200,21,111,233,241,87,24,207,204,138,8,16,216,42,32,0,110,229,55,57,1,2,247,5,190,37,170,251,79,137,252,221,228,203,143,76,107,109,4,8,140,17,16,0,199,56,26,133,0,129,235,2,55,177,233,250,96,113,70,40,90,86,28,96,43,33,64,224,13,1,1,240,13,52,47,33,64,96,156,64,171,120,212,170,216,113,123,196,72,4,8,140,23,16,0,199,155,26,145,0,129,151,2,95,73,232,229,83,139,62,129,64,209,198,42,139,64,18,1,1,48,73,163,44,147,64,9,129,207,212,83,162,154,65,69,64,25,4,105,24,2,4,78,8,8,128,39,176,60,149,0,129,55,5,254,203,56,111,190,188,201,203,40,53,105,180,50,9,68,16,16,0,35,116,193,26,8,20,21,248,47,209,28,248,79,48,23,21,120,171,44,108,111,177,121,17,1,2,103,4,4,192,51,90,158,75,128,192,49,129,127,35,204,177,39,123,214,35,1,140,143,100,124,159,0,129,171,2,2,224,85,65,175,39,64,224,75,224,191,207,174,190,190,227,
209,117,1,170,215,13,141,64,128,192,31,2,2,224,31,32,190,36,64,224,29,1,159,85,189,163,118,242,53,144,79,130,121,58,1,2,143,5,4,192,199,54,126,66,128,192,1,129,223,169,228,192,19,61,101,144,0,241,65,144,134,33,208,90,64,0,108,221,126,197,19,184,32,224,243,168,11,120,215,95,138,255,186,161,17,8,116,22,16,0,59,119,95,237,4,222,19,240,17,212,123,110,51,94,165,23,51,84,141,73,160,129,128,0,216,160,201,74,36,48,76,64,220,24,70,57,116,32,125,25,202,105,48,2,29,4,4,192,14,93,86,35,129,235,2,34,198,117,195,217,35,232,209,108,97,227,19,40,36,32,0,22,106,166,82,8,76,17,16,43,166,176,78,27,84,191,166,209,26,152,64,37,1,1,176,82,55,213,66,96,172,128,40,49,214,115,229,104,122,183,82,219,92,4,18,10,8,128,9,155,102,201,4,230,11,252,202,15,243,167,49,195,92,1,109,156,235,107,116,2,137,5,4,192,196,205,179,116,2,51,4,124,116,52,67,117,231,152,58,186,83,223,220,4,162,10,8,128,81,59,99,93,4,214,11,248,188,104,189,249,178,25,53,119,25,181,137,8,164,16,16,0,83,180,201,34,9,204,22,16,15,102,11,135,
24,95,155,67,180,193,34,8,68,16,16,0,35,116,193,26,8,236,20,16,10,118,234,111,152,91,195,55,160,155,146,64,56,1,1,48,92,75,44,136,192,58,1,81,96,157,117,176,153,180,62,88,67,44,135,192,106,1,1,112,181,184,249,8,196,16,16,0,98,244,97,235,42,108,130,173,252,38,39,176,85,64,0,220,202,111,114,2,91,4,126,158,251,91,38,54,105,64,1,187,33,96,83,44,137,192,124,1,1,112,190,177,25,8,4,18,240,153,79,160,102,196,89,138,109,17,167,23,86,66,96,145,128,0,184,8,218,52,4,246,11,248,168,103,127,15,34,175,192,254,136,220,29,107,35,48,90,64,0,28,45,106,60,2,17,5,124,194,19,177,43,1,215,100,163,4,108,138,37,17,152,34,32,0,78,97,53,40,129,64,2,62,216,9,212,140,20,75,177,99,82,180,201,34,9,92,19,16,0,175,249,121,53,129,208,2,62,207,9,221,158,200,139,179,117,34,119,199,218,8,12,16,16,0,7,32,26,130,64,68,1,31,227,68,236,74,174,53,217,67,185,250,101,181,4,206,8,8,128,103,180,60,151,64,18,1,7,119,146,70,37,88,166,189,148,160,73,150,72,224,13,1,1,240,13,52,47,33,16,89,192,129,29,185,59,57,215,102,79,229,
236,155,85,19,120,38,32,0,62,211,241,51,2,201,4,28,212,201,26,150,104,185,246,86,162,102,89,42,129,3,2,2,224,1,36,79,33,144,65,192,1,157,161,75,185,215,104,143,229,238,159,213,19,184,21,16,0,111,53,60,38,144,84,192,193,156,180,113,9,151,109,175,37,108,154,37,19,184,35,32,0,222,65,241,45,2,153,4,28,200,153,186,85,99,173,246,92,141,62,170,162,183,128,0,216,187,255,170,79,46,224,32,78,222,192,196,203,183,247,18,55,207,210,9,124,8,8,128,182,1,129,164,2,14,224,164,141,43,180,108,123,176,80,51,149,210,78,64,0,108,215,114,5,87,16,112,240,86,232,98,141,26,236,197,26,125,84,69,63,1,1,176,95,207,85,156,92,192,129,155,188,129,5,151,111,79,22,108,170,146,202,11,8,128,229,91,172,192,82,2,31,39,109,169,122,20,83,70,192,214,44,211,74,133,52,17,16,0,155,52,90,153,5,4,124,204,82,160,137,165,75,176,67,75,183,87,113,213,4,4,192,106,29,85,79,81,1,159,175,20,109,108,181,178,108,212,106,29,85,79,89,1,1,176,108,107,21,86,71,192,7,43,117,122,217,161,18,251,181,67,151,213,152,95,64,0,204,223,67,21,148,
22,112,152,150,110,111,217,226,236,219,178,173,85,88,25,1,1,176,76,43,21,82,80,224,227,20,45,88,149,146,154,8,216,190,77,26,173,204,164,2,2,96,210,198,89,118,125,1,199,103,253,30,151,175,208,38,46,223,98,5,230,21,16,0,243,246,206,202,11,11,124,156,155,62,251,43,220,223,78,165,217,203,157,186,173,214,76,2,2,96,166,110,89,107,15,1,225,175,71,159,27,85,105,75,55,106,182,82,211,8,8,128,105,90,101,161,45,4,124,92,210,162,205,13,139,180,179,27,54,93,201,177,5,4,192,216,253,177,186,86,2,62,39,105,213,238,126,197,218,224,253,122,174,226,192,2,2,96,224,230,88,90,43,1,135,99,171,118,119,45,214,54,239,218,121,117,199,19,16,0,227,245,196,138,26,10,56,22,27,54,189,107,201,54,123,215,206,171,59,152,128,0,24,172,33,150,211,79,224,227,60,244,47,126,251,181,189,117,197,246,124,235,246,43,62,136,128,0,24,164,17,150,209,84,64,248,107,218,120,101,219,250,246,0,129,189,2,2,224,94,127,179,183,22,112,4,182,110,191,226,93,0,246,0,129,141,2,2,224,70,124,83,183,22,112,248,181,110,191,226,127,11,184,12,
236,4,2,187,4,4,192,93,242,230,109,45,224,216,107,221,126,197,223,10,184,24,110,53,60,38,176,76,64,0,92,70,109,34,2,255,10,56,240,108,5,2,223,4,92,18,223,56,124,65,96,137,128,0,184,132,217,36,4,254,19,112,212,253,39,225,255,19,184,17,112,97,220,96,120,72,96,133,128,0,184,66,217,28,4,126,11,56,228,236,4,2,15,5,92,30,15,105,252,128,192,4,1,1,112,2,170,33,9,220,19,112,188,221,83,241,61,2,55,2,46,146,27,12,15,9,204,21,16,0,231,250,26,157,192,111,1,7,155,157,64,224,144,128,75,229,16,147,39,17,184,44,32,0,94,38,52,0,129,87,2,142,180,87,66,126,78,224,70,192,5,115,131,225,33,129,89,2,2,224,44,89,227,18,248,45,224,48,179,19,8,156,22,112,217,156,38,243,2,2,39,5,4,192,147,96,158,78,224,140,128,99,236,140,150,231,18,184,17,112,241,220,96,120,72,96,188,128,0,56,222,212,136,4,126,11,56,192,236,4,2,151,4,92,66,151,248,188,152,192,83,1,1,240,41,143,31,18,120,87,192,209,245,174,156,215,17,184,17,112,33,221,96,120,72,96,164,128,0,56,82,211,88,4,126,11,56,180,236,4,2,195,4,92,78,195,40,13,68,224,
70,64,0,188,193,240,144,192,16,129,127,254,25,50,140,65,8,16,248,87,192,53,101,43,16,24,46,32,0,14,39,53,96,111,1,159,86,244,238,191,234,39,9,184,176,38,193,26,182,175,128,0,216,183,247,42,31,47,224,144,26,111,106,68,2,255,10,184,188,108,5,2,35,5,4,192,145,154,198,106,45,224,120,106,221,126,197,175,16,112,145,173,80,54,71,19,1,1,176,73,163,149,57,89,192,193,52,25,216,240,4,126,11,184,212,236,4,2,99,4,4,192,49,142,70,233,45,224,79,212,123,247,95,245,107,5,92,111,107,189,205,86,84,64,0,44,218,88,101,173,19,240,137,196,58,107,51,17,248,37,224,162,179,17,8,92,22,16,0,47,19,26,160,181,128,131,168,117,251,21,191,79,192,165,183,207,222,204,53,4,4,192,26,125,84,197,30,1,191,138,218,227,110,86,2,63,5,92,127,246,1,129,11,2,2,224,5,60,47,237,45,224,19,136,222,253,87,125,0,1,23,97,128,38,88,66,86,1,1,48,107,231,172,123,175,128,131,103,175,191,217,9,252,43,224,82,180,21,8,188,39,32,0,190,231,230,85,189,5,252,234,169,119,255,85,31,75,192,245,24,171,31,86,147,68,64,0,76,210,40,203,140,35,224,
19,135,56,189,176,18,2,191,4,92,148,54,2,129,211,2,2,224,105,50,47,232,45,224,195,134,222,253,87,125,84,1,87,102,212,206,88,87,84,1,1,48,106,103,172,43,162,128,207,25,34,118,197,154,8,252,18,112,121,218,8,4,206,8,8,128,103,180,60,183,183,128,143,24,122,247,95,245,241,5,92,163,241,123,100,133,97,4,4,192,48,173,176,144,216,2,62,93,136,221,31,171,35,240,75,192,133,106,35,16,56,40,32,0,30,132,242,180,222,2,62,88,232,221,127,213,103,18,112,181,102,234,150,181,238,19,16,0,247,217,155,57,139,128,207,20,178,116,202,58,9,252,18,112,201,218,8,4,94,11,8,128,175,141,60,163,183,128,143,19,122,247,95,245,57,5,92,183,57,251,102,213,11,5,4,192,133,216,166,202,39,224,147,132,124,61,179,98,2,191,4,92,188,54,2,129,167,2,2,224,83,30,63,236,45,224,67,132,222,253,87,125,118,1,87,112,246,14,90,255,76,1,1,112,166,174,177,51,11,248,252,32,115,247,172,157,192,47,1,151,177,141,64,224,145,128,0,248,72,198,247,123,11,248,232,160,119,255,85,95,71,192,181,92,167,151,42,25,42,32,0,14,229,52,88,13,1,159,26,212,
232,163,42,8,252,18,112,65,219,8,4,238,8,8,128,119,80,124,171,183,128,15,12,122,247,95,245,21,5,92,213,21,187,170,166,107,2,2,224,53,63,175,46,39,224,160,40,215,82,5,17,248,16,112,101,219,6,4,190,11,8,128,223,61,124,213,91,192,175,138,122,247,95,245,165,5,92,222,165,219,171,184,211,2,2,224,105,50,47,40,43,224,35,130,178,173,85,24,129,95,2,174,113,27,129,192,167,128,0,248,73,225,65,115,1,71,67,243,13,160,252,22,2,174,243,22,109,86,228,17,1,1,240,136,146,231,148,23,240,203,161,242,45,86,32,129,223,2,46,118,59,129,192,47,1,1,208,70,32,224,207,195,237,1,2,173,4,124,12,216,170,221,138,125,32,32,0,62,128,241,237,62,2,14,131,62,189,86,41,129,223,2,174,122,59,129,128,0,104,15,244,22,240,235,160,222,253,87,125,91,1,151,126,219,214,43,252,95,1,1,208,86,232,44,224,99,128,206,221,87,123,119,1,215,127,247,29,208,188,126,1,176,249,6,104,93,190,219,127,235,246,43,158,128,63,255,181,7,58,11,8,128,157,187,223,187,118,241,175,119,255,85,79,224,167,128,251,128,125,208,86,64,0,108,219,250,222,133,
251,251,159,222,253,87,61,129,79,1,55,131,79,10,15,122,9,8,128,189,250,173,218,95,2,222,244,219,8,4,8,124,9,184,35,124,89,120,212,71,64,0,236,211,107,149,254,43,224,102,111,43,16,32,240,93,192,93,225,187,135,175,58,8,8,128,29,186,172,198,27,1,55,250,27,12,15,9,16,248,87,192,157,193,86,232,38,32,0,118,235,120,243,122,221,228,155,111,0,229,19,120,40,224,238,240,144,198,15,74,10,8,128,37,219,170,168,187,2,254,216,251,46,139,111,18,32,240,91,192,45,194,78,232,36,32,0,118,234,118,239,90,189,189,239,221,127,213,19,56,34,224,62,113,68,201,115,74,8,8,128,37,218,168,136,151,2,110,235,47,137,60,129,0,129,15,1,247,10,219,160,137,128,0,216,164,209,205,203,116,75,111,190,1,148,79,224,132,128,251,197,9,44,79,205,43,32,0,230,237,157,149,31,21,112,59,63,42,229,121,4,8,252,20,112,207,176,15,26,8,8,128,13,154,220,188,68,183,242,230,27,64,249,4,222,16,112,223,120,3,205,75,114,9,8,128,185,250,101,181,39,5,252,171,190,147,96,158,78,128,192,111,1,55,15,59,161,184,128,0,88,188,193,189,203,243,38,190,
119,255,85,79,224,154,128,59,200,53,63,175,142,45,32,0,198,238,143,213,93,16,112,243,190,128,231,165,4,8,124,8,184,139,216,6,117,5,4,192,186,189,109,94,153,27,119,243,13,160,124,2,67,4,220,73,134,48,26,36,160,128,0,24,176,41,150,116,93,192,77,251,186,161,17,8,16,248,41,224,110,98,31,212,20,16,0,107,246,181,121,85,110,216,205,55,128,242,9,12,21,112,71,25,202,105,176,32,2,2,96,144,70,88,198,56,1,55,235,113,150,70,34,64,224,167,128,187,138,125,80,79,64,0,172,215,211,230,21,185,81,55,223,0,202,39,48,69,192,157,101,10,171,65,55,10,8,128,27,241,77,61,94,192,77,122,188,169,17,9,16,248,41,224,238,98,31,212,18,16,0,107,245,179,121,53,110,208,205,55,128,242,9,76,21,112,135,153,202,107,240,197,2,2,224,98,112,211,205,19,112,115,158,103,107,100,2,4,126,10,184,203,216,7,117,4,4,192,58,189,108,94,137,27,115,243,13,160,124,2,75,4,220,105,150,48,155,100,129,128,0,184,0,217,20,243,5,220,148,231,27,155,129,0,129,159,2,238,54,246,65,13,1,1,176,70,31,155,87,225,134,220,124,3,40,159,192,82,1,119,156,
165,220,38,155,36,32,0,78,130,53,236,58,1,55,227,117,214,102,34,64,224,167,128,187,142,125,144,95,64,0,204,223,195,230,21,184,17,55,223,0,202,39,176,69,192,157,103,11,187,73,7,10,8,128,3,49,13,181,94,192,77,120,189,185,25,9,16,248,41,224,238,99,31,228,22,16,0,115,247,175,249,234,221,128,155,111,0,229,19,216,42,224,14,180,149,223,228,23,5,4,192,139,128,94,190,79,192,205,119,159,189,153,9,16,248,41,224,46,100,31,228,21,16,0,243,246,174,249,202,221,120,155,111,0,229,19,8,33,224,78,20,162,13,22,241,134,128,0,248,6,154,151,236,23,112,211,221,223,3,43,32,64,224,167,128,187,145,125,144,83,64,0,204,217,183,230,171,118,195,109,190,1,148,79,32,148,128,59,82,168,118,88,204,65,1,1,240,32,148,167,197,17,112,179,141,211,11,43,33,64,224,167,128,187,146,125,144,79,64,0,204,215,179,230,43,118,163,109,190,1,148,79,32,164,128,59,83,200,182,88,212,19,1,1,240,9,142,31,197,19,112,147,141,215,19,43,34,64,224,167,128,187,147,125,144,75,64,0,204,213,175,238,171,253,167,59,128,250,9,16,136,43,224,6,21,
183,55,86,246,183,128,0,248,183,137,239,68,21,240,6,59,106,103,172,139,0,129,159,2,238,81,246,65,34,1,1,48,81,179,154,47,213,173,181,249,6,80,62,129,4,2,238,83,9,154,100,137,191,5,4,64,59,33,135,128,219,106,142,62,89,37,129,238,2,238,85,221,119,64,154,250,5,192,52,173,106,189,80,183,212,214,237,87,60,129,84,2,238,87,169,218,213,119,177,2,96,223,222,231,169,220,237,52,79,175,172,148,0,1,127,11,104,15,164,16,16,0,83,180,169,245,34,197,191,214,237,87,60,129,148,2,238,91,41,219,214,107,209,2,96,175,126,39,172,214,127,88,33,97,211,44,153,0,1,183,46,123,32,184,128,0,24,188,65,221,151,231,109,116,247,29,160,126,2,89,5,220,189,178,118,174,203,186,5,192,46,157,78,89,167,27,104,202,182,89,52,1,2,191,4,220,193,108,132,200,2,2,96,228,238,52,95,155,155,103,243,13,160,124,2,233,5,220,197,210,183,176,112,1,2,96,225,230,230,46,205,141,51,119,255,172,158,0,129,159,2,238,100,246,65,84,1,1,48,106,103,154,175,203,77,179,249,6,80,62,129,50,2,238,102,101,90,89,172,16,1,176,88,67,139,148,227,223,207,
21,105,164,50,8,16,248,248,20,16,2,129,128,2,2,96,192,166,180,95,146,55,204,237,183,0,0,2,165,4,220,211,74,181,179,74,49,2,96,149,78,214,169,195,173,178,78,47,85,66,128,192,111,1,247,53,59,33,156,128,0,24,174,37,205,23,228,54,217,124,3,40,159,64,81,1,247,182,162,141,205,91,150,0,152,183,119,37,87,238,111,101,74,182,85,81,4,8,248,83,64,123,32,152,128,0,24,172,33,189,151,227,45,114,239,254,171,158,64,109,1,119,184,218,253,205,86,157,0,152,173,99,133,215,235,230,88,184,185,74,35,64,224,67,192,93,206,54,136,35,32,0,198,233,69,243,149,184,49,54,223,0,202,39,208,66,192,157,174,69,155,83,20,41,0,166,104,83,253,69,186,41,214,239,177,10,9,16,248,41,224,110,103,31,196,16,16,0,99,244,161,251,42,252,219,143,238,59,64,253,4,26,9,184,225,53,106,118,224,82,5,192,192,205,105,179,52,111,136,219,180,90,161,4,8,124,8,184,231,217,6,1,4,4,192,0,77,104,190,4,183,194,230,27,64,249,4,26,10,184,239,53,108,122,180,146,5,192,104,29,105,183,30,191,12,105,215,114,5,19,32,224,191,10,104,15,108,23,16,0,183,
183,160,247,2,188,13,238,221,127,213,19,232,43,224,238,215,183,247,49,42,23,0,99,244,161,233,42,220,0,155,54,94,217,4,8,124,8,184,3,218,6,59,5,4,192,157,250,205,231,118,243,107,190,1,148,79,160,189,128,187,96,251,45,176,17,64,0,220,136,223,124,106,127,252,215,124,3,40,159,0,1,127,10,104,15,236,19,16,0,247,217,247,158,217,27,223,222,253,87,61,1,2,191,5,220,11,237,132,77,2,2,224,38,248,230,211,186,229,53,223,0,202,39,64,224,83,192,253,240,147,194,131,149,2,2,224,74,109,115,253,43,224,183,191,182,2,1,2,4,62,5,220,18,63,41,60,88,39,32,0,174,179,54,211,191,2,222,238,218,10,4,8,16,184,21,112,87,188,213,240,120,141,128,0,184,198,217,44,159,2,110,116,159,20,30,16,32,64,224,95,1,119,70,91,97,181,128,0,184,90,188,251,124,126,213,209,125,7,168,159,0,129,187,2,110,142,119,89,124,115,154,128,0,56,141,214,192,119,4,188,201,189,131,226,91,4,8,16,248,16,112,127,180,13,150,10,8,128,75,185,155,79,230,246,214,124,3,40,159,0,129,167,2,238,145,79,121,252,112,172,128,0,56,214,211,104,79,4,252,130,
227,9,142,31,17,32,64,192,127,23,218,30,88,40,32,0,46,196,238,61,149,183,182,189,251,175,122,2,4,142,8,184,83,30,81,242,156,17,2,2,224,8,69,99,188,20,112,83,123,73,228,9,4,8,16,248,16,112,183,180,13,214,8,8,128,107,156,187,207,226,183,191,221,119,128,250,9,16,56,44,224,134,121,152,202,19,47,8,8,128,23,240,188,244,160,128,55,180,7,161,60,141,0,1,2,31,2,238,153,182,193,2,1,1,112,1,114,247,41,188,155,237,190,3,212,79,128,192,73,1,183,205,147,96,158,126,94,64,0,60,111,230,21,167,4,188,149,61,197,229,201,4,8,16,248,16,112,231,180,13,102,11,8,128,179,133,155,143,239,38,214,124,3,40,159,0,129,55,5,220,61,223,132,243,178,131,2,2,224,65,40,79,123,75,192,175,49,222,98,243,34,2,4,8,248,143,2,218,3,115,5,4,192,185,190,189,71,247,6,182,119,255,85,79,128,192,53,1,247,208,107,126,94,253,84,64,0,124,202,227,135,87,4,124,252,119,69,207,107,9,16,32,240,195,109,212,38,152,38,32,0,78,163,237,62,176,183,174,221,119,128,250,9,16,184,46,224,78,122,221,208,8,247,5,4,192,251,46,190,123,81,192,77,235,
34,160,151,19,32,64,224,151,128,187,169,141,48,71,64,0,156,227,218,125,84,191,182,232,190,3,212,79,128,192,48,1,55,212,97,148,6,186,17,16,0,111,48,60,28,36,224,13,235,32,72,195,16,32,64,224,67,192,61,213,54,152,32,32,0,78,64,237,62,164,119,171,221,119,128,250,9,16,24,44,224,182,58,24,212,112,63,126,8,128,118,193,96,1,111,85,7,131,26,142,0,1,2,62,4,180,7,134,11,8,128,195,73,155,15,232,125,106,243,13,160,124,2,4,230,8,184,185,206,113,237,59,170,0,216,183,247,51,42,247,241,223,12,85,99,18,32,64,192,95,2,218,3,131,5,4,192,193,160,173,135,19,255,90,183,95,241,4,8,76,22,112,143,157,12,220,107,120,1,176,87,191,167,86,235,23,20,83,121,13,78,128,0,1,183,89,123,96,152,128,0,56,140,178,251,64,222,154,118,223,1,234,39,64,96,190,128,59,237,124,227,46,51,8,128,93,58,61,187,78,239,75,103,11,27,159,0,1,2,31,2,110,182,182,193,24,1,1,112,140,99,247,81,188,41,237,190,3,212,79,128,192,42,1,247,219,85,210,197,231,17,0,139,55,120,77,121,222,145,174,113,54,11,1,2,4,62,4,220,114,109,131,1,2,2,224,0,
196,238,67,120,59,218,125,7,168,159,0,129,181,2,238,186,107,189,107,206,38,0,214,236,235,202,170,188,23,93,169,109,46,2,4,8,124,8,184,241,218,6,87,5,4,192,171,130,221,95,239,141,104,247,29,160,126,2,4,118,8,184,247,238,80,47,53,167,0,88,170,157,235,139,241,46,116,189,185,25,9,16,32,240,33,224,246,107,27,92,18,16,0,47,241,117,127,177,183,160,221,119,128,250,9,16,216,39,224,14,188,207,190,194,204,2,96,133,46,238,170,193,251,207,93,242,230,37,64,128,192,135,128,155,176,109,240,190,128,0,248,190,93,247,87,122,243,217,125,7,168,159,0,129,221,2,238,195,187,59,144,120,126,1,48,113,243,246,46,221,59,207,189,254,102,39,64,128,192,135,128,91,177,109,240,166,128,0,248,38,92,247,151,121,219,217,125,7,168,159,0,129,24,2,238,198,49,250,144,111,21,2,96,190,158,69,88,177,247,156,17,186,96,13,4,8,16,248,16,112,67,182,13,222,17,16,0,223,81,235,254,26,111,56,187,239,0,245,19,32,16,73,192,61,57,82,55,210,172,69,0,76,211,170,56,11,245,110,51,78,47,172,132,0,1,2,31,2,110,203,182,193,105,1,1,240,52,
89,247,23,120,171,217,125,7,168,159,0,129,120,2,238,204,241,122,18,125,69,2,96,244,14,69,91,159,247,153,209,58,98,61,4,8,16,248,16,112,115,182,13,206,9,8,128,231,188,218,63,219,45,166,253,22,0,64,128,64,76,1,183,231,152,125,9,187,42,1,48,108,107,34,46,204,47,25,34,118,197,154,8,16,32,240,83,192,29,218,62,56,35,32,0,158,209,234,254,92,239,47,187,239,0,245,19,32,16,90,192,77,58,116,123,130,45,78,0,12,214,144,192,203,241,230,50,112,115,44,141,0,1,2,31,2,238,211,182,193,97,1,1,240,48,85,247,39,122,103,217,125,7,168,159,0,129,4,2,110,213,9,154,20,99,137,2,96,140,62,132,95,133,183,149,225,91,100,129,4,8,16,248,16,112,183,182,13,142,9,8,128,199,156,186,63,203,123,202,238,59,64,253,4,8,164,17,112,195,78,211,170,173,11,21,0,183,242,103,153,220,237,36,75,167,172,147,0,1,2,254,147,128,246,192,17,1,1,240,136,82,243,231,248,133,66,243,13,160,124,2,4,146,9,184,107,39,107,216,150,229,10,128,91,216,83,77,234,227,191,84,237,178,88,2,4,8,248,223,5,177,7,94,11,8,128,175,141,122,63,195,27,201,222,
253,87,61,1,2,57,5,220,187,115,246,109,225,170,5,192,133,216,25,167,242,241,95,198,174,89,51,1,2,4,252,37,160,61,240,92,64,0,124,238,211,252,167,222,66,54,223,0,202,39,64,32,177,128,59,120,226,230,45,88,186,0,184,0,57,237,20,62,254,75,219,58,11,39,64,128,128,191,4,180,7,158,9,8,128,207,116,154,255,76,254,107,190,1,148,79,128,64,118,1,183,241,236,29,156,184,126,1,112,34,110,238,161,253,242,32,119,255,172,158,0,1,2,254,119,65,236,129,199,2,2,224,99,155,222,63,241,190,177,119,255,85,79,128,64,17,1,55,243,34,141,28,94,134,0,56,156,180,196,128,62,254,43,209,70,69,16,32,64,192,255,56,176,61,112,95,64,0,188,239,210,252,187,222,49,54,223,0,202,39,64,160,146,128,91,122,165,110,14,171,69,0,28,70,89,104,32,55,139,66,205,84,10,1,2,4,220,212,237,129,191,5,4,192,191,77,186,127,199,175,127,187,239,0,245,19,32,80,77,192,125,189,90,71,7,212,35,0,14,64,172,53,132,119,138,181,250,169,26,2,4,8,124,8,184,181,219,6,127,8,8,128,127,128,180,255,210,77,162,253,22,0,64,128,64,69,1,55,247,138,93,189,82,
147,0,120,69,175,222,107,253,154,160,94,79,85,68,128,0,129,159,2,238,239,246,193,55,1,1,240,27,71,247,47,188,67,236,190,3,212,79,128,64,97,1,183,248,194,205,61,95,154,0,120,222,172,238,43,220,28,234,246,86,101,4,8,16,240,135,128,246,192,141,128,0,120,131,209,252,161,95,15,52,223,0,202,39,64,160,188,128,251,124,249,22,31,47,80,0,60,110,85,252,153,62,254,43,222,96,229,17,32,64,192,191,6,182,7,62,5,4,192,79,138,222,15,188,45,236,221,127,213,19,32,208,69,192,221,190,75,167,95,213,41,0,190,18,234,241,115,31,255,245,232,179,42,9,16,32,224,47,1,237,129,95,2,2,160,141,240,33,32,255,217,6,4,8,16,104,35,224,150,223,166,213,207,10,21,0,159,233,52,249,153,95,8,52,105,180,50,9,16,32,240,75,192,93,223,70,248,241,67,0,180,11,188,23,180,7,8,16,32,208,76,192,141,191,89,195,239,148,43,0,222,65,233,245,45,183,129,94,253,86,45,1,2,4,62,4,220,250,219,111,3,1,176,249,22,240,139,128,230,27,64,249,4,8,52,21,112,247,111,218,248,207,178,5,192,79,138,150,15,188,7,108,217,118,69,19,32,64,192,135,128,221,
247,128,0,216,122,7,200,127,173,219,175,120,2,4,122,11,56,2,90,247,95,0,236,220,126,23,127,231,238,171,157,0,129,246,2,14,129,206,91,64,0,236,219,125,127,0,210,183,247,42,39,64,128,192,79,1,231,64,227,125,32,0,182,109,190,119,126,109,91,175,112,2,4,8,252,39,224,40,248,79,162,221,255,23,0,219,181,252,223,130,93,244,93,59,175,110,2,4,8,220,8,56,12,110,48,90,61,20,0,91,181,251,179,88,31,251,127,82,120,64,128,0,129,214,2,206,131,166,237,23,0,91,54,222,59,190,150,109,87,52,1,2,4,238,9,56,18,238,169,148,255,158,0,88,190,197,119,10,116,177,223,65,241,45,2,4,8,116,21,112,40,116,236,188,0,216,175,235,62,238,239,215,115,21,19,32,64,224,153,128,115,225,153,78,209,159,9,128,69,27,251,184,44,239,244,30,219,248,9,1,2,4,154,10,56,26,218,53,94,0,236,214,114,23,121,183,142,171,151,0,1,2,7,4,28,14,7,144,74,61,69,0,44,213,206,215,197,184,196,95,27,121,6,1,2,4,26,10,56,30,154,53,93,0,108,213,112,127,230,209,170,221,138,37,64,128,192,9,1,39,196,9,172,2,79,21,0,11,52,241,112,9,222,223,29,166,242,68,
2,4,8,244,19,112,72,116,234,185,0,216,168,219,46,237,70,205,86,42,1,2,4,206,11,56,38,206,155,165,125,133,0,152,182,117,167,23,238,194,62,77,230,5,4,8,16,232,37,224,160,232,211,111,1,176,75,175,253,113,71,151,78,171,147,0,1,2,239,11,56,43,222,183,75,246,74,1,48,89,195,222,93,174,119,117,239,202,121,29,1,2,4,90,9,56,46,154,180,91,0,236,209,104,23,116,143,62,171,146,0,1,2,151,5,28,24,151,9,83,12,32,0,166,104,211,213,69,186,156,175,10,122,61,1,2,4,218,8,56,50,90,180,90,0,108,208,102,127,210,209,160,201,74,36,64,128,192,48,1,167,198,48,202,192,3,9,128,129,155,51,104,105,222,203,13,130,52,12,1,2,4,186,8,56,56,234,119,90,0,44,223,99,151,113,249,22,43,144,0,1,2,163,5,28,29,163,69,195,141,39,0,134,107,201,224,5,185,136,7,131,26,142,0,1,2,29,4,28,30,213,187,44,0,214,238,176,63,228,168,221,95,213,17,32,64,96,150,128,243,99,150,108,144,113,5,192,32,141,152,179,12,239,224,230,184,26,149,0,1,2,13,4,28,33,165,155,44,0,86,110,175,139,183,114,119,213,70,128,0,129,201,2,14,145,201,192,91,135,23,
0,183,242,207,157,220,165,59,215,215,232,4,8,16,40,46,224,24,41,220,96,1,176,108,115,253,249,70,217,214,42,140,0,1,2,139,4,156,36,139,160,55,76,35,0,110,64,95,50,165,247,109,75,152,77,66,128,0,129,218,2,14,147,170,253,21,0,139,118,214,37,91,180,177,202,34,64,128,192,90,1,199,201,90,239,101,179,9,128,203,168,151,78,228,130,93,202,109,50,2,4,8,212,21,112,160,212,236,173,0,88,178,175,46,215,146,109,85,20,1,2,4,118,8,56,82,118,168,79,159,83,0,156,78,188,126,2,127,180,187,222,220,140,4,8,16,168,43,224,84,169,216,91,1,176,94,87,189,87,171,215,83,21,17,32,64,96,171,128,131,101,43,255,148,201,5,192,41,172,59,7,117,153,238,212,55,55,1,2,4,74,10,56,90,202,181,85,0,172,214,82,23,105,181,142,170,135,0,1,2,1,4,28,46,1,154,48,116,9,2,224,80,206,253,131,185,68,247,247,192,10,8,16,32,80,80,192,241,82,172,169,2,96,169,134,250,67,221,82,237,84,12,1,2,4,2,9,56,97,2,53,99,192,82,4,192,1,136,97,134,240,254,44,76,43,44,132,0,1,2,245,4,28,50,149,122,42,0,22,234,166,75,179,80,51,149,66,128,0,129,120,
2,142,153,120,61,121,123,69,2,224,219,116,225,94,232,194,12,215,18,11,34,64,128,64,45,1,7,77,157,126,10,128,101,122,233,178,44,211,74,133,16,32,64,32,170,128,163,38,106,103,78,175,75,0,60,77,22,243,5,254,56,55,102,95,172,138,0,1,2,181,4,156,54,85,250,41,0,214,232,164,247,100,53,250,168,10,2,4,8,132,23,112,224,132,111,209,161,5,10,128,135,152,162,63,201,229,24,189,67,214,71,128,0,129,50,2,142,156,18,173,20,0,43,180,209,197,88,161,139,106,32,64,128,64,18,1,135,78,146,70,61,93,166,0,248,148,39,199,15,93,138,57,250,100,149,4,8,16,40,34,224,216,41,208,72,1,48,127,19,93,136,249,123,168,2,2,4,8,164,18,112,240,164,106,215,221,197,10,128,119,89,18,125,211,63,200,74,212,44,75,37,64,128,64,17,1,103,79,250,70,10,128,201,91,232,93,88,242,6,90,62,1,2,4,114,10,56,126,114,246,237,115,213,2,224,39,69,202,7,46,192,148,109,179,104,2,4,8,228,23,112,0,229,238,161,0,152,186,127,46,191,212,237,179,120,2,4,8,100,22,112,4,101,238,222,15,1,48,115,251,92,124,153,187,103,237,4,8,16,72,46,224,16,202,220,
64,1,48,113,247,92,122,137,155,103,233,4,8,16,200,47,224,24,74,220,67,1,48,111,243,92,120,121,123,103,229,4,8,16,40,33,224,32,202,219,70,1,48,107,239,252,19,252,172,157,179,110,2,4,8,212,17,112,22,165,237,165,0,152,180,117,222,117,37,109,156,101,19,32,64,160,150,128,227,40,105,63,5,192,156,141,115,193,229,236,155,85,19,32,64,160,156,128,3,41,103,75,5,192,148,125,115,185,165,108,155,69,19,32,64,160,162,128,35,41,101,87,5,192,140,109,115,177,101,236,154,53,19,32,64,160,168,128,67,41,99,99,5,192,132,93,115,169,37,108,154,37,19,32,64,160,174,128,99,41,97,111,5,192,124,77,115,161,229,235,153,21,19,32,64,160,180,128,131,41,95,123,5,192,108,61,243,79,238,179,117,204,122,9,16,32,80,95,192,217,148,174,199,2,96,178,150,121,151,149,172,97,150,75,128,0,129,30,2,142,167,100,125,22,0,115,53,204,5,150,171,95,86,75,128,0,129,54,2,14,168,92,173,22,0,83,245,203,229,149,170,93,22,75,128,0,129,78,2,142,168,84,221,22,0,51,181,203,197,149,169,91,214,74,128,0,129,102,2,14,169,76,13,23,0,19,117,203,
165,149,168,89,150,74,128,0,129,126,2,142,169,68,61,23,0,243,52,203,133,149,167,87,86,74,128,0,129,150,2,14,170,60,109,23,0,211,244,202,101,149,166,85,22,74,128,0,129,174,2,142,170,52,157,23,0,179,180,202,69,149,165,83,214,73,128,0,129,198,2,14,171,44,205,23,0,115,116,202,127,98,51,71,159,172,146,0,1,2,221,5,156,87,73,118,128,0,152,162,81,222,81,165,104,147,69,18,32,64,128,192,143,31,142,172,20,187,64,0,204,208,38,23,83,134,46,89,35,1,2,4,8,252,18,112,104,101,216,8,2,96,130,46,185,148,18,52,201,18,9,16,32,64,224,63,1,199,214,127,18,129,255,191,0,24,184,57,255,46,205,133,20,191,71,86,72,128,0,1,2,55,2,14,174,27,140,160,15,5,192,160,141,249,90,150,203,232,203,194,35,2,4,8,16,72,33,224,232,10,223,38,1,48,122,139,92,68,209,59,100,125,4,8,16,32,240,151,128,195,235,47,146,96,223,16,0,131,53,228,207,229,184,132,254,20,241,53,1,2,4,8,36,16,112,124,5,111,146,0,24,187,65,46,160,216,253,177,58,2,4,8,16,120,32,224,0,123,0,19,228,219,2,96,144,70,220,95,134,203,231,190,139,239,18,32,64,128,
64,120,1,71,88,232,22,9,128,145,219,227,226,137,220,29,107,35,64,128,0,129,167,2,14,177,167,60,155,127,40,0,110,110,192,179,233,93,58,207,116,252,140,0,1,2,4,130,11,56,198,2,55,72,0,140,219,28,23,78,220,222,88,25,1,2,4,8,28,16,112,144,29,64,218,244,20,1,112,19,252,203,105,253,207,105,191,36,242,4,2,4,8,16,8,46,224,44,11,219,32,1,48,104,107,188,107,10,218,24,203,34,64,128,0,129,51,2,142,179,51,90,11,159,43,0,46,196,62,49,149,11,230,4,150,167,18,32,64,128,64,92,1,7,90,204,222,8,128,33,251,226,114,9,217,22,139,34,64,128,0,129,243,2,142,180,243,102,11,94,33,0,46,64,62,61,133,139,229,52,153,23,16,32,64,128,64,84,1,135,90,196,206,8,128,1,187,226,82,9,216,20,75,34,64,128,0,129,119,5,28,107,239,202,77,124,157,0,56,17,247,205,161,93,40,111,194,121,25,1,2,4,8,196,20,112,176,197,235,139,0,24,174,39,46,147,112,45,177,32,2,4,8,16,184,38,224,104,187,230,55,225,213,2,224,4,212,75,67,186,72,46,241,121,49,1,2,4,8,68,20,112,184,69,235,138,0,24,172,35,46,145,96,13,177,28,2,4,8,16,24,33,224,120,
27,161,56,112,12,1,112,32,230,128,161,92,32,3,16,13,65,128,0,1,2,241,4,28,112,177,122,34,0,134,234,135,203,35,84,59,44,134,0,1,2,4,198,9,56,226,198,89,14,24,73,0,28,128,56,108,8,23,199,48,74,3,17,32,64,128,64,52,1,135,92,164,142,8,128,129,186,225,210,8,212,12,75,33,64,128,0,129,209,2,142,185,209,162,23,198,19,0,47,224,13,126,169,11,99,48,168,225,8,16,32,64,32,150,128,131,46,78,63,4,192,48,189,112,89,132,105,133,133,16,32,64,128,192,28,1,71,221,28,215,55,70,21,0,223,64,155,242,18,23,197,20,86,131,18,32,64,128,64,36,1,135,93,148,110,8,128,65,58,225,146,8,210,8,203,32,64,128,0,129,153,2,142,187,153,186,39,198,22,0,79,96,77,124,170,11,98,34,174,161,9,16,32,64,32,142,128,3,47,70,47,4,192,16,125,112,57,132,104,131,69,16,32,64,128,192,124,1,71,222,124,227,3,51,8,128,7,144,166,63,197,197,48,157,216,4,4,8,16,32,16,69,192,161,23,161,19,2,96,128,46,184,20,2,52,193,18,8,16,32,64,96,149,128,99,111,149,244,147,121,4,192,39,56,139,126,228,66,88,4,109,26,2,4,8,16,136,33,224,224,219,223,7,1,112,
123,15,92,6,219,91,96,1,4,8,16,32,176,86,192,209,183,214,251,206,108,2,224,29,148,165,223,114,17,44,229,54,25,1,2,4,8,68,16,112,248,237,238,130,0,184,185,3,46,129,205,13,48,61,1,2,4,8,236,16,112,252,237,80,191,153,83,0,188,193,216,240,208,5,176,1,221,148,4,8,16,32,176,95,192,1,184,183,7,2,224,86,127,219,127,43,191,201,9,16,32,64,96,159,128,35,112,159,253,199,204,2,224,78,126,155,127,167,190,185,9,16,32,64,96,171,128,67,112,39,191,0,184,81,223,214,223,136,111,106,2,4,8,16,216,45,224,24,220,216,1,1,112,31,190,141,191,207,222,204,4,8,16,32,16,64,192,65,184,175,9,2,224,54,123,219,126,27,189,137,9,16,32,64,32,134,128,163,112,91,31,4,192,93,244,54,253,46,121,243,18,32,64,128,64,24,1,135,225,174,86,8,128,155,228,109,249,77,240,166,37,64,128,0,129,72,2,142,195,77,221,16,0,247,192,219,240,123,220,205,74,128,0,1,2,193,4,28,136,123,26,34,0,110,113,183,221,183,176,155,148,0,1,2,4,226,9,56,18,183,244,68,0,220,193,110,179,239,80,55,39,1,2,4,8,132,20,112,40,238,104,139,0,184,65,221,86,223,128,
110,74,2,4,8,16,136,42,224,88,220,208,25,1,112,61,186,141,190,222,220,140,4,8,16,32,16,88,192,193,184,190,57,2,224,114,115,219,124,57,185,9,9,16,32,64,32,182,128,163,113,121,127,4,192,213,228,54,249,106,113,243,17,32,64,128,64,120,1,135,227,234,22,9,128,139,197,109,241,197,224,166,35,64,128,0,129,12,2,142,199,197,93,18,0,215,130,219,224,107,189,205,70,128,0,1,2,73,4,28,144,107,27,37,0,46,245,182,189,151,114,155,140,0,1,2,4,242,8,56,34,151,246,74,0,92,201,109,115,175,212,54,23,1,2,4,8,164,18,112,72,174,108,151,0,184,80,219,214,94,136,109,42,2,4,8,16,200,38,224,152,92,216,49,1,112,29,182,141,189,206,218,76,4,8,16,32,144,80,192,65,185,174,105,2,224,50,107,219,122,25,181,137,8,16,32,64,32,167,128,163,114,89,223,4,192,85,212,54,245,42,105,243,16,32,64,128,64,90,1,135,229,170,214,9,128,139,164,109,233,69,208,166,33,64,128,0,129,204,2,142,203,69,221,19,0,215,64,219,208,107,156,205,66,128,0,1,2,201,5,28,152,107,26,40,0,46,113,182,157,151,48,155,132,0,1,2,4,242,11,56,50,151,244,80,0,92,
193,108,51,175,80,54,7,1,2,4,8,148,16,112,104,174,104,163,0,184,64,217,86,94,128,108,10,2,4,8,16,168,34,224,216,92,208,73,1,112,62,178,141,60,223,216,12,4,8,16,32,80,72,192,193,57,191,153,2,224,116,99,219,120,58,177,9,8,16,32,64,160,150,128,163,115,122,63,5,192,233,196,38,32,64,128,0,1,2,4,8,196,18,16,0,103,247,195,187,152,217,194,198,39,64,128,0,129,114,2,14,207,217,45,21,0,39,11,219,194,147,129,13,79,128,0,1,2,21,5,28,159,147,187,42,0,206,5,182,129,231,250,26,157,0,1,2,4,138,10,56,64,231,54,86,0,156,234,107,251,78,229,53,56,1,2,4,8,212,21,112,132,78,237,173,0,56,147,215,230,157,169,107,108,2,4,8,16,40,45,224,16,157,217,94,1,112,162,174,173,59,17,215,208,4,8,16,32,80,93,192,49,58,177,195,2,224,60,92,27,119,158,173,145,9,16,32,64,160,129,128,131,116,94,147,5,192,105,182,182,237,52,90,3,19,32,64,128,64,15,1,71,233,180,62,11,128,179,104,109,218,89,178,198,37,64,128,0,129,54,2,14,211,89,173,22,0,39,201,218,178,147,96,13,75,128,0,1,2,157,4,28,167,147,186,45,0,206,129,181,97,231,184,
26,149,0,1,2,4,154,9,56,80,231,52,92,0,156,226,106,187,78,97,53,40,1,2,4,8,244,19,112,164,78,233,185,0,56,131,213,102,157,161,106,76,2,4,8,16,104,41,224,80,157,209,118,1,112,134,170,49,9,16,32,64,128,0,1,2,129,5,4,192,9,205,241,94,101,2,170,33,9,16,32,64,160,171,128,99,117,66,231,5,192,241,168,54,234,120,83,35,18,32,64,128,64,99,1,7,235,248,230,11,128,195,77,109,211,225,164,6,36,64,128,0,129,222,2,142,214,225,253,23,0,71,147,218,164,163,69,141,71,128,0,1,2,237,5,28,174,163,183,128,0,56,88,212,22,29,12,106,56,2,4,8,16,32,240,227,135,227,117,240,46,16,0,199,130,218,160,99,61,141,70,128,0,1,2,4,126,9,56,96,199,110,4,1,112,168,167,237,57,148,211,96,4,8,16,32,64,224,63,1,71,236,127,18,67,254,191,0,56,132,241,223,65,108,206,145,154,198,34,64,128,0,1,2,55,2,14,217,27,140,203,15,5,192,203,132,95,3,216,154,95,22,30,17,32,64,128,0,129,193,2,142,217,129,160,2,224,64,76,67,17,32,64,128,0,1,2,4,50,8,8,128,227,186,228,157,201,56,75,35,17,32,64,128,0,129,191,4,28,180,127,145,188,253,13,1,240,
109,186,63,95,104,91,254,41,226,107,2,4,8,16,32,48,84,192,81,59,140,83,0,28,69,105,83,142,146,52,14,1,2,4,8,16,120,32,224,176,125,0,115,250,219,2,224,105,178,251,47,176,37,239,187,248,46,1,2,4,8,16,24,40,224,184,29,132,41,0,142,129,180,33,199,56,26,133,0,1,2,4,8,60,21,112,224,62,229,57,252,67,1,240,48,213,179,39,218,142,207,116,252,140,0,1,2,4,8,12,19,112,228,14,161,20,0,71,48,218,140,35,20,141,65,128,0,1,2,4,14,8,56,116,15,32,189,124,138,0,248,146,200,19,8,16,32,64,128,0,1,2,181,4,4,192,1,253,244,94,100,0,162,33,8,16,32,64,128,192,49,1,199,238,49,167,167,207,18,0,159,242,28,250,161,141,120,136,201,147,8,16,32,64,128,192,24,1,7,239,117,71,1,240,178,161,109,120,153,208,0,4,8,16,32,64,224,140,128,163,247,140,214,221,231,10,128,119,89,78,124,211,38,60,129,229,169,4,8,16,32,64,96,132,128,195,247,170,162,0,120,81,208,22,188,8,232,229,4,8,16,32,64,224,188,128,227,247,188,217,183,87,8,128,223,56,78,127,97,3,158,38,243,2,2,4,8,16,32,112,93,192,1,124,205,80,0,188,228,103,251,93,226,243,
98,2,4,8,16,32,240,174,128,35,248,93,185,95,175,19,0,47,241,121,49,1,2,4,8,16,32,64,32,159,128,0,120,165,103,222,125,92,209,243,90,2,4,8,16,32,112,65,192,33,124,1,239,135,0,120,65,207,214,187,128,231,165,4,8,16,32,64,224,154,128,99,248,130,159,0,248,62,158,141,247,190,157,87,18,32,64,128,0,129,203,2,14,226,247,9,5,192,183,237,108,187,183,233,188,144,0,1,2,4,8,140,16,112,20,191,173,40,0,190,75,103,211,189,43,231,117,4,8,16,32,64,96,144,128,195,248,93,72,1,240,77,57,91,238,77,56,47,35,64,128,0,1,2,227,4,28,199,111,90,10,128,111,194,121,25,1,2,4,8,16,32,64,32,171,128,0,248,94,231,188,227,120,207,205,171,8,16,32,64,128,192,80,1,7,242,123,156,2,224,91,110,182,219,91,108,94,68,128,0,1,2,4,70,11,56,146,223,18,21,0,223,97,179,217,222,81,243,26,2,4,8,16,32,48,65,192,161,252,14,170,0,248,134,154,173,246,6,154,151,16,32,64,128,0,129,57,2,142,229,55,92,5,192,243,104,54,218,121,51,175,32,64,128,0,1,2,211,4,28,204,231,105,5,192,243,102,94,65,128,0,1,2,4,8,16,72,45,32,0,158,110,159,247,25,167,
201,188,128,0,1,2,4,8,204,20,112,52,159,214,21,0,207,146,217,100,103,197,60,159,0,1,2,4,8,76,22,112,56,159,5,22,0,79,138,217,98,39,193,60,157,0,1,2,4,8,204,23,112,60,159,52,22,0,207,129,217,96,231,188,60,155,0,1,2,4,8,44,17,112,64,159,99,22,0,79,121,217,94,167,184,60,153,0,1,2,4,8,172,18,112,68,159,146,22,0,79,113,121,50,1,2,4,8,16,32,64,32,191,128,0,120,166,135,222,93,156,209,242,92,2,4,8,16,32,176,80,192,33,125,6,91,0,60,161,101,107,157,192,242,84,2,4,8,16,32,176,86,192,49,125,194,91,0,60,142,101,99,29,183,242,76,2,4,8,16,32,176,92,192,65,125,156,92,0,60,108,101,91,29,166,242,68,2,4,8,16,32,176,67,192,81,125,88,93,0,60,74,101,83,29,149,242,60,2,4,8,16,32,176,73,192,97,125,20,94,0,60,42,229,121,4,8,16,32,64,128,0,129,34,2,2,224,193,70,122,79,113,16,202,211,8,16,32,64,128,192,62,1,199,245,65,123,1,240,24,148,13,117,204,201,179,8,16,32,64,128,192,86,1,7,246,49,126,1,240,144,147,237,116,136,201,147,8,16,32,64,128,192,110,1,71,246,161,14,8,128,71,152,108,166,35,74,158,67,128,0,1,
2,4,2,8,56,180,143,52,65,0,60,162,228,57,4,8,16,32,64,128,0,129,66,2,2,224,129,102,122,47,113,0,201,83,8,16,32,64,128,64,12,1,199,246,129,62,8,128,175,145,108,164,215,70,158,65,128,0,1,2,4,194,8,56,184,95,183,66,0,124,105,100,27,189,36,242,4,2,4,8,16,32,16,73,192,209,253,178,27,2,224,43,34,155,232,149,144,159,19,32,64,128,0,129,96,2,14,239,87,13,17,0,95,9,249,57,1,2,4,8,16,32,64,160,152,128,0,248,162,161,222,67,188,0,242,99,2,4,8,16,32,16,79,192,241,253,162,39,2,224,115,32,27,232,185,143,159,18,32,64,128,0,129,144,2,14,240,231,109,17,0,159,250,216,62,79,121,252,144,0,1,2,4,8,68,21,112,132,63,237,140,0,248,140,199,230,121,166,227,103,4,8,16,32,64,32,176,128,67,252,89,115,4,192,103,58,126,70,128,0,1,2,4,8,16,40,40,32,0,62,105,170,247,14,79,112,252,136,0,1,2,4,8,196,22,112,140,63,233,143,0,248,24,199,198,121,108,227,39,4,8,16,32,64,32,188,128,131,252,113,139,4,192,135,54,182,205,67,26,63,32,64,128,0,1,2,25,4,28,229,15,187,36,0,62,162,177,105,30,201,248,62,1,2,4,8,16,72,34,224,48,
127,212,40,1,240,145,140,239,19,32,64,128,0,1,2,4,138,10,8,128,15,26,235,61,195,3,24,223,38,64,128,0,1,2,121,4,28,231,15,122,37,0,222,135,177,97,238,187,248,46,1,2,4,8,16,72,37,224,64,191,223,46,1,240,174,139,237,114,151,197,55,9,16,32,64,128,64,54,1,71,250,221,142,9,128,247,88,108,150,123,42,190,71,128,0,1,2,4,18,10,56,212,239,53,77,0,188,167,226,123,4,8,16,32,64,128,0,129,194,2,2,224,157,230,122,175,112,7,197,183,8,16,32,64,128,64,78,1,199,250,157,190,9,128,127,163,216,40,127,155,248,14,1,2,4,8,16,72,43,224,96,255,187,117,2,224,95,38,182,201,95,36,190,65,128,0,1,2,4,50,11,56,218,255,234,158,0,248,23,137,111,16,32,64,128,0,1,2,4,106,11,8,128,127,246,215,187,132,63,69,124,77,128,0,1,2,4,146,11,56,220,255,108,160,0,248,135,136,45,242,7,136,47,9,16,32,64,128,64,126,1,199,251,31,61,20,0,191,131,216,32,223,61,124,69,128,0,1,2,4,74,8,56,224,191,183,81,0,252,238,225,43,2,4,8,16,32,64,128,64,121,1,1,240,91,139,189,63,248,198,225,11,2,4,8,16,32,80,69,192,17,255,173,147,2,224,45,135,205,
113,171,225,49,1,2,4,8,16,40,36,224,144,191,109,166,0,120,163,97,107,220,96,120,72,128,0,1,2,4,106,9,56,230,111,250,41,0,126,97,216,24,95,22,30,17,32,64,128,0,129,114,2,14,250,175,150,10,128,95,22,30,17,32,64,128,0,1,2,4,90,8,8,128,159,109,246,190,224,147,194,3,2,4,8,16,32,80,81,192,81,255,217,85,1,240,63,10,155,226,63,9,255,159,0,1,2,4,8,20,21,112,216,255,215,88,1,240,95,9,91,226,191,45,225,255,19,32,64,128,0,129,178,2,142,251,127,91,43,0,150,221,227,10,35,64,128,0,1,2,4,8,220,23,16,0,127,187,120,71,112,127,127,248,46,1,2,4,8,16,40,37,224,192,255,221,78,1,240,151,131,237,80,234,234,86,12,1,2,4,8,16,120,36,224,200,255,37,35,0,254,100,176,25,30,93,38,190,79,128,0,1,2,4,138,9,56,244,127,54,84,0,44,182,173,149,67,128,0,1,2,4,8,16,120,37,32,0,126,8,121,47,240,106,155,248,57,1,2,4,8,16,40,35,224,216,255,104,165,0,40,255,149,185,162,21,66,128,0,1,2,4,142,8,72,128,2,224,145,125,226,57,4,8,16,32,64,128,0,129,82,2,62,1,244,11,224,82,27,90,49,4,8,16,32,64,224,165,128,143,0,253,10,88,254,
123,121,153,120,2,1,2,4,8,16,40,38,32,1,182,255,4,208,22,40,118,77,43,135,0,1,2,4,8,188,22,104,127,252,183,15,128,175,247,136,103,16,32,64,128,0,1,2,4,106,9,116,15,128,237,223,1,212,218,206,170,33,64,128,0,1,2,199,4,186,7,128,230,1,176,123,251,143,93,36,158,69,128,0,1,2,4,202,9,52,143,0,189,3,96,243,230,151,187,152,21,68,128,0,1,2,4,14,11,244,14,1,189,3,224,225,77,226,137,4,8,16,32,64,128,0,129,58,2,173,3,96,239,236,95,103,19,171,132,0,1,2,4,8,188,33,208,58,6,116,14,128,173,27,255,198,133,226,37,4,8,16,32,64,160,148,64,231,32,208,56,0,118,110,123,169,235,87,49,4,8,16,32,64,224,61,129,198,81,160,113,0,124,111,175,120,21,1,2,4,8,16,32,64,32,187,64,223,0,216,56,245,103,223,180,214,79,128,0,1,2,4,198,8,244,13,3,109,3,96,223,150,143,185,100,140,66,128,0,1,2,4,10,8,180,141,3,109,3,96,129,77,171,4,2,4,8,16,32,64,128,192,91,2,93,3,96,219,196,255,214,46,241,34,2,4,8,16,32,80,84,160,107,32,104,26,0,187,182,187,232,213,171,44,2,4,8,16,32,240,174,64,211,72,208,51,0,54,109,246,187,215,134,
215,17,32,64,128,0,129,186,2,61,67,65,207,0,88,119,23,171,140,0,1,2,4,8,16,32,240,82,160,101,0,236,153,245,95,238,5,79,32,64,128,0,1,2,29,5,90,198,130,142,1,176,101,163,59,94,209,106,38,64,128,0,1,2,71,4,58,6,131,142,1,240,200,94,240,28,2,4,8,16,32,64,128,64,89,129,134,1,176,99,206,47,187,127,21,70,128,0,1,2,4,174,11,52,140,6,253,2,96,195,38,95,191,50,140,64,128,0,1,2,4,42,11,244,11,7,253,2,96,229,253,171,54,2,4,8,16,32,64,128,192,1,129,118,1,176,95,198,63,176,11,60,133,0,1,2,4,8,244,22,104,23,15,186,5,192,118,13,238,125,61,171,158,0,1,2,4,8,28,19,232,22,16,154,5,192,110,237,61,182,233,61,139,0,1,2,4,8,180,23,104,22,17,154,5,192,246,219,27,0,1,2,4,8,16,32,64,224,71,175,0,216,44,221,219,223,4,8,16,32,64,128,192,81,129,94,33,161,85,0,236,213,218,163,27,222,243,8,16,32,64,128,0,129,15,129,86,49,161,85,0,180,189,9,16,32,64,128,0,1,2,4,126,180,250,21,112,171,100,111,115,19,32,64,128,0,1,2,231,4,58,5,133,70,159,0,118,106,235,185,13,239,217,4,8,16,32,64,128,192,135,64,163,168,208,40,
0,218,218,4,8,16,32,64,128,0,1,2,63,5,250,4,192,70,169,222,214,38,64,128,0,1,2,4,222,17,232,19,22,218,4,192,62,45,125,103,195,123,13,1,2,4,8,16,32,240,33,208,38,46,116,9,128,109,26,234,242,37,64,128,0,1,2,4,222,23,232,18,24,186,4,192,247,119,130,87,18,32,64,128,0,1,2,4,138,9,52,9,128,93,242,124,177,221,169,28,2,4,8,16,32,176,90,160,73,100,232,17,0,155,52,115,245,53,98,62,2,4,8,16,32,80,79,160,71,104,232,17,0,235,237,78,21,17,32,64,128,0,1,2,4,222,22,104,17,0,123,100,249,183,247,128,23,18,32,64,128,0,1,2,95,2,45,98,67,135,0,216,162,145,95,251,214,35,2,4,8,16,32,64,224,138,64,135,224,208,33,0,94,217,3,94,75,128,0,1,2,4,8,16,40,39,208,32,0,118,200,241,229,246,165,130,8,16,32,64,128,192,62,129,6,209,161,126,0,108,208,196,125,87,136,153,9,16,32,64,128,64,69,129,250,225,161,126,0,172,184,47,213,68,128,0,1,2,4,8,16,184,32,80,62,0,214,207,240,23,186,239,165,4,8,16,32,64,128,192,61,129,242,241,161,122,0,44,223,192,123,187,214,247,8,16,32,64,128,0,129,107,2,213,3,68,245,0,120,173,251,94,
77,128,0,1,2,4,8,16,40,40,80,60,0,86,207,239,5,119,164,146,8,16,32,64,128,64,4,129,226,17,162,118,0,44,222,188,8,215,135,53,16,32,64,128,0,129,154,2,181,67,68,237,0,88,115,71,170,138,0,1,2,4,8,16,32,112,73,160,116,0,172,157,221,47,245,221,139,9,16,32,64,128,0,129,231,2,165,99,68,229,0,88,186,113,207,247,172,159,18,32,64,128,0,1,2,87,5,42,7,137,202,1,240,106,223,189,158,0,1,2,4,8,16,32,80,82,160,112,0,172,156,219,75,238,69,69,17,32,64,128,0,129,88,2,133,163,68,221,0,88,184,105,177,174,14,171,33,64,128,0,1,2,85,5,234,134,137,186,1,176,234,94,84,23,1,2,4,8,16,32,64,224,162,64,217,0,88,55,179,95,236,184,151,19,32,64,128,0,1,2,71,5,202,198,137,170,1,176,108,195,142,238,88,207,35,64,128,0,1,2,4,174,11,84,13,20,85,3,224,245,142,27,129,0,1,2,4,8,16,32,80,84,160,104,0,172,154,215,139,238,66,101,17,32,64,128,0,129,168,2,69,35,69,205,0,88,180,89,81,175,13,235,34,64,128,0,1,2,117,5,106,134,138,154,1,176,238,46,84,25,1,2,4,8,16,32,64,224,178,64,201,0,88,51,171,95,238,181,1,8,16,32,64,128,
0,129,243,2,37,99,69,201,0,120,190,183,94,65,128,0,1,2,4,8,16,232,35,80,49,0,150,76,234,125,182,164,74,9,16,32,64,128,64,44,129,138,193,162,96,0,172,216,166,88,23,130,213,16,32,64,128,0,129,86,2,5,163,69,193,0,216,106,75,42,150,0,1,2,4,8,16,32,112,90,160,94,0,44,152,210,79,119,213,11,8,16,32,64,128,0,129,129,2,245,194,69,185,0,88,175,69,3,247,175,161,8,16,32,64,128,0,129,119,4,202,197,139,114,1,240,157,174,122,13,1,2,4,8,16,32,64,160,147,64,181,0,88,46,161,119,218,140,106,37,64,128,0,1,2,81,5,170,5,140,98,1,176,90,123,162,94,6,214,69,128,0,1,2,4,154,9,20,139,24,197,2,96,179,205,168,92,2,4,8,16,32,64,128,192,27,2,181,2,96,177,116,254,70,63,189,132,0,1,2,4,8,16,152,34,80,43,100,212,10,128,83,26,110,80,2,4,8,16,32,64,128,64,45,129,82,1,176,86,54,175,181,209,84,67,128,0,1,2,4,146,11,148,138,25,149,2,96,169,198,36,191,72,44,159,0,1,2,4,8,148,19,168,20,52,42,5,192,114,27,77,65,4,8,16,32,64,128,0,129,25,2,133,2,96,165,92,62,163,213,198,36,64,128,0,1,2,4,46,9,20,138,26,117,2,96,161,166,
92,218,156,94,76,128,0,1,2,4,8,76,18,168,19,54,234,4,192,73,173,54,44,1,2,4,8,16,32,64,160,154,64,153,0,88,39,147,87,219,98,234,33,64,128,0,1,2,101,4,202,196,141,50,1,176,204,214,82,8,1,2,4,8,16,32,64,96,178,64,149,0,88,38,145,79,238,183,225,9,16,32,64,128,0,129,11,2,85,2,71,145,0,88,165,29,23,118,164,151,18,32,64,128,0,1,2,243,5,138,68,142,34,1,112,126,191,205,64,128,0,1,2,4,8,16,168,34,80,35,0,22,73,227,85,54,149,58,8,16,32,64,128,64,93,129,26,161,163,68,0,172,209,138,186,151,138,202,8,16,32,64,128,64,33,129,18,177,163,68,0,44,180,169,148,66,128,0,1,2,4,8,16,152,46,80,33,0,150,72,226,211,59,109,2,2,4,8,16,32,64,96,136,64,133,224,81,33,0,14,105,166,65,8,16,32,64,128,0,1,2,93,4,10,4,192,10,57,188,203,118,83,39,1,2,4,8,16,40,32,80,32,122,228,15,128,5,154,80,224,82,80,2,1,2,4,8,16,104,36,144,63,124,228,15,128,141,182,155,82,9,16,32,64,128,0,1,2,35,4,210,7,192,252,25,124,68,27,141,65,128,0,1,2,4,8,44,20,72,31,63,210,7,192,133,205,54,21,1,2,4,8,16,32,64,160,132,64,246,0,152,62,129,
151,216,69,138,32,64,128,0,1,2,205,4,178,7,144,228,1,48,59,127,179,171,69,185,4,8,16,32,64,160,138,64,242,8,146,60,0,86,217,69,234,32,64,128,0,1,2,4,8,172,19,200,29,0,147,167,239,117,109,54,19,1,2,4,8,16,32,48,86,32,119,8,201,29,0,199,118,210,104,4,8,16,32,64,128,0,129,22,2,169,3,96,238,236,221,98,127,41,146,0,1,2,4,8,84,21,72,29,67,50,7,192,212,240,85,175,6,117,17,32,64,128,0,129,46,2,153,131,72,230,0,216,101,127,169,147,0,1,2,4,8,16,32,48,84,32,113,0,204,156,187,135,246,208,96,4,8,16,32,64,128,192,14,129,196,81,36,113,0,220,209,105,115,18,32,64,128,0,1,2,4,242,11,228,13,128,137,83,119,254,109,163,2,2,4,8,16,32,64,224,199,143,188,97,36,109,0,204,75,238,130,33,64,128,0,1,2,4,138,8,164,141,35,105,3,96,145,141,163,12,2,4,8,16,32,64,128,192,114,129,172,1,48,109,226,94,222,97,19,18,32,64,128,0,1,2,211,4,178,6,146,172,1,112,90,35,13,76,128,0,1,2,4,8,16,168,46,144,52,0,102,205,219,213,183,147,250,8,16,32,64,128,64,51,129,164,145,36,105,0,108,182,185,148,75,128,0,1,2,4,8,16,24,40,144,
51,0,38,77,219,3,251,102,40,2,4,8,16,32,64,32,132,64,206,80,146,50,0,230,164,14,177,75,45,130,0,1,2,4,8,16,24,43,144,50,150,164,12,128,99,251,102,52,2,4,8,16,32,64,128,64,47,129,140,1,48,101,210,238,181,173,84,75,128,0,1,2,4,250,8,100,12,38,25,3,96,159,29,165,82,2,4,8,16,32,64,128,192,4,129,132,1,48,99,206,158,208,57,67,18,32,64,128,0,1,2,49,4,18,70,147,124,1,48,33,114,140,221,105,21,4,8,16,32,64,128,192,28,129,124,225,36,95,0,156,211,57,163,18,32,64,128,0,1,2,4,218,8,164,11,128,249,50,118,155,189,164,80,2,4,8,16,32,208,85,32,93,60,73,23,0,187,238,44,117,19,32,64,128,0,1,2,4,70,9,100,11,128,233,18,246,168,70,25,135,0,1,2,4,8,16,136,43,144,45,160,100,11,128,113,59,111,101,4,8,16,32,64,128,0,129,36,2,201,2,96,182,124,157,100,23,88,38,1,2,4,8,16,32,112,77,32,89,68,73,22,0,175,245,198,171,9,16,32,64,128,0,1,2,4,126,252,200,21,0,147,165,107,27,140,0,1,2,4,8,16,232,34,144,43,164,164,10,128,185,104,187,108,120,117,18,32,64,128,0,1,2,31,2,169,98,74,170,0,104,123,17,32,64,128,0,1,2,4,
8,92,23,200,20,0,83,37,235,235,173,49,2,1,2,4,8,16,32,144,73,32,83,80,201,20,0,51,237,1,107,37,64,128,0,1,2,4,8,132,21,72,20,0,51,229,234,176,253,182,48,2,4,8,16,32,64,96,150,64,162,168,146,40,0,206,234,150,113,9,16,32,64,128,0,1,2,189,4,242,4,192,68,169,186,215,22,82,45,1,2,4,8,16,32,240,91,32,79,88,73,19,0,243,144,186,8,8,16,32,64,128,0,129,166,2,105,226,74,154,0,216,116,35,41,155,0,1,2,4,8,16,32,48,92,32,75,0,76,147,168,135,119,200,128,4,8,16,32,64,128,64,26,129,44,129,37,75,0,76,211,120,11,37,64,128,0,1,2,4,8,68,23,72,18,0,179,228,233,232,237,182,62,2,4,8,16,32,64,96,170,64,146,200,146,36,0,78,109,149,193,9,16,32,64,128,0,1,2,173,4,114,4,192,36,105,186,213,206,81,44,1,2,4,8,16,32,112,71,32,71,104,201,17,0,239,240,250,22,1,2,4,8,16,32,64,128,192,123,2,41,2,96,142,44,253,94,3,188,138,0,1,2,4,8,16,40,37,144,34,182,164,8,128,165,182,133,98,8,16,32,64,128,0,1,2,155,5,50,4,192,20,73,122,115,31,77,79,128,0,1,2,4,8,4,17,200,16,92,18,4,192,12,140,65,118,156,101,16,32,64,128,0,1,2,
251,5,18,68,151,4,1,112,127,31,173,128,0,1,2,4,8,16,32,80,73,32,126,0,76,144,162,43,109,8,181,16,32,64,128,0,1,2,87,5,226,135,151,248,1,240,106,15,188,158,0,1,2,4,8,16,32,64,224,155,64,248,0,24,63,67,127,243,244,5,1,2,4,8,16,32,64,32,124,124,9,31,0,237,33,2,4,8,16,32,64,128,0,129,177,2,209,3,96,248,4,61,182,29,70,35,64,128,0,1,2,4,42,8,68,15,48,209,3,96,133,61,160,6,2,4,8,16,32,64,128,64,40,129,224,1,48,122,126,14,213,75,139,33,64,128,0,1,2,4,162,8,4,143,48,193,3,96,148,46,90,7,1,2,4,8,16,32,64,160,142,64,236,0,24,60,61,215,217,6,42,33,64,128,0,1,2,4,198,10,196,14,49,177,3,224,216,78,24,141,0,1,2,4,8,16,32,64,224,67,32,116,0,140,157,157,237,31,2,4,8,16,32,64,128,192,67,129,208,49,38,114,0,12,13,247,176,221,126,64,128,0,1,2,4,8,16,248,16,136,28,100,34,7,64,155,135,0,1,2,4,8,16,32,64,96,130,64,224,0,24,57,55,79,232,132,33,9,16,32,64,128,0,129,90,2,129,163,76,224,0,88,107,15,168,134,0,1,2,4,8,16,32,16,69,32,110,0,12,156,154,163,52,207,58,8,16,32,64,128,0,129,200,2,113,195,76,220,
0,24,185,159,214,70,128,0,1,2,4,8,16,72,44,16,54,0,198,205,204,137,187,109,233,4,8,16,32,64,128,192,74,129,176,113,38,108,0,92,217,29,115,17,32,64,128,0,1,2,4,58,9,68,13,128,97,19,115,167,205,161,86,2,4,8,16,32,64,224,154,64,212,64,19,53,0,94,211,246,106,2,4,8,16,32,64,128,0,129,135,2,65,3,96,212,188,252,208,209,15,8,16,32,64,128,0,1,2,127,11,4,141,52,65,3,224,223,126,190,67,128,0,1,2,4,8,16,32,48,70,32,102,0,12,154,150,199,144,27,133,0,1,2,4,8,16,232,35,16,51,212,196,12,128,125,118,133,74,9,16,32,64,128,0,1,2,203,5,66,6,192,152,89,121,121,111,76,72,128,0,1,2,4,8,228,23,8,25,107,66,6,192,252,189,86,1,1,2,4,8,16,32,64,32,174,64,196,0,24,50,41,199,109,161,149,17,32,64,128,0,1,2,145,5,34,6,155,136,1,48,114,15,173,141,0,1,2,4,8,16,32,144,94,32,96,0,140,152,147,211,247,89,1,4,8,16,32,64,128,192,46,129,128,209,38,96,0,220,213,29,243,18,32,64,128,0,1,2,4,122,8,196,11,128,1,83,114,143,173,160,74,2,4,8,16,32,64,96,142,64,188,112,19,47,0,206,145,55,42,1,2,4,8,16,32,64,128,192,191,2,225,
2,96,188,140,108,175,16,32,64,128,0,1,2,4,46,9,132,139,55,225,2,224,37,94,47,38,64,128,0,1,2,4,8,16,120,41,16,45,0,134,75,200,47,5,61,129,0,1,2,4,8,16,32,240,66,32,90,192,137,22,0,95,240,249,49,1,2,4,8,16,32,64,128,192,85,129,96,1,48,90,62,190,202,235,245,4,8,16,32,64,128,0,129,15,129,96,17,39,88,0,180,69,8,16,32,64,128,0,1,2,4,102,11,196,10,128,193,210,241,108,124,227,19,32,64,128,0,1,2,93,4,98,133,156,88,1,176,203,30,80,39,1,2,4,8,16,32,64,96,163,64,168,0,24,43,27,111,236,138,169,9,16,32,64,128,0,129,106,2,161,98,78,168,0,88,173,211,234,33,64,128,0,1,2,4,8,68,20,136,20,0,67,37,227,136,205,178,38,2,4,8,16,32,64,32,175,64,164,160,19,41,0,230,237,168,149,19,32,64,128,0,1,2,4,18,9,4,10,128,145,114,113,162,14,90,42,1,2,4,8,16,32,144,67,32,80,212,9,20,0,115,244,206,42,9,16,32,64,128,0,1,2,217,5,226,4,192,64,169,56,123,83,173,159,0,1,2,4,8,16,136,40,16,39,236,196,9,128,17,251,100,77,4,8,16,32,64,128,0,129,130,2,97,2,96,156,76,92,176,203,74,34,64,128,0,1,2,4,34,8,132,137,59,97,2,96,
132,174,88,3,1,2,4,8,16,32,64,160,131,64,148,0,24,38,17,119,104,186,26,9,16,32,64,128,0,129,61,2,81,2,79,148,0,184,167,11,102,37,64,128,0,1,2,4,8,52,20,8,18,0,163,228,225,134,59,64,201,4,8,16,32,64,128,192,58,129,32,145,39,72,0,92,231,110,38,2,4,8,16,32,64,128,64,119,129,24,1,48,72,26,238,190,25,212,79,128,0,1,2,4,8,204,22,136,17,122,98,4,192,217,214,198,39,64,128,0,1,2,4,8,16,248,20,8,17,0,99,100,225,79,19,15,8,16,32,64,128,0,1,2,179,4,66,196,158,16,1,112,150,176,113,9,16,32,64,128,0,1,2,4,254,22,136,16,0,67,36,225,191,105,124,135,0,1,2,4,8,16,32,48,94,32,66,240,137,16,0,199,203,26,145,0,1,2,4,8,16,32,64,224,161,128,0,248,144,198,15,8,16,32,64,128,0,1,2,53,5,2,4,192,8,31,132,214,108,174,170,8,16,32,64,128,0,129,128,2,1,162,79,128,0,24,176,49,150,68,128,0,1,2,4,8,16,40,44,176,63,0,6,72,193,133,251,171,52,2,4,8,16,32,64,32,156,192,254,240,179,63,0,134,107,138,5,17,32,64,128,0,1,2,4,106,11,108,15,128,251,51,112,237,6,171,142,0,1,2,4,8,16,8,39,176,61,254,108,15,128,225,90,98,65,
4,8,16,32,64,128,0,129,226,2,187,3,224,246,4,92,188,191,202,35,64,128,0,1,2,4,2,10,236,14,64,187,3,96,192,150,88,18,1,2,4,8,16,32,64,160,182,192,230,0,184,59,255,214,110,174,234,8,16,32,64,128,0,129,160,2,155,35,208,230,0,24,180,41,150,69,128,0,1,2,4,8,16,40,44,176,55,0,110,78,191,133,251,170,52,2,4,8,16,32,64,32,180,192,222,16,180,55,0,134,110,140,197,17,32,64,128,0,1,2,4,106,10,8,128,53,251,170,42,2,4,8,16,32,64,128,192,67,129,173,1,112,239,135,159,15,77,252,128,0,1,2,4,8,16,32,48,91,96,107,12,218,26,0,103,203,26,159,0,1,2,4,8,16,32,64,224,111,129,157,1,112,107,242,253,155,194,119,8,16,32,64,128,0,1,2,235,4,118,6,161,157,1,112,157,176,153,8,16,32,64,128,0,1,2,4,62,5,54,6,192,157,185,247,179,126,15,8,16,32,64,128,0,1,2,123,4,54,70,161,141,1,112,143,181,89,9,16,32,64,128,0,1,2,221,5,246,5,192,141,169,183,123,211,213,79,128,0,1,2,4,8,68,16,216,23,134,246,5,192,8,238,214,64,128,0,1,2,4,8,16,104,40,176,45,0,238,203,188,13,187,172,100,2,4,8,16,32,64,32,162,192,182,56,180,45,0,70,
236,130,53,17,32,64,128,0,1,2,4,58,8,8,128,29,186,172,70,2,4,8,16,32,64,128,192,141,192,174,0,184,237,35,207,155,218,61,36,64,128,0,1,2,4,8,108,21,216,21,136,118,5,192,173,216,38,39,64,128,0,1,2,4,8,116,22,216,20,0,119,229,221,206,173,86,59,1,2,4,8,16,32,16,78,96,83,36,218,20,0,195,241,91,16,1,2,4,8,16,32,64,160,141,192,158,0,184,41,237,182,233,170,66,9,16,32,64,128,0,129,36,2,123,66,209,158,0,152,164,37,150,73,128,0,1,2,4,8,16,168,40,176,37,0,238,201,186,21,219,167,38,2,4,8,16,32,64,32,185,192,150,88,180,37,0,38,111,148,229,19,32,64,128,0,1,2,4,82,11,8,128,169,219,103,241,4,8,16,32,64,128,0,129,243,2,59,2,224,150,143,58,207,211,120,5,1,2,4,8,16,32,64,96,190,192,142,96,180,35,0,206,151,52,3,1,2,4,8,16,32,64,128,192,67,129,13,1,112,71,206,125,88,191,31,16,32,64,128,0,1,2,4,246,10,108,136,70,27,2,224,94,99,179,19,32,64,128,0,1,2,4,186,11,172,15,128,27,82,110,247,38,171,159,0,1,2,4,8,16,136,44,176,62,28,173,15,128,145,253,173,141,0,1,2,4,8,16,32,208,64,64,0,108,208,100,37,18,32,
64,128,0,1,2,4,110,5,150,7,192,245,31,114,222,150,235,49,1,2,4,8,16,32,64,32,156,192,242,120,180,60,0,134,35,183,32,2,4,8,16,32,64,128,64,51,129,213,1,112,121,194,109,214,79,229,18,32,64,128,0,1,2,9,5,86,7,164,213,1,48,97,75,44,153,0,1,2,4,8,16,32,80,75,96,113,0,92,157,111,107,53,75,53,4,8,16,32,64,128,64,81,129,197,17,105,113,0,44,218,52,101,17,32,64,128,0,1,2,4,18,9,8,128,137,154,101,169,4,8,16,32,64,128,0,129,17,2,107,3,224,226,143,55,71,0,25,131,0,1,2,4,8,16,32,48,95,96,109,72,90,27,0,231,235,153,129,0,1,2,4,8,16,32,64,224,133,192,210,0,184,54,219,190,168,220,143,9,16,32,64,128,0,1,2,113,4,150,198,164,165,1,48,142,177,149,16,32,64,128,0,1,2,4,250,10,172,12,128,75,147,109,223,150,170,156,0,1,2,4,8,16,200,40,176,50,40,173,12,128,25,123,97,205,4,8,16,32,64,128,0,129,114,2,2,96,185,150,42,136,0,1,2,4,8,16,32,240,92,96,97,0,92,249,193,230,243,162,253,148,0,1,2,4,8,16,32,16,78,96,97,84,90,24,0,195,49,91,16,1,2,4,8,16,32,64,160,165,192,186,0,184,48,213,182,236,164,162,9,16,32,64,
128,0,129,228,2,235,194,210,186,0,152,188,37,150,79,128,0,1,2,4,8,16,168,34,32,0,86,233,164,58,8,16,32,64,128,0,1,2,7,5,150,5,192,117,31,106,30,172,220,211,8,16,32,64,128,0,1,2,177,4,150,197,165,101,1,48,150,175,213,16,32,64,128,0,1,2,4,250,10,172,10,128,203,18,109,223,86,170,156,0,1,2,4,8,16,200,46,176,42,48,173,10,128,217,251,97,253,4,8,16,32,64,128,0,129,50,2,2,96,153,86,42,132,0,1,2,4,8,16,32,112,76,96,81,0,92,245,129,230,177,162,61,139,0,1,2,4,8,16,32,16,82,96,81,100,90,20,0,67,18,91,20,1,2,4,8,16,32,64,160,165,192,154,0,184,40,205,182,236,160,162,9,16,32,64,128,0,129,66,2,107,66,211,154,0,88,168,45,74,33,64,128,0,1,2,4,8,100,23,16,0,179,119,208,250,9,16,32,64,128,0,1,2,39,5,150,4,192,53,31,102,158,172,220,211,9,16,32,64,128,0,1,2,241,4,150,196,166,37,1,48,158,173,21,17,32,64,128,0,1,2,4,250,10,172,8,128,75,146,108,223,22,170,156,0,1,2,4,8,16,168,36,176,34,56,173,8,128,149,122,162,22,2,4,8,16,32,64,128,64,122,1,1,48,125,11,21,64,128,0,1,2,4,8,16,56,39,176,32,0,174,248,32,
243,92,209,158,77,128,0,1,2,4,8,16,8,43,176,32,58,45,8,128,97,121,45,140,0,1,2,4,8,16,32,208,82,96,126,0,92,144,98,91,118,78,209,4,8,16,32,64,128,64,81,129,249,225,105,126,0,44,218,26,101,17,32,64,128,0,1,2,4,178,10,8,128,89,59,103,221,4,8,16,32,64,128,0,129,55,5,166,7,192,249,31,98,190,89,185,151,17,32,64,128,0,1,2,4,98,10,76,143,79,211,3,96,76,87,171,34,64,128,0,1,2,4,8,244,21,152,29,0,167,39,216,190,173,83,57,1,2,4,8,16,32,80,85,96,118,128,154,29,0,171,246,69,93,4,8,16,32,64,128,0,129,180,2,2,96,218,214,89,56,1,2,4,8,16,32,64,224,61,129,201,1,112,246,7,152,239,21,237,85,4,8,16,32,64,128,0,129,208,2,147,35,212,228,0,24,154,214,226,8,16,32,64,128,0,1,2,45,5,230,6,192,201,233,181,101,199,20,77,128,0,1,2,4,8,52,16,152,27,162,230,6,192,6,237,81,34,1,2,4,8,16,32,64,32,155,128,0,152,173,99,214,75,128,0,1,2,4,8,16,184,40,48,53,0,206,253,240,242,98,229,94,78,128,0,1,2,4,8,16,136,43,48,53,70,77,13,128,113,77,173,140,0,1,2,4,8,16,32,208,87,64,0,236,219,123,149,19,32,64,128,0,1,2,77,5,
102,6,192,169,31,93,54,237,151,178,9,16,32,64,128,0,129,38,2,51,131,212,204,0,216,164,61,202,36,64,128,0,1,2,4,8,228,18,152,24,0,103,230,214,92,200,86,75,128,0,1,2,4,8,16,56,45,48,49,74,77,12,128,167,203,244,2,2,4,8,16,32,64,128,0,129,5,2,2,224,2,100,83,16,32,64,128,0,1,2,4,34,9,204,11,128,19,63,182,140,4,104,45,4,8,16,32,64,128,0,129,57,2,243,194,212,188,0,56,71,194,168,4,8,16,32,64,128,0,1,2,23,5,4,192,139,128,94,78,128,0,1,2,4,8,16,200,38,48,45,0,206,251,208,50,27,177,245,18,32,64,128,0,1,2,4,222,18,152,22,167,166,5,192,183,202,244,34,2,4,8,16,32,64,128,0,129,233,2,179,2,224,180,196,58,93,196,4,4,8,16,32,64,128,0,129,32,2,179,2,213,172,0,24,132,205,50,8,16,32,64,128,0,1,2,4,254,20,16,0,255,20,241,53,1,2,4,8,16,32,64,160,184,192,164,0,56,235,3,203,226,221,80,30,1,2,4,8,16,32,64,224,86,96,82,164,154,20,0,111,87,238,49,1,2,4,8,16,32,64,128,64,36,1,1,48,82,55,172,133,0,1,2,4,8,16,32,176,64,96,78,0,156,244,113,229,2,15,83,16,32,64,128,0,1,2,4,2,9,204,9,85,115,2,96,32,54,75,33,64,
128,0,1,2,4,8,16,248,46,32,0,126,247,240,21,1,2,4,8,16,32,64,160,188,192,148,0,56,231,195,202,242,189,80,32,1,2,4,8,16,32,64,224,79,129,41,177,106,74,0,252,115,229,190,38,64,128,0,1,2,4,8,16,136,35,32,0,198,233,133,149,16,32,64,128,0,1,2,4,150,8,204,8,128,83,62,170,92,162,97,18,2,4,8,16,32,64,128,64,48,129,25,193,106,70,0,12,198,102,57,4,8,16,32,64,128,0,1,2,183,2,19,2,224,140,156,122,187,100,143,9,16,32,64,128,0,1,2,141,4,38,68,171,9,1,176,81,67,148,74,128,0,1,2,4,8,16,72,40,32,0,38,108,154,37,19,32,64,128,0,1,2,4,174,8,140,15,128,19,62,166,188,82,160,215,18,32,64,128,0,1,2,4,114,11,140,15,87,227,3,96,110,97,171,39,64,128,0,1,2,4,8,148,23,16,0,203,183,88,129,4,8,16,32,64,128,0,129,239,2,195,3,224,248,15,41,191,47,216,87,4,8,16,32,64,128,0,129,102,2,195,227,213,240,0,216,172,33,202,37,64,128,0,1,2,4,8,164,19,16,0,211,181,204,130,9,16,32,64,128,0,1,2,215,4,70,7,192,225,31,81,94,43,207,171,9,16,32,64,128,0,1,2,249,5,70,7,172,209,1,48,191,176,10,8,16,32,64,128,0,1,2,197,5,4,192,
226,13,86,30,1,2,4,8,16,32,64,224,79,129,193,1,112,244,7,148,127,46,215,215,4,8,16,32,64,128,0,129,134,2,131,35,214,224,0,216,176,33,74,38,64,128,0,1,2,4,8,36,19,16,0,147,53,204,114,9,16,32,64,128,0,1,2,87,5,198,6,192,193,31,79,94,45,206,235,9,16,32,64,128,0,1,2,53,4,198,134,172,177,1,176,134,176,42,8,16,32,64,128,0,1,2,165,5,4,192,210,237,85,28,1,2,4,8,16,32,64,224,111,129,161,1,112,236,135,147,127,47,214,119,8,16,32,64,128,0,1,2,77,5,134,198,172,161,1,176,105,67,148,77,128,0,1,2,4,8,16,72,37,32,0,166,106,151,197,18,32,64,128,0,1,2,4,174,11,140,12,128,67,63,154,188,94,154,17,8,16,32,64,128,0,1,2,117,4,70,6,173,145,1,176,142,176,74,8,16,32,64,128,0,1,2,133,5,4,192,194,205,85,26,1,2,4,8,16,32,64,224,158,192,192,0,56,242,131,201,123,75,245,61,2,4,8,16,32,64,128,64,99,129,129,81,107,96,0,108,220,16,165,19,32,64,128,0,1,2,4,18,9,8,128,137,154,101,169,4,8,16,32,64,128,0,129,17,2,227,2,224,192,143,37,71,20,102,12,2,4,8,16,32,64,128,64,45,129,113,97,107,92,0,172,37,172,26,2,4,8,16,32,
64,128,64,89,1,1,176,108,107,21,70,128,0,1,2,4,8,16,184,47,48,44,0,142,251,80,242,254,66,125,151,0,1,2,4,8,16,32,208,92,96,88,220,26,22,0,155,55,68,249,4,8,16,32,64,128,0,129,52,2,2,96,154,86,89,40,1,2,4,8,16,32,64,96,140,192,168,0,56,236,35,201,49,101,25,133,0,1,2,4,8,16,32,80,79,96,84,224,26,21,0,235,9,171,136,0,1,2,4,8,16,32,80,84,64,0,44,218,88,101,17,32,64,128,0,1,2,4,30,9,12,10,128,163,62,144,124,180,76,223,39,64,128,0,1,2,4,8,16,248,49,40,114,13,10,128,26,66,128,0,1,2,4,8,16,32,144,69,64,0,204,210,41,235,36,64,128,0,1,2,4,8,12,18,24,19,0,7,125,28,57,168,38,195,16,32,64,128,0,1,2,4,138,10,140,9,93,99,2,96,81,98,101,17,32,64,128,0,1,2,4,42,10,8,128,21,187,170,38,2,4,8,16,32,64,128,192,19,129,33,1,112,204,135,145,79,86,233,71,4,8,16,32,64,128,0,1,2,63,5,134,196,174,33,1,80,63,8,16,32,64,128,0,1,2,4,242,8,8,128,121,122,101,165,4,8,16,32,64,128,0,129,33,2,35,2,224,144,143,34,135,84,99,16,2,4,8,16,32,64,128,64,113,129,17,193,107,68,0,44,206,172,60,2,4,8,16,32,64,128,64,45,1,
1,176,86,63,85,67,128,0,1,2,4,8,16,120,41,32,0,190,36,242,4,2,4,8,16,32,64,128,64,45,129,1,1,112,196,111,162,107,161,170,134,0,1,2,4,8,16,32,48,77,96,64,244,26,16,0,167,149,103,96,2,4,8,16,32,64,128,0,129,9,2,2,224,4,84,67,18,32,64,128,0,1,2,4,34,11,92,15,128,3,62,134,140,12,100,109,4,8,16,32,64,128,0,129,88,2,215,195,215,245,0,24,75,196,106,8,16,32,64,128,0,1,2,4,94,8,8,128,47,128,252,152,0,1,2,4,8,16,32,80,77,224,114,0,188,254,33,100,53,82,245,16,32,64,128,0,1,2,4,166,10,92,142,95,151,3,224,212,242,12,78,128,0,1,2,4,8,16,32,48,92,64,0,28,78,106,64,2,4,8,16,32,64,128,64,108,129,171,1,240,242,71,144,177,121,172,142,0,1,2,4,8,16,32,16,79,224,106,0,187,26,0,227,137,88,17,1,2,4,8,16,32,64,128,192,83,1,1,240,41,143,31,18,32,64,128,0,1,2,4,234,9,8,128,245,122,170,34,2,4,8,16,32,64,128,192,83,129,139,1,240,234,111,160,159,174,205,15,9,16,32,64,128,0,1,2,4,238,9,92,140,96,23,3,224,189,21,249,30,1,2,4,8,16,32,64,128,64,100,1,1,48,114,119,172,141,0,1,2,4,8,16,32,48,65,224,90,0,188,248,
241,227,132,122,12,73,128,0,1,2,4,8,16,104,32,112,45,132,93,11,128,13,120,149,72,128,0,1,2,4,8,16,168,38,32,0,86,235,168,122,8,16,32,64,128,0,1,2,47,4,4,192,23,64,126,76,128,0,1,2,4,8,16,168,38,112,41,0,94,251,237,115,53,74,245,16,32,64,128,0,1,2,4,150,9,92,138,97,151,2,224,178,18,77,68,128,0,1,2,4,8,16,32,48,76,64,0,28,70,105,32,2,4,8,16,32,64,128,64,14,129,43,1,240,210,71,143,57,120,172,146,0,1,2,4,8,16,32,16,83,224,74,16,187,18,0,99,106,88,21,1,2,4,8,16,32,64,128,192,83,1,1,240,41,143,31,18,32,64,128,0,1,2,4,234,9,92,8,128,87,62,120,172,7,169,34,2,4,8,16,32,64,128,192,82,129,11,81,236,66,0,92,90,162,201,8,16,32,64,128,0,1,2,4,6,9,8,128,131,32,13,67,128,0,1,2,4,8,16,200,34,32,0,102,233,148,117,18,32,64,128,0,1,2,4,6,9,188,31,0,47,252,222,121,208,218,13,67,128,0,1,2,4,8,16,104,44,240,126,24,123,63,0,54,230,86,58,1,2,4,8,16,32,64,32,179,128,0,152,185,123,214,78,128,0,1,2,4,8,16,120,67,64,0,124,3,205,75,8,16,32,64,128,0,1,2,153,5,222,14,128,239,255,214,57,51,151,181,19,32,64,128,
0,1,2,4,194,8,188,29,199,222,14,128,97,74,183,16,2,4,8,16,32,64,128,0,129,83,2,2,224,41,46,79,38,64,128,0,1,2,4,8,228,23,120,55,0,190,253,145,99,126,50,21,16,32,64,128,0,1,2,4,98,8,188,27,200,222,13,128,49,170,182,10,2,4,8,16,32,64,128,0,129,211,2,2,224,105,50,47,32,64,128,0,1,2,4,8,228,22,16,0,115,247,207,234,9,16,32,64,128,0,1,2,167,5,222,12,128,239,254,198,249,244,250,188,128,0,1,2,4,8,16,32,64,224,145,192,155,145,236,205,0,248,104,21,190,79,128,0,1,2,4,8,16,32,16,93,64,0,140,222,33,235,35,64,128,0,1,2,4,8,12,22,120,47,0,190,249,113,227,224,181,27,142,0,1,2,4,8,16,32,208,92,224,189,80,246,94,0,108,78,173,124,2,4,8,16,32,64,128,64,102,1,1,48,115,247,172,157,0,1,2,4,8,16,32,240,134,128,0,248,6,154,151,16,32,64,128,0,1,2,4,50,11,188,21,0,223,251,109,115,102,38,107,39,64,128,0,1,2,4,8,132,20,120,43,150,189,21,0,67,150,111,81,4,8,16,32,64,128,0,1,2,135,4,4,192,67,76,158,68,128,0,1,2,4,8,16,168,35,32,0,214,233,165,74,8,16,32,64,128,0,1,2,135,4,222,9,128,111,253,174,249,208,106,60,
137,0,1,2,4,8,16,32,64,224,148,192,59,193,236,157,0,120,106,81,158,76,128,0,1,2,4,8,16,32,16,75,64,0,140,213,15,171,33,64,128,0,1,2,4,8,76,23,16,0,167,19,155,128,0,1,2,4,8,16,32,16,75,224,141,0,248,206,111,154,99,21,109,53,4,8,16,32,64,128,0,129,50,2,111,68,179,55,2,96,25,46,133,16,32,64,128,0,1,2,4,90,10,8,128,45,219,174,104,2,4,8,16,32,64,160,179,128,0,216,185,251,106,39,64,128,0,1,2,4,90,10,156,15,128,111,252,158,185,165,172,162,9,16,32,64,128,0,1,2,75,4,206,135,179,243,1,112,73,33,38,33,64,128,0,1,2,4,8,16,152,37,32,0,206,146,53,46,1,2,4,8,16,32,64,32,168,128,0,24,180,49,150,69,128,0,1,2,4,8,16,152,37,112,58,0,158,255,45,243,172,165,27,151,0,1,2,4,8,16,32,64,224,67,224,116,60,59,29,0,49,19,32,64,128,0,1,2,4,8,228,22,16,0,115,247,207,234,9,16,32,64,128,0,1,2,167,5,4,192,211,100,94,64,128,0,1,2,4,8,16,200,45,112,54,0,158,254,29,115,110,30,171,39,64,128,0,1,2,4,8,196,23,56,27,208,206,6,192,248,2,86,72,128,0,1,2,4,8,16,32,240,84,64,0,124,202,227,135,4,8,16,32,64,128,0,129,122,
2,2,96,189,158,170,136,0,1,2,4,8,16,32,240,84,224,100,0,60,251,27,230,167,115,251,33,1,2,4,8,16,32,64,128,192,8,129,147,17,237,100,0,28,177,66,99,16,32,64,128,0,1,2,4,8,236,20,16,0,119,234,155,155,0,1,2,4,8,16,32,176,65,64,0,220,128,110,74,2,4,8,16,32,64,128,192,78,129,115,1,240,228,239,151,119,22,102,110,2,4,8,16,32,64,128,64,31,129,115,33,237,92,0,236,163,168,82,2,4,8,16,32,64,128,64,89,1,1,176,108,107,21,70,128,0,1,2,4,8,16,184,47,32,0,222,119,241,93,2,4,8,16,32,64,128,64,89,129,83,1,240,220,111,151,203,154,41,140,0,1,2,4,8,16,32,16,77,224,84,76,59,21,0,163,85,106,61,4,8,16,32,64,128,0,1,2,231,5,4,192,243,102,94,65,128,0,1,2,4,8,16,72,45,32,0,166,110,159,197,19,32,64,128,0,1,2,4,206,11,156,9,128,167,126,183,124,126,41,94,65,128,0,1,2,4,8,16,32,240,174,192,153,160,118,38,0,190,187,30,175,35,64,128,0,1,2,4,8,16,8,36,32,0,6,106,134,165,16,32,64,128,0,1,2,4,86,8,8,128,43,148,205,65,128,0,1,2,4,8,16,8,36,112,34,0,158,249,205,114,160,10,45,133,0,1,2,4,8,16,32,208,65,224,68,84,59,
17,0,59,200,169,145,0,1,2,4,8,16,32,80,95,64,0,172,223,99,21,18,32,64,128,0,1,2,4,190,9,8,128,223,56,124,65,128,0,1,2,4,8,16,168,47,32,0,214,239,177,10,9,16,32,64,128,0,1,2,223,4,142,7,192,19,127,88,248,109,6,95,16,32,64,128,0,1,2,4,8,44,16,56,30,214,142,7,192,5,203,54,5,1,2,4,8,16,32,64,128,192,124,1,1,112,190,177,25,8,16,32,64,128,0,1,2,161,4,4,192,80,237,176,24,2,4,8,16,32,64,128,192,124,129,195,1,240,248,111,149,231,47,218,12,4,8,16,32,64,128,0,1,2,127,9,28,142,107,135,3,224,95,83,248,6,1,2,4,8,16,32,64,128,64,74,1,1,48,101,219,44,154,0,1,2,4,8,16,32,240,190,128,0,248,190,157,87,18,32,64,128,0,1,2,4,82,10,8,128,41,219,102,209,4,8,16,32,64,128,0,129,247,5,142,6,192,195,127,84,248,254,82,188,146,0,1,2,4,8,16,32,64,224,138,192,209,192,118,52,0,94,89,139,215,18,32,64,128,0,1,2,4,8,4,18,16,0,3,53,195,82,8,16,32,64,128,0,1,2,43,4,4,192,21,202,230,32,64,128,0,1,2,4,8,4,18,56,24,0,143,254,70,57,80,101,150,66,128,0,1,2,4,8,16,232,38,112,48,178,29,12,128,221,244,212,75,128,0,1,2,4,
8,16,168,43,32,0,214,237,173,202,8,16,32,64,128,0,1,2,119,5,4,192,187,44,190,73,128,0,1,2,4,8,16,168,43,32,0,214,237,173,202,8,16,32,64,128,0,1,2,119,5,142,5,192,131,127,80,120,119,6,223,36,64,128,0,1,2,4,8,16,88,36,112,44,180,29,11,128,139,150,108,26,2,4,8,16,32,64,128,0,129,249,2,2,224,124,99,51,16,32,64,128,0,1,2,4,66,9,8,128,161,218,97,49,4,8,16,32,64,128,0,129,249,2,135,2,224,177,223,38,207,95,172,25,8,16,32,64,128,0,1,2,4,158,10,28,138,109,135,2,224,211,105,252,144,0,1,2,4,8,16,32,64,32,149,128,0,152,170,93,22,75,128,0,1,2,4,8,16,184,46,32,0,94,55,52,2,1,2,4,8,16,32,64,32,149,128,0,152,170,93,22,75,128,0,1,2,4,8,16,184,46,112,36,0,30,250,99,194,235,75,49,2,1,2,4,8,16,32,64,128,192,85,129,35,193,237,72,0,188,186,14,175,39,64,128,0,1,2,4,8,16,8,36,32,0,6,106,134,165,16,32,64,128,0,1,2,4,86,8,8,128,43,148,205,65,128,0,1,2,4,8,16,8,36,32,0,6,106,134,165,16,32,64,128,0,1,2,4,86,8,28,8,128,71,254,148,112,197,82,205,65,128,0,1,2,4,8,16,32,240,82,224,64,116,59,16,0,95,78,227,9,
4,8,16,32,64,128,0,1,2,137,4,4,192,68,205,178,84,2,4,8,16,32,64,128,192,8,1,1,112,132,162,49,8,16,32,64,128,0,1,2,137,4,4,192,68,205,178,84,2,4,8,16,32,64,128,192,8,129,215,1,240,192,31,18,142,88,136,49,8,16,32,64,128,0,1,2,4,70,8,188,14,111,175,3,224,136,117,24,131,0,1,2,4,8,16,32,64,32,140,128,0,24,166,21,22,66,128,0,1,2,4,8,16,88,35,32,0,174,113,54,11,1,2,4,8,16,32,64,32,140,128,0,24,166,21,22,66,128,0,1,2,4,8,16,88,35,240,50,0,190,254,51,194,53,11,53,11,1,2,4,8,16,32,64,128,192,33,129,151,241,237,101,0,60,52,141,39,17,32,64,128,0,1,2,4,8,164,17,16,0,211,180,202,66,9,16,32,64,128,0,1,2,99,4,4,192,49,142,70,33,64,128,0,1,2,4,8,164,17,16,0,211,180,202,66,9,16,32,64,128,0,1,2,99,4,94,5,192,151,127,68,56,102,25,70,33,64,128,0,1,2,4,8,16,24,37,240,42,192,189,10,128,163,214,97,28,2,4,8,16,32,64,128,0,129,32,2,2,96,144,70,88,6,1,2,4,8,16,32,64,96,149,128,0,184,74,218,60,4,8,16,32,64,128,0,129,32,2,2,96,144,70,88,6,1,2,4,8,16,32,64,96,149,128,0,184,74,218,60,4,8,16,32,64,128,0,129,
32,2,47,2,224,171,127,67,18,164,10,203,32,64,128,0,1,2,4,8,16,248,18,120,17,225,94,4,192,175,113,60,34,64,128,0,1,2,4,8,16,168,33,32,0,214,232,163,42,8,16,32,64,128,0,1,2,135,5,4,192,195,84,158,72,128,0,1,2,4,8,16,168,33,32,0,214,232,163,42,8,16,32,64,128,0,1,2,135,5,158,7,192,23,127,64,120,120,22,79,36,64,128,0,1,2,4,8,16,88,40,240,60,196,61,15,128,11,151,105,42,2,4,8,16,32,64,128,0,129,53,2,2,224,26,103,179,16,32,64,128,0,1,2,4,194,8,8,128,97,90,97,33,4,8,16,32,64,128,0,129,53,2,2,224,26,103,179,16,32,64,128,0,1,2,4,194,8,8,128,97,90,97,33,4,8,16,32,64,128,0,129,53,2,79,3,224,243,127,63,178,102,129,102,33,64,128,0,1,2,4,8,16,56,45,240,52,198,61,13,128,167,167,242,2,2,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,207,2,224,211,127,61,18,190,50,11,36,64,128,0,1,2,4,8,52,22,120,22,228,158,5,192,198,100,74,39,64,128,
0,1,2,4,8,212,21,16,0,235,246,86,101,4,8,16,32,64,128,0,129,187,2,2,224,93,22,223,36,64,128,0,1,2,4,8,212,21,16,0,235,246,86,101,4,8,16,32,64,128,0,129,187,2,2,224,93,22,223,36,64,128,0,1,2,4,8,212,21,120,18,0,159,253,219,145,186,32,42,35,64,128,0,1,2,4,8,148,16,120,18,229,158,4,192,18,165,43,130,0,1,2,4,8,16,32,64,224,15,1,1,240,15,16,95,18,32,64,128,0,1,2,4,170,11,8,128,213,59,172,62,2,4,8,16,32,64,128,192,31,2,2,224,31,32,190,36,64,128,0,1,2,4,8,84,23,16,0,171,119,88,125,4,8,16,32,64,128,0,129,63,4,30,7,192,39,255,114,228,143,49,124,73,128,0,1,2,4,8,16,32,16,78,224,113,152,123,28,0,195,21,97,65,4,8,16,32,64,128,0,1,2,35,4,4,192,17,138,198,32,64,128,0,1,2,4,8,36,18,16,0,19,53,203,82,9,16,32,64,128,0,1,2,35,4,4,192,17,138,198,32,64,128,0,1,2,4,8,36,18,16,0,19,53,203,82,9,16,32,64,128,0,1,2,35,4,30,6,192,199,255,110,100,196,180,198,32,64,128,0,1,2,4,8,16,152,44,240,48,206,61,12,128,147,23,100,120,2,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,8,128,
187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,128,0,184,75,222,188,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,60,10,128,15,255,217,240,174,133,154,151,0,1,2,4,8,16,32,64,224,156,192,163,64,247,40,0,158,27,221,179,9,16,32,64,128,0,1,2,4,210,8,8,128,105,90,101,161,4,8,16,32,64,128,0,129,49,2,2,224,24,71,163,16,32,64,128,0,1,2,4,210,8,8,128,105,90,101,161,4,8,16,32,64,128,0,129,49,2,2,224,24,71,163,16,32,64,128,0,1,2,4,210,8,60,8,128,143,254,205,72,154,186,44,148,0,1,2,4,8,16,32,64,224,65,164,123,16,0,121,17,32,64,128,0,1,2,4,8,84,21,16,0,171,118,86,93,4,8,16,32,64,128,0,129,7,2,2,224,3,24,223,38,64,128,0,1,2,4,8,84,21,16,0,171,118,86,93,4,8,16,32,64,128,0,129,7,2,2,224,3,24,223,38,64,128,0,1,2,4,8,84,21,16,0,171,118,86,93,4,8,16,32,64,128,0,129,7,2,247,3,224,131,127,50,252,96,12,223,38,64,128,0,1,2,4,8,16,8,41,112,63,212,221,15,128,33,11,176,40,2,4,8,16,32,64,128,0,129,17,2,2,224,8,69,99,16,32,64,128,0,1,2,4,18,9,
8,128,137,154,101,169,4,8,16,32,64,128,0,129,17,2,2,224,8,69,99,16,32,64,128,0,1,2,4,18,9,8,128,137,154,101,169,4,8,16,32,64,128,0,129,17,2,2,224,8,69,99,16,32,64,128,0,1,2,4,18,9,8,128,137,154,101,169,4,8,16,32,64,128,0,129,17,2,119,3,224,253,255,98,204,136,233,140,65,128,0,1,2,4,8,16,32,176,80,224,110,172,187,27,0,23,46,202,84,4,8,16,32,64,128,0,1,2,139,5,4,192,197,224,166,35,64,128,0,1,2,4,8,236,22,16,0,119,119,192,252,4,8,16,32,64,128,0,129,197,2,2,224,98,112,211,17,32,64,128,0,1,2,4,118,11,8,128,187,59,96,126,2,4,8,16,32,64,128,192,98,1,1,112,49,184,233,8,16,32,64,128,0,1,2,187,5,238,5,192,187,255,92,120,247,66,205,79,128,0,1,2,4,8,16,32,112,94,224,94,176,187,23,0,207,143,236,21,4,8,16,32,64,128,0,1,2,105,4,4,192,52,173,178,80,2,4,8,16,32,64,128,192,24,1,1,112,140,163,81,8,16,32,64,128,0,1,2,105,4,4,192,52,173,178,80,2,4,8,16,32,64,128,192,24,1,1,112,140,163,81,8,16,32,64,128,0,1,2,105,4,4,192,52,173,178,80,2,4,8,16,32,64,128,192,24,1,1,112,140,163,81,8,16,32,64,128,0,1,
2,105,4,4,192,52,173,178,80,2,4,8,16,32,64,128,192,24,129,59,1,240,222,127,46,112,204,100,70,33,64,128,0,1,2,4,8,16,88,44,112,39,218,221,9,128,139,23,101,58,2,4,8,16,32,64,128,0,129,165,2,2,224,82,110,147,17,32,64,128,0,1,2,4,246,11,8,128,251,123,96,5,4,8,16,32,64,128,0,129,165,2,2,224,82,110,147,17,32,64,128,0,1,2,4,246,11,8,128,251,123,96,5,4,8,16,32,64,128,0,129,165,2,2,224,82,110,147,17,32,64,128,0,1,2,4,246,11,8,128,251,123,96,5,4,8,16,32,64,128,0,129,165,2,127,7,192,59,255,173,152,165,43,50,25,1,2,4,8,16,32,64,128,192,64,129,191,195,221,223,1,112,224,116,134,34,64,128,0,1,2,4,8,16,136,39,32,0,198,235,137,21,17,32,64,128,0,1,2,4,166,10,8,128,83,121,13,78,128,0,1,2,4,8,16,136,39,32,0,198,235,137,21,17,32,64,128,0,1,2,4,166,10,8,128,83,121,13,78,128,0,1,2,4,8,16,136,39,32,0,198,235,137,21,17,32,64,128,0,1,2,4,166,10,8,128,83,121,13,78,128,0,1,2,4,8,16,136,39,32,0,198,235,137,21,17,32,64,128,0,1,2,4,166,10,252,21,0,255,254,79,5,78,157,223,224,4,8,16,32,64,128,0,1,2,115,5,254,
138,119,127,5,192,185,243,27,157,0,1,2,4,8,16,32,64,96,183,128,0,184,187,3,230,39,64,128,0,1,2,4,8,44,22,16,0,23,131,155,142,0,1,2,4,8,16,32,176,91,64,0,220,221,1,243,19,32,64,128,0,1,2,4,22,11,8,128,139,193,77,71,128,0,1,2,4,8,16,216,45,32,0,238,238,128,249,9,16,32,64,128,0,1,2,139,5,4,192,197,224,166,35,64,128,0,1,2,4,8,236,22,16,0,119,119,192,252,4,8,16,32,64,128,0,129,197,2,2,224,98,112,211,17,32,64,128,0,1,2,4,118,11,252,25,0,255,250,47,69,239,94,160,249,9,16,32,64,128,0,1,2,4,174,9,252,25,240,254,12,128,215,70,247,106,2,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,128,0,56,214,211,104,4,8,16,32,64,128,0,129,240,2,2,96,248,22,89,32,1,2,4,8,16,32,64,96,172,192,31,1,240,207,255,
161,144,177,147,25,141,0,1,2,4,8,16,32,64,96,131,192,31,17,239,143,0,184,97,65,166,36,64,128,0,1,2,4,8,16,88,42,32,0,46,229,54,25,1,2,4,8,16,32,64,96,191,128,0,184,191,7,86,64,128,0,1,2,4,8,16,88,42,32,0,46,229,54,25,1,2,4,8,16,32,64,96,191,128,0,184,191,7,86,64,128,0,1,2,4,8,16,88,42,32,0,46,229,54,25,1,2,4,8,16,32,64,96,191,128,0,184,191,7,86,64,128,0,1,2,4,8,16,88,42,32,0,46,229,54,25,1,2,4,8,16,32,64,96,191,128,0,184,191,7,86,64,128,0,1,2,4,8,16,88,42,32,0,46,229,54,25,1,2,4,8,16,32,64,96,191,192,247,0,248,199,255,76,200,254,229,89,1,1,2,4,8,16,32,64,128,192,117,129,239,33,239,123,0,188,62,186,17,8,16,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,2,224,104,81,227,17,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,2,224,104,81,227,17,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,2,224,104,81,227,17,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,2,224,104,81,227,
17,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,2,224,104,81,227,17,32,64,128,0,1,2,4,130,11,8,128,193,27,100,121,4,8,16,32,64,128,0,129,209,2,223,2,224,247,255,153,224,209,83,25,143,0,1,2,4,8,16,32,64,96,147,192,183,152,247,45,0,110,90,144,105,9,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,8,128,11,177,77,69,128,0,1,2,4,8,16,136,32,32,0,70,232,130,53,16,32,64,128,0,1,2,4,22,10,220,6,192,127,22,206,107,42,2,4,8,16,32,64,128,0,129,133,2,183,
65,239,54,0,46,92,130,169,8,16,32,64,128,0,1,2,4,118,9,8,128,187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,128,0,184,75,222,188,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,8,128,187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,128,0,184,75,222,188,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,8,128,187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,128,0,184,75,222,188,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,8,128,187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,128,0,184,75,222,188,4,8,16,32,64,128,0,129,77,2,2,224,38,120,211,18,32,64,128,0,1,2,4,118,9,8,128,187,228,205,75,128,0,1,2,4,8,16,216,36,32,0,110,130,55,45,1,2,4,8,16,32,64,96,151,192,77,0,252,103,215,26,204,75,128,0,1,2,4,8,16,32,48,91,224,38,234,221,4,192,217,179,26,159,0,1,2,4,8,16,32,64,32,130,128,
0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,
0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,128,0,24,161,11,214,64,128,0,1,2,4,8,16,88,40,32,0,46,196,54,21,1,2,4,8,16,32,64,32,130,192,87,0,252,39,194,114,172,129,0,1,2,4,8,16,32,64,96,142,192,87,216,251,10,128,115,102,50,42,1,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,
0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,108,124,2,4,8,16,32,64,128,64,48,1,1,48,88,67,44,135,0,1,2,4,8,16,32,48,91,64,0,156,45,
108,124,2,4,8,16,32,64,128,64,48,129,127,190,214,115,243,240,235,155,30,17,32,64,128,0,1,2,4,8,148,16,248,223,103,21,62,1,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,
0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,4,192,30,125,86,37,1,2,4,8,16,32,64,224,83,64,0,252,164,240,128,0,1,2,4,8,16,32,208,67,64,0,236,209,103,85,18,32,64,128,0,1,2,4,62,5,4,192,79,10,15,8,16,32,64,128,0,1,2,61,4,254,185,41,243,246,241,205,183,61,36,64,128,0,1,2,4,8,16,72,47,240,191,175,10,124,2,248,101,225,17,1,2,4,8,16,32,64,160,133,128,0,216,162,205,138,36,64,128,0,1,2,4,8,124,9,8,128,95,22,30,17,32,64,128,0,1,2,4,90,8,8,128,45,218,172,72,2,4,8,16,32,64,128,192,151,128,0,248,101,225,17,1,2,4,8,16,32,64,160,133,128,0,216,162,205,138,36,64,128,0,
1,2,4,8,124,9,8,128,95,22,30,17,32,64,128,0,1,2,4,90,8,8,128,45,218,172,72,2,4,8,16,32,64,128,192,151,128,0,248,101,225,17,1,2,4,8,16,32,64,160,133,128,0,216,162,205,138,36,64,128,0,1,2,4,8,124,9,8,128,95,22,30,17,32,64,128,0,1,2,4,90,8,8,128,45,218,172,72,2,4,8,16,32,64,128,192,151,128,0,248,101,225,17,1,2,4,8,16,32,64,160,133,128,0,216,162,205,138,36,64,128,0,1,2,4,8,124,9,8,128,95,22,30,17,32,64,128,0,1,2,4,90,8,8,128,45,218,172,72,2,4,8,16,32,64,128,192,151,128,0,248,101,225,17,1,2,4,8,16,32,64,160,133,128,0,216,162,205,138,36,64,128,0,1,2,4,8,124,9,8,128,95,22,30,17,32,64,128,0,1,2,4,90,8,252,115,91,229,183,47,110,127,224,49,1,2,4,8,16,32,64,128,64,106,129,255,221,172,222,39,128,55,24,30,18,32,64,128,0,1,2,4,58,8,8,128,29,186,172,70,2,4,8,16,32,64,128,192,141,128,0,120,131,225,33,1,2,4,8,16,32,64,160,131,128,0,216,161,203,106,36,64,128,0,1,2,4,8,220,8,8,128,55,24,30,18,32,64,128,0,1,2,4,58,8,8,128,29,186,172,70,2,4,8,16,32,64,128,192,141,128,0,120,131,225,33,1,2,4,8,16,32,
64,160,131,128,0,216,161,203,106,36,64,128,0,1,2,4,8,220,8,8,128,55,24,30,18,32,64,128,0,1,2,4,58,8,8,128,29,186,172,70,2,4,8,16,32,64,128,192,141,128,0,120,131,225,33,1,2,4,8,16,32,64,160,131,128,0,216,161,203,106,36,64,128,0,1,2,4,8,220,8,8,128,55,24,30,18,32,64,128,0,1,2,4,58,8,8,128,29,186,172,70,2,4,8,16,32,64,128,192,141,128,0,120,131,225,33,1,2,4,8,16,32,64,160,131,192,63,223,138,252,254,213,183,31,249,130,0,1,2,4,8,16,32,64,32,173,192,255,110,87,238,19,192,91,13,143,9,16,32,64,128,0,1,2,13,4,4,192,6,77,86,34,1,2,4,8,16,32,64,224,86,64,0,188,213,240,152,0,1,2,4,8,16,32,208,64,64,0,108,208,100,37,18,32,64,128,0,1,2,4,110,5,4,192,91,13,143,9,16,32,64,128,0,1,2,13,4,4,192,6,77,86,34,1,2,4,8,16,32,64,224,86,64,0,188,213,240,152,0,1,2,4,8,16,32,208,64,64,0,108,208,100,37,18,32,64,128,0,1,2,4,110,5,4,192,91,13,143,9,16,32,64,128,0,1,2,13,4,4,192,6,77,86,34,1,2,4,8,16,32,64,224,86,64,0,188,213,240,152,0,1,2,4,8,16,32,208,64,64,0,108,208,100,37,18,32,64,128,0,1,2,4,110,5,254,185,
253,226,199,143,63,190,252,254,67,95,17,32,64,128,192,255,183,119,95,219,145,220,200,162,64,117,231,255,255,249,92,73,173,102,211,148,73,3,19,102,207,203,144,85,153,64,96,7,146,136,5,84,181,8,16,32,64,32,165,192,255,125,137,218,14,224,23,14,191,16,32,64,128,0,1,2,4,234,11,40,0,235,231,216,8,9,16,32,64,128,0,1,2,95,4,20,128,95,56,252,66,128,0,1,2,4,8,16,168,47,160,0,172,159,99,35,36,64,128,0,1,2,4,8,124,17,80,0,126,225,240,11,1,2,4,8,16,32,64,160,190,128,2,176,126,142,141,144,0,1,2,4,8,16,32,240,69,64,1,248,133,195,47,4,8,16,32,64,128,0,129,250,2,10,192,250,57,54,66,2,4,8,16,32,64,128,192,23,1,5,224,23,14,191,16,32,64,128,0,1,2,4,234,11,40,0,235,231,216,8,9,16,32,64,128,0,1,2,95,4,190,255,183,223,190,255,254,229,98,191,16,32,64,128,0,1,2,4,8,36,20,248,250,95,130,251,203,14,96,194,28,10,153,0,1,2,4,8,16,32,112,71,64,1,120,71,207,189,4,8,16,32,64,128,0,129,132,2,10,192,132,73,19,50,1,2,4,8,16,32,64,224,142,128,2,240,142,158,123,9,16,32,64,128,0,1,2,9,5,20,128,9,147,38,100,2,4,8,
16,32,64,128,192,29,1,5,224,29,61,247,18,32,64,128,0,1,2,4,18,10,40,0,19,38,77,200,4,8,16,32,64,128,0,129,59,2,10,192,59,122,238,37,64,128,0,1,2,4,8,36,20,80,0,38,76,154,144,9,16,32,64,128,0,1,2,119,4,20,128,119,244,220,75,128,0,1,2,4,8,16,72,40,240,227,63,253,246,227,133,132,131,18,50,1,2,4,8,16,32,64,128,192,31,129,111,255,37,56,255,41,184,63,52,126,34,64,128,0,1,2,4,8,244,16,112,4,220,35,207,70,73,128,0,1,2,4,8,16,248,16,80,0,126,80,248,129,0,1,2,4,8,16,32,208,67,64,1,216,35,207,70,73,128,0,1,2,4,8,16,248,16,80,0,126,80,248,129,0,1,2,4,8,16,32,208,67,64,1,216,35,207,70,73,128,0,1,2,4,8,16,248,16,80,0,126,80,248,129,0,1,2,4,8,16,32,208,67,64,1,216,35,207,70,73,128,0,1,2,4,8,16,248,16,80,0,126,80,248,129,0,1,2,4,8,16,32,208,67,224,231,127,248,227,231,43,61,36,140,146,0,1,2,4,8,16,32,80,83,224,251,127,8,196,127,9,164,102,158,141,138,0,1,2,4,8,16,32,240,92,192,17,240,115,27,239,16,32,64,128,0,1,2,4,74,10,40,0,75,166,213,160,8,16,32,64,128,0,1,2,207,5,20,128,207,109,188,67,128,
0,1,2,4,8,16,40,41,160,0,44,153,86,131,34,64,128,0,1,2,4,8,60,23,80,0,62,183,241,14,1,2,4,8,16,32,64,160,164,128,2,176,100,90,13,138,0,1,2,4,8,16,32,240,92,64,1,248,220,198,59,4,8,16,32,64,128,0,129,146,2,15,254,217,231,7,47,149,28,186,65,17,32,64,128,0,1,2,4,58,8,252,248,119,160,253,67,208,29,210,110,140,4,8,16,32,64,128,0,129,207,2,142,128,63,107,248,153,0,1,2,4,8,16,32,208,64,64,1,216,32,201,134,72,128,0,1,2,4,8,16,248,44,160,0,252,172,225,103,2,4,8,16,32,64,128,64,3,1,5,96,131,36,27,34,1,2,4,8,16,32,64,224,179,128,2,240,179,134,159,9,16,32,64,128,0,1,2,13,4,20,128,13,146,108,136,4,8,16,32,64,128,0,129,207,2,143,254,209,191,71,175,125,190,199,207,4,8,16,32,64,128,0,1,2,89,4,126,254,51,128,254,29,192,44,185,19,39,1,2,4,8,16,32,64,96,148,128,35,224,81,146,218,33,64,128,0,1,2,4,8,36,17,80,0,38,73,148,48,9,16,32,64,128,0,1,2,163,4,20,128,163,36,181,67,128,0,1,2,4,8,16,72,34,160,0,76,146,40,97,18,32,64,128,0,1,2,4,70,9,40,0,71,73,106,135,0,1,2,4,8,16,32,144,68,64,1,152,36,81,194,
36,64,128,0,1,2,4,8,140,18,80,0,142,146,212,14,1,2,4,8,16,32,64,32,137,192,195,127,244,249,225,139,73,6,36,76,2,4,8,16,32,64,128,0,129,63,2,15,254,29,104,255,16,244,31,30,63,17,32,64,128,0,1,2,4,122,8,56,2,238,145,103,163,36,64,128,0,1,2,4,8,124,8,40,0,63,40,252,64,128,0,1,2,4,8,16,232,33,160,0,236,145,103,163,36,64,128,0,1,2,4,8,124,8,40,0,63,40,252,64,128,0,1,2,4,8,16,232,33,160,0,236,145,103,163,36,64,128,0,1,2,4,8,124,8,60,254,23,95,30,191,250,113,147,31,8,16,32,64,128,0,1,2,4,82,8,60,250,87,96,252,51,48,41,82,39,72,2,4,8,16,32,64,128,192,64,1,71,192,3,49,53,69,128,0,1,2,4,8,16,200,32,160,0,204,144,37,49,18,32,64,128,0,1,2,4,6,10,40,0,7,98,106,138,0,1,2,4,8,16,32,144,65,64,1,152,33,75,98,36,64,128,0,1,2,4,8,12,20,80,0,14,196,212,20,1,2,4,8,16,32,64,32,131,128,2,48,67,150,196,72,128,0,1,2,4,8,16,24,40,240,228,95,252,123,242,242,192,142,53,69,128,0,1,2,4,8,16,32,48,91,224,225,63,3,232,223,1,156,205,174,125,2,4,8,16,32,64,128,64,52,1,71,192,209,50,34,30,2,4,8,16,32,64,128,192,
100,1,5,224,100,96,205,19,32,64,128,0,1,2,4,162,9,40,0,163,101,68,60,4,8,16,32,64,128,0,129,201,2,10,192,201,192,154,39,64,128,0,1,2,4,8,68,19,80,0,70,203,136,120,8,16,32,64,128,0,1,2,147,5,158,253,123,47,207,94,159,28,142,230,9,16,32,64,128,0,1,2,4,134,9,60,254,87,96,252,51,48,195,128,53,68,128,0,1,2,4,8,16,72,34,224,8,56,73,162,132,73,128,0,1,2,4,8,16,24,37,160,0,28,37,169,29,2,4,8,16,32,64,128,64,18,1,5,96,146,68,9,147,0,1,2,4,8,16,32,48,74,64,1,56,74,82,59,4,8,16,32,64,128,0,129,36,2,79,191,237,251,244,141,36,3,19,38,1,2,4,8,16,32,64,160,187,192,147,47,1,251,22,112,247,137,97,252,4,8,16,32,64,128,64,63,1,71,192,253,114,110,196,4,8,16,32,64,128,64,115,1,5,96,243,9,96,248,4,8,16,32,64,128,64,63,1,5,96,191,156,27,49,1,2,4,8,16,32,208,92,64,1,216,124,2,24,62,1,2,4,8,16,32,208,79,64,1,216,47,231,70,76,128,0,1,2,4,8,52,23,120,254,175,189,60,127,167,57,153,225,19,32,64,128,0,1,2,4,82,8,60,251,87,96,252,51,48,41,210,39,72,2,4,8,16,32,64,128,192,64,1,71,192,3,49,53,69,128,0,1,2,4,
8,16,200,32,160,0,204,144,37,49,18,32,64,128,0,1,2,4,6,10,40,0,7,98,106,138,0,1,2,4,8,16,32,144,65,64,1,152,33,75,98,36,64,128,0,1,2,4,8,12,20,120,241,93,223,23,111,13,12,64,83,4,8,16,32,64,128,0,1,2,51,4,158,126,9,216,183,128,103,112,107,147,0,1,2,4,8,16,32,16,89,192,17,112,228,236,136,141,0,1,2,4,8,16,32,48,65,64,1,56,1,85,147,4,8,16,32,64,128,0,129,200,2,10,192,200,217,17,27,1,2,4,8,16,32,64,96,130,128,2,112,2,170,38,9,16,32,64,128,0,1,2,145,5,94,125,213,247,213,123,145,199,36,54,2,4,8,16,32,64,128,0,129,231,95,2,246,45,96,179,131,0,1,2,4,8,16,32,208,77,192,17,112,183,140,27,47,1,2,4,8,16,32,208,94,64,1,216,126,10,0,32,64,128,0,1,2,4,186,9,40,0,187,101,220,120,9,16,32,64,128,0,129,246,2,10,192,246,83,0,0,1,2,4,8,16,32,208,77,224,229,55,125,95,190,217,77,202,120,9,16,32,64,128,0,1,2,137,4,94,124,9,216,183,128,19,229,81,168,4,8,16,32,64,128,0,129,33,2,142,128,135,48,106,132,0,1,2,4,8,16,32,144,71,64,1,152,39,87,34,37,64,128,0,1,2,4,8,12,17,80,0,14,97,212,8,1,2,4,8,16,32,64,32,
143,128,2,48,79,174,68,74,128,0,1,2,4,8,16,24,34,240,250,139,190,175,223,29,18,128,70,8,16,32,64,128,0,1,2,4,134,11,188,250,18,176,111,1,15,231,214,32,1,2,4,8,16,32,64,32,184,128,35,224,224,9,18,30,1,2,4,8,16,32,64,96,180,128,2,112,180,168,246,8,16,32,64,128,0,1,2,193,5,20,128,193,19,36,60,2,4,8,16,32,64,128,192,104,1,5,224,104,81,237,17,32,64,128,0,1,2,4,130,11,188,249,158,239,155,183,131,15,78,120,4,8,16,32,64,128,0,129,158,2,47,191,4,236,91,192,61,39,133,81,19,32,64,128,0,1,2,157,5,28,1,119,206,190,177,19,32,64,128,0,1,2,45,5,20,128,45,211,110,208,4,8,16,32,64,128,64,103,1,5,96,231,236,27,59,1,2,4,8,16,32,208,82,224,221,183,60,222,189,223,18,205,160,9,16,32,64,128,0,1,2,161,5,94,127,7,196,151,64,66,39,79,112,4,8,16,32,64,128,0,129,9,2,142,128,39,160,106,146,0,1,2,4,8,16,32,16,89,64,1,24,57,59,98,35,64,128,0,1,2,4,8,76,16,80,0,78,64,213,36,1,2,4,8,16,32,64,32,178,128,2,48,114,118,196,70,128,0,1,2,4,8,16,152,32,240,246,91,190,111,47,152,16,148,38,9,16,32,64,128,0,1,2,4,174,11,
188,249,18,176,111,1,95,167,117,39,1,2,4,8,16,32,64,32,167,128,35,224,156,121,19,53,1,2,4,8,16,32,64,224,178,128,2,240,50,157,27,9,16,32,64,128,0,1,2,57,5,20,128,57,243,38,106,2,4,8,16,32,64,128,192,101,129,247,223,241,120,127,197,229,206,221,72,128,0,1,2,4,8,16,32,48,92,224,221,119,64,124,9,100,56,185,6,9,16,32,64,128,0,1,2,193,5,28,1,7,79,144,240,8,16,32,64,128,0,1,2,163,5,20,128,163,69,181,71,128,0,1,2,4,8,16,8,46,160,0,12,158,32,225,17,32,64,128,0,1,2,4,70,11,28,248,138,199,129,75,70,71,165,61,2,4,8,16,32,64,128,0,129,139,2,111,191,3,226,75,32,23,101,221,70,128,0,1,2,4,8,16,72,43,224,8,56,109,234,4,78,128,0,1,2,4,8,16,184,38,160,0,188,230,230,46,2,4,8,16,32,64,128,64,90,1,5,96,218,212,9,156,0,1,2,4,8,16,32,112,77,224,200,55,60,142,92,115,173,119,119,17,32,64,128,0,1,2,4,8,140,21,120,255,29,16,95,2,25,43,174,53,2,4,8,16,32,64,128,64,124,1,71,192,241,115,36,66,2,4,8,16,32,64,128,192,80,1,5,224,80,78,141,17,32,64,128,0,1,2,4,226,11,40,0,227,231,72,132,4,8,16,32,64,128,0,129,
161,2,135,190,224,113,232,162,161,97,105,140,0,1,2,4,8,16,32,64,224,138,192,129,239,128,248,18,200,21,88,247,16,32,64,128,0,1,2,4,50,11,56,2,206,156,61,177,19,32,64,128,0,1,2,4,46,8,40,0,47,160,185,133,0,1,2,4,8,16,32,144,89,64,1,152,57,123,98,39,64,128,0,1,2,4,8,92,16,56,246,253,142,99,87,93,232,222,45,4,8,16,32,64,128,0,1,2,3,5,142,124,7,196,151,64,6,130,107,138,0,1,2,4,8,16,32,144,66,192,17,112,138,52,9,146,0,1,2,4,8,16,32,48,78,64,1,56,206,82,75,4,8,16,32,64,128,0,129,20,2,7,63,221,119,240,178,20,67,22,36,1,2,4,8,16,32,64,160,170,192,161,143,0,250,12,96,213,244,27,23,1,2,4,8,16,32,64,224,153,128,35,224,103,50,94,39,64,128,0,1,2,4,8,20,21,80,0,22,77,172,97,17,32,64,128,0,1,2,4,158,9,40,0,159,201,120,157,0,1,2,4,8,16,32,80,84,224,232,183,59,142,94,87,148,201,176,8,16,32,64,128,0,1,2,9,4,142,125,7,196,151,64,18,164,82,136,4,8,16,32,64,128,0,129,161,2,142,128,135,114,106,140,0,1,2,4,8,16,32,16,95,64,1,24,63,71,34,36,64,128,0,1,2,4,8,12,21,56,252,217,190,195,23,14,13,79,99,4,8,
16,32,64,128,0,1,2,71,5,14,126,4,208,103,0,143,130,186,142,0,1,2,4,8,16,32,80,69,192,17,112,149,76,26,7,1,2,4,8,16,32,64,224,160,128,2,240,32,148,203,8,16,32,64,128,0,1,2,85,4,20,128,85,50,105,28,4,8,16,32,64,128,0,129,131,2,199,191,219,113,252,202,131,93,187,140,0,1,2,4,8,16,32,64,96,160,192,209,239,128,248,18,200,64,116,77,17,32,64,128,0,1,2,4,82,8,56,2,78,145,38,65,18,32,64,128,0,1,2,4,198,9,40,0,199,89,106,137,0,1,2,4,8,16,32,144,66,224,196,39,251,78,92,154,98,232,130,36,64,128,0,1,2,4,8,84,18,56,252,17,64,159,1,172,148,118,99,33,64,128,0,1,2,4,8,28,17,112,4,124,68,201,53,4,8,16,32,64,128,0,129,66,2,10,192,66,201,52,20,2,4,8,16,32,64,128,192,17,1,5,224,17,37,215,16,32,64,128,0,1,2,4,10,9,156,249,102,199,153,107,11,17,25,10,1,2,4,8,16,32,64,32,129,192,241,239,128,248,18,72,130,116,10,145,0,1,2,4,8,16,32,48,84,192,17,240,80,78,141,17,32,64,128,0,1,2,4,226,11,40,0,227,231,72,132,4,8,16,32,64,128,0,129,161,2,167,62,215,119,234,226,161,97,106,140,0,1,2,4,8,16,32,64,224,149,192,
137,143,0,250,12,224,43,72,239,17,32,64,128,0,1,2,4,42,10,56,2,174,152,85,99,34,64,128,0,1,2,4,8,188,16,80,0,190,192,241,22,1,2,4,8,16,32,64,160,162,192,185,143,245,157,187,186,162,151,49,17,32,64,128,0,1,2,4,34,10,156,249,8,160,207,0,70,204,160,152,8,16,32,64,128,0,1,2,51,5,28,1,207,212,213,54,1,2,4,8,16,32,64,32,160,128,2,48,96,82,132,68,128,0,1,2,4,8,16,152,41,112,242,83,125,39,47,159,25,185,182,9,16,32,64,128,0,1,2,4,254,19,56,245,17,64,159,1,52,111,8,16,32,64,128,0,1,2,221,4,28,1,119,203,184,241,18,32,64,128,0,1,2,237,5,20,128,237,167,0,0,2,4,8,16,32,64,160,155,192,217,15,245,157,189,190,155,167,241,18,32,64,128,0,1,2,4,214,11,156,251,8,160,207,0,174,207,144,30,9,16,32,64,128,0,1,2,123,5,28,1,239,245,215,59,1,2,4,8,16,32,64,96,185,128,2,112,57,185,14,9,16,32,64,128,0,1,2,123,5,78,127,166,239,244,13,123,199,167,119,2,4,8,16,32,64,128,64,121,129,147,31,1,244,25,192,242,51,194,0,9,16,32,64,128,0,1,2,223,4,28,1,127,3,241,43,1,2,4,8,16,32,64,160,186,128,2,176,122,134,141,143,
0,1,2,4,8,16,32,240,77,224,252,71,250,206,223,241,173,75,191,18,32,64,128,0,1,2,4,8,12,20,56,251,17,64,159,1,28,136,175,41,2,4,8,16,32,64,128,64,10,1,71,192,41,210,36,72,2,4,8,16,32,64,128,192,56,1,5,224,56,75,45,17,32,64,128,0,1,2,4,82,8,92,248,68,223,133,91,82,80,8,146,0,1,2,4,8,16,32,144,81,224,244,71,0,125,6,48,99,154,197,76,128,0,1,2,4,8,16,184,35,224,8,248,142,158,123,9,16,32,64,128,0,1,2,9,5,20,128,9,147,38,100,2,4,8,16,32,64,128,192,29,129,43,31,232,187,114,207,157,24,221,75,128,0,1,2,4,8,16,32,240,76,224,252,71,0,125,6,240,153,165,215,9,16,32,64,128,0,1,2,85,5,28,1,87,205,172,113,17,32,64,128,0,1,2,4,158,8,40,0,159,192,120,153,0,1,2,4,8,16,32,80,85,224,210,231,249,46,221,84,85,208,184,8,16,32,64,128,0,1,2,27,5,46,124,4,208,103,0,55,230,75,215,4,8,16,32,64,128,0,129,45,2,142,128,183,176,235,148,0,1,2,4,8,16,32,176,79,64,1,184,207,94,207,4,8,16,32,64,128,0,129,45,2,215,62,206,119,237,174,45,3,212,41,1,2,4,8,16,32,64,160,176,192,149,143,0,250,12,96,225,9,97,104,4,8,16,32,
64,128,0,129,135,2,142,128,31,178,120,145,0,1,2,4,8,16,32,80,87,64,1,88,55,183,70,70,128,0,1,2,4,8,16,120,40,112,241,211,124,23,111,123,24,130,23,9,16,32,64,128,0,1,2,4,174,9,92,250,8,160,207,0,94,195,118,23,1,2,4,8,16,32,64,32,175,128,35,224,188,185,19,57,1,2,4,8,16,32,64,224,146,192,213,179,220,171,247,93,10,210,77,4,8,16,32,64,128,0,1,2,15,4,174,157,0,59,2,126,64,233,37,2,4,8,16,32,64,128,64,105,1,71,192,165,211,107,112,4,8,16,32,64,128,0,129,159,2,10,192,159,38,94,33,64,128,0,1,2,4,8,148,22,184,252,89,190,203,55,150,230,52,56,2,4,8,16,32,64,128,192,58,129,139,31,1,244,25,192,117,41,210,19,1,2,4,8,16,32,64,32,134,128,35,224,24,121,16,5,1,2,4,8,16,32,64,96,153,192,245,147,220,235,119,46,27,156,142,8,16,32,64,128,0,1,2,133,5,174,158,0,59,2,46,60,41,12,141,0,1,2,4,8,16,32,240,80,192,17,240,67,22,47,18,32,64,128,0,1,2,4,234,10,40,0,235,230,214,200,8,16,32,64,128,0,1,2,15,5,110,124,146,239,198,173,15,67,241,34,1,2,4,8,16,32,64,128,192,113,129,203,31,1,244,25,192,227,200,174,36,
64,128,0,1,2,4,8,212,16,112,4,92,35,143,70,65,128,0,1,2,4,8,16,56,44,160,0,60,76,229,66,2,4,8,16,32,64,128,64,13,129,59,31,228,187,115,111,13,61,163,32,64,128,0,1,2,4,8,236,18,184,254,17,64,159,1,220,149,51,253,18,32,64,128,0,1,2,4,118,9,56,2,222,37,175,95,2,4,8,16,32,64,128,192,38,129,91,199,184,183,110,222,52,96,221,18,32,64,128,0,1,2,4,42,8,220,56,1,118,4,92,97,2,24,3,1,2,4,8,16,32,64,224,140,128,35,224,51,90,174,37,64,128,0,1,2,4,8,20,16,184,119,138,123,239,238,2,124,134,64,128,0,1,2,4,8,16,216,34,112,231,4,216,17,240,150,148,233,148,0,1,2,4,8,16,32,176,81,192,17,240,70,124,93,19,32,64,128,0,1,2,4,118,8,40,0,119,168,235,147,0,1,2,4,8,16,32,176,81,224,230,167,248,110,222,190,113,224,186,38,64,128,0,1,2,4,8,228,21,184,245,17,64,159,1,204,155,120,145,19,32,64,128,0,1,2,4,174,9,56,2,190,230,230,46,2,4,8,16,32,64,128,64,90,129,187,103,184,119,239,79,11,39,112,2,4,8,16,32,64,128,192,54,129,123,39,192,142,128,183,37,78,199,4,8,16,32,64,128,0,129,77,2,142,128,55,193,235,150,0,1,2,
4,8,16,32,176,75,64,1,184,75,94,191,4,8,16,32,64,128,0,129,77,2,183,63,195,119,187,129,77,3,215,45,1,2,4,8,16,32,64,32,171,192,205,143,0,250,12,96,214,196,139,155,0,1,2,4,8,16,32,112,85,192,17,240,85,57,247,17,32,64,128,0,1,2,4,146,10,220,63,193,189,223,66,82,58,97,19,32,64,128,0,1,2,4,182,8,220,61,1,118,4,188,37,109,58,37,64,128,0,1,2,4,8,108,20,112,4,188,17,95,215,4,8,16,32,64,128,0,129,29,2,3,14,112,7,52,177,99,228,250,36,64,128,0,1,2,4,8,164,20,184,125,2,236,8,56,101,222,5,77,128,0,1,2,4,8,16,184,33,224,8,248,6,158,91,9,16,32,64,128,0,1,2,25,5,70,156,223,142,104,35,163,157,152,9,16,32,64,128,0,1,2,235,5,238,159,0,59,2,94,159,53,61,18,32,64,128,0,1,2,4,246,10,56,2,222,235,175,119,2,4,8,16,32,64,128,192,114,1,5,224,114,114,29,18,32,64,128,0,1,2,4,246,10,12,249,252,222,144,70,246,58,232,157,0,1,2,4,8,16,32,144,66,96,192,71,0,125,6,48,69,166,5,73,128,0,1,2,4,8,16,24,40,224,8,120,32,166,166,8,16,32,64,128,0,1,2,25,4,198,156,222,142,105,37,131,151,24,9,16,32,64,128,0,1,2,59,5,70,
156,0,59,2,222,153,65,125,19,32,64,128,0,1,2,4,118,8,56,2,222,161,174,79,2,4,8,16,32,64,128,192,70,129,65,135,183,131,154,217,8,161,107,2,4,8,16,32,64,128,64,124,129,33,39,192,142,128,227,39,90,132,4,8,16,32,64,128,0,129,177,2,142,128,199,122,106,141,0,1,2,4,8,16,32,16,94,96,212,217,237,168,118,194,131,9,144,0,1,2,4,8,16,32,176,77,96,204,9,176,35,224,109,9,212,49,1,2,4,8,16,32,64,96,147,128,35,224,77,240,186,37,64,128,0,1,2,4,8,236,18,24,118,116,59,172,161,93,18,250,37,64,128,0,1,2,4,8,4,23,24,116,2,236,8,56,120,158,133,71,128,0,1,2,4,8,16,24,46,224,8,120,56,169,6,9,16,32,64,128,0,1,2,177,5,198,157,220,142,107,41,182,152,232,8,16,32,64,128,0,1,2,123,4,70,157,0,59,2,222,147,63,189,18,32,64,128,0,1,2,4,246,9,56,2,222,103,175,103,2,4,8,16,32,64,128,192,22,129,129,7,183,3,155,218,66,161,83,2,4,8,16,32,64,128,64,100,129,97,39,192,142,128,35,167,89,108,4,8,16,32,64,128,0,129,25,2,142,128,103,168,106,147,0,1,2,4,8,16,32,16,88,96,228,185,237,200,182,2,147,9,141,0,1,2,4,8,16,32,176,65,
96,220,9,176,35,224,13,233,211,37,1,2,4,8,16,32,64,96,171,128,35,224,173,252,58,39,64,128,0,1,2,4,8,172,23,24,122,108,59,180,177,245,22,122,36,64,128,0,1,2,4,8,132,21,24,120,2,236,8,56,108,150,5,70,128,0,1,2,4,8,16,152,36,224,8,120,18,172,102,9,16,32,64,128,0,1,2,81,5,198,158,218,142,109,45,170,153,184,8,16,32,64,128,0,1,2,171,5,70,158,0,59,2,94,157,61,253,17,32,64,128,0,1,2,4,118,11,56,2,222,157,1,253,19,32,64,128,0,1,2,4,22,11,12,62,180,29,220,220,98,12,221,17,32,64,128,0,1,2,4,98,10,12,61,1,118,4,28,51,201,162,34,64,128,0,1,2,4,8,204,19,112,4,60,207,86,203,4,8,16,32,64,128,0,129,144,2,163,207,108,71,183,23,18,77,80,4,8,16,32,64,128,0,129,165,2,99,79,128,29,1,47,77,158,206,8,16,32,64,128,0,1,2,1,4,28,1,7,72,130,16,8,16,32,64,128,0,1,2,43,5,134,31,217,14,111,112,165,134,190,8,16,32,64,128,0,1,2,1,5,6,159,0,59,2,14,152,99,33,17,32,64,128,0,1,2,4,166,10,56,2,158,202,171,113,2,4,8,16,32,64,128,64,60,129,241,39,182,227,91,140,167,38,34,2,4,8,16,32,64,128,192,58,129,209,39,192,142,
128,215,229,78,79,4,8,16,32,64,128,0,129,24,2,142,128,99,228,65,20,4,8,16,32,64,128,0,129,101,2,19,14,108,39,52,185,140,67,71,4,8,16,32,64,128,0,129,104,2,195,79,128,29,1,71,75,177,120,8,16,32,64,128,0,1,2,179,5,28,1,207,22,214,62,1,2,4,8,16,32,64,32,152,192,140,243,218,25,109,6,99,19,14,1,2,4,8,16,32,64,96,145,192,248,19,96,71,192,139,82,167,27,2,4,8,16,32,64,128,64,24,129,41,187,117,83,26,13,67,38,16,2,4,8,16,32,64,128,192,58,129,9,27,128,118,0,215,165,79,79,4,8,16,32,64,128,0,129,24,2,190,4,18,35,15,162,32,64,128,0,1,2,4,8,44,19,152,115,90,59,167,213,101,40,58,34,64,128,0,1,2,4,8,4,17,152,113,2,236,8,56,72,114,133,65,128,0,1,2,4,8,16,88,38,224,8,120,25,181,142,8,16,32,64,128,0,1,2,49,4,38,29,214,78,106,54,134,153,40,8,16,32,64,128,0,1,2,139,4,166,156,0,59,2,94,148,61,221,16,32,64,128,0,1,2,4,194,8,56,2,14,147,10,129,16,32,64,128,0,1,2,4,214,8,204,58,171,157,213,238,26,21,189,16,32,64,128,0,1,2,4,34,8,204,57,1,118,4,28,33,183,98,32,64,128,0,1,2,4,8,172,20,112,4,188,82,91,95,
4,8,16,32,64,128,0,129,0,2,211,142,106,167,53,28,0,77,8,4,8,16,32,64,128,0,129,21,2,147,78,128,29,1,175,72,158,62,8,16,32,64,128,0,1,2,145,4,230,109,212,205,107,57,146,159,88,8,16,32,64,128,0,1,2,179,4,102,109,0,218,1,156,149,49,237,18,32,64,128,0,1,2,4,162,10,248,18,72,212,204,136,139,0,1,2,4,8,16,32,48,73,96,226,65,237,196,166,39,97,104,150,0,1,2,4,8,16,32,16,71,96,218,9,176,35,224,56,73,22,9,1,2,4,8,16,32,64,96,141,128,35,224,53,206,122,33,64,128,0,1,2,4,8,132,17,152,121,78,59,179,237,48,128,2,33,64,128,0,1,2,4,8,76,17,152,119,2,236,8,120,74,194,52,74,128,0,1,2,4,8,16,8,44,48,117,151,110,106,227,129,81,133,70,128,0,1,2,4,8,16,184,43,48,113,3,208,14,224,221,228,184,159,0,1,2,4,8,16,32,144,77,192,151,64,178,101,76,188,4,8,16,32,64,128,0,129,155,2,115,79,105,231,182,126,115,232,110,39,64,128,0,1,2,4,8,132,21,152,121,2,236,8,56,108,218,5,70,128,0,1,2,4,8,16,152,36,224,8,120,18,172,102,9,16,32,64,128,0,1,2,81,5,38,31,210,78,110,62,170,170,184,8,16,32,64,128,0,1,2,183,4,166,158,
0,59,2,190,149,27,55,19,32,64,128,0,1,2,4,18,10,204,222,162,155,221,126,66,114,33,19,32,64,128,0,1,2,4,222,8,204,221,0,180,3,248,134,223,219,4,8,16,32,64,128,0,129,114,2,190,4,82,46,165,6,68,128,0,1,2,4,8,16,120,45,48,253,136,118,122,7,175,199,231,93,2,4,8,16,32,64,128,64,58,129,201,39,192,142,128,211,205,8,1,19,32,64,128,0,1,2,4,110,10,204,223,160,155,223,195,77,2,183,19,32,64,128,0,1,2,4,66,9,204,222,0,180,3,24,42,221,130,33,64,128,0,1,2,4,8,44,16,240,37,144,5,200,186,32,64,128,0,1,2,4,8,68,18,88,112,64,187,160,139,72,162,98,33,64,128,0,1,2,4,8,220,18,152,126,2,236,8,248,86,126,220,76,128,0,1,2,4,8,16,72,40,176,98,123,110,69,31,9,233,133,76,128,0,1,2,4,8,16,120,32,48,127,3,208,14,224,3,118,47,17,32,64,128,0,1,2,4,74,11,248,18,72,233,244,26,28,1,2,4,8,16,32,64,224,167,192,146,227,217,37,157,252,28,155,87,8,16,32,64,128,0,1,2,233,4,22,156,0,59,2,78,55,43,4,76,128,0,1,2,4,8,16,184,41,176,102,115,110,77,47,55,41,220,78,128,0,1,2,4,8,16,216,46,176,98,3,208,14,224,246,52,11,128,0,
1,2,4,8,16,32,176,88,192,151,64,22,131,235,142,0,1,2,4,8,16,32,176,91,96,209,225,236,162,110,118,107,234,159,0,1,2,4,8,16,32,112,75,96,201,9,176,35,224,91,57,114,51,1,2,4,8,16,32,64,32,161,192,170,173,185,85,253,36,76,129,144,9,16,32,64,128,0,1,2,255,9,172,217,0,180,3,104,194,17,32,64,128,0,1,2,4,186,9,248,18,72,183,140,27,47,1,2,4,8,16,32,208,94,96,217,209,236,178,142,218,167,20,0,1,2,4,8,16,32,144,85,96,209,9,176,35,224,172,19,68,220,4,8,16,32,64,128,0,129,171,2,235,54,230,214,245,116,213,194,125,4,8,16,32,64,128,0,129,157,2,171,54,0,237,0,238,204,178,190,9,16,32,64,128,0,1,2,59,4,124,9,100,135,186,62,9,16,32,64,128,0,1,2,27,5,22,30,204,46,236,106,35,168,174,9,16,32,64,128,0,1,2,215,4,150,157,0,59,2,190,150,32,119,17,32,64,128,0,1,2,4,242,10,172,220,150,91,217,87,222,140,136,156,0,1,2,4,8,16,232,41,176,110,3,208,14,96,207,25,102,212,4,8,16,32,64,128,64,103,1,95,2,233,156,125,99,39,64,128,0,1,2,4,90,10,44,61,150,93,218,89,203,116,26,52,1,2,4,8,16,32,144,85,96,225,9,176,35,224,
172,147,68,220,4,8,16,32,64,128,0,129,171,2,107,55,229,214,246,118,213,196,125,4,8,16,32,64,128,0,129,213,2,43,55,0,237,0,174,206,174,254,8,16,32,64,128,0,1,2,187,5,22,239,201,45,238,110,183,174,254,9,16,32,64,128,0,1,2,135,4,150,110,0,218,1,60,148,19,23,17,32,64,128,0,1,2,4,10,9,248,103,96,10,37,211,80,8,16,32,64,128,0,1,2,71,4,86,159,201,174,238,239,136,129,107,8,16,32,64,128,0,1,2,123,5,214,158,0,59,2,222,155,109,189,19,32,64,128,0,1,2,4,214,11,44,223,145,91,222,225,122,83,61,18,32,64,128,0,1,2,4,78,9,44,222,0,180,3,120,42,59,46,38,64,128,0,1,2,4,8,20,16,88,191,33,183,190,199,2,105,50,4,2,4,8,16,32,64,160,176,192,234,13,64,59,128,133,39,147,161,17,32,64,128,0,1,2,4,30,10,248,103,96,30,178,120,145,0,1,2,4,8,16,32,80,87,96,195,129,236,134,46,235,230,207,200,8,16,32,64,128,0,129,244,2,203,79,128,29,1,167,159,51,6,64,128,0,1,2,4,8,16,56,41,176,99,59,110,71,159,39,89,92,78,128,0,1,2,4,8,16,88,36,176,126,3,208,14,224,162,212,234,134,0,1,2,4,8,16,32,16,70,96,203,110,220,150,78,195,
144,11,132,0,1,2,4,8,16,32,240,71,96,195,6,160,29,192,63,252,126,34,64,128,0,1,2,4,8,244,16,240,207,192,244,200,179,81,18,32,64,128,0,1,2,4,62,4,246,156,198,238,233,245,99,208,126,32,64,128,0,1,2,4,8,4,17,216,113,2,236,8,56,72,242,133,65,128,0,1,2,4,8,16,88,38,176,105,47,110,83,183,203,88,117,68,128,0,1,2,4,8,16,56,34,176,101,3,208,14,224,145,212,184,134,0,1,2,4,8,16,32,80,73,96,215,86,220,174,126,43,229,206,88,8,16,32,64,128,0,129,236,2,123,54,0,237,0,102,159,55,226,39,64,128,0,1,2,4,8,156,21,216,182,19,183,173,227,179,66,174,39,64,128,0,1,2,4,8,76,18,216,180,1,104,7,112,82,62,53,75,128,0,1,2,4,8,16,8,43,224,31,130,14,155,26,129,17,32,64,128,0,1,2,4,230,8,236,59,137,221,215,243,28,73,173,18,32,64,128,0,1,2,4,206,9,236,58,1,118,4,124,46,79,174,38,64,128,0,1,2,4,8,228,23,216,184,15,183,177,235,252,121,51,2,2,4,8,16,32,64,32,189,192,182,13,64,59,128,233,231,142,1,16,32,64,128,0,1,2,4,78,10,236,220,134,219,217,247,73,38,151,19,32,64,128,0,1,2,4,6,11,236,219,0,180,3,56,56,149,154,
35,64,128,0,1,2,4,8,132,23,216,186,11,183,181,243,240,169,17,32,1,2,4,8,16,32,80,89,96,227,6,160,29,192,202,19,203,216,8,16,32,64,128,0,1,2,143,4,246,110,194,237,237,253,145,135,215,8,16,32,64,128,0,1,2,43,4,118,110,0,218,1,92,145,97,125,16,32,64,128,0,1,2,4,34,9,248,79,193,69,202,134,88,8,16,32,64,128,0,1,2,11,4,54,31,194,110,238,126,1,176,46,8,16,32,64,128,0,1,2,63,5,182,158,0,59,2,254,153,16,175,16,32,64,128,0,1,2,4,106,11,236,222,130,219,221,127,237,236,26,29,1,2,4,8,16,32,16,83,96,239,6,160,29,192,152,179,66,84,4,8,16,32,64,128,0,129,121,2,219,119,224,182,7,48,207,86,203,4,8,16,32,64,128,0,129,135,2,155,55,0,237,0,62,204,138,23,9,16,32,64,128,0,1,2,133,5,246,111,192,237,143,160,112,122,13,141,0,1,2,4,8,16,8,40,176,123,3,208,14,96,192,73,33,36,2,4,8,16,32,64,128,192,84,129,0,251,111,1,66,152,74,172,113,2,4,8,16,32,64,128,192,103,129,237,27,128,118,0,63,167,195,207,4,8,16,32,64,128,0,129,14,2,17,182,223,34,196,208,33,215,198,72,128,0,1,2,4,8,68,16,216,191,1,104,7,48,194,60,
16,3,1,2,4,8,16,32,64,96,165,192,255,86,118,166,47,2,4,8,16,32,64,128,0,129,253,2,33,142,95,67,4,177,63,23,34,32,64,128,0,1,2,4,26,8,4,56,1,118,4,220,96,158,25,34,1,2,4,8,16,32,64,224,139,64,140,205,183,24,81,124,129,241,11,1,2,4,8,16,32,64,96,130,64,132,13,64,59,128,19,18,171,73,2,4,8,16,32,64,128,64,104,129,32,123,111,65,194,8,157,42,193,17,32,64,128,0,1,2,249,5,66,108,0,218,1,204,63,145,140,128,0,1,2,4,8,16,32,112,78,32,202,214,91,148,56,206,233,185,154,0,1,2,4,8,16,32,112,70,32,198,6,160,29,192,51,57,115,45,1,2,4,8,16,32,64,160,130,64,152,157,183,48,129,84,200,170,49,16,32,64,128,0,1,2,33,5,130,108,0,218,1,12,57,59,4,69,128,0,1,2,4,8,16,152,40,16,103,227,45,78,36,19,185,53,77,128,0,1,2,4,8,52,22,136,178,1,104,7,176,241,36,52,116,2,4,8,16,32,64,160,169,64,160,125,183,64,161,52,157,12,134,77,128,0,1,2,4,8,204,20,8,179,1,104,7,112,102,154,181,77,128,0,1,2,4,8,16,136,40,16,105,219,45,82,44,17,115,37,38,2,4,8,16,32,64,32,179,64,156,13,64,59,128,153,231,145,216,9,16,32,64,128,0,
1,2,87,4,66,237,186,133,10,230,138,166,123,8,16,32,64,128,0,1,2,79,4,2,109,0,218,1,124,146,35,47,19,32,64,128,0,1,2,4,202,10,196,218,116,139,21,77,217,164,27,24,1,2,4,8,16,32,176,92,32,210,6,160,29,192,229,233,215,33,1,2,4,8,16,32,64,96,179,64,176,61,183,96,225,108,78,142,238,9,16,32,64,128,0,129,42,2,161,54,0,237,0,86,153,86,198,65,128,0,1,2,4,8,16,56,42,16,109,203,45,90,60,71,29,93,71,128,0,1,2,4,8,16,120,46,16,107,3,208,14,224,243,76,121,135,0,1,2,4,8,16,32,80,83,32,220,142,91,184,128,106,230,221,168,8,16,32,64,128,0,129,133,2,193,54,0,237,0,46,204,189,174,8,16,32,64,128,0,1,2,33,4,226,109,184,197,139,40,68,162,4,65,128,0,1,2,4,8,164,21,136,182,1,104,7,48,237,84,18,56,1,2,4,8,16,32,64,224,162,64,192,253,182,128,33,93,196,117,27,1,2,4,8,16,32,64,224,175,191,194,109,0,218,1,52,45,9,16,32,64,128,0,1,2,221,4,34,110,183,69,140,169,219,188,48,94,2,4,8,16,32,64,96,148,64,188,13,64,59,128,163,114,171,29,2,4,8,16,32,64,128,64,22,129,144,187,109,33,131,202,146,81,113,18,32,64,128,0,
1,2,161,4,2,110,0,218,1,12,53,67,4,67,128,0,1,2,4,8,16,88,32,16,115,179,45,102,84,11,210,161,11,2,4,8,16,32,64,160,152,64,196,13,64,59,128,197,38,153,225,16,32,64,128,0,1,2,4,222,10,4,221,107,11,26,214,91,78,23,16,32,64,128,0,1,2,4,62,11,132,220,0,180,3,248,57,69,126,38,64,128,0,1,2,4,8,116,16,136,186,213,22,53,174,14,115,194,24,9,16,32,64,128,0,129,81,2,49,55,0,237,0,142,202,175,118,8,16,32,64,128,0,1,2,89,4,194,238,180,133,13,44,75,102,197,73,128,0,1,2,4,8,108,23,8,186,1,104,7,112,251,204,16,0,1,2,4,8,16,32,64,96,177,64,220,141,182,184,145,45,78,145,238,8,16,32,64,128,0,129,164,2,81,55,0,237,0,38,157,80,194,38,64,128,0,1,2,4,8,92,22,8,188,207,22,56,180,203,220,110,36,64,128,0,1,2,4,250,8,132,221,0,180,3,216,103,18,26,41,1,2,4,8,16,32,64,224,151,64,228,109,182,200,177,153,63,4,8,16,32,64,128,0,129,215,2,113,55,0,237,0,190,206,156,119,9,16,32,64,128,0,1,2,245,4,66,239,178,133,14,174,222,92,48,34,2,4,8,16,32,64,96,160,64,224,13,192,191,98,215,88,177,163,27,56,69,52,69,128,0,1,
2,4,8,20,19,136,92,255,57,2,46,54,217,12,135,0,1,2,4,8,16,32,240,86,32,248,30,91,240,240,222,242,186,128,0,1,2,4,8,16,232,41,16,122,3,208,14,96,207,73,105,212,4,8,16,32,64,128,64,103,129,232,91,108,209,227,235,60,119,140,157,0,1,2,4,8,16,120,38,16,123,3,208,14,224,179,188,121,157,0,1,2,4,8,16,32,80,85,32,252,14,91,248,0,171,206,12,227,34,64,128,0,1,2,4,46,11,4,223,0,180,3,120,57,179,110,36,64,128,0,1,2,4,8,36,21,136,191,193,22,63,194,164,169,23,54,1,2,4,8,16,32,48,73,32,250,6,160,29,192,73,137,215,44,1,2,4,8,16,32,64,32,172,64,130,253,181,4,33,134,77,175,192,8,16,32,64,128,0,129,245,2,225,55,0,237,0,174,159,20,122,36,64,128,0,1,2,4,8,236,21,200,176,189,150,33,198,189,89,212,59,1,2,4,8,16,32,16,71,32,254,6,224,95,41,138,171,20,65,198,153,118,34,33,64,128,0,1,2,4,54,10,36,168,255,28,1,111,156,31,186,38,64,128,0,1,2,4,8,108,17,200,177,185,150,35,202,45,9,212,41,1,2,4,8,16,32,16,74,32,195,6,160,29,192,80,83,70,48,4,8,16,32,64,128,0,129,5,2,73,246,214,146,132,185,32,97,186,32,64,128,
0,1,2,4,34,11,164,216,0,180,3,24,121,10,137,141,0,1,2,4,8,16,32,48,67,32,203,214,90,150,56,103,228,72,155,4,8,16,32,64,128,64,22,129,28,27,128,118,0,179,204,39,113,18,32,64,128,0,1,2,4,70,9,164,217,89,75,19,232,168,204,104,135,0,1,2,4,8,16,72,39,144,100,3,208,14,96,186,153,37,96,2,4,8,16,32,64,128,192,77,129,60,27,107,121,34,189,153,18,183,19,32,64,128,0,1,2,73,5,178,108,0,230,248,79,193,253,154,4,42,192,164,15,131,176,9,16,32,64,128,64,19,129,52,245,159,35,224,38,51,210,48,9,16,32,64,128,0,1,2,31,2,153,182,213,50,197,250,1,236,7,2,4,8,16,32,64,160,137,64,158,13,64,59,128,77,166,164,97,18,32,64,128,0,1,2,4,62,4,82,237,170,165,10,246,131,216,15,4,8,16,32,64,128,64,7,129,68,27,128,118,0,59,76,72,99,36,64,128,0,1,2,4,8,124,22,200,181,169,150,43,218,207,206,126,38,64,128,0,1,2,4,106,11,100,218,0,204,244,207,192,252,51,107,84,128,181,159,29,163,35,64,128,0,1,2,89,5,82,213,127,142,128,179,78,51,113,19,32,64,128,0,1,2,4,174,10,100,219,82,203,22,239,213,188,184,143,0,1,2,4,8,16,200,36,
144,107,3,208,14,96,166,185,37,86,2,4,8,16,32,64,128,192,8,129,116,59,106,233,2,30,145,37,109,16,32,64,128,0,1,2,161,5,146,109,0,218,1,12,61,155,4,71,128,0,1,2,4,8,16,152,32,144,111,67,45,95,196,19,210,166,73,2,4,8,16,32,64,32,144,64,182,13,64,59,128,129,38,143,80,8,16,32,64,128,0,1,2,75,4,18,238,167,37,12,121,73,42,117,66,128,0,1,2,4,8,236,17,72,183,1,152,242,95,86,86,1,238,153,221,122,37,64,128,0,1,2,4,30,9,228,171,255,28,1,63,202,163,215,8,16,32,64,128,0,1,2,149,5,82,238,166,165,12,186,242,44,50,54,2,4,8,16,32,208,88,32,225,6,160,29,192,198,243,213,208,9,16,32,64,128,0,129,166,2,57,55,211,114,70,221,116,138,25,54,1,2,4,8,16,40,45,144,113,3,48,229,151,64,254,158,69,42,192,210,143,146,193,17,32,64,128,0,129,52,2,41,235,63,71,192,105,230,151,64,9,16,32,64,128,0,1,2,131,4,178,110,165,101,141,123,80,218,52,67,128,0,1,2,4,8,132,16,200,185,1,104,7,48,196,228,17,4,1,2,4,8,16,32,64,96,161,64,218,157,180,180,129,47,76,174,174,8,16,32,64,128,0,129,185,2,73,55,0,237,0,206,157,22,90,39,
64,128,0,1,2,4,8,196,19,200,187,145,150,55,242,120,179,64,68,4,8,16,32,64,128,192,21,129,172,27,128,153,255,61,21,21,224,149,153,234,30,2,4,8,16,32,64,96,148,64,218,250,207,17,240,168,41,160,29,2,4,8,16,32,64,128,64,22,129,204,219,104,153,99,207,50,63,196,73,128,0,1,2,4,8,60,19,200,187,1,104,7,240,89,78,189,78,128,0,1,2,4,8,16,168,42,144,122,23,45,117,240,85,103,148,113,17,32,64,128,0,129,38,2,137,55,0,51,127,9,228,239,217,165,2,108,242,136,25,38,1,2,4,8,16,8,39,144,185,254,115,4,28,110,58,9,136,0,1,2,4,8,16,32,48,89,32,249,30,90,242,240,39,39,87,243,4,8,16,32,64,128,192,44,129,212,27,128,118,0,103,77,11,237,18,32,64,128,0,1,2,4,162,10,100,223,66,203,30,127,212,121,33,46,2,4,8,16,32,64,224,149,64,238,13,192,252,95,163,80,1,190,154,157,222,35,64,128,0,1,2,4,102,8,36,175,255,28,1,207,152,20,218,36,64,128,0,1,2,4,8,68,22,200,191,129,150,127,4,145,231,135,216,8,16,32,64,128,0,129,159,2,217,55,0,237,0,254,204,169,87,8,16,32,64,128,0,1,2,181,5,10,236,159,21,24,66,237,57,102,116,4,8,
16,32,64,160,152,64,250,13,192,252,95,2,249,123,70,169,0,139,61,86,134,67,128,0,1,2,4,66,11,228,175,255,28,1,135,158,96,130,35,64,128,0,1,2,4,8,76,16,40,177,123,86,98,16,19,146,171,73,2,4,8,16,32,64,96,188,64,129,13,64,59,128,227,167,133,22,9,16,32,64,128,0,1,2,177,5,106,108,158,213,24,69,236,153,34,58,2,4,8,16,32,64,224,31,129,10,27,128,85,190,64,161,2,244,76,18,32,64,128,0,1,2,43,4,74,212,127,142,128,87,76,21,125,16,32,64,128,0,1,2,4,34,9,84,217,58,171,50,142,72,115,67,44,4,8,16,32,64,128,192,119,129,26,27,128,85,142,128,253,99,128,223,231,167,223,9,16,32,64,128,0,129,241,2,69,234,63,71,192,227,167,134,22,9,16,32,64,128,0,1,2,177,5,234,28,157,214,25,73,236,25,35,58,2,4,8,16,32,208,87,160,202,6,160,29,192,190,115,216,200,9,16,32,64,128,0,129,174,2,133,246,205,10,13,165,235,108,52,110,2,4,8,16,32,16,90,160,204,6,96,157,47,129,252,61,95,84,128,161,31,26,193,17,32,64,128,0,129,228,2,117,234,63,71,192,201,167,162,240,9,16,32,64,128,0,1,2,167,5,74,237,154,149,26,204,233,84,186,129,
0,1,2,4,8,16,152,41,80,104,3,176,216,177,169,10,112,230,188,215,54,1,2,4,8,16,232,44,80,169,254,115,4,220,121,38,27,59,1,2,4,8,16,32,208,83,160,216,158,89,177,225,244,156,147,70,77,128,0,1,2,4,2,10,148,218,0,180,3,24,112,134,9,137,0,1,2,4,8,16,32,48,85,160,218,150,89,181,241,76,77,190,198,9,16,32,64,128,0,129,131,2,181,54,0,139,125,9,228,239,28,170,0,15,78,100,151,17,32,64,128,0,1,2,135,5,138,213,127,142,128,15,103,222,133,4,8,16,32,64,128,0,129,34,2,245,54,204,234,141,168,200,84,51,12,2,4,8,16,32,144,86,160,218,6,96,197,19,83,21,96,218,199,75,224,4,8,16,32,64,32,164,64,185,250,207,17,112,200,121,38,40,2,4,8,16,32,64,128,192,68,129,138,219,101,21,199,52,113,10,104,154,0,1,2,4,8,16,120,41,80,111,3,176,226,17,176,111,2,191,156,196,222,36,64,128,0,1,2,4,78,9,20,172,255,28,1,159,154,1,46,38,64,128,0,1,2,4,8,20,16,168,121,92,90,115,84,5,166,155,33,16,32,64,128,0,129,116,2,21,55,0,237,0,166,155,134,2,38,64,128,0,1,2,4,8,220,20,40,186,87,86,116,88,55,147,237,118,2,4,8,16,32,64,224,172,
64,201,13,192,154,95,2,249,59,181,42,192,179,243,219,245,4,8,16,32,64,128,192,79,129,154,245,159,35,224,159,153,246,10,1,2,4,8,16,32,64,160,182,64,217,157,178,178,3,171,61,31,141,142,0,1,2,4,8,132,18,40,186,1,88,248,168,84,5,24,234,1,18,12,1,2,4,8,16,72,40,80,181,254,115,4,156,112,50,10,153,0,1,2,4,8,16,32,112,75,160,240,62,89,225,161,221,74,185,155,9,16,32,64,128,0,129,99,2,101,55,0,11,31,1,251,38,240,177,185,237,42,2,4,8,16,32,64,224,177,64,221,250,207,17,240,227,140,123,149,0,1,2,4,8,16,32,80,87,160,244,57,105,233,193,213,157,147,70,70,128,0,1,2,4,66,8,20,222,0,44,125,4,236,16,56,196,227,35,8,2,4,8,16,32,144,82,160,114,253,231,8,56,229,148,20,52,1,2,4,8,16,32,64,224,134,64,241,83,210,226,195,187,145,120,183,18,32,64,128,0,1,2,175,4,74,111,0,22,63,2,118,8,252,106,102,123,143,0,1,2,4,8,16,120,38,80,187,254,115,4,252,44,239,94,39,64,128,0,1,2,4,8,84,21,40,127,70,90,126,128,85,103,166,113,17,32,64,128,0,129,141,2,197,55,0,203,31,1,59,4,222,248,240,232,154,0,1,2,4,8,36,21,168,94,
255,57,2,78,58,49,133,77,128,0,1,2,4,8,16,184,44,208,224,132,180,193,16,47,167,223,141,4,8,16,32,64,128,192,79,129,242,27,128,13,142,128,29,2,255,156,215,94,33,64,128,0,1,2,4,158,11,212,175,255,28,1,63,207,190,119,8,16,32,64,128,0,1,2,53,5,90,156,143,182,24,100,205,249,105,84,4,8,16,32,64,96,185,64,131,13,192,22,71,192,14,129,151,63,58,58,36,64,128,0,1,2,105,5,58,212,127,142,128,211,78,79,129,19,32,64,128,0,1,2,4,46,10,52,57,29,109,50,204,139,147,192,109,4,8,16,32,64,128,192,111,129,22,27,128,77,142,128,29,2,255,158,213,254,159,0,1,2,4,8,16,120,37,208,163,254,115,4,252,106,14,120,143,0,1,2,4,8,16,32,80,81,160,205,217,104,155,129,86,156,165,198,68,128,0,1,2,4,22,9,52,217,0,108,115,4,236,16,120,209,131,163,27,2,4,8,16,32,144,88,160,75,253,215,168,0,236,52,212,196,79,158,208,9,16,32,64,128,192,62,129,54,245,159,207,0,238,155,100,122,38,64,128,0,1,2,4,8,236,17,232,244,209,184,78,99,221,51,155,244,74,128,0,1,2,4,50,11,244,217,0,236,117,46,170,2,204,252,84,138,157,0,1,2,4,8,204,21,
104,84,255,57,2,158,59,149,180,78,128,0,1,2,4,8,16,136,39,208,107,83,172,215,104,227,205,54,17,17,32,64,128,0,129,184,2,157,54,0,123,29,1,251,183,96,226,62,117,34,35,64,128,0,1,2,123,5,90,213,127,142,128,247,78,54,189,19,32,64,128,0,1,2,4,214,11,116,59,20,237,54,222,245,51,74,143,4,8,16,32,64,32,163,64,175,13,192,110,71,192,14,129,51,62,147,98,38,64,128,0,1,2,179,5,154,213,127,253,10,192,134,35,158,253,204,104,159,0,1,2,4,8,100,23,232,86,255,249,12,96,246,25,43,126,2,4,8,16,32,64,128,192,89,129,134,159,137,107,56,228,179,179,194,245,4,8,16,32,64,160,149,64,187,13,192,150,7,162,42,192,86,15,181,193,18,32,64,128,0,129,55,2,253,234,63,71,192,111,166,132,183,9,16,32,64,128,0,1,2,229,4,90,238,134,181,28,116,185,169,107,64,4,8,16,32,64,96,140,64,195,13,192,150,71,192,254,45,152,49,207,139,86,8,16,32,64,128,64,5,129,142,245,159,35,224,10,51,215,24,8,16,32,64,128,0,1,2,103,4,154,158,134,54,29,246,153,153,225,90,2,4,8,16,32,208,66,160,229,6,96,211,35,96,135,192,45,30,105,131,36,64,128,
0,1,2,111,5,122,214,127,109,11,192,190,3,127,251,36,184,128,0,1,2,4,8,244,17,104,90,255,249,12,96,159,41,110,164,4,8,16,32,64,128,0,129,95,2,125,63,12,215,119,228,230,62,1,2,4,8,16,32,240,75,160,235,6,96,231,147,80,21,160,167,159,0,1,2,4,8,244,22,104,91,255,57,2,238,61,241,141,158,0,1,2,4,8,16,232,40,208,121,27,172,243,216,59,206,117,99,38,64,128,0,1,2,95,5,250,110,0,118,62,2,246,111,193,124,125,10,252,70,128,0,1,2,4,122,9,52,174,255,122,23,128,205,71,223,235,41,55,90,2,4,8,16,32,240,85,160,115,253,231,51,128,95,231,130,223,8,16,32,64,128,0,1,2,245,5,154,127,14,174,249,240,235,207,111,35,36,64,128,0,1,2,79,4,90,111,0,182,63,4,85,1,62,121,44,188,76,128,0,1,2,4,74,11,244,174,255,218,23,128,0,74,63,221,6,71,128,0,1,2,4,30,11,52,175,255,124,6,240,241,180,240,42,1,2,4,8,16,32,64,160,174,128,35,80,2,117,103,183,145,17,32,64,128,0,129,199,2,221,55,0,157,128,250,215,0,31,63,25,94,37,64,128,0,1,2,117,5,218,215,127,10,192,191,39,183,61,192,186,79,184,145,17,32,64,128,0,129,159,2,234,63,
159,1,252,57,43,188,66,128,0,1,2,4,8,16,168,45,96,247,235,239,252,66,168,61,201,141,142,0,1,2,4,8,124,22,176,1,168,246,249,53,31,84,128,159,159,11,63,19,32,64,128,0,129,202,2,234,191,191,179,251,191,202,25,54,54,2,4,8,16,32,64,128,0,129,159,2,246,190,254,53,193,240,115,106,120,133,0,1,2,4,8,84,20,176,1,248,79,86,85,62,191,230,54,135,138,207,184,49,17,32,64,128,0,129,239,2,234,191,127,69,20,62,255,77,12,16,223,159,16,191,19,32,64,128,0,129,122,2,234,191,95,57,245,25,192,122,115,219,136,8,16,32,64,128,0,1,2,47,5,108,124,253,230,33,241,91,194,255,19,32,64,128,0,129,170,2,54,0,255,203,172,178,231,99,138,163,248,160,240,3,1,2,4,8,16,40,41,160,254,251,157,86,85,207,111,9,95,136,249,35,225,39,2,4,8,16,32,80,81,64,253,247,145,85,159,1,252,160,240,3,1,2,4,8,16,32,64,160,135,128,29,192,79,121,134,241,9,195,143,4,8,16,32,64,160,152,128,13,192,63,9,85,243,252,177,112,8,252,217,194,207,4,8,16,32,64,160,150,128,250,239,83,62,21,128,159,48,84,128,95,48,252,66,128,0,1,2,4,10,9,168,255,62,39,
83,1,248,89,67,5,248,85,195,111,4,8,16,32,64,160,138,128,250,239,75,38,125,9,228,11,135,95,8,16,32,64,128,0,1,2,245,5,236,0,126,203,49,144,111,32,126,37,64,128,0,1,2,5,4,108,0,126,77,162,122,231,171,135,67,224,239,30,126,39,64,128,0,1,2,249,5,212,127,223,114,168,0,252,6,162,2,252,1,226,5,2,4,8,16,32,144,92,64,253,247,61,129,62,3,248,93,196,239,4,8,16,32,64,128,0,129,226,2,118,0,127,38,152,201,79,19,175,16,32,64,128,0,129,188,2,54,0,127,228,78,177,243,131,196,33,240,3,18,47,17,32,64,128,0,129,180,2,234,191,159,169,83,0,254,52,81,1,62,50,241,26,1,2,4,8,16,200,41,160,254,123,144,55,159,1,124,128,226,37,2,4,8,16,32,64,128,64,101,1,59,128,15,179,139,229,33,139,23,9,16,32,64,128,64,58,1,27,128,143,82,166,210,121,164,226,16,248,177,138,87,9,16,32,64,128,64,54,1,245,223,195,140,41,0,31,178,168,0,159,176,120,153,0,1,2,4,8,164,18,80,255,61,78,151,2,240,177,139,10,240,153,139,215,9,16,32,64,128,64,30,1,245,223,147,92,249,18,200,19,24,47,19,32,64,128,0,1,2,4,170,10,216,1,124,154,89,52,79,
105,188,65,128,0,1,2,4,82,8,216,0,124,150,38,85,206,51,25,135,192,207,101,188,67,128,0,1,2,4,50,8,168,255,158,102,73,1,248,148,70,5,248,130,198,91,4,8,16,32,64,32,188,128,250,239,121,138,20,128,207,109,84,128,175,108,188,71,128,0,1,2,4,98,11,168,255,94,228,199,151,64,94,224,120,139,0,1,2,4,8,16,32,80,81,192,14,224,203,172,226,121,201,227,77,2,4,8,16,32,16,86,192,6,224,171,212,168,112,94,233,56,4,126,173,227,93,2,4,8,16,32,16,85,64,253,247,50,51,10,192,151,60,42,192,55,60,222,38,64,128,0,1,2,33,5,212,127,175,211,162,0,124,237,163,2,124,231,227,125,2,4,8,16,32,16,79,64,253,247,38,39,190,4,242,6,200,219,4,8,16,32,64,128,0,129,106,2,118,0,223,102,20,209,91,34,23,16,32,64,128,0,129,80,2,54,0,223,165,67,117,243,78,200,33,240,123,33,87,16,32,64,128,0,129,72,2,234,191,183,217,80,0,190,37,82,1,30,32,114,9,1,2,4,8,16,8,35,160,254,123,159,10,5,224,123,35,21,224,17,35,215,16,32,64,128,0,129,24,2,234,191,3,121,240,37,144,3,72,46,33,64,128,0,1,2,4,8,84,18,176,3,120,40,155,152,14,49,185,136,
0,1,2,4,8,108,23,176,1,120,36,5,42,155,35,74,14,129,143,41,185,138,0,1,2,4,8,236,22,80,255,29,202,128,2,240,16,147,10,240,32,147,203,8,16,32,64,128,192,86,1,245,223,49,126,5,224,49,39,21,224,81,39,215,17,32,64,128,0,129,125,2,234,191,131,246,190,4,114,16,202,101,4,8,16,32,64,128,0,129,42,2,118,0,15,103,18,213,97,42,23,18,32,64,128,0,129,45,2,54,0,143,178,171,106,142,74,57,4,62,46,229,74,2,4,8,16,32,176,67,64,253,119,88,93,1,120,152,74,5,120,130,202,165,4,8,16,32,64,96,185,128,250,239,56,185,2,240,184,149,10,240,140,149,107,9,16,32,64,128,192,90,1,245,223,9,111,5,224,9,44,21,224,41,44,23,19,32,64,128,0,129,133,2,234,191,51,216,190,5,124,70,203,181,4,8,16,32,64,128,0,129,2,2,118,0,207,37,145,215,57,47,87,19,32,64,128,0,129,53,2,54,0,79,57,43,104,78,113,57,4,62,201,229,114,2,4,8,16,32,176,68,64,253,119,142,89,1,120,206,75,5,120,214,203,245,4,8,16,32,64,96,190,128,250,239,164,177,2,240,36,152,10,240,52,152,27,8,16,32,64,128,192,100,1,245,223,89,96,5,224,89,49,21,224,121,49,119,16,
32,64,128,0,129,153,2,234,191,211,186,190,5,124,154,204,13,4,8,16,32,64,128,0,129,220,2,118,0,47,228,15,218,5,52,183,16,32,64,128,0,129,73,2,54,0,207,195,170,101,206,155,57,4,190,98,230,30,2,4,8,16,32,48,71,64,253,119,193,85,1,120,1,77,5,120,9,205,77,4,8,16,32,64,96,130,128,250,239,10,170,2,240,138,154,10,240,154,154,187,8,16,32,64,128,192,104,1,245,223,37,81,5,224,37,54,21,224,69,54,183,17,32,64,128,0,129,161,2,234,191,107,156,190,5,124,205,205,93,4,8,16,32,64,128,0,129,180,2,118,0,175,166,142,220,85,57,247,17,32,64,128,0,129,81,2,54,0,47,74,42,99,46,194,57,4,190,12,231,70,2,4,8,16,32,48,72,64,253,119,21,82,1,120,85,78,5,120,93,206,157,4,8,16,32,64,96,132,128,250,239,178,162,2,240,50,157,10,240,6,157,91,9,16,32,64,128,192,109,1,245,223,117,66,5,224,117,59,21,224,29,59,247,18,32,64,128,0,129,123,2,234,191,27,126,10,192,27,120,42,192,91,120,110,38,64,128,0,1,2,55,4,212,127,55,240,254,242,207,192,220,209,115,47,1,2,4,8,16,32,64,32,161,128,29,192,123,73,227,119,207,207,221,4,8,16,
32,64,224,154,128,13,192,107,110,255,221,165,128,185,197,231,16,248,38,159,219,9,16,32,64,128,192,37,1,245,223,37,182,143,155,20,128,31,20,23,127,32,120,17,206,109,4,8,16,32,64,224,178,128,250,239,50,221,175,27,149,47,55,1,237,1,222,6,212,0,1,2,4,8,16,56,41,160,254,59,9,246,227,114,5,224,15,146,211,47,48,60,77,230,6,2,4,8,16,32,112,67,64,253,119,3,239,215,173,138,151,219,132,246,0,7,16,106,130,0,1,2,4,8,28,22,80,255,29,166,122,122,161,2,240,41,205,137,55,40,158,192,114,41,1,2,4,8,16,184,37,160,254,187,197,247,235,102,255,14,224,0,68,77,16,32,64,128,0,1,2,4,50,9,216,187,26,146,45,140,67,24,53,66,128,0,1,2,4,222,10,216,0,124,75,116,224,2,149,203,1,164,3,151,112,60,128,228,18,2,4,8,16,32,112,91,64,253,119,155,240,159,6,20,46,67,24,65,14,98,212,12,1,2,4,8,16,120,41,160,254,123,201,115,248,77,5,224,97,170,55,23,146,124,3,228,109,2,4,8,16,32,112,91,64,253,119,155,240,87,3,202,150,65,144,246,0,135,65,106,136,0,1,2,4,8,60,17,80,255,61,129,57,253,178,2,240,52,217,211,27,88,62,165,241,
6,1,2,4,8,16,24,32,160,254,27,128,248,171,9,69,203,48,74,123,128,3,41,53,69,128,0,1,2,4,126,8,168,255,126,144,92,126,193,191,3,120,153,206,141,4,8,16,32,64,128,0,129,156,2,118,0,71,230,141,230,72,77,109,17,32,64,128,0,129,207,2,54,0,63,107,220,252,89,201,114,19,240,235,237,56,191,122,248,141,0,1,2,4,8,140,18,80,255,141,146,252,167,29,21,203,72,77,158,99,53,181,70,128,0,1,2,4,126,11,168,255,126,75,12,249,127,5,224,16,198,63,141,0,253,99,225,39,2,4,8,16,32,48,74,64,253,55,74,242,87,59,234,149,177,158,246,0,71,123,106,143,0,1,2,4,8,252,245,151,250,111,240,44,80,0,14,6,85,1,14,7,213,32,1,2,4,8,180,23,80,255,141,158,2,10,192,209,162,42,192,241,162,90,36,64,128,0,129,222,2,234,191,225,249,87,0,14,39,85,1,78,32,213,36,1,2,4,8,52,22,80,255,141,79,190,2,112,188,169,10,112,134,169,54,9,16,32,64,160,171,128,250,111,66,230,253,151,64,38,160,106,146,0,1,2,4,8,16,32,16,89,192,14,224,148,236,96,157,194,170,81,2,4,8,16,104,40,96,3,112,70,210,85,42,51,84,29,2,207,81,213,42,1,2,4,8,244,19,80,255,
77,201,185,2,112,10,171,10,112,18,171,102,9,16,32,64,160,153,128,250,111,78,194,21,128,115,92,85,128,179,92,181,75,128,0,1,2,157,4,212,127,147,178,173,0,156,4,171,2,156,6,171,97,2,4,8,16,104,35,160,254,155,149,106,5,224,44,89,21,224,60,89,45,19,32,64,128,64,15,1,245,223,180,60,43,0,167,209,170,0,39,210,106,154,0,1,2,4,26,8,168,255,230,37,89,1,56,207,86,5,56,211,86,219,4,8,16,32,80,93,64,253,55,49,195,10,192,137,184,42,192,169,184,26,39,64,128,0,129,210,2,234,191,153,233,85,0,206,212,85,1,206,213,213,58,1,2,4,8,212,21,80,255,77,205,173,2,112,42,175,10,112,50,175,230,9,16,32,64,160,168,128,250,111,110,98,21,128,115,125,85,128,179,125,181,79,128,0,1,2,21,5,212,127,147,179,170,0,156,12,172,2,156,14,172,3,2,4,8,16,40,39,160,254,155,157,210,255,205,238,64,251,4,8,16,32,64,128,0,1,2,177,4,236,0,206,207,7,227,249,198,122,32,64,128,0,129,74,2,54,0,167,103,83,113,50,157,216,33,240,2,98,93,16,32,64,128,64,33,1,245,223,252,100,42,0,231,27,171,0,87,24,235,131,0,1,2,4,170,8,168,255,22,100,
82,1,184,0,89,5,184,4,89,39,4,8,16,32,80,66,64,253,183,34,141,10,192,21,202,42,192,53,202,122,33,64,128,0,129,252,2,234,191,37,57,84,0,46,97,86,1,46,98,214,13,1,2,4,8,36,23,80,255,173,73,160,2,112,141,179,10,112,149,179,126,8,16,32,64,32,179,128,250,111,81,246,20,128,139,160,85,128,203,160,117,68,128,0,1,2,105,5,212,127,171,82,167,0,92,37,173,2,92,39,173,39,2,4,8,16,200,41,160,254,91,150,55,5,224,50,106,21,224,66,106,93,17,32,64,128,64,66,1,245,223,186,164,41,0,215,89,171,0,87,90,235,139,0,1,2,4,178,9,168,255,22,102,76,1,184,16,91,5,184,20,91,103,4,8,16,32,144,74,64,253,183,50,93,10,192,149,218,42,192,181,218,122,35,64,128,0,129,60,2,234,191,165,185,82,0,46,229,86,1,46,230,214,29,1,2,4,8,36,17,80,255,173,77,148,2,112,173,183,10,112,181,183,254,8,16,32,64,32,131,128,250,111,113,150,20,128,139,193,85,128,203,193,117,72,128,0,1,2,225,5,212,127,171,83,164,0,92,45,174,2,92,47,174,71,2,4,8,16,136,45,160,254,91,158,31,5,224,114,114,21,224,6,114,93,18,32,64,128,64,96,1,245,223,250,228,
40,0,215,155,171,0,119,152,235,147,0,1,2,4,162,10,168,255,54,100,70,1,184,1,93,5,184,5,93,167,4,8,16,32,16,82,64,253,183,35,45,10,192,29,234,42,192,61,234,122,37,64,128,0,129,120,2,234,191,45,57,81,0,110,97,87,1,110,98,215,45,1,2,4,8,4,19,80,255,237,73,136,2,112,143,187,10,112,151,187,126,9,16,32,64,32,146,128,250,111,83,54,20,128,155,224,85,128,219,224,117,76,128,0,1,2,97,4,212,127,187,82,161,0,220,37,175,2,220,39,175,103,2,4,8,16,136,33,160,254,219,150,7,5,224,54,122,21,224,70,122,93,19,32,64,128,64,0,1,245,223,190,36,40,0,247,217,171,0,119,218,235,155,0,1,2,4,118,11,168,255,54,102,64,1,184,17,95,5,184,21,95,231,4,8,16,32,176,85,64,253,183,147,95,1,184,83,95,5,184,87,95,239,4,8,16,32,176,79,64,253,183,207,254,239,158,21,128,91,249,37,96,51,191,238,9,16,32,64,96,147,128,250,111,19,252,127,221,42,0,247,250,171,0,119,251,235,159,0,1,2,4,118,8,168,255,118,168,127,234,83,1,248,9,99,207,143,82,176,199,93,175,4,8,16,32,176,79,64,253,183,207,254,87,207,170,143,221,25,176,7,184,63,3,
34,32,64,128,0,129,181,2,234,191,181,222,15,122,83,0,62,64,89,253,146,36,172,22,215,31,1,2,4,8,236,20,80,255,237,212,255,213,183,218,99,127,14,236,1,70,200,129,24,8,16,32,64,96,149,128,250,111,149,244,139,126,20,128,47,112,214,189,37,13,235,172,245,68,128,0,1,2,123,5,212,127,123,253,127,245,174,242,136,144,5,123,128,49,178,32,10,2,4,8,16,152,47,160,254,155,111,124,160,7,5,224,1,164,21,151,72,196,10,101,125,16,32,64,128,192,110,1,245,223,238,12,252,234,95,221,17,35,15,246,0,163,228,65,28,4,8,16,32,48,83,64,253,55,83,247,68,219,10,192,19,88,115,47,149,138,185,190,90,39,64,128,0,129,253,2,234,191,253,57,248,21,129,170,35,74,38,236,1,198,201,132,72,8,16,32,64,96,142,128,250,111,142,235,133,86,21,128,23,208,102,221,34,25,179,100,181,75,128,0,1,2,17,4,212,127,17,178,240,43,6,53,71,156,92,216,3,140,148,11,177,16,32,64,128,192,104,1,245,223,104,209,27,237,41,0,111,224,141,191,85,58,198,155,106,145,0,1,2,4,98,8,168,255,98,228,225,87,20,42,142,72,217,176,7,24,43,27,162,33,64,128,0,129,
113,2,234,191,113,150,3,90,82,0,14,64,28,217,132,132,140,212,212,22,1,2,4,8,68,17,80,255,69,201,196,175,56,212,27,177,242,97,15,48,90,62,196,67,128,0,1,2,35,4,212,127,35,20,7,182,161,0,28,136,57,166,41,41,25,227,168,21,2,4,8,16,136,35,160,254,139,147,139,95,145,168,54,162,101,196,30,96,188,140,136,136,0,1,2,4,238,9,168,255,238,249,77,184,91,1,56,1,245,110,147,146,114,87,208,253,4,8,16,32,16,73,64,253,23,41,27,191,98,81,107,196,203,137,61,192,136,57,17,19,1,2,4,8,92,21,80,255,93,149,155,120,159,2,112,34,238,245,166,165,229,186,157,59,9,16,32,64,32,150,128,250,47,86,62,126,69,163,210,136,152,21,123,128,49,179,34,42,2,4,8,16,56,47,160,254,59,111,182,224,14,5,224,2,228,43,93,72,204,21,53,247,16,32,64,128,64,52,1,245,95,180,140,252,138,71,157,17,51,47,246,0,163,230,69,92,4,8,16,32,112,70,64,253,119,70,107,225,181,10,192,133,216,39,187,146,155,147,96,46,39,64,128,0,129,96,2,202,191,96,9,249,19,142,34,227,143,69,184,159,36,39,92,74,4,68,128,0,1,2,39,4,212,127,39,176,22,95,170,198,88,
12,126,170,59,217,57,197,229,98,2,4,8,16,8,37,160,254,11,149,142,175,193,40,49,190,122,4,251,77,122,130,37,68,56,4,8,16,32,112,88,64,253,119,152,106,195,133,42,140,13,232,39,186,148,159,19,88,46,37,64,128,0,129,64,2,234,191,64,201,248,25,138,2,227,167,73,168,87,36,40,84,58,4,67,128,0,1,2,7,5,212,127,7,161,54,93,166,190,216,4,127,184,91,25,58,76,229,66,2,4,8,16,8,35,160,254,11,147,138,199,129,40,47,30,187,4,122,85,138,2,37,67,40,4,8,16,32,112,72,64,253,119,136,105,227,69,170,139,141,248,7,187,150,163,131,80,46,35,64,128,0,129,32,2,234,191,32,137,120,30,134,226,226,185,77,152,119,36,41,76,42,4,66,128,0,1,2,7,4,212,127,7,144,54,95,162,182,216,156,128,67,221,203,210,33,38,23,17,32,64,128,64,8,1,245,95,136,52,188,14,66,105,241,218,39,200,187,210,20,36,17,194,32,64,128,0,129,183,2,234,191,183,68,1,46,80,89,4,72,194,129,16,228,233,0,146,75,8,16,32,64,32,128,128,250,47,64,18,222,135,160,176,120,111,20,227,10,153,138,145,7,81,16,32,64,128,192,43,1,229,223,43,157,64,239,41,43,2,37,227,
117,40,82,245,218,199,187,4,8,16,32,176,95,64,253,183,63,7,199,34,80,85,28,115,138,112,149,92,69,200,130,24,8,16,32,64,224,185,128,250,239,185,77,176,119,20,21,193,18,242,42,28,201,122,165,227,61,2,4,8,16,216,45,160,254,219,157,129,227,253,171,41,142,91,237,191,82,182,246,231,64,4,4,8,16,32,240,76,64,253,247,76,38,224,235,74,138,128,73,121,30,146,116,61,183,241,14,1,2,4,8,236,21,80,255,237,245,63,215,187,138,226,156,215,238,171,229,107,119,6,244,79,128,0,1,2,143,5,212,127,143,93,130,190,170,160,8,154,152,103,97,73,216,51,25,175,19,32,64,128,192,78,1,245,223,78,253,243,125,171,39,206,155,237,189,67,198,246,250,235,157,0,1,2,4,30,9,168,255,30,169,4,126,77,57,17,56,57,79,66,147,179,39,48,94,38,64,128,0,129,77,2,202,191,77,240,215,187,85,76,92,183,219,118,167,164,109,163,215,49,1,2,4,8,60,16,80,255,61,64,9,254,146,90,34,120,130,30,134,39,107,15,89,188,72,128,0,1,2,91,4,212,127,91,216,239,117,170,148,184,231,183,233,110,105,219,4,175,91,2,4,8,16,248,33,160,254,251,65,146,224,5,149,
68,130,36,61,8,81,222,30,160,120,137,0,1,2,4,54,8,168,255,54,160,223,239,82,33,113,223,112,75,11,18,183,133,93,167,4,8,16,32,240,77,64,253,247,13,36,201,175,234,136,36,137,250,17,166,204,253,32,241,2,1,2,4,8,44,23,80,255,45,39,31,211,161,50,98,140,227,142,86,228,110,135,186,62,9,16,32,64,224,143,128,242,239,143,69,178,159,20,17,201,18,246,57,92,201,251,172,225,103,2,4,8,16,88,45,160,254,91,45,62,174,63,53,196,56,203,245,45,201,222,122,115,61,18,32,64,128,192,111,1,245,223,111,137,132,255,175,132,72,152,180,63,33,75,223,31,11,63,17,32,64,128,192,90,1,245,223,90,239,177,189,169,32,198,122,174,110,77,254,86,139,235,143,0,1,2,4,126,9,168,255,82,207,4,5,68,234,244,253,245,151,4,38,79,160,240,9,16,32,144,84,64,253,151,52,113,255,133,173,126,200,157,63,21,96,246,252,137,159,0,1,2,57,5,212,127,57,243,246,17,181,2,240,131,34,237,15,114,152,54,117,2,39,64,128,64,82,1,229,95,210,196,253,9,91,241,240,199,34,237,79,146,152,54,117,2,39,64,128,64,74,1,245,95,202,180,125,9,90,237,240,133,35,
233,47,178,152,52,113,194,38,64,128,64,74,1,245,95,202,180,125,13,90,233,240,213,35,233,111,210,152,52,113,194,38,64,128,64,66,1,245,95,194,164,253,8,89,229,240,131,36,229,11,242,152,50,109,130,38,64,128,64,66,1,245,95,194,164,253,12,89,225,240,211,36,229,43,18,153,50,109,130,38,64,128,64,58,1,245,95,186,148,61,12,88,221,240,144,37,227,139,82,153,49,107,98,38,64,128,64,46,1,229,95,174,124,61,143,86,213,240,220,38,219,59,114,153,45,99,226,37,64,128,64,54,1,245,95,182,140,61,141,87,209,240,148,38,223,27,146,153,47,103,34,38,64,128,64,38,1,245,95,166,108,189,142,85,205,240,218,39,215,187,178,153,43,95,162,37,64,128,64,46,1,245,95,174,124,189,140,86,201,240,146,39,219,155,210,153,45,99,226,37,64,128,64,30,1,245,95,158,92,189,143,84,197,240,222,40,213,21,18,154,42,93,130,37,64,128,64,26,1,229,95,154,84,29,10,84,189,112,136,41,209,69,50,154,40,89,66,37,64,128,64,26,1,245,95,154,84,29,11,84,185,112,204,41,209,85,82,154,40,89,66,37,64,128,64,18,1,245,95,146,68,29,14,83,181,112,152,42,
205,133,114,154,38,85,2,37,64,128,64,18,1,245,95,146,68,29,15,83,177,112,220,42,205,149,146,154,38,85,2,37,64,128,64,10,1,245,95,138,52,157,10,82,173,112,138,43,203,197,210,154,37,83,226,36,64,128,64,124,1,229,95,252,28,157,143,80,165,112,222,44,195,29,242,154,33,75,98,36,64,128,64,6,1,245,95,134,44,157,142,81,161,112,154,44,199,13,18,155,35,79,162,36,64,128,64,116,1,245,95,244,12,93,139,79,157,112,205,45,254,93,50,27,63,71,34,36,64,128,64,124,1,245,95,252,28,93,138,80,153,112,137,45,195,77,82,155,33,75,98,36,64,128,64,108,1,245,95,236,252,92,143,78,149,112,221,46,252,157,146,27,62,69,2,36,64,128,64,104,1,229,95,232,244,220,10,78,141,112,139,47,248,205,178,27,60,65,194,35,64,128,64,104,1,245,95,232,244,220,11,78,137,112,207,47,248,221,210,27,60,65,194,35,64,128,64,96,1,245,95,224,228,220,14,77,133,112,155,48,116,3,242,27,58,61,130,35,64,128,64,96,1,245,95,224,228,220,15,77,129,112,223,48,118,11,50,28,59,63,162,35,64,128,64,76,1,229,95,204,188,12,139,74,121,48,140,50,106,67,82,
28,53,51,226,34,64,128,64,92,1,245,95,220,220,140,137,76,117,48,198,49,114,43,114,28,57,59,98,35,64,128,64,68,1,245,95,196,172,12,141,73,113,48,148,51,102,99,146,28,51,47,162,34,64,128,64,84,1,245,95,212,204,140,139,75,109,48,206,50,112,75,210,28,56,57,66,35,64,128,64,48,1,229,95,176,132,76,9,71,101,48,133,53,92,163,242,28,46,37,2,34,64,128,64,80,1,245,95,208,196,140,13,75,97,48,214,51,108,107,18,29,54,53,2,35,64,128,64,40,1,245,95,168,116,76,11,70,93,48,141,54,88,195,50,29,44,33,194,33,64,128,64,72,1,245,95,200,180,140,15,74,89,48,222,52,106,139,114,29,53,51,226,34,64,128,64,20,1,229,95,148,76,76,143,67,81,48,157,56,78,7,146,29,39,23,34,33,64,128,64,68,1,245,95,196,172,204,137,73,77,48,199,53,102,171,178,29,51,47,162,34,64,128,64,12,1,245,95,140,60,44,137,66,73,176,132,57,74,39,210,29,37,19,226,32,64,128,64,60,1,245,95,188,156,204,139,72,69,48,207,54,100,203,18,30,50,45,130,34,64,128,192,118,1,229,223,246,20,44,13,64,61,176,148,59,64,103,50,30,32,9,66,32,64,128,64,56,1,245,95,
184,148,204,13,72,57,48,215,55,96,235,82,30,48,41,66,34,64,128,192,102,1,245,223,230,4,44,239,94,53,176,156,124,123,135,114,190,61,5,2,32,64,128,64,48,1,245,95,176,132,204,15,71,49,48,223,56,94,15,178,30,47,39,34,34,64,128,192,62,1,229,223,62,251,109,61,43,5,182,209,239,236,88,218,119,234,235,155,0,1,2,177,4,212,127,177,242,177,38,26,149,192,26,231,104,189,200,123,180,140,136,135,0,1,2,187,4,212,127,187,228,183,246,171,16,216,202,191,177,115,153,223,136,175,107,2,4,8,132,17,80,254,133,73,197,218,64,148,1,107,189,3,245,38,245,129,146,33,20,2,4,8,108,18,80,255,109,130,223,222,173,42,96,123,10,182,5,32,247,219,232,117,76,128,0,129,32,2,234,191,32,137,88,31,134,34,96,189,121,156,30,101,63,78,46,68,66,128,0,129,245,2,202,191,245,230,97,122,84,2,132,73,197,142,64,164,127,135,186,62,9,16,32,16,67,64,253,23,35,15,123,162,80,1,236,113,143,210,171,252,71,201,132,56,8,16,32,176,90,64,253,183,90,60,84,127,10,128,80,233,88,31,140,9,176,222,92,143,4,8,16,136,32,160,254,139,144,133,125,49,88,
255,247,217,7,233,217,20,8,146,8,97,16,32,64,96,161,128,242,111,33,118,200,174,172,254,33,211,178,52,40,115,96,41,183,206,8,16,32,16,64,64,253,23,32,9,123,67,176,248,239,245,15,209,187,73,16,34,13,130,32,64,128,192,50,1,245,223,50,234,176,29,89,251,195,166,102,101,96,166,193,74,109,125,17,32,64,96,175,128,242,111,175,127,140,222,173,252,49,242,176,59,10,243,96,119,6,244,79,128,0,129,85,2,234,191,85,210,161,251,177,240,135,78,207,186,224,76,132,117,214,122,34,64,128,192,78,1,245,223,78,253,56,125,91,247,227,228,98,115,36,166,194,230,4,232,158,0,1,2,11,4,148,127,11,144,83,116,97,213,79,145,166,37,65,154,11,75,152,117,66,128,0,129,141,2,234,191,141,248,177,186,182,232,199,202,199,222,104,204,134,189,254,122,39,64,128,192,92,1,229,223,92,223,84,173,91,242,83,165,107,118,176,166,195,108,97,237,19,32,64,96,159,128,250,111,159,125,188,158,173,248,241,114,178,51,34,243,97,167,190,190,9,16,32,48,83,64,253,55,83,55,93,219,22,252,116,41,155,28,176,25,49,25,88,243,4,8,16,216,34,160,252,219,
194,30,183,83,203,125,220,220,108,138,204,148,216,4,175,91,2,4,8,76,20,80,255,77,196,77,217,180,213,62,101,218,166,6,109,78,76,229,213,56,1,2,4,54,8,168,255,54,160,199,238,210,98,31,59,63,123,162,51,43,246,184,235,149,0,1,2,115,4,148,127,115,92,83,183,106,169,79,157,190,89,193,155,22,179,100,181,75,128,0,129,245,2,234,191,245,230,241,123,180,210,199,207,209,142,8,205,139,29,234,250,36,64,128,192,12,1,245,223,12,213,244,109,90,232,211,167,112,210,0,204,140,73,176,154,37,64,128,192,82,1,229,223,82,238,60,157,89,230,243,228,106,113,164,166,198,98,112,221,17,32,64,96,130,128,250,111,2,106,137,38,173,242,37,210,56,103,16,38,199,28,87,173,18,32,64,96,149,128,242,111,149,116,190,126,172,241,249,114,182,46,98,179,99,157,181,158,8,16,32,48,94,64,253,55,222,180,76,139,150,248,50,169,156,49,16,211,99,134,170,54,9,16,32,176,70,64,253,183,198,57,103,47,86,248,156,121,91,22,181,9,178,140,90,71,4,8,16,24,42,160,252,27,202,89,174,49,235,123,185,148,14,30,144,25,50,24,84,115,4,8,16,88,34,160,
254,91,194,156,183,19,203,123,222,220,173,138,220,28,89,37,173,31,2,4,8,140,18,80,254,141,146,44,219,142,197,189,108,106,199,13,204,36,25,103,169,37,2,4,8,172,16,80,255,173,80,206,221,135,181,61,119,254,22,69,111,154,44,130,214,13,1,2,4,6,8,40,255,6,32,150,111,194,202,94,62,197,67,6,104,158,12,97,212,8,1,2,4,22,8,168,255,22,32,231,239,194,194,158,63,135,75,70,96,162,44,97,214,9,1,2,4,110,11,168,255,110,19,182,104,192,186,222,34,205,35,6,105,170,140,80,212,6,1,2,4,230,10,40,255,230,250,214,105,221,170,94,39,151,179,71,98,174,204,22,214,62,1,2,4,238,10,168,255,238,10,182,185,223,162,222,38,213,3,6,106,182,12,64,212,4,1,2,4,166,9,40,255,166,209,214,107,216,146,94,47,167,19,71,100,186,76,196,213,52,1,2,4,110,10,168,255,110,2,182,186,221,138,222,42,221,247,7,107,194,220,55,212,2,1,2,4,102,8,40,255,102,168,214,109,211,122,94,55,183,115,70,102,198,204,113,213,42,1,2,4,238,9,168,255,238,249,181,187,219,114,222,46,229,119,7,108,202,220,21,116,63,1,2,4,198,11,168,255,198,155,214,110,209,
106,94,59,191,83,70,103,210,76,97,213,40,1,2,4,46,11,40,255,46,211,181,189,209,90,222,54,245,55,6,110,214,220,192,115,43,1,2,4,134,11,168,255,134,147,214,111,208,82,94,63,199,51,70,104,222,204,80,213,38,1,2,4,174,8,40,255,174,168,181,191,199,66,222,126,10,92,3,48,113,174,185,185,139,0,1,2,163,5,212,127,163,69,123,180,103,29,239,145,231,9,163,52,117,38,160,106,146,0,1,2,39,5,148,127,39,193,92,254,159,128,85,220,84,184,42,96,238,92,149,115,31,1,2,4,70,9,168,255,70,73,182,107,199,34,222,46,229,3,7,108,246,12,196,212,20,1,2,4,78,11,40,255,78,147,185,225,183,128,37,252,183,132,255,191,32,96,250,92,64,115,11,1,2,4,6,9,168,255,6,65,182,108,198,10,222,50,237,227,6,109,2,141,179,212,18,1,2,4,206,8,40,255,206,104,185,246,187,128,245,251,187,136,223,207,9,152,65,231,188,92,77,128,0,129,49,2,234,191,49,142,109,91,177,124,183,77,253,176,129,155,67,195,40,53,68,128,0,129,131,2,202,191,131,80,46,123,38,96,241,126,38,227,245,195,2,38,209,97,42,23,18,32,64,96,136,128,250,111,8,99,235,70,172,221,
173,211,63,106,240,166,209,40,73,237,16,32,64,224,189,128,242,239,189,145,43,222,9,88,185,223,9,121,255,136,128,121,116,68,201,53,4,8,16,24,33,160,254,27,161,216,190,13,11,119,251,41,48,8,192,76,26,4,169,25,2,4,8,188,20,80,254,189,228,241,230,81,1,203,246,81,41,215,189,17,48,149,222,0,121,155,0,1,2,3,4,212,127,3,16,53,241,183,128,85,219,52,24,38,96,50,13,163,212,16,1,2,4,30,10,40,255,30,178,120,241,130,128,53,251,2,154,91,158,8,152,77,79,96,188,76,128,0,129,33,2,234,191,33,140,26,249,71,192,146,109,30,140,20,48,159,70,106,106,139,0,1,2,159,5,148,127,159,53,252,124,83,192,130,125,19,208,237,223,4,204,168,111,32,126,37,64,128,192,16,1,229,223,16,70,141,252,22,176,92,255,150,240,255,131,4,76,169,65,144,154,33,64,128,192,39,1,245,223,39,12,63,14,16,176,90,15,64,212,196,87,1,147,234,171,135,223,8,16,32,112,87,64,249,119,87,208,253,223,5,172,213,223,69,252,126,95,192,172,186,111,168,5,2,4,8,252,17,80,255,253,177,240,211,32,1,75,245,32,72,205,124,17,48,175,190,112,248,133,0,1,2,55,4,
148,127,55,240,220,250,76,192,66,253,76,198,235,183,4,76,172,91,124,110,38,64,128,192,135,128,250,239,131,194,15,3,5,172,211,3,49,53,245,89,192,212,250,172,225,103,2,4,8,92,19,80,254,93,115,115,215,59,1,171,244,59,33,239,95,22,48,185,46,211,185,145,0,1,2,255,10,40,255,76,132,89,2,214,232,89,178,218,245,207,140,155,3,4,8,16,184,39,160,254,187,231,231,238,23,2,10,192,23,56,222,186,45,96,126,221,38,212,0,1,2,109,5,148,127,109,83,191,98,224,22,232,21,202,141,251,48,193,26,39,223,208,9,16,184,37,160,254,187,197,231,230,55,2,214,231,55,64,222,190,43,96,138,221,21,116,63,1,2,29,5,148,127,29,179,190,114,204,86,231,149,218,77,251,50,201,154,38,222,176,9,16,184,44,160,252,187,76,231,198,131,2,214,230,131,80,46,187,33,96,150,221,192,115,43,1,2,13,5,212,127,13,147,190,122,200,150,230,213,226,61,251,51,207,122,230,221,168,9,16,184,34,160,252,187,162,230,158,147,2,22,230,147,96,46,191,38,96,162,93,115,115,23,1,2,253,4,212,127,253,114,190,99,196,214,229,29,234,45,251,52,213,90,166,221,160,9,
16,56,41,160,252,59,9,230,242,139,2,86,229,139,112,110,59,47,96,178,157,55,115,7,1,2,189,4,148,127,189,242,189,115,180,214,228,157,250,221,250,54,219,186,101,220,120,9,16,56,39,160,254,59,231,229,234,27,2,150,228,27,120,110,61,45,96,190,157,38,115,3,1,2,109,4,148,127,109,82,29,97,160,22,228,8,89,232,20,131,25,215,41,219,198,74,128,192,113,1,229,223,113,43,87,14,16,176,28,15,64,212,196,25,1,83,238,140,150,107,9,16,232,34,160,254,235,146,233,40,227,180,26,71,201,68,163,56,76,186,70,201,54,84,2,4,14,9,40,255,14,49,185,104,160,128,181,120,32,166,166,142,10,152,118,71,165,92,71,128,64,7,1,229,95,135,44,71,27,163,149,56,90,70,122,196,99,222,245,200,179,81,18,32,112,68,64,253,119,68,201,53,131,5,44,196,131,65,53,119,80,192,204,59,8,229,50,2,4,138,11,40,255,138,39,56,234,240,44,195,81,51,83,63,46,115,175,126,142,141,144,0,129,119,2,202,191,119,66,222,159,36,96,17,158,4,171,217,247,2,38,223,123,35,87,16,32,80,91,64,253,87,59,191,145,71,103,13,142,156,157,242,177,153,126,229,83,108,128,
4,8,188,16,80,254,189,192,241,214,100,1,43,240,100,96,205,191,22,48,1,95,251,120,151,0,129,186,2,202,191,186,185,205,48,50,235,111,134,44,149,142,209,20,44,157,94,131,35,64,224,137,128,242,239,9,140,151,23,9,88,125,23,65,235,230,169,128,57,248,148,198,27,4,8,148,21,80,255,149,77,109,150,129,89,124,179,100,170,114,156,102,97,229,236,26,27,1,2,63,5,148,127,63,77,188,178,88,192,210,187,24,92,119,15,5,204,195,135,44,94,36,64,160,164,128,242,175,100,90,179,13,202,194,155,45,99,69,227,53,17,139,38,214,176,8,16,248,33,160,254,251,65,226,133,13,2,214,221,13,232,186,124,36,96,42,62,82,241,26,1,2,213,4,148,127,213,50,154,117,60,86,221,172,153,43,24,183,201,88,48,169,134,68,128,192,23,1,229,223,23,14,191,108,20,176,230,110,196,215,245,119,1,211,241,187,136,223,9,16,168,36,160,252,171,148,205,236,99,177,226,102,207,96,177,248,77,200,98,9,53,28,2,4,62,4,148,127,31,20,126,8,32,96,189,13,144,4,33,124,18,48,35,63,97,248,145,0,129,66,2,234,191,66,201,172,48,20,203,109,133,44,214,26,131,57,89,
43,159,70,67,128,192,63,2,202,63,243,32,152,128,197,54,88,66,132,243,183,128,89,105,26,16,32,80,75,64,249,87,43,159,37,70,99,169,45,145,198,114,131,48,47,203,165,212,128,8,52,22,80,254,53,78,126,220,161,91,104,227,230,166,117,100,38,102,235,244,27,60,129,82,2,234,191,82,233,44,51,24,235,108,153,84,86,27,136,169,89,45,163,198,67,160,167,128,242,175,103,222,227,143,218,42,27,63,71,109,35,52,57,219,166,222,192,9,148,17,80,254,149,73,101,185,129,88,99,203,165,180,210,128,76,207,74,217,52,22,2,253,4,148,127,253,114,158,103,196,86,216,60,185,106,25,169,9,218,50,237,6,77,160,132,128,242,175,68,26,203,14,194,250,90,54,181,85,6,102,138,86,201,164,113,16,232,37,160,252,235,149,239,124,163,181,186,230,203,89,183,136,205,209,110,25,55,94,2,21,4,212,127,21,178,88,122,12,22,215,210,233,45,50,56,179,180,72,34,13,131,64,27,1,229,95,155,84,231,29,168,165,53,111,238,58,69,110,158,118,202,182,177,18,200,46,160,252,203,158,193,22,241,91,88,91,164,185,192,32,205,212,2,73,52,4,2,45,4,148,127,45,210,
156,127,144,150,213,252,57,236,50,2,115,181,75,166,141,147,64,102,1,229,95,230,236,181,138,221,162,218,42,221,201,7,107,182,38,79,160,240,9,148,23,80,254,149,79,113,157,1,90,82,235,228,178,195,72,204,215,14,89,54,70,2,89,5,148,127,89,51,215,50,110,11,106,203,180,231,29,180,9,155,55,119,34,39,80,93,64,253,87,61,195,181,198,103,61,173,149,207,6,163,49,101,27,36,217,16,9,36,20,80,254,37,76,90,235,144,173,166,173,211,159,115,240,38,109,206,188,137,154,64,101,1,229,95,229,236,214,28,155,181,180,102,94,139,143,202,180,45,158,96,195,35,144,76,64,249,151,44,97,194,253,91,192,74,106,26,164,20,48,113,83,166,77,208,4,74,10,40,255,74,166,181,252,160,172,163,229,83,92,117,128,166,110,213,204,26,23,129,92,2,202,191,92,249,18,237,111,1,171,232,111,9,255,159,78,192,228,77,151,50,1,19,40,39,160,252,43,151,210,54,3,178,134,182,73,117,197,129,154,190,21,179,106,76,4,242,8,40,255,242,228,74,164,223,5,172,160,223,69,252,158,74,192,4,78,149,46,193,18,40,37,160,252,43,149,206,118,131,177,126,182,75,
121,181,1,155,194,213,50,106,60,4,114,8,40,255,114,228,73,148,207,4,172,158,207,100,188,158,70,192,36,78,147,42,129,18,40,35,160,252,43,147,202,182,3,177,118,182,77,125,165,129,155,198,149,178,105,44,4,226,11,40,255,226,231,72,132,239,4,172,156,239,132,188,159,66,192,68,78,145,38,65,18,40,33,160,252,43,145,198,246,131,176,110,182,159,2,85,0,76,229,42,153,52,14,2,177,5,148,127,177,243,35,186,163,2,86,205,163,82,174,11,47,96,50,135,79,145,0,9,164,23,80,254,165,79,161,1,252,39,96,205,52,21,10,9,152,206,133,146,105,40,4,2,10,40,255,2,38,69,72,23,5,172,152,23,225,220,22,83,192,132,142,153,23,81,17,168,32,160,252,171,144,69,99,248,45,96,189,252,45,225,255,139,8,152,210,69,18,105,24,4,130,9,40,255,130,37,68,56,55,5,172,150,55,1,221,30,79,192,164,142,151,19,17,17,200,46,160,252,203,158,65,241,127,23,176,86,126,23,241,123,1,1,211,186,64,18,13,129,64,32,1,229,95,160,100,8,101,144,128,149,114,16,164,102,98,9,152,216,177,242,33,26,2,153,5,148,127,153,179,39,246,103,2,214,201,103,50,94,79,
46,96,106,39,79,160,240,9,4,17,80,254,5,73,132,48,6,11,88,37,7,131,106,46,142,128,201,29,39,23,34,33,144,85,64,249,151,53,115,226,126,39,96,141,124,39,228,253,196,2,166,119,226,228,9,157,64,0,1,229,95,128,36,8,97,146,128,21,114,18,172,102,99,8,152,224,49,242,32,10,2,25,5,148,127,25,179,38,230,163,2,214,199,163,82,174,203,42,96,142,103,205,156,184,9,236,20,80,253,237,212,215,247,2,1,139,227,2,100,93,108,22,48,203,55,39,64,247,4,210,9,40,255,210,165,76,192,103,5,44,141,103,197,92,159,81,192,60,207,152,53,49,19,216,37,160,252,219,37,175,223,133,2,22,198,133,216,186,218,40,96,166,111,196,215,53,129,84,2,202,191,84,233,18,236,85,1,203,226,85,57,247,101,19,48,215,179,101,76,188,4,118,8,40,255,118,168,235,115,131,128,69,113,3,186,46,55,9,152,237,155,224,117,75,32,141,128,242,47,77,170,4,122,87,192,146,120,87,208,253,169,4,76,248,84,233,18,44,129,165,2,170,191,165,220,58,219,44,96,61,220,156,0,221,175,22,48,229,87,139,235,143,64,14,1,229,95,142,60,137,114,148,128,213,112,148,164,118,
210,8,152,244,105,82,37,80,2,203,4,148,127,203,168,117,20,68,192,90,24,36,17,194,88,41,96,218,175,212,214,23,129,248,2,202,191,248,57,18,225,104,1,43,225,104,81,237,165,16,48,241,83,164,73,144,4,150,8,40,255,150,48,235,36,152,128,117,48,88,66,132,179,76,192,220,95,70,173,35,2,129,5,84,127,129,147,35,180,153,2,22,193,153,186,218,142,45,96,246,199,206,143,232,8,204,23,80,254,205,55,214,67,80,1,75,96,208,196,8,107,137,128,249,191,132,89,39,4,130,10,40,255,130,38,70,88,43,4,44,128,43,148,245,17,87,192,19,16,55,55,34,35,48,87,64,249,55,215,87,235,193,5,44,127,193,19,36,188,249,2,30,130,249,198,122,32,16,77,64,245,23,45,35,226,89,45,96,237,91,45,174,191,128,2,30,131,128,73,17,18,129,137,2,202,191,137,184,154,78,34,96,229,75,146,40,97,206,21,240,32,204,245,213,58,129,72,2,202,191,72,217,16,203,46,1,235,222,46,121,253,70,19,240,44,68,203,136,120,8,204,16,80,253,205,80,213,102,66,1,139,94,194,164,9,121,146,128,167,97,18,172,102,9,132,17,80,254,133,73,133,64,118,11,88,242,118,103,64,255,
145,4,60,15,145,178,33,22,2,163,5,148,127,163,69,181,151,88,192,130,151,56,121,66,159,33,224,145,152,161,170,77,2,251,5,84,127,251,115,32,130,72,2,86,187,72,217,16,75,8,1,15,69,136,52,8,130,192,80,1,229,223,80,78,141,21,16,176,214,21,72,162,33,140,22,240,88,140,22,213,30,129,189,2,202,191,189,254,122,143,40,96,165,139,152,21,49,237,23,240,100,236,207,129,8,8,140,17,80,253,141,113,212,74,49,1,203,92,177,132,26,206,48,1,207,198,48,74,13,17,216,40,160,252,219,136,175,235,200,2,22,185,200,217,17,219,102,1,143,199,230,4,232,158,192,77,1,213,223,77,64,183,23,22,176,194,21,78,174,161,221,23,240,128,220,55,212,2,129,93,2,202,191,93,242,250,205,32,96,125,203,144,37,49,238,20,240,140,236,212,215,55,129,171,2,170,191,171,114,238,107,34,96,113,107,146,104,195,188,33,224,41,185,129,231,86,2,91,4,148,127,91,216,117,154,73,192,210,150,41,91,98,221,38,224,65,217,70,175,99,2,167,5,84,127,167,201,220,208,80,192,186,214,48,233,134,124,69,192,163,114,69,205,61,4,214,11,40,255,214,155,235,49,163,
128,85,45,99,214,196,188,71,192,211,178,199,93,175,4,142,11,168,254,142,91,185,178,185,128,37,173,249,4,48,252,83,2,158,151,83,92,46,38,176,88,64,249,183,24,92,119,153,5,44,104,153,179,39,246,13,2,30,153,13,232,186,36,112,64,64,245,119,0,201,37,4,62,4,172,102,31,20,126,32,112,76,192,67,115,204,201,85,4,86,10,40,255,86,106,235,171,130,128,181,172,66,22,141,97,181,128,231,102,181,184,254,8,188,18,80,253,189,210,241,30,129,135,2,22,178,135,44,94,36,240,70,192,147,243,6,200,219,4,150,9,40,255,150,81,235,168,146,128,101,172,82,54,141,101,169,128,135,103,41,183,206,8,60,20,80,253,61,100,241,34,129,183,2,214,176,183,68,46,32,240,84,192,243,243,148,198,27,4,22,8,168,254,22,32,235,162,170,128,5,172,106,102,141,107,141,128,39,104,141,179,94,8,252,20,80,254,253,52,241,10,129,195,2,150,175,195,84,46,36,240,88,192,67,244,216,197,171,4,102,10,168,254,102,234,106,187,131,128,181,171,67,150,141,113,182,128,231,104,182,176,246,9,124,22,80,253,125,214,240,51,129,75,2,22,174,75,108,110,34,240,77,
192,147,244,13,196,175,4,166,9,40,255,166,209,106,184,147,128,101,171,83,182,141,117,170,128,135,105,42,175,198,9,252,43,160,250,51,17,8,140,17,176,102,141,113,212,10,129,127,4,60,79,230,1,129,153,2,170,191,153,186,218,110,38,96,193,106,150,112,195,157,45,224,145,154,45,172,253,174,2,170,191,174,153,55,238,57,2,86,171,57,174,90,237,44,224,169,234,156,125,99,159,35,160,250,155,227,170,213,198,2,150,170,198,201,55,244,105,2,158,171,105,180,26,110,41,160,252,107,153,118,131,158,43,96,161,154,235,171,245,182,2,30,173,182,169,55,240,193,2,170,191,193,160,154,35,240,175,128,85,202,68,32,48,75,192,211,53,75,86,187,125,4,84,127,125,114,109,164,139,5,44,81,139,193,117,215,75,192,3,214,43,223,70,59,86,64,245,55,214,83,107,4,62,11,88,159,62,107,248,153,192,120,1,207,216,120,83,45,118,16,80,253,117,200,178,49,110,20,176,56,109,196,215,117,23,1,143,89,151,76,27,231,40,1,213,223,40,73,237,16,120,38,96,101,122,38,227,117,2,35,5,60,105,35,53,181,85,91,64,245,87,59,191,70,23,68,192,178,20,36,
17,194,168,47,224,97,171,159,99,35,188,47,160,250,187,111,168,5,2,71,4,172,73,71,148,92,67,96,140,128,231,109,140,163,86,170,10,168,254,170,102,214,184,2,10,88,144,2,38,69,72,149,5,60,114,149,179,107,108,119,4,84,127,119,244,220,75,224,172,128,213,232,172,152,235,9,220,21,240,212,221,21,116,127,61,1,213,95,189,156,26,81,112,1,75,81,240,4,9,175,166,128,7,175,102,94,141,234,154,128,234,239,154,155,187,8,220,17,176,14,221,209,115,47,129,235,2,158,189,235,118,238,172,36,160,250,171,148,77,99,73,36,96,17,74,148,44,161,86,19,240,248,85,203,168,241,156,21,80,253,157,21,115,61,129,81,2,86,160,81,146,218,33,112,69,192,19,120,69,205,61,53,4,84,127,53,242,104,20,73,5,44,63,73,19,39,236,58,2,30,194,58,185,52,146,227,2,170,191,227,86,174,36,48,67,192,218,51,67,85,155,4,78,10,120,16,79,130,185,60,181,128,226,47,117,250,4,95,68,192,186,83,36,145,134,145,94,192,179,152,62,133,6,112,72,64,245,119,136,201,69,4,102,11,88,116,102,11,107,159,192,97,1,143,227,97,42,23,38,21,80,253,37,77,156,176,11,
10,88,113,10,38,213,144,18,11,120,34,19,39,79,232,111,4,84,127,111,128,188,77,96,165,128,229,102,165,182,190,8,28,17,240,84,30,81,114,77,46,1,197,95,174,124,137,182,129,128,165,166,65,146,13,49,159,128,7,51,95,206,68,252,92,64,245,247,220,198,59,4,118,9,88,103,118,201,235,151,192,27,1,15,231,27,32,111,167,16,80,252,165,72,147,32,27,10,88,99,26,38,221,144,211,8,120,62,211,164,74,160,15,5,84,127,15,89,188,72,32,130,128,5,38,66,22,196,64,224,169,128,71,244,41,141,55,130,11,168,254,130,39,72,120,205,5,172,46,205,39,128,225,103,16,240,152,102,200,146,24,63,11,40,254,62,107,248,153,64,68,1,43,75,196,172,136,137,192,15,1,143,234,15,18,47,4,21,80,252,5,77,140,176,8,124,17,176,170,124,225,240,11,129,192,2,158,214,192,201,17,218,127,2,170,63,83,129,64,18,1,75,74,146,68,9,147,192,191,2,158,88,19,33,174,128,226,47,110,110,68,70,224,135,128,229,228,7,137,23,8,196,22,240,208,198,206,79,215,232,84,127,93,51,111,220,89,5,172,37,89,51,39,238,214,2,30,220,214,233,15,55,120,197,95,184,148,8,136,
192,91,1,235,200,91,34,23,16,136,41,224,225,141,153,151,110,81,41,254,186,101,220,120,171,8,88,67,170,100,210,56,90,10,120,128,91,166,61,204,160,21,127,97,82,33,16,2,167,5,172,31,167,201,220,64,32,150,128,135,56,86,62,186,68,163,248,235,146,105,227,172,42,96,237,168,154,89,227,106,37,224,65,110,149,238,237,131,85,252,109,79,129,0,8,220,22,176,110,220,38,212,0,129,24,2,30,230,24,121,168,30,133,226,175,122,134,141,175,139,128,53,163,75,166,141,179,133,128,7,186,69,154,183,13,82,241,183,141,94,199,4,134,11,88,47,134,147,106,144,192,94,1,15,245,94,255,170,189,43,254,170,102,214,184,186,10,88,43,186,102,222,184,75,11,120,176,75,167,119,249,224,20,127,203,201,117,72,96,186,128,117,98,58,177,14,8,236,17,240,112,239,113,175,214,171,226,175,90,70,141,135,192,47,1,107,132,153,64,160,176,128,7,188,112,114,23,12,77,241,183,0,89,23,4,54,9,88,31,54,193,235,150,192,50,1,79,249,50,234,66,29,169,253,10,37,211,80,8,60,18,176,52,60,82,241,26,129,106,2,158,244,106,25,157,57,30,197,223,76,93,109,
19,8,34,96,89,8,146,8,97,16,152,47,224,113,159,111,156,189,7,181,95,246,12,138,159,192,81,1,43,194,81,41,215,17,40,33,224,145,47,145,198,41,131,80,252,77,97,213,40,129,160,2,86,131,160,137,17,22,129,137,2,158,251,137,184,41,155,86,251,165,76,155,160,9,220,17,176,16,220,209,115,47,129,188,2,158,253,188,185,27,27,185,226,111,172,167,214,8,36,17,176,8,36,73,148,48,9,204,16,240,7,96,134,106,158,54,213,126,121,114,37,82,2,163,5,252,253,31,45,170,61,2,217,4,252,21,200,150,177,17,241,170,253,70,40,106,131,64,98,1,127,250,19,39,79,232,4,198,9,248,83,48,206,50,122,75,106,191,232,25,18,31,129,21,2,254,234,175,80,214,7,129,28,2,254,30,228,200,211,245,40,213,126,215,237,220,73,160,152,128,63,248,197,18,106,56,4,238,10,248,163,112,87,48,230,253,106,191,152,121,17,21,129,93,2,254,214,239,146,215,47,129,208,2,254,52,132,78,207,169,224,148,126,167,184,92,76,160,137,128,191,242,77,18,109,152,4,46,8,248,251,112,1,45,212,45,106,191,80,233,16,12,129,72,2,254,192,71,202,134,88,8,68,20,240,87,34,98,
86,222,197,164,244,123,39,228,125,2,205,5,252,105,111,62,1,12,159,192,65,1,127,43,14,66,109,191,76,233,183,61,5,2,32,144,65,192,31,245,12,89,18,35,129,40,2,254,98,68,201,196,163,56,148,126,143,84,188,70,128,192,67,1,127,206,31,178,120,145,0,129,23,2,254,110,188,192,217,242,150,210,111,11,187,78,9,100,22,240,135,60,115,246,196,78,96,167,128,191,30,59,245,127,247,173,244,251,45,225,255,9,16,56,37,224,79,248,41,46,23,19,32,240,93,192,31,145,239,34,107,126,87,249,173,113,214,11,129,170,2,254,118,87,205,172,113,17,88,42,224,79,201,58,110,165,223,58,107,61,17,168,43,224,175,118,221,220,26,25,129,245,2,254,162,204,52,87,249,205,212,213,54,129,102,2,254,92,55,75,184,225,18,88,34,224,47,203,72,102,133,223,72,77,109,17,32,240,175,128,63,211,38,2,1,2,211,4,252,129,185,71,171,242,187,231,231,110,2,4,158,11,248,251,252,220,198,59,4,8,140,18,240,151,230,140,164,186,239,140,150,107,9,16,184,36,224,207,242,37,54,55,17,32,112,73,192,95,156,87,108,10,191,87,58,222,35,64,96,168,128,63,199,67,57,
53,70,128,192,49,1,127,122,254,56,169,251,254,88,248,137,0,1,2,4,8,16,104,33,240,255,154,254,175,69,114,13,146,0,1,2,4,8,16,32,240,70,160,126,41,248,6,192,219,4,8,16,32,64,128,0,129,198,2,149,106,193,198,105,52,116,2,4,8,16,32,64,128,192,69,129,124,213,224,197,129,186,141,0,1,2,4,8,16,32,64,224,177,64,188,130,240,113,156,94,37,64,128,0,1,2,4,8,16,152,40,176,174,40,156,56,8,77,19,32,64,128,0,1,2,4,8,140,21,120,95,36,142,237,79,107,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,64,128,0,1,2,4,8,16,32,208,77,224,255,3,122,153,1,124,253,16,176,73,0,0,0,0,73,69,78,68,174,66,96,130);

implementation

end.
